@@ -218,6 +218,7 @@ CREATE TABLE history_log (
 	PRIMARY KEY (id)
 ) with OIDS;
 CREATE INDEX history_log_1 on history_log (itemid,clock);
+CREATE UNIQUE INDEX history_log_2 on history_log (itemid,id);
 CREATE TABLE history_text (
 	id		bigint		DEFAULT '0'	NOT NULL,
 	itemid		bigint		DEFAULT '0'	NOT NULL,
@@ -226,6 +227,7 @@ CREATE TABLE history_text (
 	PRIMARY KEY (id)
 ) with OIDS;
 CREATE INDEX history_text_1 on history_text (itemid,clock);
+CREATE UNIQUE INDEX history_text_2 on history_text (itemid,id);
 CREATE TABLE proxy_history (
 	id		serial			NOT NULL,
 	itemid		bigint		DEFAULT '0'	NOT NULL,
@@ -444,6 +446,7 @@ CREATE TABLE graphs_items (
 	PRIMARY KEY (gitemid)
 ) with OIDS;
 CREATE INDEX graphs_items_1 on graphs_items (itemid);
+CREATE INDEX graphs_items_2 on graphs_items (graphid);
 CREATE TABLE groups (
 	groupid		bigint		DEFAULT '0'	NOT NULL,
 	name		varchar(64)		DEFAULT ''	NOT NULL,
