@@ -216,6 +216,7 @@ CREATE TABLE IF NOT EXISTS history_log (
 	PRIMARY KEY (id)
 );
 CREATE INDEX IF NOT EXISTS history_log_1 on history_log (itemid,clock);
+CREATE UNIQUE INDEX IF NOT EXISTS history_log_2 on history_log (itemid,id);
 CREATE TABLE IF NOT EXISTS history_text (
 	id		bigint		DEFAULT '0'	NOT NULL,
 	itemid		bigint		DEFAULT '0'	NOT NULL,
@@ -224,6 +225,7 @@ CREATE TABLE IF NOT EXISTS history_text (
 	PRIMARY KEY (id)
 );
 CREATE INDEX IF NOT EXISTS history_text_1 on history_text (itemid,clock);
+CREATE UNIQUE INDEX IF NOT EXISTS history_text_2 on history_text (itemid,id);
 CREATE TABLE IF NOT EXISTS proxy_history (
 	id		integer			NOT NULL	PRIMARY KEY AUTOINCREMENT,
 	itemid		bigint		DEFAULT '0'	NOT NULL,
@@ -440,6 +442,7 @@ CREATE TABLE IF NOT EXISTS graphs_items (
 	PRIMARY KEY (gitemid)
 );
 CREATE INDEX IF NOT EXISTS graphs_items_1 on graphs_items (itemid);
+CREATE INDEX IF NOT EXISTS graphs_items_2 on graphs_items (graphid);
 CREATE TABLE IF NOT EXISTS groups (
 	groupid		bigint		DEFAULT '0'	NOT NULL,
 	name		varchar(64)		DEFAULT ''	NOT NULL,
