@@ -60,21 +60,28 @@ include_once "include/page_header.php";
 	$r_form->SetMethod('get');
 	
 	$druleid = get_request('druleid', 0);
+	$fullscreen = get_request('fullscreen', 0);
 
 	$cmbDRules = new CComboBox('druleid',$druleid,'submit()');
 	$cmbDRules->AddItem(0,S_ALL_SMALL);
-	$db_drules = DBselect('select distinct druleid,name from drules where '.DBin_node('druleid').' order by name');
+	$sql = 'SELECT DISTINCT druleid,name '.
+			' FROM drules '.
+			' WHERE '.DBin_node('druleid').
+				' AND status='.DRULE_STATUS_ACTIVE.
+			' ORDER BY name';
+	$db_drules = DBselect($sql);
 	while($drule = DBfetch($db_drules))
 		$cmbDRules->AddItem(
 				$drule['druleid'],
 				get_node_name_by_elid($drule['druleid']).$drule['name']
 				);
+	$r_form->addVar('fullscreen', $fullscreen);
 	$r_form->AddItem(array(S_DISCOVERY_RULE.SPACE,$cmbDRules));
 
 // Header	
 	$text = array(SPACE);
 	
-	$url = '?fullscreen='.($_REQUEST['fullscreen']?'0':'1');
+	$url = '?fullscreen='.($_REQUEST['fullscreen']?'0':'1').'&amp;druleid='.$druleid;
 
 	$fs_icon = new CDiv(SPACE,'fullscreen');
 	$fs_icon->AddOption('title',$_REQUEST['fullscreen']?S_NORMAL.' '.S_VIEW:S_FULLSCREEN);
@@ -86,10 +93,17 @@ include_once "include/page_header.php";
 
 	$services = array();
 
-	$db_dservices = DBselect('SELECT s.type,s.port,s.key_ FROM dservices s,dhosts h'.
+	$sql_where='';
+	if($druleid>0){
+		$sql_where = ' AND h.druleid='.$druleid;
+	}
+
+	$sql = 'SELECT s.type,s.port,s.key_ '.
+			' FROM dservices s,dhosts h '.
 			' WHERE '.DBin_node('s.dserviceid').
-			' AND s.dhostid=h.dhostid'.
-			($druleid > 0 ? ' AND h.druleid='.$druleid : ''));
+				' AND s.dhostid=h.dhostid'.
+				$sql_where;
+	$db_dservices = DBselect($sql);
 	while ($dservice = DBfetch($db_dservices)) {
 		$service_name = discovery_check_type2str($dservice['type']).
 				discovery_port2str($dservice['type'], $dservice['port']).
@@ -112,9 +126,17 @@ include_once "include/page_header.php";
 	$table  = new CTableInfo();
 	$table->SetHeader($header,'vertical_header');
 
-	$db_drules = DBselect('select distinct druleid,name from drules where '.DBin_node('druleid').
-			($druleid > 0 ? ' and druleid='.$druleid : '').
-			' order by name');
+	$sql_where='';
+	if($druleid>0){
+		$sql_where = ' AND druleid='.$druleid;
+	}
+	$sql = 'SELECT DISTINCT druleid,name '.
+			' FROM drules '.
+			' WHERE '.DBin_node('druleid').
+				$sql_where.
+				' AND status='.DRULE_STATUS_ACTIVE.
+			' ORDER BY name';
+	$db_drules = DBselect($sql);
 	while($drule = DBfetch($db_drules)) {
 		$discovery_info = array();
 
