@@ -18,8 +18,8 @@
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/
 
-	require_once "include/config.inc.php";
-	require_once "include/forms.inc.php";
+	require_once('include/config.inc.php');
+	require_once('include/forms.inc.php');
 ?>
 <?php
 	if(isset($_REQUEST['export']) && isset($_REQUEST['hosts'])){
@@ -67,7 +67,7 @@ include_once "include/page_header.php";
 	$config = get_request('config', 0);
 	$update = get_request('update', null);
 	
-	update_profile("web.exp_imp.config", $config);
+	update_profile("web.exp_imp.config", $config, PROFILE_TYPE_INT);
 ?>
 <?php
 	if($config == 1){
@@ -79,9 +79,16 @@ include_once "include/page_header.php";
 
 	}
 	else{
-		validate_group(PERM_READ_ONLY);
-	
-		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY,get_current_nodeid());
+		$params=array();
+		$options = array('only_current_node');
+		foreach($options as $option) $params[$option] = 1;
+		
+		$PAGE_GROUPS = get_viewed_groups(PERM_READ_ONLY, $params);
+		$PAGE_HOSTS = get_viewed_hosts(PERM_READ_ONLY, $PAGE_GROUPS['selected'], $params);
+
+		validate_group($PAGE_GROUPS,$PAGE_HOSTS, false);
+
+		$available_hosts = $PAGE_HOSTS['hostids'];
 
 		$hosts		= get_request('hosts', array());
 		$templates	= get_request('templates', array());
@@ -127,12 +134,12 @@ include_once "include/page_header.php";
 	}
 
 	$form = new CForm();
-	$form->SetMethod('get');
+	$form->setMethod('get');
 	
 	$cmbConfig = new CComboBox('config', $config, 'submit()');
-	$cmbConfig->AddItem(0, S_EXPORT);
-	$cmbConfig->AddItem(1, S_IMPORT);
-	$form->AddItem($cmbConfig);
+	$cmbConfig->addItem(0, S_EXPORT);
+	$cmbConfig->addItem(1, S_IMPORT);
+	$form->addItem($cmbConfig);
 
 	show_table_header($title, $form);
 	if($config == 1){
@@ -142,12 +149,10 @@ include_once "include/page_header.php";
 			DBstart();
 			
 			$importer = new CZabbixXMLImport();
-			$importer->SetRules($rules['host'],$rules['template'],$rules['item'],$rules['trigger'],$rules['graph']);
+			$importer->setRules($rules['host'],$rules['template'],$rules['item'],$rules['trigger'],$rules['graph']);
 			$result = $importer->Parse($_FILES['import_file']['tmp_name']);
-
 			unset($importer);
 			$result = DBend($result);
-			
 			show_messages($result, S_IMPORTED.SPACE.S_SUCCESSEFULLY_SMALL, S_IMPORT.SPACE.S_FAILED_SMALL);
 		}
 		
@@ -185,8 +190,8 @@ include_once "include/page_header.php";
 		echo SBR;
 		if($preview){
 			$table = new CTableInfo(S_NO_DATA_FOR_EXPORT);
-			$table->SetHeader(array(S_HOST, S_ELEMENTS));
-			$table->ShowStart();
+			$table->setHeader(array(S_HOST, S_ELEMENTS));
+			$table->showStart();
 
 			$hostids = array_keys($hosts);
 			$sql = 'SELECT * '.
@@ -235,56 +240,43 @@ include_once "include/page_header.php";
 			}
 			
 			$form = new CForm(null,'post');
-			$form->SetName('hosts');
-			$form->AddVar("config",		$config);
-			$form->AddVar('update',		true);
-			$form->AddVar('hosts',		$hosts);
-			$form->AddVar('templates',	$templates);
-			$form->AddVar('items', 		$items);
-			$form->AddVar('graphs', 	$graphs);
-			$form->AddVar('triggers',	$triggers);
+			$form->setName('hosts');
+			$form->addVar("config",		$config);
+			$form->addVar('update',		true);
+			$form->addVar('hosts',		$hosts);
+			$form->addVar('templates',	$templates);
+			$form->addVar('items', 		$items);
+			$form->addVar('graphs', 	$graphs);
+			$form->addVar('triggers',	$triggers);
 
-			$form->AddItem(array(
+			$form->addItem(array(
 				new CButton('back', S_BACK),
 				new CButton('preview', S_REFRESH),
 				new CButton('export', S_EXPORT)
 				));
 			
-			$table->SetFooter(new CCol($form));
+			$table->setFooter(new CCol($form));
 			
-			$table->ShowEnd();
+			$table->showEnd();
 		}
 		else{
 	/* table HOSTS */
 			$form = new CForm(null,'post');
 			$form->SetName('hosts');
-			$form->AddVar("config",$config);
+			$form->AddVar('config',$config);
 			$form->AddVar('update', true);
 			
-			$cmbGroups = new CComboBox("groupid",get_request("groupid",0),"submit()");
-			$cmbGroups->AddItem(0,S_ALL_SMALL);
-			$result=DBselect('SELECT DISTINCT g.groupid,g.name '.
-					' FROM groups g,hosts_groups hg,hosts h '.
-					' WHERE '.DBcondition('h.hostid',$available_hosts).
-						' AND g.groupid=hg.groupid '.
-						' AND h.hostid=hg.hostid '.
-					' ORDER BY g.name');
-			while($row=DBfetch($result)){
-				$cmbGroups->AddItem($row["groupid"],$row["name"]);
-				if((bccomp($row["groupid"] , $_REQUEST["groupid"])==0)) $correct_host = 1;
-			}
-			
-			if(!isset($correct_host)){
-				unset($_REQUEST["groupid"]);
-				$cmbGroups->SetValue(0);
+			$cmbGroups = new CComboBox('groupid',$PAGE_GROUPS['selected'],'javascript: submit();');		
+			foreach($PAGE_GROUPS['groups'] as $groupid => $name){
+				$cmbGroups->addItem($groupid, get_node_name_by_elid($groupid).$name);
 			}
 			
 			$header = get_table_header(S_HOSTS_BIG, array(S_GROUP.SPACE, $cmbGroups));
 
-			$form->AddItem($header);
+			$form->addItem($header);
 
 			$table = new CTableInfo(S_NO_HOSTS_DEFINED);
-			$table->SetHeader(array(
+			$table->setHeader(array(
 				array(	new CCheckBox("all_hosts",true, "CheckAll('".$form->GetName()."','all_hosts','hosts');"),
 					make_sorting_link(S_NAME,'h.host')),
 				make_sorting_link(S_DNS,'h.dns'),
@@ -308,12 +300,14 @@ include_once "include/page_header.php";
 		
 			$sql_from = '';
 			$sql_where = '';
-			if(isset($_REQUEST["groupid"])){
+			if($_REQUEST['groupid']>0){
 				$sql_from.= ' ,hosts_groups hg ';
 				$sql_where.= ' AND hg.groupid='.$_REQUEST['groupid'].
 							' AND hg.hostid=h.hostid ';
 			} 
 			
+			$hosts = array();
+			$hostids = array();
 			$sql = 'SELECT DISTINCT h.* '.
 					' FROM hosts h '.$sql_from.
 					' WHERE '.DBcondition('h.hostid',$available_hosts).
@@ -322,94 +316,123 @@ include_once "include/page_header.php";
 					order_by('h.host,h.dns,h.ip,h.port,h.status');
 
 			$result=DBselect($sql);
-		
-			while($row=DBfetch($result)){
+			while($host=DBfetch($result)){
+				$hosts[$host['hostid']] = $host;
+				$hostids[$host['hostid']] = $host['hostid'];
+			}
+// templates
+			$sql = 'SELECT hostid,count(hosttemplateid) as cnt '.
+					' FROM hosts_templates '.
+					' WHERE '.DBcondition('hostid',$hostids).
+					' GROUP BY hostid';
+			$result = DBselect($sql);
+			while($templates=DBfetch($result)){
+				$hosts[$templates['hostid']]['templates_cnt'] = $templates['cnt'];
+			}
+// items
+			$sql = 'SELECT hostid,count(itemid) as cnt '.
+					' FROM items '.
+					' WHERE '.DBcondition('hostid',$hostids).
+					' GROUP BY hostid';
+			$result = DBselect($sql);
+			while($items=DBfetch($result)){
+				$hosts[$items['hostid']]['items_cnt'] = $items['cnt'];
+			}
+// triggers
+			$sql = 'SELECT count(DISTINCT f.triggerid) as cnt, i.hostid '.
+					' FROM functions f, items i '.
+					' WHERE f.itemid=i.itemid '.
+						' AND '.DBcondition('i.hostid',$hostids).
+					' GROUP BY i.hostid';
+			$result = DBselect($sql);
+			while($triggers=DBfetch($result)){
+				$hosts[$triggers['hostid']]['triggers_cnt'] = $triggers['cnt'];
+			}
+// graphs
+			$sql = 'SELECT count(DISTINCT gi.graphid) as cnt, i.hostid '.
+					' FROM graphs_items gi, items i '.
+					' WHERE gi.itemid=i.itemid '.
+						' AND '.DBcondition('i.hostid',$hostids).
+					' GROUP BY i.hostid';
+			$result = DBselect($sql);
+			while($graphs=DBfetch($result)){
+				$hosts[$graphs['hostid']]['graphs_cnt'] = $graphs['cnt'];
+			}
 			
-				$host=new CCol(array(
-					new CCheckBox('hosts['.$row['hostid'].']',
-						isset($hosts[$row['hostid']]) || !isset($update),
+			foreach($hosts as $hostid => $host){
+				$host_name=new CCol(array(
+					new CCheckBox('hosts['.$host['hostid'].']',
+						isset($hosts[$host['hostid']]) || !isset($update),
 						NULL,true),
 					SPACE,
-					$row["host"]
+					$host['host']
 					));
 				
-				$status = new CCol(host_status2str($row['status']),host_status2style($row['status']));
-				
+				$status = new CCol(host_status2str($host['status']),host_status2style($host['status']));
 				
 				/* calculate template */
-				$template_cnt = DBfetch(DBselect('select count(hosttemplateid) as cnt from hosts_templates where hostid='.$row['hostid']));
-				if($template_cnt['cnt'] > 0){
-					$template_cnt = array(new CCheckBox('templates['.$row['hostid'].']',
-							isset($templates[$row['hostid']]) || !isset($update),
+				if(isset($host['templates_cnt']) && ($host['templates_cnt'] > 0)){
+					$template_cnt = array(new CCheckBox('templates['.$host['hostid'].']',
+							isset($templates[$host['hostid']]) || !isset($update),
 							NULL,true),
-						$template_cnt['cnt']);
+						$host['templates_cnt']);
 				}
 				else{
 					$template_cnt = '-';
 				}
 								
 				/* calculate items */
-				$item_cnt = DBfetch(DBselect('select count(itemid) as cnt from items where hostid='.$row['hostid']));
-				if($item_cnt['cnt'] > 0){
-					$item_cnt = array(new CCheckBox('items['.$row['hostid'].']',
-							isset($items[$row['hostid']]) || !isset($update),
+			
+				if(isset($host['items_cnt']) && ($host['items_cnt'] > 0)){
+					$item_cnt = array(new CCheckBox('items['.$host['hostid'].']',
+							isset($items[$host['hostid']]) || !isset($update),
 							NULL,true),
-						$item_cnt['cnt']);
+						$host['items_cnt']);
 				}
 				else{
 					$item_cnt = '-';
 				}
 				
 				/* calculate triggers */
-				$trigger_cnt = 0;
-				$db_triggers = DBselect('select f.triggerid, i.hostid, count(distinct i.hostid) as cnt from functions f, items i '.
-					' where f.itemid=i.itemid group by f.triggerid, i.hostid');
-				while($db_tr = DBfetch($db_triggers)) if($db_tr['cnt'] == 1 && (bccomp($db_tr['hostid'] , $row['hostid'])==0)) $trigger_cnt++;
-				if($trigger_cnt > 0){
-					$trigger_cnt = array(new CCheckBox('triggers['.$row['hostid'].']',
-							isset($triggers[$row['hostid']]) || !isset($update),
+				if(isset($host['triggers_cnt']) && ($host['triggers_cnt'] > 0)){
+					$trigger_cnt = array(new CCheckBox('triggers['.$host['hostid'].']',
+							isset($triggers[$host['hostid']]) || !isset($update),
 							NULL,true),
-						$trigger_cnt);
+						$host['triggers_cnt']);
 				}
 				else{
 					$trigger_cnt = '-';
 				}
 			
 				/* calculate graphs */
-				$graph_cnt = 0;
-				$db_graphs = DBselect('SELECT gi.graphid, i.hostid, count(distinct i.hostid) as cnt'.
-					' FROM graphs_items gi, items i '.
-					' WHERE gi.itemid=i.itemid group by gi.graphid, i.hostid');
-				while($db_tr = DBfetch($db_graphs)) if($db_tr['cnt'] == 1 && (bccomp($db_tr['hostid'] , $row['hostid'])==0)) $graph_cnt++;
-				if($graph_cnt > 0){
-					$graph_cnt = array(new CCheckBox('graphs['.$row['hostid'].']',
-							isset($graphs[$row['hostid']]) || !isset($update),
+				if(isset($host['graphs_cnt']) && ($host['graphs_cnt'] > 0)){
+					$graph_cnt = array(new CCheckBox('graphs['.$host['hostid'].']',
+							isset($graphs[$host['hostid']]) || !isset($update),
 							NULL,true),
-						$graph_cnt);
+						$host['graphs_cnt']);
 				}
 				else{
 					$graph_cnt = '-';
 				}
 				
 				/* $screens = 0; */
-
-				if($row["status"] == HOST_STATUS_TEMPLATE){
+				if($host["status"] == HOST_STATUS_TEMPLATE){
 					$ip = $dns = $port = '-';
 				}
 				else{
-					$ip = (empty($row["ip"]))?'-':$row["ip"];
-					$dns = (empty($row["dns"]))?'-':$row["dns"];
+					$ip = (empty($host["ip"]))?'-':$host["ip"];
+					$dns = (empty($host["dns"]))?'-':$host["dns"];
 
-					if($row["useip"]==1)
+					if($host["useip"]==1)
 						$ip = bold($ip);
 					else
 						$dns = bold($dns);
 
-					$port = (empty($row["port"]))?'-':$row["port"];
+					$port = (empty($host["port"]))?'-':$host["port"];
 				}
 
 				$table->AddRow(array(
-					$host,
+					$host_name,
 					$dns,
 					$ip,
 					$port,
