@@ -32,19 +32,19 @@ include_once('include/page_header.php');
 
 	$_REQUEST['config'] = get_request('config',get_profile('web.hosts.config',0));
 	
+	$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE);
 	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE);
-	if(isset($_REQUEST['hostid']) && $_REQUEST['hostid'] > 0 && !uint_in_array($_REQUEST['hostid'], $available_hosts)) {
+	
+	if(isset($_REQUEST['groupid']) && ($_REQUEST['groupid']>0) && !isset($available_groups[$_REQUEST['groupid']])){
 		access_deny();
 	}
-	if(isset($_REQUEST['apphostid']) && $_REQUEST['apphostid'] > 0 && !uint_in_array($_REQUEST['apphostid'], $available_hosts)) {
+	if(isset($_REQUEST['hostid']) && ($_REQUEST['hostid']>0) && !isset($available_hosts[$_REQUEST['hostid']])) {
+		access_deny();
+	}
+	if(isset($_REQUEST['apphostid']) && ($_REQUEST['apphostid']>0) && !isset($available_hosts[$_REQUEST['apphostid']])) {
 		access_deny();
 	}
 
-	if(isset($_REQUEST['groupid']) && $_REQUEST['groupid'] > 0){
-		if(!uint_in_array($_REQUEST['groupid'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY))){
-			access_deny();
-		}
-	}
 ?>
 <?php
 //		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
@@ -135,13 +135,6 @@ include_once('include/page_header.php');
 
 	check_fields($fields);
 	validate_sort_and_sortorder('h.host',ZBX_SORT_UP);
-	
-	if($_REQUEST['config']==4)
-		validate_group_with_host(PERM_READ_WRITE,array('always_select_first_host','only_current_node'),'web.last.conf.groupid', 'web.last.conf.hostid');
-	else if($_REQUEST['config']==0)
-		validate_group(PERM_READ_WRITE,array('real_hosts'),'web.last.conf.groupid');
-	else if($_REQUEST['config']==3)
-		validate_group(PERM_READ_WRITE,array('templated_hosts'),'web.last.conf.groupid');
 
 	update_profile('web.hosts.config',$_REQUEST['config'], PROFILE_TYPE_INT);
 ?>
@@ -301,16 +294,19 @@ include_once('include/page_header.php');
 			if($result && isset($visible['useprofile'])){
 				
 				$host_profile=DBfetch(DBselect('SELECT * FROM hosts_profiles WHERE hostid='.$hostid));
-				
+				$host_profile_fields = array('devicetype', 'name', 'os', 'serialno', 'tag',
+					'macaddress', 'hardware', 'software', 'contact', 'location', 'notes');
+
 				delete_host_profile($hostid);			
 				
 				if(get_request('useprofile','no') == 'yes'){				
-					foreach($host_profile as $key => $value){
-						if(isset($visible[$key])){
-							$host_profile[$key] = $_REQUEST[$key];
-						}
+					foreach($host_profile_fields as $field){
+						if(isset($visible[$field])) 
+							$host_profile[$field] = $_REQUEST[$field];
+						elseif(!isset($host_profile[$field])) 
+							$host_profile[$field] = '';								
 					}
-
+					
 					$result &= add_host_profile($hostid,
 						$host_profile['devicetype'],$host_profile['name'],$host_profile['os'],
 						$host_profile['serialno'],$host_profile['tag'],$host_profile['macaddress'],
@@ -323,23 +319,27 @@ include_once('include/page_header.php');
 			if($result && isset($visible['useprofile_ext'])){
 
 				$host_profile_ext=DBfetch(DBselect('SELECT * FROM hosts_profiles_ext WHERE hostid='.$hostid));
-
+				$host_profile_ext_fields = array('device_alias','device_type','device_chassis','device_os','device_os_short',
+					'device_hw_arch','device_serial','device_model','device_tag','device_vendor','device_contract',
+					'device_who','device_status','device_app_01','device_app_02','device_app_03','device_app_04',
+					'device_app_05','device_url_1','device_url_2','device_url_3','device_networks','device_notes',
+					'device_hardware','device_software','ip_subnet_mask','ip_router','ip_macaddress','oob_ip',
+					'oob_subnet_mask','oob_router','date_hw_buy','date_hw_install','date_hw_expiry','date_hw_decomm','site_street_1',
+					'site_street_2','site_street_3','site_city','site_state','site_country','site_zip','site_rack','site_notes',
+					'poc_1_name','poc_1_email','poc_1_phone_1','poc_1_phone_2','poc_1_cell','poc_1_screen','poc_1_notes','poc_2_name',
+					'poc_2_email','poc_2_phone_1','poc_2_phone_2','poc_2_cell','poc_2_screen','poc_2_notes');
+				
 				delete_host_profile_ext($hostid);
 //ext_host_profiles
 				$useprofile_ext = get_request('useprofile_ext',false);
 				$ext_host_profiles = get_request('ext_host_profiles',array());
-				
-				if($useprofile_ext && !empty($ext_host_profiles)){
-					$result = add_host_profile_ext($hostid, $ext_host_profiles);
-				}
-				$result = DBend($result);
-				
+							
 				if($useprofile_ext && !empty($ext_host_profiles)){
 					$ext_host_profiles = get_request('ext_host_profiles',array());
 					
-					foreach($host_profile_ext as $key => $value){
-						if(isset($visible[$key])){
-							$host_profile_ext[$key] = $ext_host_profiles[$key];
+					foreach($host_profile_ext_fields as $field){
+						if(isset($visible[$field])){
+							$host_profile_ext[$field] = $ext_host_profiles[$field];
 						}
 					}
 
@@ -434,9 +434,10 @@ include_once('include/page_header.php');
 			$audit_action 	= AUDIT_ACTION_ADD;
 		}
 
-		if(!zbx_empty($hostid) && $clone_hostid && ($_REQUEST['form'] == 'full_clone')){
+		if(!zbx_empty($hostid) && $hostid && $clone_hostid && ($_REQUEST['form'] == 'full_clone')){
 // Host applications
-			$res = get_applications_by_hostid($clone_hostid);
+			$sql = 'SELECT * FROM applications WHERE hostid='.$clone_hostid.' AND templateid=0';
+			$res = DBselect($sql);
 			while($db_app = DBfetch($res)){
 				add_application($db_app['name'], $hostid, 0);
 			}
@@ -454,7 +455,7 @@ include_once('include/page_header.php');
 			}
 						
 // Host triggers
-			$available_triggers = get_accessible_triggers(PERM_READ_ONLY, PERM_RES_IDS_ARRAY);
+			$available_triggers = get_accessible_triggers(PERM_READ_ONLY, array($clone_hostid), PERM_RES_IDS_ARRAY);
 			
 			$sql = 'SELECT DISTINCT t.triggerid, t.description '.
 					' FROM triggers t, items i, functions f'.
@@ -469,9 +470,9 @@ include_once('include/page_header.php');
 			while($db_trig = DBfetch($res)){
 				$result &= copy_trigger_to_host($db_trig['triggerid'], $hostid, true);
 			}
-		
+
 // Host graphs
-			$available_graphs = get_accessible_graphs(PERM_READ_ONLY, PERM_RES_IDS_ARRAY);
+			$available_graphs = get_accessible_graphs(PERM_READ_ONLY, array($clone_hostid), PERM_RES_IDS_ARRAY);
 			
 			$sql = 'SELECT DISTINCT g.graphid, g.name '.
 						' FROM graphs g, graphs_items gi,items i '.
@@ -489,6 +490,7 @@ include_once('include/page_header.php');
 			
 			$_REQUEST['hostid'] = $clone_hostid;
 		}
+		
 		$result	= DBend($result);
 		
 		if($result){
@@ -524,7 +526,7 @@ include_once('include/page_header.php');
 			$result = DBend($result);
 		}
 //HOSTS PROFILE EXTANDED Section		
-		
+
 		show_messages($result, $msg_ok, $msg_fail);
 		
 		if($result){
@@ -588,9 +590,8 @@ include_once('include/page_header.php');
 	}
 /* ADD / REMOVE HOSTS FROM GROUP*/
 	else if(($_REQUEST['config']==0 || $_REQUEST['config']==3) && (inarr_isset(array('add_to_group','hostid')))){
-		global $USER_DETAILS;
-
-		if(!uint_in_array($_REQUEST['add_to_group'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY))){
+//		if(!uint_in_array($_REQUEST['add_to_group'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY))){
+		if(!isset($available_groups[$_REQUEST['add_to_group']])){
 			access_deny();
 		}
 
@@ -601,9 +602,8 @@ include_once('include/page_header.php');
 		show_messages($result,S_HOST_UPDATED,S_CANNOT_UPDATE_HOST);
 	}
 	else if(($_REQUEST['config']==0 || $_REQUEST['config']==3) && (inarr_isset(array('delete_from_group','hostid')))){
-		global $USER_DETAILS;
-
-		if(!uint_in_array($_REQUEST['delete_from_group'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY))){
+//		if(!uint_in_array($_REQUEST['delete_from_group'], get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY))){
+		if(!isset($available_groups[$_REQUEST['delete_from_group']])){
 			access_deny();
 		}
 
@@ -968,29 +968,103 @@ include_once('include/page_header.php');
 			unset($_REQUEST['disable']);
 	}
 
-	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY,null,AVAILABLE_NOCACHE); /* update available_hosts after ACTIONS */
+//	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_RES_IDS_ARRAY,null,AVAILABLE_NOCACHE); /* update available_hosts after ACTIONS */
 ?>
 <?php
+	$params = array();	
+	switch($_REQUEST['config']){
+		case 0:
+			$options = array('only_current_node','allow_all','real_hosts');
+			if(isset($_REQUEST['form']) || isset($_REQUEST['massupdate'])) array_push($options,'do_not_select_if_empty');
+			
+			foreach($options as $option) $params[$option] = 1;
+			$PAGE_GROUPS = get_viewed_groups(PERM_READ_WRITE, $params);
+			$PAGE_HOSTS = get_viewed_hosts(PERM_READ_WRITE, $PAGE_GROUPS['selected'], $params);
+			
+			validate_group($PAGE_GROUPS, $PAGE_HOSTS, false);
+			break;
+		case 1:
+			$options = array('only_current_node');
+			if(isset($_REQUEST['form']) || isset($_REQUEST['massupdate'])) array_push($options,'do_not_select_if_empty');
+			
+			foreach($options as $option) $params[$option] = 1;
+			$PAGE_GROUPS = get_viewed_groups(PERM_READ_WRITE, $params);
+			$PAGE_HOSTS = get_viewed_hosts(PERM_READ_WRITE, $PAGE_GROUPS['groupids'], $params);
+
+			validate_group($PAGE_GROUPS, $PAGE_HOSTS, $PAGE_HOSTS, false);
+			break;
+		case 2:
+			$options = array('only_current_node','templated_hosts');
+			if(isset($_REQUEST['form']) || isset($_REQUEST['massupdate'])) array_push($options,'do_not_select_if_empty');
+			
+			foreach($options as $option) $params[$option] = 1;
+			$PAGE_GROUPS = get_viewed_groups(PERM_READ_WRITE, $params);
+
+//			$params = array();	
+//			$options = array('only_current_node','not_proxy_hosts');
+//			foreach($options as $option) $params[$option] = 1;
+			$PAGE_HOSTS = get_viewed_hosts(PERM_READ_WRITE, $available_groups, $params);	// more hosts
+
+			validate_group($PAGE_GROUPS, $PAGE_HOSTS, false);
+
+			break;
+		case 3:
+			$options = array('only_current_node','allow_all','templated_hosts');
+			if(isset($_REQUEST['form']) || isset($_REQUEST['massupdate'])) array_push($options,'do_not_select_if_empty');
+			
+			foreach($options as $option) $params[$option] = 1;
+			$PAGE_GROUPS = get_viewed_groups(PERM_READ_WRITE, $params);
+			$PAGE_HOSTS = get_viewed_hosts(PERM_READ_WRITE, $PAGE_GROUPS['selected'], $params);
+	
+			validate_group($PAGE_GROUPS, $PAGE_HOSTS, false);
+			break;
+		case 5:
+			$options = array('only_current_node');
+			if(isset($_REQUEST['form']) || isset($_REQUEST['massupdate'])) array_push($options,'do_not_select_if_empty');
+			
+			foreach($options as $option) $params[$option] = 1;
+			$PAGE_GROUPS = get_viewed_groups(PERM_READ_WRITE, $params);
+			$PAGE_HOSTS = get_viewed_hosts(PERM_READ_WRITE, $PAGE_GROUPS['selected'], $params);
+	
+			validate_group($PAGE_GROUPS, $PAGE_HOSTS, false);
+			break;
+		default:
+			$options = array('only_current_node');
+			if(isset($_REQUEST['form']) || isset($_REQUEST['massupdate'])) array_push($options,'do_not_select_if_empty');
+			
+			foreach($options as $option) $params[$option] = 1;
+			$PAGE_GROUPS = get_viewed_groups(PERM_READ_WRITE, $params);
+			$PAGE_HOSTS = get_viewed_hosts(PERM_READ_WRITE, $PAGE_GROUPS['selected'], $params);
+			
+			validate_group_with_host($PAGE_GROUPS,$PAGE_HOSTS);
+	}
+
+//	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,null,null,AVAILABLE_NOCACHE); /* update available_hosts after ACTIONS */
+	$available_groups = $PAGE_GROUPS['groupids'];
+	$available_hosts = $PAGE_HOSTS['hostids'];
+?>
+<?php
+
 	$frmForm = new CForm();
-	$frmForm->SetMethod('get');
+	$frmForm->setMethod('get');
 	
 	$cmbConf = new CComboBox('config',$_REQUEST['config'],'submit()');
-	$cmbConf->AddItem(0,S_HOSTS);
-	$cmbConf->AddItem(3,S_TEMPLATES);
-	$cmbConf->AddItem(5,S_PROXIES);
-	$cmbConf->AddItem(1,S_HOST_GROUPS);
-	$cmbConf->AddItem(2,S_TEMPLATE_LINKAGE);
-	$cmbConf->AddItem(4,S_APPLICATIONS);
-//	$cmbConf->AddItem(6,S_MASS_UPDATE);
+	$cmbConf->addItem(0,S_HOSTS);
+	$cmbConf->addItem(3,S_TEMPLATES);
+	$cmbConf->addItem(5,S_PROXIES);
+	$cmbConf->addItem(1,S_HOST_GROUPS);
+	$cmbConf->addItem(2,S_TEMPLATE_LINKAGE);
+	$cmbConf->addItem(4,S_APPLICATIONS);
+//	$cmbConf->addItem(6,S_MASS_UPDATE);
 
 	switch($_REQUEST['config']){
 		case 0:
 			$btn = new CButton('form',S_CREATE_HOST);
-			$frmForm->AddVar('groupid',get_request('groupid',0));
+			$frmForm->addVar('groupid',get_request('groupid',0));
 			break;
 		case 3:
 			$btn = new CButton('form',S_CREATE_TEMPLATE);
-			$frmForm->AddVar('groupid',get_request('groupid',0));
+			$frmForm->addVar('groupid',get_request('groupid',0));
 			break;
 		case 5:
 			$btn = new CButton('form',S_CREATE_PROXY);
@@ -1000,23 +1074,24 @@ include_once('include/page_header.php');
 			break;
 		case 4: 
 			$btn = new CButton('form',S_CREATE_APPLICATION);
-			$frmForm->AddVar('hostid',get_request('hostid',0));
+			$frmForm->addVar('hostid',get_request('hostid',0));
 			break;
 		case 2: 
 			break;
 	}
 
-	$frmForm->AddItem($cmbConf);
+	$frmForm->addItem($cmbConf);
 	if(isset($btn) && !isset($_REQUEST['form'])){
-		$frmForm->AddItem(SPACE);
-		$frmForm->AddItem($btn);
+		$frmForm->addItem(SPACE);
+		$frmForm->addItem($btn);
 	}
 	show_table_header(S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES, $frmForm);
 	echo SBR;
 ?>
 <?php
+	$row_count = 0;
+	
 	if($_REQUEST['config']==0 || $_REQUEST['config']==3){
-
 		$show_only_tmp=($_REQUEST['config'] == 3)?1:0;
 
 		if(isset($_REQUEST['massupdate']) && isset($_REQUEST['hosts'])){
@@ -1025,46 +1100,31 @@ include_once('include/page_header.php');
 		else if(isset($_REQUEST['form'])){
 			insert_host_form($show_only_tmp);
 		}
-		else {
-			if($show_only_tmp==1)
-				$status_filter = ' AND h.status IN ('.HOST_STATUS_TEMPLATE.') ';
-			else
-				$status_filter = ' AND h.status IN ('.HOST_STATUS_MONITORED.','.HOST_STATUS_NOT_MONITORED.') ';
-
-			$cmbGroups = new CComboBox('groupid',get_request('groupid',0),'submit()');
-			$cmbGroups->AddItem(0,S_ALL_SMALL);
-
-			$sql = 'SELECT DISTINCT g.groupid,g.name '.
-					' FROM groups g,hosts_groups hg,hosts h '.
-					' WHERE '.DBcondition('h.hostid',$available_hosts).
-						' AND g.groupid=hg.groupid '.
-						' AND h.hostid=hg.hostid'.
-						$status_filter.
-					' ORDER BY g.name';
-
-			$result=DBselect($sql);
-			while($row=DBfetch($result)){
-				$cmbGroups->addItem($row['groupid'],$row['name']);
-				if(bccomp($row['groupid'], $_REQUEST['groupid']) == 0) $correct_host = 1;
-			}
-			
-			if(!isset($correct_host)){
-				$_REQUEST['groupid'] = 0;
-				$cmbGroups->setValue($_REQUEST['groupid']);
-			}
-
+		else{
+		
 			$frmForm = new CForm();
 			$frmForm->setMethod('get');
 
 			$frmForm->addVar('config',$_REQUEST['config']);
-			$frmForm->addItem(S_GROUP.SPACE);
-			$frmForm->addItem($cmbGroups);
-			show_table_header($show_only_tmp ? S_TEMPLATES_BIG : S_HOSTS_BIG, $frmForm);
 
-	/* table HOSTS */
+			$cmbGroups = new CComboBox('groupid',$PAGE_GROUPS['selected'],'javascript: submit();');
+			foreach($PAGE_GROUPS['groups'] as $groupid => $name){
+				$cmbGroups->addItem($groupid, get_node_name_by_elid($groupid).$name);
+			}
 			
-			if(isset($_REQUEST['groupid']) && $_REQUEST['groupid']==0) unset($_REQUEST['groupid']);
+			$frmForm->addItem(array(S_GROUP.SPACE,$cmbGroups));
+			
+			$numrows = new CSpan(null,'info');
+			$numrows->addOption('name','numrows');
+			$header_name = ($show_only_tmp) ? S_TEMPLATES_BIG : S_HOSTS_BIG;
+	
+			$header = get_table_header(array($header_name,
+							new CSpan(SPACE.SPACE.'|'.SPACE.SPACE, 'divider'),
+							S_FOUND.': ',$numrows,)
+							);							
+			show_table_header($header, $frmForm);
 
+/* table HOSTS */			
 			$form = new CForm();
 			
 			$form->setName('hosts');
@@ -1084,37 +1144,35 @@ include_once('include/page_header.php');
 				S_ACTIONS
 				));
 		
-			$sql='SELECT DISTINCT h.* FROM ';
-				
-			if(isset($_REQUEST["groupid"])){
-				$sql.= ' hosts h,hosts_groups hg ';
-				$sql.= ' WHERE hg.groupid='.$_REQUEST['groupid'].
-							' AND hg.hostid=h.hostid '.
-							' AND';
-			} 
-			else{  
-				$sql.= ' hosts h WHERE ';
-			}
-			
-			$sql.= DBcondition('h.hostid',$available_hosts).
-				$status_filter.
-				order_by('h.host,h.port,h.ip,h.status,h.available,h.dns');
 
+				
+			$sql_from = '';
+			$sql_where = '';
+			if($_REQUEST['groupid'] > 0){
+				$sql_from.= ',hosts_groups hg ';
+				$sql_where.= ' AND hg.groupid='.$_REQUEST['groupid'].' AND hg.hostid=h.hostid ';
+			} 
+			
+			$sql='SELECT DISTINCT h.* '.
+				' FROM hosts h '.$sql_from.
+				' WHERE '.DBcondition('h.hostid',$available_hosts).
+					$sql_where.
+				order_by('h.host,h.port,h.ip,h.status,h.available,h.dns');
 			$result=DBselect($sql);
 			while($row=DBfetch($result)){
 				$description = array();
 
-				if($row["proxy_hostid"]){
-					$proxy = get_host_by_hostid($row["proxy_hostid"]);
-					array_push($description,$proxy["host"],":");
+				if($row['proxy_hostid']){
+					$proxy = get_host_by_hostid($row['proxy_hostid']);
+					array_push($description,$proxy['host'],':');
 				}
 			
-				array_push($description, new CLink($row["host"], "hosts.php?form=update&hostid=".$row["hostid"].url_param("groupid").url_param("config"), 'action'));
+				array_push($description, new CLink($row['host'], 'hosts.php?form=update&hostid='.$row['hostid'].url_param('groupid').url_param('config'), 'action'));
 
 				$templates = get_templates_by_hostid($row['hostid']);
 				
 				$host=new CCol(array(
-					new CCheckBox('hosts['.$row["hostid"].']',NULL,NULL,$row["hostid"]),
+					new CCheckBox('hosts['.$row['hostid'].']',NULL,NULL,$row['hostid']),
 					SPACE,
 					$description));
 		
@@ -1130,7 +1188,7 @@ include_once('include/page_header.php');
 				else{
 					$dns = empty($row['dns'])?'-':$row['dns'];
 					$ip = empty($row['ip'])?'-':$row['ip'];
-					$port = empty($row['port'])?'-':$row["port"];
+					$port = empty($row['port'])?'-':$row['port'];
 
 					if(1 == $row['useip']){
 						$ip = bold($ip);
@@ -1168,11 +1226,11 @@ include_once('include/page_header.php');
 					if($row['error'] == '')	$error = new CCol(SPACE,'off');
 					else			$error = new CCol($row['error'],'on');
 
-					$row["error"] = trim($row["error"]);
-					if(empty($row["error"]))
-						$error = new CCol('-',"off");
+					$row['error'] = trim($row['error']);
+					if(empty($row['error']))
+						$error = new CCol('-','off');
 					else 
-						$error = new CCol($row["error"],"on");
+						$error = new CCol($row['error'],'on');
 				}
 
 
@@ -1193,6 +1251,8 @@ include_once('include/page_header.php');
 					$available,
 					$error,
 					$show));
+					
+				$row_count++;
 
 				$jsmenu = new CPUMenu(null,270);
 				$jsmenu->InsertJavaScript();
@@ -1219,68 +1279,69 @@ include_once('include/page_header.php');
 
 		}
 	}
-	else if($_REQUEST["config"]==1){
+	else if($_REQUEST['config']==1){
 	
-		if(isset($_REQUEST["form"])){
-			insert_hostgroups_form(get_request("groupid",NULL));
+		if(isset($_REQUEST['form'])){
+			insert_hostgroups_form($_REQUEST['groupid']);
 		} 
 		else {
-			show_table_header(S_HOST_GROUPS_BIG);
+		
+			$numrows = new CSpan(null,'info');
+			$numrows->addOption('name','numrows');	
+			$header = get_table_header(array(S_HOST_GROUPS_BIG,
+							new CSpan(SPACE.SPACE.'|'.SPACE.SPACE, 'divider'),
+							S_FOUND.': ',$numrows,)
+							);						
+			show_table_header($header );
 
 			$form = new CForm('hosts.php');
 			
-			$form->SetName('groups');
-			$form->AddVar("config",get_request("config",0));
+			$form->setName('groups');
+			$form->addVar('config',get_request('config',0));
 
 			$table = new CTableInfo(S_NO_HOST_GROUPS_DEFINED);
 
 			$table->setHeader(array(
-				array(	new CCheckBox("all_groups",NULL,
-						"CheckAll('".$form->GetName()."','all_groups');"),
-					SPACE,
-					make_sorting_link(S_NAME,'g.name')),
-				' # ',
-				S_MEMBERS));
+				array(new CCheckBox('all_groups',NULL,"CheckAll('".$form->GetName()."','all_groups');"),SPACE,make_sorting_link(S_NAME,'g.name')),
+					' # ',
+					S_MEMBERS));
 
-			$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_WRITE);
-
-			$db_groups=DBselect('SELECT g.groupid,g.name '.
-							' FROM groups g'.
-							' WHERE '.DBcondition('g.groupid',$available_groups).
-							order_by('g.name'));
+			$sql = 'SELECT g.groupid,g.name '.
+					' FROM groups g'.
+					' WHERE '.DBcondition('g.groupid',$available_groups).
+					order_by('g.name');
+			$db_groups=DBselect($sql);
 			while($db_group=DBfetch($db_groups)){
-				$db_hosts = DBselect('SELECT DISTINCT h.host, h.status'.
+				$count = 0;
+				$hosts = array();
+
+				$sql = 'SELECT DISTINCT h.host, h.status'.
 						' FROM hosts h, hosts_groups hg'.
 						' WHERE h.hostid=hg.hostid '.
 							' AND hg.groupid='.$db_group['groupid'].
 							' AND '.DBcondition('h.hostid',$available_hosts).
-							' AND h.status in ('.HOST_STATUS_MONITORED.','.HOST_STATUS_NOT_MONITORED.','.HOST_STATUS_TEMPLATE.') '.
-						' order by host'
-						);
-
-				$hosts = array();
-				$count = 0;
+						' ORDER BY host';
+				$db_hosts = DBselect($sql);
 				while($db_host=DBfetch($db_hosts)){
-					$style = $db_host["status"]==HOST_STATUS_MONITORED ? NULL: ( 
-						$db_host["status"]==HOST_STATUS_TEMPLATE ? "unknown" :
-						"on");
+					$style = ($db_host['status']==HOST_STATUS_MONITORED)?NULL:(($db_host['status']==HOST_STATUS_TEMPLATE)?'unknown':'on');
 
-					array_push($hosts, empty($hosts) ? '' : ', ', new CSpan($db_host["host"], $style));
+					array_push($hosts, empty($hosts)?'':', ', new CSpan($db_host['host'], $style));
 					$count++;
 				}
 
-				$table->AddRow(array(
+				$table->addRow(array(
 					array(
-						new CCheckBox('groups['.$db_group["groupid"].']',NULL,NULL,$db_group["groupid"]),
+						new CCheckBox('groups['.$db_group['groupid'].']',NULL,NULL,$db_group['groupid']),
 						SPACE,
 						new CLink(
-							$db_group["name"],
-							"hosts.php?form=update&groupid=".$db_group["groupid"].
-							url_param("config"),'action')
+							$db_group['name'],
+							'hosts.php?form=update&groupid='.$db_group['groupid'].
+							url_param('config'),'action')
 					),
 					$count,
 					new CCol((empty($hosts)?'-':$hosts),'wraptext')
 					));
+					$row_count++;
 			}
 			$table->SetFooter(new CCol(array(
 				new CButtonQMessage('activate',S_ACTIVATE_SELECTED,S_ACTIVATE_SELECTED_HOSTS_Q),
@@ -1297,103 +1358,130 @@ include_once('include/page_header.php');
 // Original mod by scricca@vipsnet.net
 // Modified by Aly
 /* this code adds links to Template Names in Template_Linkage page and link them to the form in forms.inc.php */
-	else if($_REQUEST["config"]==2){
+	else if($_REQUEST['config']==2){
 	
-		if(isset($_REQUEST["form"])){
-			insert_template_form(get_request("hostid",NULL));
+		if(isset($_REQUEST['form'])){
+			insert_template_form($PAGE_HOSTS['hostids']);
 		} 
 		else{
-	
-			show_table_header(S_TEMPLATE_LINKAGE_BIG);
-		
-			$table = new CTableInfo(S_NO_LINKAGES);
-			$table->SetHeader(array(S_TEMPLATES,S_HOSTS));
-		
-			$templates = DBSelect('SELECT h.* FROM hosts h'.
-					' WHERE h.status='.HOST_STATUS_TEMPLATE.
-						' AND '.DBcondition('h.hostid',$available_hosts).
-					' ORDER BY h.host');
-			while($template = DBfetch($templates)){
-			
-				$hosts = DBSelect('SELECT h.* '.
-					' FROM hosts h, hosts_templates ht '.
-					' WHERE ht.templateid='.$template['hostid'].
-						' AND ht.hostid=h.hostid '.
-						' AND h.status IN ('.HOST_STATUS_MONITORED.','.HOST_STATUS_NOT_MONITORED.') '.
-						' AND '.DBcondition('h.hostid',$available_hosts).
-					' ORDER BY host');
-				$host_list = array();
-				while($host = DBfetch($hosts)){
-					$style = ($host["status"] == HOST_STATUS_MONITORED)?NULL:'on';
-					array_push($host_list, empty($host_list)?'':', ', new CSpan($host["host"], $style));
-				}
-				$table->AddRow(array(		
-					new CCol(array(
-						new CLink($template['host'],'hosts.php?form=update&hostid='.
-							$template['hostid'].url_param('hostid').url_param('config'), 'action')
-						),'unknown'),
-					empty($host_list)?'-':new CCol($host_list,'wraptext')
-				));
+			$frmForm = new CForm();
+			$frmForm->setMethod('get');
+
+			$frmForm->addVar('config',$_REQUEST['config']);
+
+			$cmbGroups = new CComboBox('groupid',$PAGE_GROUPS['selected'],'javascript: submit();');
+			foreach($PAGE_GROUPS['groups'] as $groupid => $name){
+				$cmbGroups->addItem($groupid, get_node_name_by_elid($groupid).$name);
 			}
 			
-			$table->Show();
-		}
+			$frmForm->addItem(array(S_GROUP.SPACE,$cmbGroups));
+			
+			$numrows = new CSpan(null,'info');
+			$numrows->addOption('name','numrows');
+			$header = get_table_header(array(S_TEMPLATE_LINKAGE_BIG,
+							new CSpan(SPACE.SPACE.'|'.SPACE.SPACE, 'divider'),
+							S_FOUND.': ',$numrows,)
+							);							
+			show_table_header($header, $frmForm);
+		
+			$table = new CTableInfo(S_NO_LINKAGES);
+			$table->setHeader(array(S_TEMPLATES,S_HOSTS));
+					
+			$sql_from = '';
+			$sql_where = '';
+			if($_REQUEST['groupid'] > 0){
+				$sql_from.= ',hosts_groups hg ';
+				$sql_where.= ' AND hg.groupid='.$_REQUEST['groupid'].' AND hg.hostid=h.hostid ';
+			} 
+
+			$templates = array();
+			$templateids = array();
+			$sql = 'SELECT h.hostid, h.host '.
+					' FROM hosts h '.$sql_from.
+					' WHERE '.DBcondition('h.hostid',$available_hosts).
+						$sql_where.
+					' ORDER BY h.host';
+			$result = DBSelect($sql);
+			while($template = DBfetch($result)) {
+				$templateids[$template['hostid']] = $template['hostid'];
+				$templates[$template['hostid']] = $template; 
+			}
+			
+			$allowed_hosts = get_accessible_hosts_by_user($USER_DETAILS, PERM_READ_ONLY);
+			
+			$sql = 'SELECT h.host, h.hostid, h.status, ht.templateid '.
+					' FROM hosts h, hosts_templates ht '.
+					' WHERE ht.hostid=h.hostid '.
+						' AND '.DBcondition('h.hostid', $allowed_hosts).
+						' AND '.DBcondition('ht.templateid', $templateids).
+					' ORDER BY host';
+			$result = DBSelect($sql);
+			while($host = DBfetch($result)){
+				if(!isset($templates[$host['templateid']]['hosts'])) $templates[$host['templateid']]['hosts'] = array(); 
+				$templates[$host['templateid']]['hosts'][] = $host;
+			}
+			
+			foreach($templates as $templateid => $template) {
+				$host_list = array();
+				
+				if(isset($template['hosts'])) {
+					foreach($template['hosts'] as $host) {
+						switch($host['status']) {
+							case HOST_STATUS_NOT_MONITORED:
+								$style = 'on';
+								break;
+							case HOST_STATUS_TEMPLATE:
+								$style = 'unknown';
+								break;
+							default:
+								$style = null;
+						}										
+						array_push($host_list, empty($host_list)?'':', ', new CSpan($host['host'], $style));
+					}
+				}
+				
+				$table->addRow(array(		
+					new CCol(array(
+						new CLink($template['host'],'hosts.php?form=update&hostid='.
+							$template['hostid'].url_param('groupid').url_param('config'), 'action')
+						), 'unknown'),
+					empty($host_list)?'-':new CCol($host_list,'wraptext')
+				));
+			}	
+			$table->show();
+			$row_count = $table->getNumRows();
+		}		
 //----- END MODE -----
 	}
-	else if($_REQUEST["config"]==4){
-		if(isset($_REQUEST["form"])){
+	else if($_REQUEST['config']==4){
+		if(isset($_REQUEST['form'])){
 			insert_application_form();
 		} 
 		else {
 	// Table HEADER
 			$form = new CForm();
-			$form->SetMethod('get');
+			$form->setMethod('get');
 			
-			$cmbGroup = new CComboBox("groupid",$_REQUEST["groupid"],"submit();");
-			$cmbGroup->AddItem(0,S_ALL_SMALL);
-
-			$result=DBselect('SELECT DISTINCT g.groupid,g.name '.
-						' FROM groups g,hosts_groups hg '.
-						' WHERE g.groupid=hg.groupid '.
-							' AND '.DBcondition('hg.hostid',$available_hosts).
-							' ORDER BY name');
-							
-			while($row=DBfetch($result)){
-				$cmbGroup->AddItem($row["groupid"],$row["name"]);
+			$cmbGroups = new CComboBox('groupid',$PAGE_GROUPS['selected'],'javascript: submit();');
+			$cmbHosts = new CComboBox('hostid',$PAGE_HOSTS['selected'],'javascript: submit();');
+		
+			foreach($PAGE_GROUPS['groups'] as $groupid => $name){
+				$cmbGroups->addItem($groupid, get_node_name_by_elid($groupid).$name);
+			}
+			foreach($PAGE_HOSTS['hosts'] as $hostid => $name){
+				$cmbHosts->addItem($hostid, get_node_name_by_elid($hostid).$name);
 			}
 			
-			$form->AddItem(S_GROUP.SPACE);
-			$form->AddItem($cmbGroup);
-
-			if(isset($_REQUEST["groupid"]) && $_REQUEST["groupid"]>0){
-				$sql='SELECT DISTINCT h.hostid,h.host '.
-					' FROM hosts h,hosts_groups hg '.
-					' WHERE hg.groupid='.$_REQUEST['groupid'].
-						' AND hg.hostid=h.hostid '.
-						' AND '.DBcondition('h.hostid',$available_hosts).
-						' AND h.status IN ('.HOST_STATUS_MONITORED.','.HOST_STATUS_NOT_MONITORED.','.HOST_STATUS_TEMPLATE.')'.
-					' GROUP BY h.hostid,h.host '.
-					' ORDER BY h.host';
-			}
-			else{
-				$sql='SELECT DISTINCT h.hostid,h.host '.
-					' FROM hosts h '.
-					' WHERE '.DBcondition('h.hostid',$available_hosts).
-						' AND h.status IN ('.HOST_STATUS_MONITORED.','.HOST_STATUS_NOT_MONITORED.','.HOST_STATUS_TEMPLATE.') '.
-						' GROUP BY h.hostid,h.host '.
-						' ORDER BY h.host';
-			}
-			$cmbHosts = new CComboBox("hostid",$_REQUEST["hostid"],"submit();");
-
-			$result=DBselect($sql);
-			while($row=DBfetch($result)){
-				$cmbHosts->AddItem($row["hostid"],$row["host"]);
-			}
-
-			$form->AddItem(SPACE.S_HOST.SPACE);
-			$form->AddItem($cmbHosts);
+			$form->addItem(array(S_GROUP.SPACE,$cmbGroups));
+			$form->addItem(array(SPACE.S_HOST.SPACE,$cmbHosts));
 			
-			show_table_header(S_APPLICATIONS_BIG, $form);
+			$numrows = new CSpan(null,'info');
+			$numrows->addOption('name','numrows');
+			$header = get_table_header(array(S_APPLICATIONS_BIG,
+							new CSpan(SPACE.SPACE.'|'.SPACE.SPACE, 'divider'),
+							S_FOUND.': ',$numrows,)
+							);							
+			show_table_header($header, $form);
 
 /* TABLE */
 
@@ -1402,7 +1490,7 @@ include_once('include/page_header.php');
 
 			$table = new CTableInfo();
 			$table->SetHeader(array(
-				array(new CCheckBox("all_applications",NULL,"CheckAll('".$form->GetName()."','all_applications');"),
+				array(new CCheckBox('all_applications',NULL,"CheckAll('".$form->GetName()."','all_applications');"),
 				SPACE,
 				make_sorting_link(S_APPLICATION,'a.name')),
 				S_SHOW
@@ -1413,63 +1501,68 @@ include_once('include/page_header.php');
 									' WHERE a.hostid='.$_REQUEST['hostid'].
 									order_by('a.name'));
 									
-			while($db_app = DBfetch($db_applications))
-			{
-				if($db_app["templateid"]==0)
-				{
+			while($db_app = DBfetch($db_applications)){
+				if($db_app['templateid']==0){
 					$name = new CLink(
-						$db_app["name"],
-						"hosts.php?form=update&applicationid=".$db_app["applicationid"].
-						url_param("config"),'action');
-				} else {
-					$template_host = get_realhost_by_applicationid($db_app["templateid"]);
+						$db_app['name'],
+						'hosts.php?form=update&applicationid='.$db_app['applicationid'].
+						url_param('config'),'action');
+				}
+				else {
+					$template_host = get_realhost_by_applicationid($db_app['templateid']);
 					$name = array(		
-						new CLink($template_host["host"],
-							"hosts.php?hostid=".$template_host["hostid"].url_param("config"),
+						new CLink($template_host['host'],
+							'hosts.php?hostid='.$template_host['hostid'].url_param('config'),
 							'action'),
-						":",
-						$db_app["name"]
+						':',
+						$db_app['name']
 						);
 				}
-				$items=get_items_by_applicationid($db_app["applicationid"]);
+				$items=get_items_by_applicationid($db_app['applicationid']);
 				$rows=0;
 				while(DBfetch($items))	$rows++;
 
-
-				$table->AddRow(array(
-					array(new CCheckBox('applications['.$db_app["applicationid"].']',NULL,NULL,$db_app["applicationid"]),SPACE,$name),
-					array(new CLink(S_ITEMS,"items.php?hostid=".$db_app["hostid"],"action"),
-					SPACE."($rows)")
+				$table->addRow(array(
+					array(new CCheckBox('applications['.$db_app['applicationid'].']',NULL,NULL,$db_app['applicationid']),SPACE,$name),
+					array(new CLink(S_ITEMS,'items.php?hostid='.$db_app['hostid'],'action'),
+					SPACE.'('.$rows.')')
 					));
+				$row_count++;
 			}
-			$table->SetFooter(new CCol(array(
+			$table->setFooter(new CCol(array(
 				new CButtonQMessage('activate',S_ACTIVATE_ITEMS,S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q),
 				SPACE,
 				new CButtonQMessage('disable',S_DISABLE_ITEMS,S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q),
 				SPACE,
 				new CButtonQMessage('delete',S_DELETE_SELECTED,S_DELETE_SELECTED_APPLICATIONS_Q)
 			)));
-			$form->AddItem($table);
-			$form->Show();
+			$form->addItem($table);
+			$form->show();
 		}
 	}
-	else if($_REQUEST["config"]==5){ /* Proxies */
-		if(isset($_REQUEST["form"])){
-			insert_proxies_form(get_request("hostid",NULL));
+	else if($_REQUEST['config']==5){ /* Proxies */
+		if(isset($_REQUEST['form'])){
+			insert_proxies_form(get_request('hostid',NULL));
 		} 
-		else {
-			show_table_header(S_PROXIES_BIG);
-
-			$form = new CForm('hosts.php');
-			$form->SetMethod('get');
+		else {		
+			$numrows = new CSpan(null,'info');
+			$numrows->addOption('name','numrows');
+			$header = get_table_header(array(S_PROXIES_BIG,
+							new CSpan(SPACE.SPACE.'|'.SPACE.SPACE, 'divider'),
+							S_FOUND.': ',$numrows,)
+							);							
+			show_table_header($header);
 			
-			$form->SetName('hosts');
-			$form->AddVar("config",get_request("config",0));
+			$form = new CForm('hosts.php');
+			$form->setMethod('get');
+			
+			$form->setName('hosts');
+			$form->addVar('config',get_request('config',0));
 
 			$table = new CTableInfo(S_NO_PROXIES_DEFINED);
 
 			$table->setHeader(array(
-					array(new CCheckBox("all_hosts",NULL,"CheckAll('".$form->GetName()."','all_hosts');"),
+					array(new CCheckBox('all_hosts',NULL,"CheckAll('".$form->GetName()."','all_hosts');"),
 						SPACE,
 						make_sorting_link(S_NAME,'g.name')),
 						S_LASTSEEN_AGE,
@@ -1484,21 +1577,19 @@ include_once('include/page_header.php');
 								order_by('host'));
 					
 			while($db_proxy=DBfetch($db_proxies)){
-				$db_hosts = DBselect('SELECT DISTINCT host,status'.
+				$count = 0;
+				$hosts = array();
+				
+				$sql = 'SELECT DISTINCT host,status '.
 						' FROM hosts'.
 						' WHERE proxy_hostid='.$db_proxy['hostid'].
 							' AND '.DBcondition('hostid',$available_hosts).
 							' AND status in ('.HOST_STATUS_MONITORED.','.HOST_STATUS_NOT_MONITORED.')'.
-						' ORDER BY host'
-						);
-
-				$hosts = array();
-				$count = 0;
+						' ORDER BY host';
+				$db_hosts = DBselect($sql);
 				while($db_host=DBfetch($db_hosts)){
-					$style = $db_host["status"]==HOST_STATUS_MONITORED ? NULL: ( 
-						$db_host["status"]==HOST_STATUS_TEMPLATE ? "unknown" :
-						"on");
-					array_push($hosts, empty($hosts) ? '' : ', ', new CSpan($db_host["host"], $style));
+					$style = ($db_host['status']==HOST_STATUS_MONITORED)?NULL:(($db_host['status']==HOST_STATUS_TEMPLATE)?'unknown' :'on');
+					array_push($hosts, empty($hosts) ? '' : ', ', new CSpan($db_host['host'], $style));
 					$count++;
 				}
 
@@ -1507,20 +1598,22 @@ include_once('include/page_header.php');
 				else
 					$lastclock = '-';
 
-				$table->AddRow(array(
+				$table->addRow(array(
 					array(
-						new CCheckBox('hosts['.$db_proxy["hostid"].']', NULL, NULL, $db_proxy["hostid"]),
+						new CCheckBox('hosts['.$db_proxy['hostid'].']', NULL, NULL, $db_proxy['hostid']),
 						SPACE,
-						new CLink($db_proxy["host"],
-								"hosts.php?form=update&hostid=".$db_proxy["hostid"].url_param("config"),
+						new CLink($db_proxy['host'],
+								'hosts.php?form=update&hostid='.$db_proxy['hostid'].url_param('config'),
 								'action')
 					),
 					$lastclock,
 					$count,
-					new CCol((empty($hosts) ? '-' : $hosts), 'wraptext')
+					new CCol((empty($hosts)?'-':$hosts), 'wraptext')
 					));
+				$row_count++;
 			}
-			$table->SetFooter(new CCol(array(
+			
+			$table->setFooter(new CCol(array(
 				new CButtonQMessage('activate',S_ACTIVATE_SELECTED,S_ACTIVATE_SELECTED_HOSTS_Q),
 				SPACE,
 				new CButtonQMessage('disable',S_DISABLE_SELECTED,S_DISABLE_SELECTED_HOSTS_Q),
@@ -1528,14 +1621,16 @@ include_once('include/page_header.php');
 				new CButtonQMessage('delete',S_DELETE_SELECTED,S_DELETE_SELECTED_GROUPS_Q)
 			)));
 
-			$form->AddItem($table);
-			$form->Show();
+			$form->addItem($table);
+			$form->show();
 		}
 	}
+	
+zbx_add_post_js('insert_in_element("numrows","'.$row_count.'");');
 
 ?>
 <?php
 
-include_once "include/page_footer.php";
+include_once 'include/page_footer.php';
 
 ?>
