@@ -30,8 +30,8 @@ function action_accessible($actionid,$perm){
 	if (DBselect('select actionid from actions where actionid='.$actionid.' and '.DBin_node('actionid'))){
 		$result = true;
 		
-		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY);
-		$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_ONLY);
+		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,$perm,null,get_current_nodeid(true));
+		$available_groups = get_accessible_groups_by_user($USER_DETAILS,$perm,null,get_current_nodeid(true));
 		
 		$db_result = DBselect('SELECT * FROM conditions WHERE actionid='.$actionid);
 		while(($ac_data = DBfetch($db_result)) && $result){
@@ -39,13 +39,13 @@ function action_accessible($actionid,$perm){
 
 			switch($ac_data['conditiontype']){
 				case CONDITION_TYPE_HOST_GROUP:
-					if(!uint_in_array($ac_data['value'],$available_groups)){
+					if(!isset($available_groups[$ac_data['value']])){
 						$result = false;
 					}
 					break;
 				case CONDITION_TYPE_HOST:
 				case CONDITION_TYPE_HOST_TEMPLATE:
-					if(!uint_in_array($ac_data['value'],$available_hosts)){
+					if(!isset($available_hosts[$ac_data['value']])){
 						$result = false;
 					}
 					break;
@@ -72,22 +72,22 @@ function check_permission_for_action_conditions($conditions){
 
 	$result = true;
 
-	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY);
-	$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_ONLY);
-	
+	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,null,get_current_nodeid(true));
+	$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_ONLY,null,get_current_nodeid(true));
+
 	foreach($conditions as $ac_data){
 		if($ac_data['operator'] != 0) continue;
 
 		switch($ac_data['type']){
 			case CONDITION_TYPE_HOST_GROUP:
-				if(!uint_in_array($ac_data['value'],$available_groups)){
+				if(!isset($available_groups[$ac_data['value']])){
 					error(S_INCORRECT_GROUP);
 					$result = false;
 				}
 				break;
 			case CONDITION_TYPE_HOST:
 			case CONDITION_TYPE_HOST_TEMPLATE:
-				if(!uint_in_array($ac_data['value'],$available_hosts)){
+				if(!isset($available_hosts[$ac_data['value']])){
 					error(S_INCORRECT_HOST);
 					$result = false;
 				}
@@ -370,21 +370,24 @@ function	condition_type2str($conditiontype)
 	return S_UNKNOWN;
 }
 	
-function	condition_value2str($conditiontype, $value)
-{
-	switch($conditiontype)
-	{
+function condition_value2str($conditiontype, $value){
+	switch($conditiontype){
 		case CONDITION_TYPE_HOST_GROUP:
-			$str_val = get_hostgroup_by_groupid($value);
-			$str_val = $str_val['name'];
+			$group = get_hostgroup_by_groupid($value);
+			
+			$str_val = '';
+			if(id2nodeid($value) != get_current_nodeid()) $str_val = get_node_name_by_elid($value, true);
+			$str_val.= $group['name'];
 			break;
 		case CONDITION_TYPE_TRIGGER:
 			$str_val = expand_trigger_description($value);
 			break;
 		case CONDITION_TYPE_HOST:
 		case CONDITION_TYPE_HOST_TEMPLATE:
-			$str_val = get_host_by_hostid($value);
-			$str_val = $str_val['host'];
+			$host = get_host_by_hostid($value);			
+			$str_val = '';
+			if(id2nodeid($value) != get_current_nodeid()) $str_val = get_node_name_by_elid($value, true);
+			$str_val.= $host['host'];
 			break;
 		case CONDITION_TYPE_TRIGGER_NAME:
 			$str_val = $value;
@@ -429,8 +432,7 @@ function	condition_value2str($conditiontype, $value)
 	return '"'.$str_val.'"';
 }
 
-function	get_condition_desc($conditiontype, $operator, $value)
-{
+function get_condition_desc($conditiontype, $operator, $value){
 	return condition_type2str($conditiontype).' '.
 		condition_operator2str($operator).' '.
 		condition_value2str($conditiontype, $value);
@@ -695,25 +697,21 @@ function	update_action_status($actionid, $status)
 	return DBexecute("update actions set status=$status where actionid=$actionid");
 }
 
-function validate_condition($conditiontype, $value)
-{
+function validate_condition($conditiontype, $value){
 	global $USER_DETAILS;
 
-	switch($conditiontype)
-	{
+	switch($conditiontype){
 		case CONDITION_TYPE_HOST_GROUP:
-			if(!uint_in_array($value,
-				get_accessible_groups_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY)))
-			{
+			$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_ONLY,null,get_current_nodeid(true));
+			if(!isset($available_groups[$value])){
 				error(S_INCORRECT_GROUP);
 				return false;
 			}
 			break;
 		case CONDITION_TYPE_HOST_TEMPLATE:
-			if(!uint_in_array($value,
-				get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY)))
-			{
-				error(S_INCORRECT_GROUP);
+			$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,null,get_current_nodeid(true));
+			if(!isset($available_hosts[$value])){
+				error(S_INCORRECT_HOST);
 				return false;
 			}
 			break;
@@ -726,44 +724,38 @@ function validate_condition($conditiontype, $value)
 			}
 			break;
 		case CONDITION_TYPE_HOST:
-			if(!uint_in_array($value,
-				get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY)))
-			{
+			$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,null,get_current_nodeid(true));
+			if(!isset($available_hosts[$value])){
 				error(S_INCORRECT_HOST);
 				return false;
 			}
 			break;
 		case CONDITION_TYPE_TIME_PERIOD:
-			if( !validate_period($value) )
-			{
+			if( !validate_period($value) ){
 				error(S_INCORRECT_PERIOD.' ['.$value.']');
 				return false;
 			}
 			break;
 		case CONDITION_TYPE_DHOST_IP:
-			if( !validate_ip_range($value) )
-			{
+			if( !validate_ip_range($value) ){
 				error(S_INCORRECT_IP.' ['.$value.']');
 				return false;
 			}
 			break;
 		case CONDITION_TYPE_DSERVICE_TYPE:
-			if( S_UNKNOWN == discovery_check_type2str($value) )
-			{
+			if( S_UNKNOWN == discovery_check_type2str($value) ){
 				error(S_INCORRECT_DISCOVERY_CHECK);
 				return false;
 			}
 			break;
 		case CONDITION_TYPE_DSERVICE_PORT:
-			if( !validate_port_list($value) )
-			{
+			if( !validate_port_list($value) ){
 				error(S_INCORRECT_PORT.' ['.$value.']');
 				return false;
 			}
 			break;
 		case CONDITION_TYPE_DSTATUS:
-			if( S_UNKNOWN == discovery_object_status2str($value) )
-			{
+			if( S_UNKNOWN == discovery_object_status2str($value) ){
 				error(S_INCORRECT_DISCOVERY_STATUS);
 				return false;
 			}
@@ -893,7 +885,7 @@ return $delays;
 }
 
 function get_history_of_actions($start,$num,$sql_cond=''){
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, PERM_RES_IDS_ARRAY);
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, array(), PERM_RES_IDS_ARRAY);
 
 	$table = new CTableInfo(S_NO_ACTIONS_FOUND);
 	$table->SetHeader(array(
@@ -915,7 +907,6 @@ function get_history_of_actions($start,$num,$sql_cond=''){
 				' AND '.DBcondition('e.objectid',$available_triggers).
 				' AND '.DBin_node('a.alertid').
 			order_by('a.clock,a.alertid,mt.description,a.sendto,a.status,a.retries');
-
 	$result=DBselect($sql,10*$start+$num);
 		
 	$col=0;
@@ -966,7 +957,17 @@ function get_history_of_actions($start,$num,$sql_cond=''){
 	
 // Author: Aly
 function get_action_msgs_for_event($eventid){
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, PERM_RES_IDS_ARRAY);
+	$hostids = array();
+	$sql = 'SELECT DISTINCT i.hostid '.
+			' FROM events e, functions f, items i '.
+			' WHERE e.eventid='.$eventid.
+				' AND e.object='.EVENT_SOURCE_TRIGGERS.
+				' AND f.triggerid=e.objectid '.
+				' AND i.itemid=f.itemid';
+	if($host = DBfetch(DBselect($sql,1))){
+		$hostids[$host['hostid']] = $host['hostid'];
+	}
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, $hostids);
 
 	$table = new CTableInfo(S_NO_ACTIONS_FOUND);
 	$table->SetHeader(array(
@@ -1041,7 +1042,17 @@ return $table;
 
 // Author: Aly
 function get_action_cmds_for_event($eventid){
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, PERM_RES_IDS_ARRAY);
+	$hostids = array();
+	$sql = 'SELECT DISTINCT i.hostid '.
+			' FROM events e, functions f, items i '.
+			' WHERE e.eventid='.$eventid.
+				' AND e.object='.EVENT_SOURCE_TRIGGERS.
+				' AND f.triggerid=e.objectid '.
+				' AND i.itemid=f.itemid';
+	if($host = DBfetch(DBselect($sql,1))){
+		$hostids[$host['hostid']] = $host['hostid'];
+	}
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, $hostids);
 
 	$table = new CTableInfo(S_NO_ACTIONS_FOUND);
 	$table->SetHeader(array(
@@ -1104,7 +1115,17 @@ return $table;
 
 // Author: Aly
 function get_actions_hint_by_eventid($eventid,$status=NULL){
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, PERM_RES_IDS_ARRAY);
+	$hostids = array();
+	$sql = 'SELECT DISTINCT i.hostid '.
+			' FROM events e, functions f, items i '.
+			' WHERE e.eventid='.$eventid.
+				' AND e.object='.EVENT_SOURCE_TRIGGERS.
+				' AND f.triggerid=e.objectid '.
+				' AND i.itemid=f.itemid';
+	if($host = DBfetch(DBselect($sql,1))){
+		$hostids[$host['hostid']] = $host['hostid'];
+	}
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, $hostids);
 	
 	$tab_hint = new CTableInfo(S_NO_ACTIONS_FOUND);
 	$tab_hint->AddOption('style', 'width: 300px;');
