@@ -178,7 +178,7 @@ function make_system_summary(){
 	
 	$available_groups = get_accessible_groups_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
 	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY,array(),PERM_RES_IDS_ARRAY);
 		
 	$table = new CTableInfo();
 	$table->SetHeader(array(
@@ -243,9 +243,8 @@ function make_system_summary(){
 		}
 
 		foreach($tab_priority as $key => $value){
-			$normal = $value;
+			$tr_count = 0;
 			if($value){
-				$tr_count = 0;
 //* trigger list
 				$table_inf  = new CTableInfo();
 				$table_inf->AddOption('style', 'width: 400px;');
@@ -258,7 +257,7 @@ function make_system_summary(){
 					S_ACTIONS
 					));
 				
-				$sql = 'SELECT DISTINCT t.triggerid,t.status,t.description, t.priority, t.lastchange,t.value,h.host,h.hostid '.
+				$sql = 'SELECT DISTINCT t.triggerid,t.status,t.description,t.expression,t.priority,t.lastchange,t.value,h.host,h.hostid '.
 							' FROM triggers t,hosts h,items i,functions f, hosts_groups hg '.
 							' WHERE f.itemid=i.itemid '.
 								' AND hg.groupid='.$group['groupid'].
@@ -329,7 +328,7 @@ function make_system_summary(){
 				$value->SetHint($table_inf);
 //-------------*/
 			}
-			$group_row->AddItem(new CCol($value,get_severity_style($key,$normal)));
+			$group_row->AddItem(new CCol($value,get_severity_style($key,$tr_count)));
 			unset($table_inf);
 		}		
 		$table->AddRow($group_row);
@@ -352,21 +351,27 @@ function make_status_of_zbx(){
 
 	$table->AddRow(array(S_ZABBIX_SERVER_IS_RUNNING,new CSpan($status['zabbix_server'], ($status['zabbix_server'] == S_YES ? 'off' : 'on')),' - '));
 //	$table->AddRow(array(S_VALUES_STORED,$status['history_count']));$table->AddRow(array(S_TRENDS_STORED,$status['trends_count']));
-	$table->AddRow(array(S_NUMBER_OF_HOSTS,$status['hosts_count'],
+	$title = new CSpan(S_NUMBER_OF_HOSTS);
+	$title->addOption('title', 'asdad');
+	$table->AddRow(array(S_NUMBER_OF_HOSTS ,$status['hosts_count'],
 		array(
 			new CSpan($status['hosts_count_monitored'],'off'),' / ',
 			new CSpan($status['hosts_count_not_monitored'],'on'),' / ',
 			new CSpan($status['hosts_count_template'],'unknown')
 		)
 	));
-	$table->AddRow(array(S_NUMBER_OF_ITEMS,$status['items_count'],
+	$title = new CSpan(S_NUMBER_OF_ITEMS);
+	$title->addOption('title', S_NUMBER_OF_ITEMS_TOOLTIP);
+	$table->AddRow(array($title, $status['items_count'],
 		array(
 			new CSpan($status['items_count_monitored'],'off'),' / ',
 			new CSpan($status['items_count_disabled'],'on'),' / ',
 			new CSpan($status['items_count_not_supported'],'unknown')
 		)
 	));
-	$table->AddRow(array(S_NUMBER_OF_TRIGGERS,$status['triggers_count'],
+	$title = new CSpan(S_NUMBER_OF_TRIGGERS);
+	$title->addOption('title', S_NUMBER_OF_TRIGGERS_TOOLTIP);
+	$table->AddRow(array($title,$status['triggers_count'],
 		array(
 			$status['triggers_count_enabled'],' / ',
 			$status['triggers_count_disabled'].SPACE.SPACE.'[',
@@ -453,7 +458,7 @@ function make_latest_issues(){
 	global $USER_DETAILS;
 	
 	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY);
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY);
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, array());
 
 	$scripts_by_hosts = get_accessible_scripts_by_hosts($available_hosts);
 	$config=select_config();
@@ -469,7 +474,7 @@ function make_latest_issues(){
 		S_ACTIONS
 		));
 	
-	$sql = 'SELECT DISTINCT t.triggerid,t.status,t.description, t.priority, t.lastchange,t.value,h.host,h.hostid '.
+	$sql = 'SELECT DISTINCT t.triggerid,t.status,t.description,t.expression,t.priority,t.lastchange,t.value,h.host,h.hostid '.
 				' FROM triggers t,hosts h,items i,functions f, hosts_groups hg '.
 				' WHERE f.itemid=i.itemid '.
 					' AND h.hostid=i.hostid '.
@@ -499,7 +504,7 @@ function make_latest_issues(){
 		}
 
 		$menus.= "[".zbx_jsvalue(S_LINKS).",null,null,{'outer' : ['pum_oheader'],'inner' : ['pum_iheader']}],";
-		$menus.= "['".S_LATEST_DATA."',\"javascript: redirect('latest.php?hostid=".$row['hostid']."')\", null,{'outer' : ['pum_o_item'],'inner' : ['pum_i_item']}],";
+		$menus.= "['".S_LATEST_DATA."',\"javascript: redirect('latest.php?groupid=0&hostid=".$row['hostid']."')\", null,{'outer' : ['pum_o_item'],'inner' : ['pum_i_item']}],";
 
 		$menus = rtrim($menus,',');
 		$menus="show_popup_menu(event,[[".zbx_jsvalue(S_TOOLS).",null,null,{'outer' : ['pum_oheader'],'inner' : ['pum_iheader']}],".$menus."],180);";
@@ -508,7 +513,7 @@ function make_latest_issues(){
 		$host->AddOption('onclick','javascript: '.$menus);
 		$host->AddOption('onmouseover',"javascript: this.style.cursor = 'pointer';");
 
-		$event_sql = 'SELECT e.eventid, e.value, e.clock, e.objectid as triggerid, e.acknowledged, t.type '.
+		$event_sql = 'SELECT e.eventid, e.value, e.clock, e.objectid as triggerid, e.acknowledged, t.type, t.url '.
 					' FROM events e, triggers t '.
 					' WHERE e.object='.EVENT_SOURCE_TRIGGERS.
 						' AND e.objectid='.$row['triggerid'].
@@ -532,14 +537,17 @@ function make_latest_issues(){
 				}
 			}
 
-			$description = expand_trigger_description_by_data(
-					array_merge($row, array("clock"=>$row_event["clock"])),
-					ZBX_FLAG_EVENT);
+//			$description = expand_trigger_description($row['triggerid']);
+
+			$description = expand_trigger_description_by_data(array_merge($row, array('clock'=>$row_event['clock'])),ZBX_FLAG_EVENT);
 					
 //actions								
 			$actions = get_event_actions_stat_hints($row_event['eventid']);
 //--------			
-			$clock = new CLink(zbx_date2str(S_DATE_FORMAT_YMDHMS,$row_event['clock']),'events.php?triggerid='.$row['triggerid'].'&source=0&nav_time='.$row['lastchange'],'action');
+			$clock = new CLink(zbx_date2str(S_DATE_FORMAT_YMDHMS,$row_event['clock']),'events.php?triggerid='.$row['triggerid'].'&source=0&show_unknown=1&nav_time='.$row_event['clock'],'action');
+			
+			
+			$description = ($row_event['url']) ? new CLink($description, $row_event['url'], 'action', null, true) : $description;
 			
 			$table->AddRow(array(
 				get_node_name_by_elid($row['triggerid']),
