@@ -473,13 +473,7 @@ class Chart extends Graph{
 		}
 	}
 
-	function drawElement(
-		&$data, $from, $to, 
-		$minX, $maxX, $minY, $maxY, 
-		$drawtype, $max_color, $avg_color, $min_color, $minmax_color,
-		$calc_fnc, 
-		$axisside
-		){	
+	function drawElement(&$data, $from, $to, $minX, $maxX, $minY, $maxY, $drawtype, $max_color, $avg_color, $min_color, $minmax_color,$calc_fnc, $axisside){	
 		if(!isset($data->max[$from]) || !isset($data->max[$to])) return;
 
 		$oxy = $this->oxy[$axisside];
@@ -540,7 +534,7 @@ class Chart extends Graph{
 				$a[4] = $x2;		$a[5] = $y2min;
 				$a[6] = $x2;		$a[7] = $y2max;
 				
-				ImageFilledPolygon($this->im,$a,4,$minmax_color);
+				imagefilledpolygon($this->im,$a,4,$minmax_color);
 				imageline($this->im,$x1,$y1max,$x2,$y2max,$max_color);
 				imageline($this->im,$x1,$y1min,$x2,$y2min,$min_color);
 				
@@ -561,7 +555,26 @@ class Chart extends Graph{
 		
 		$y1_shift	= $zero - $shift_from/$unit2px;
 		$y2_shift	= $zero - $shift_to/$unit2px;//*/
+		
+		
+// Fixes graph out of bounds problem
+		if( (($y1 > ($this->sizeY+$this->shiftY)) && ($y2 > ($this->sizeY+$this->shiftY))) || (($y1 < $this->shiftY) && ($y2 < $this->shiftY)) ){
+			if($this->type != GRAPH_TYPE_STACKED) return true;
+		}
 
+
+		$y_first = !(($y1 > ($this->sizeY+$this->shiftY)) || ($y1 < $this->shiftY));
+		$y_second = !(($y2 > ($this->sizeY+$this->shiftY)) || ($y2 < $this->shiftY));
+		
+		if(!$y_first){
+			$y1 = ($y1 > ($this->sizeY+$this->shiftY))?($this->sizeY+$this->shiftY):$this->shiftY;
+		}
+		
+		if(!$y_second){
+			$y2 = ($y2 > ($this->sizeY+$this->shiftY))?($this->sizeY+$this->shiftY):$this->shiftY;
+		}
+//--------
+			
 		/* draw main line */
 		switch($drawtype){
 			case GRAPH_ITEM_DRAWTYPE_BOLD_LINE:
@@ -579,7 +592,7 @@ class Chart extends Graph{
 				
 //					SDI($a);
 				
-				ImageFilledPolygon($this->im,$a,4,$avg_color);
+				imagefilledpolygon($this->im,$a,4,$avg_color);
 				break;
 			case GRAPH_ITEM_DRAWTYPE_DOT:
 				imagefilledrectangle($this->im,$x1-1,$y1-1,$x1+1,$y1+1,$avg_color);
@@ -971,7 +984,7 @@ class Chart extends Graph{
 			
 			$sql_arr = array();
 	
-			if((($real_item['history']*86400) > (time()-($from_time+$this->period/2))) &&				// should pick data from history or trends
+			if((($real_item['history']*86400) > (time()-($this->from_time+$this->period/2))) &&				// should pick data from history or trends
 				(($this->period / $this->sizeX) <= (ZBX_MAX_TREND_DIFF / ZBX_GRAPH_MAX_SKIP_CELL)))		// is reasonable to take data from history?
 			{
 				array_push($sql_arr,
