@@ -19,42 +19,53 @@
 **/
 ?>
 <?php
-	class CLink extends CTag
-	{
+	class CLink extends CTag{
 /* public */
-		function CLink($item=NULL,$url=NULL,$class=NULL,$action=NULL)
-		{
-			parent::CTag("a","yes");
+		function CLink($item=NULL,$url=NULL,$class=NULL,$action=NULL, $nosid=NULL){
+			parent::CTag('a','yes');
+			
+			$this->tag_start= '';
+			$this->tag_end = '';
+			$this->tag_body_start = '';
+			$this->tag_body_end = '';
+			$this->nosid = $nosid;
 
-			$this->tag_start= "";
-			$this->tag_end = "";
-			$this->tag_body_start = "";
-			$this->tag_body_end = "";
-
-			if(!is_null($class))	$this->SetClass($class);
-			if(!is_null($item))	$this->AddItem($item);
-			if(!is_null($url))	$this->SetUrl($url);
-			if(!is_null($action))	$this->SetAction($action);
+			if(!is_null($class))	$this->setClass($class);
+			if(!is_null($item))		$this->addItem($item);
+			if(!is_null($url))		$this->setUrl($url);
+			if(!is_null($action))	$this->setAction($action);
 		}
-		function SetAction($value=NULL)
-		{
+		
+		function setAction($value=NULL){
 			if(is_null($value))
 				return $this->options['action'] = $page['file'];
 
-			return parent::AddAction('onClick', $value);
+			return parent::addAction('onclick', $value);
 		}
-		function SetUrl($value)
-		{
-			$this->AddOption('href', $value);
+		
+		function setUrl($value){
+			if(is_null($this->nosid)) {
+				$uri = new Curl($value);
+				$url = $uri->getUrl();
+			}
+			else {
+				$url = $value;
+			}
+			$this->addOption('href', $url);
 		}
-		function SetTarget($value=NULL)
-		{
-			if(is_null($value))
-			{
+		
+		function getUrl(){
+			if(isset($this->options['href']))
+				return $this->options['href'];
+			else
+				return null;
+		}
+		
+		function setTarget($value=NULL){
+			if(is_null($value)){
 				unset($this->options['target']);
 			}
-			else
-			{
+			else{
 				$this->options['target'] = $value;
 			}
 		}
