@@ -400,7 +400,7 @@ if(!isset($DB)){
 					}
 					$result = DBexecute($query);
 					if(!$result){
-						$e = ocierror($stid);
+						$e = ocierror($result);
 						error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
 					}
 	
@@ -602,7 +602,6 @@ else {
 
 	function DBid2nodeid($id_name){
 		global $DB;
-
 		switch($DB['TYPE']){
 			case "MYSQL":
 				$result = '('.$id_name.' div 100000000000000)';
@@ -731,7 +730,23 @@ else {
 		return bcmod($id,'100000000000');
 	}
 
-	function DBcondition($fieldname, &$array, $notin=false){
+	function check_db_fields(&$db_fields, &$args){
+		if(!is_array($args)) return false;
+		
+		foreach($db_fields as $field => $def){
+			if(!isset($args[$field])){
+				if(is_null($def)){
+					return false;
+				}
+				else{
+					$args[$field] = $def;
+				}
+			}
+		}
+	return true;
+	}
+	
+	function DBcondition($fieldname, &$array, $notin=false, $string=false){
 		global $DB;
 		$condition = '';
 		
@@ -744,23 +759,27 @@ else {
 
 		$in = 		$notin?' NOT IN ':' IN ';
 		$concat = 	$notin?' AND ':' OR ';
+		$glue = 	$string?"','":',';
 
 		switch($DB['TYPE']) {
+			case 'SQLITE3':
 			case 'MYSQL':
+			case 'POSTGRESQL':
 			case 'ORACLE':
+			default:
 				$items = array_chunk($array, 950);
 				foreach($items as $id => $values){
 					$condition.=!empty($condition)?')'.$concat.$fieldname.$in.'(':'';
-					$condition.= implode(',',$values);
+					
+					if($string)	$condition.= "'".implode($glue,$values)."'";
+					else		$condition.= implode($glue,$values);
 				}
 				break;
-			default:
-				$condition = implode(',',$array);
 		}
 		
-		if(zbx_empty($condition)) $condition = '-1';
+		if(zbx_empty($condition)) $condition = $string?"'-1'":'-1';
 
 	return ' ('.$fieldname.$in.'('.$condition.')) ';
 	}
 	
-?>
+?>
\ No newline at end of file
