@@ -19,8 +19,37 @@
 **/
 ?>
 <?php
-	define('ZABBIX_VERSION','1.6.1');
+	define('ZABBIX_VERSION','1.6.4');
+
+/* USER DEFINES */	
+
+	define('ZBX_LOGIN_ATTEMPTS', 	5);
+	define('ZBX_LOGIN_BLOCK', 		30); // sec
 	
+	define('TRIGGERS_OPTION_DISABLED',		0);		// reserved
+	define('TRIGGERS_OPTION_ONLYTRUE',		1);		// use 0 to disable
+	define('TRIGGERS_OPTION_ALL',			2);		// use 0 to disable
+	define('TRIGGERS_OPTION_NOFALSEFORB',	0);		// use 0 to disable
+	
+	define('TRIGGER_FALSE_PERIOD', 			1800);	// 30min,  0 - disable
+	define('TRIGGER_BLINK_PERIOD',			1800);	// 30min,  0 - disable
+
+	define('EVENTS_OPTION_DISABLED',		0);		//	reserved
+	define('EVENTS_OPTION_NOEVENT',			1);		//	use 0 to disable
+	define('EVENTS_OPTION_ALL',				2);		//	use 0 to disable
+	define('EVENTS_OPTION_NOT_ACK',			3);		//	use 0 to disable
+	define('EVENTS_OPTION_ONLYTRUE_NOTACK',	4);		//	use 0 to disable
+	define('EVENTS_OPTION_NOFALSEFORB',		5);		//  reserved for TRIGGERS_OPTION_NOFALSEFORB, to disable set TRIGGERS_OPTION_NOFALSEFORB to 0
+
+	define('ZBX_MIN_PERIOD', 3600);					// ~1 hour
+	define('ZBX_MAX_PERIOD', 12*31*24*3600);		// ~1 year
+	define('ZBX_PERIOD_DEFAULT', ZBX_MIN_PERIOD);
+
+	define('ZBX_DROPDOWN_FIRST_ENTRY',		2);		// 0 - NONE, 1 - ALL, 2 - SIMILAR ZBX 1.6.2 (compatibility mode)
+	define('ZBX_DROPDOWN_FIRST_REMEMBER',	1);		// 0 - do NOT remember, 1 - do remember
+	
+/* END OF USERS DEFINES */
+
 	define('ZBX_AUTH_INTERNAL',	0);
 	define('ZBX_AUTH_LDAP',		1);
 	define('ZBX_AUTH_HTTP',		2);
@@ -31,11 +60,12 @@
 	define('PAGE_TYPE_JS',			3);	//javascript
 	define('PAGE_TYPE_HTML_BLOCK',	4);	//simple block of html (as text)
 	
-	define('ZBX_LOGIN_ATTEMPTS', 	5);
-	define('ZBX_LOGIN_BLOCK', 		30); // sec
-	
 	define('ZBX_SESSION_ACTIVE', 0);
 	define('ZBX_SESSION_PASSIVE', 1);
+	
+	define('ZBX_DROPDOWN_FIRST_NONE',		0);
+	define('ZBX_DROPDOWN_FIRST_ALL',		1);
+	define('ZBX_DROPDOWN_FIRST_ZBX162',		2);
 
 	define('T_ZBX_STR',			0);
 	define('T_ZBX_INT',			1);
@@ -161,6 +191,7 @@
 	define('SYSMAP_ELEMENT_TYPE_MAP',	1);
 	define('SYSMAP_ELEMENT_TYPE_TRIGGER',	2);
 	define('SYSMAP_ELEMENT_TYPE_HOST_GROUP',3);
+	define('SYSMAP_ELEMENT_TYPE_IMAGE',	4);
 
 	define('SYSMAP_ELEMENT_ICON_ON',	0);
 	define('SYSMAP_ELEMENT_ICON_OFF',	1);
@@ -191,42 +222,34 @@
 	define('ITEM_STATUS_NOTSUPPORTED',3);
 
 	define('ITEM_SNMPV3_SECURITYLEVEL_NOAUTHNOPRIV',0);
-	define('ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV',1);
-	define('ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV',2);
+	define('ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV',	1);
+	define('ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV',	2);
 
-	define('GRAPH_ITEM_DRAWTYPE_LINE',		0);
+	define('GRAPH_ITEM_DRAWTYPE_LINE',			0);
 	define('GRAPH_ITEM_DRAWTYPE_FILLED_REGION',	1);
 	define('GRAPH_ITEM_DRAWTYPE_BOLD_LINE',		2);
-	define('GRAPH_ITEM_DRAWTYPE_DOT',		3);
+	define('GRAPH_ITEM_DRAWTYPE_DOT',			3);
 	define('GRAPH_ITEM_DRAWTYPE_DASHED_LINE',	4);
 
-	define('MAP_LINK_DRAWTYPE_LINE',		0);
+	define('MAP_LINK_DRAWTYPE_LINE',			0);
 	define('MAP_LINK_DRAWTYPE_BOLD_LINE',		2);
-	define('MAP_LINK_DRAWTYPE_DOT',			3);
+	define('MAP_LINK_DRAWTYPE_DOT',				3);
 	define('MAP_LINK_DRAWTYPE_DASHED_LINE',		4);
 
-	define('SERVICE_ALGORITHM_NONE',0);
-	define('SERVICE_ALGORITHM_MAX',1);
-	define('SERVICE_ALGORITHM_MIN',2);
+	define('SERVICE_ALGORITHM_NONE',	0);
+	define('SERVICE_ALGORITHM_MAX',		1);
+	define('SERVICE_ALGORITHM_MIN',		2);
 	
 	define('TRIGGER_MULT_EVENT_DISABLED',0);
-	define('TRIGGER_MULT_EVENT_ENABLED',1);
+	define('TRIGGER_MULT_EVENT_ENABLED'	,1);
 	
-	define('TRIGGER_STATUS_ENABLED',0);
+	define('TRIGGER_STATUS_ENABLED'	,0);
 	define('TRIGGER_STATUS_DISABLED',1);
-	define('TRIGGER_STATUS_UNKNOWN',2);
+	define('TRIGGER_STATUS_UNKNOWN'	,2);
 	
-	define('TRIGGERS_OPTION_DISABLED',		0);	// reserved
-	define('TRIGGERS_OPTION_ONLYTRUE',		1);	// use 0 to disable
-	define('TRIGGERS_OPTION_ALL',			2);	// use 0 to disable
-	define('TRIGGERS_OPTION_NOFALSEFORB',	0);	// use 0 to disable
-
-	define('TRIGGER_VALUE_FALSE',0);
-	define('TRIGGER_VALUE_TRUE',1);
-	define('TRIGGER_VALUE_UNKNOWN',2);
-
-	define('TRIGGER_FALSE_PERIOD', 			1800);	
-	define('TRIGGER_BLINK_PERIOD',			1800);
+	define('TRIGGER_VALUE_FALSE'	,0);
+	define('TRIGGER_VALUE_TRUE'		,1);
+	define('TRIGGER_VALUE_UNKNOWN'	,2);
 
 	define('TRIGGER_SEVERITY_NOT_CLASSIFIED',	0);
 	define('TRIGGER_SEVERITY_INFORMATION',		1);
@@ -317,8 +340,8 @@
 	define('STYLE_TOP', 1);
 
 /* time module tipe */
-        define('TIME_TYPE_LOCAL',	0);
-        define('TIME_TYPE_SERVER',	1);
+	define('TIME_TYPE_LOCAL',	0);
+	define('TIME_TYPE_SERVER',	1);
 
 	define('FILTER_TAST_SHOW',	0);
 	define('FILTER_TAST_HIDE',	1);
@@ -355,29 +378,22 @@
 	define('GROUP_STATUS_DISABLED', 1);	
 	define('GROUP_STATUS_ENABLED', 0);
 	
-// IMPORTANT!!!    by priority	DESC
+// IMPORTANT!!!    by priority	ASC
 	define('GROUP_GUI_ACCESS_SYSTEM', 	0);
 	define('GROUP_GUI_ACCESS_INTERNAL', 1);
 	define('GROUP_GUI_ACCESS_DISABLED', 2);	
 	
 
-	define('PERM_MAX',		3);
+	define('PERM_MAX',			3);
 	define('PERM_READ_WRITE',	3);
 	define('PERM_READ_ONLY',	2);
 	define('PERM_READ_LIST',	1);
-	define('PERM_DENY',		0);
+	define('PERM_DENY',			0);
 	
 	define('PERM_RES_STRING_LINE',	0); /* return string of nodes id - '1,2,3,4,5' */
 	define('PERM_RES_IDS_ARRAY',	1); /* return array of nodes id - array(1,2,3,4) */
 	define('PERM_RES_DATA_ARRAY',	2); 
 
-	define('PERM_MODE_NE',	5);
-	define('PERM_MODE_EQ',	4);
-	define('PERM_MODE_GT',	3);
-	define('PERM_MODE_LT',	2);
-	define('PERM_MODE_LE',	1);
-	define('PERM_MODE_GE',	0);
-
 	define('RESOURCE_TYPE_NODE',		0);
 	define('RESOURCE_TYPE_GROUP',		1);
 
@@ -413,13 +429,6 @@
 	define('EVENT_OBJECT_DHOST',		1);
 	define('EVENT_OBJECT_DSERVICE',		2);
 	
-	define('EVENTS_OPTION_DISABLED',		0);		//	reserved
-	define('EVENTS_OPTION_NOEVENT',			1);		//	use 0 to disable
-	define('EVENTS_OPTION_ALL',				2);		//	use 0 to disable
-	define('EVENTS_OPTION_NOT_ACK',			3);		//	use 0 to disable
-	define('EVENTS_OPTION_ONLYTRUE_NOTACK',	4);		//	use 0 to disable
-	define('EVENTS_OPTION_NOFALSEFORB',		5);		//  reserved for TRIGGERS_OPTION_NOFALSEFORB, to disable set TRIGGERS_OPTION_NOFALSEFORB to 0
-
 	define('DOBJECT_STATUS_UP',		0);
 	define('DOBJECT_STATUS_DOWN',		1);
 	define('DOBJECT_STATUS_DISCOVER',	2); /* only for events,           */
@@ -502,10 +511,6 @@ else{
 	define('ZBX_EXPRESSION_SIMPLE_EXPRESSION_ID', 2);
 	define('ZBX_EXPRESSION_MACRO_ID', 13);
 	define('ZBX_EXPRESSION_RIGHT_ID', 14);
-
-	define('ZBX_MIN_PERIOD', 3600);				// ~1 hour
-	define('ZBX_MAX_PERIOD', 12*31*24*3600);	// ~1 year
-	define('ZBX_PERIOD_DEFAULT', ZBX_MIN_PERIOD);
 	
 	define('ZBX_HISTORY_COUNT',5);
 	
