@@ -224,7 +224,7 @@
 	
 	function zbx_xmlwriter_output_memory(&$mem, $val){ 
 /* NOTE: use this function only in the end of xml file creation */
-		echo '>';
+		echo '>'."\n";
 	}
 	
 	function zbx_xmlwriter_write_element(&$mem, $name, $val){
@@ -312,7 +312,7 @@
 			$data = DBfetch(DBselect($sql));
 			if(!$data) return false;
 
-			$data['item'] = '{HOSTNAME}:'.$data['key_'];
+			$data['item'] = $data['host'].':'.$data['key_'];
 			
 			zbx_xmlwriter_start_element ($memory,XML_TAG_GRAPH_ELEMENT);
 			
