@@ -165,7 +165,7 @@
  */		
 	function graph_accessible($graphid){
 		global $USER_DETAILS;
-		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, PERM_READ_ONLY, PERM_RES_IDS_ARRAY);
+		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, PERM_READ_ONLY, PERM_RES_IDS_ARRAY,get_current_nodeid(true));
 		
 		$sql = 	'SELECT g.graphid '.
 				' FROM graphs g, graphs_items gi, items i '.
@@ -191,16 +191,17 @@
  *     Aly
  *
  */		
-	function get_accessible_graphs($perm,$perm_res=null,$nodeid=null,$hostid=null,$cache=1){
+	function get_accessible_graphs($perm,$hostids,$perm_res=null,$nodeid=null,$cache=1){
 		global $USER_DETAILS;
 		static $available_graphs;
 		
 		if(is_null($perm_res)) $perm_res = PERM_RES_IDS_ARRAY;
 		$nodeid_str =(is_array($nodeid))?implode('',$nodeid):strval($nodeid);
-		$hostid_str =(is_array($hostid))?implode('',$hostid):strval($hostid);
+		$hostid_str = implode('',$hostids);
 		
-		if($cache && isset($available_graphs[$perm][$perm_res][$nodeid_str][$hostid_str])){
-			return $available_graphs[$perm][$perm_res][$nodeid_str][$hostid_str];
+		$cache_hash = md5($perm.$perm_res.$nodeid_str.$hostid_str);
+		if($cache && isset($available_graphs[$cache_hash])){
+			return $available_graphs[$cache_hash];
 		}
 		
 		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, $perm, PERM_RES_IDS_ARRAY, $nodeid);
@@ -208,11 +209,15 @@
 		$denied_graphs = array();
 		$result = array();
 		
+		$sql_where = '';
+		if(!empty($hostids)){
+			$sql_where.= ' AND '.DBcondition('i.hostid',$hostids);
+		}		
 		$sql = 	'SELECT DISTINCT g.graphid '.
 				' FROM graphs g, graphs_items gi, items i '.
 				' WHERE g.graphid=gi.graphid '.
-					(!empty($hostid)?' AND i.hostid='.$hostid:'').
 					' AND i.itemid=gi.itemid '.
+					$sql_where.
 					' AND '.DBcondition('i.hostid',$available_hosts, true);
 
 		$db_graphs = DBselect($sql);
@@ -223,11 +228,9 @@
 		$sql = 	'SELECT DISTINCT g.graphid '.
 				' FROM graphs g, graphs_items gi, items i '.
 				' WHERE g.graphid=gi.graphid '.
-					(!empty($hostid)?' AND i.hostid='.$hostid:'').
 					' AND i.itemid=gi.itemid '.
-					' AND i.status='.ITEM_STATUS_ACTIVE.
+					$sql_where.
 					(!empty($denied_graphs)?' AND '.DBcondition('g.graphid',$denied_graphs,true):'');
-
 		$db_graphs = DBselect($sql);
 		while($graph = DBfetch($db_graphs)){
 			$result[$graph['graphid']] = $graph['graphid'];
@@ -240,7 +243,7 @@
 				$result = implode(',',$result);
 		}
 
-		$available_graphs[$perm][$perm_res][$nodeid_str][$hostid_str] = $result;
+		$available_graphs[$cache_hash] = $result;
 
 	return $result;
 	}
@@ -254,26 +257,21 @@
  * Author:
  *     Aly
  *
+ * Comment:
+ *	   sql is splited to many sql's to optimize search on history tables
+ *
  */	
 	function get_min_itemclock_by_graphid($graphid){
-		$min = 0;
-		$row = DBfetch(DBselect('SELECT MIN(t.clock) as clock '.
-						' FROM graphs_items gi, trends t '.
-						' WHERE gi.graphid='.$graphid.
-						  ' AND t.itemid = gi.itemid')); 
-						  
-		if(!empty($row) && $row && $row['clock']) 
-			$min = $row['clock'];
+		$itemids = array();
+		$sql = 'SELECT DISTINCT gi.itemid '.
+				' FROM graphs_items gi '.
+				' WHERE gi.graphid='.$graphid;
+		$res = DBselect($sql);
+		while($item = DBfetch($res)){
+			$itemids[$item['itemid']] = $item['itemid'];
+		}
 
-		$row = DBfetch(DBselect('SELECT MIN(t.clock) as clock '.
-						' FROM graphs_items gi, trends_uint t '.
-						' WHERE gi.graphid='.$graphid.
-						  ' AND t.itemid = gi.itemid')); 
-						  
-		if(!empty($row) && $row && $row['clock']) 
-			$min = $min == 0 ? $row['clock'] : min($min, $row['clock']);
-
-	return $min;
+	return get_min_itemclock_by_itemid($itemids);
 	}
 
 /*
@@ -286,49 +284,95 @@
  *     Aly
  *
  */	
-	function get_min_itemclock_by_itemid($itemid){
-		$min = 0;
-		$row = DBfetch(DBselect('SELECT MIN(t.clock) as clock '.
-						' FROM trends t '.
-						' WHERE t.itemid='.$itemid)); 
-						  
-		if(!empty($row) && $row && $row['clock']) 
-			$min = $row['clock'];
+	function get_min_itemclock_by_itemid($itemids){
+		zbx_value2array($itemids);
+		$min = null;
+		$result = time() - 86400*365;
+		
+		$items_by_type = array(ITEM_VALUE_TYPE_FLOAT => array(), ITEM_VALUE_TYPE_STR =>  array(), ITEM_VALUE_TYPE_LOG => array(), 
+						ITEM_VALUE_TYPE_UINT64 => array(), ITEM_VALUE_TYPE_TEXT => array());
+						
+		$sql = 'SELECT i.itemid, i.value_type '.
+				' FROM items i WHERE '.DBcondition('i.itemid', $itemids);
+		$db_result = DBselect($sql);
+		
+		while($item = DBfetch($db_result)) {
+			$items_by_type[$item['value_type']][$item['itemid']] = $item['itemid'];
+		}
+		
+		// data for ITEM_VALUE_TYPE_FLOAT and ITEM_VALUE_TYPE_UINT64 can be stored in trends tables or history table
+		// get max trends and history values for such type items to find out in what tables to look for data
+		$sql_from = 'history';
+		$sql_from_num = '';
+		if(!empty($items_by_type[ITEM_VALUE_TYPE_FLOAT]) || !empty($items_by_type[ITEM_VALUE_TYPE_UINT64])) {
+			$itemids_numeric = array_merge($items_by_type[ITEM_VALUE_TYPE_FLOAT], $items_by_type[ITEM_VALUE_TYPE_UINT64]);
+			$sql = 'SELECT MAX(i.history) as history, MAX(i.trends) as trends FROM items i WHERE '.DBcondition('i.itemid', $itemids_numeric);
 
-		$row = DBfetch(DBselect('SELECT MIN(t.clock) as clock '.
-						' FROM trends_uint t '.
-						' WHERE t.itemid='.$itemid)); 
-						  
-		if(!empty($row) && $row && $row['clock']) 
-			$min = $min == 0 ? $row['clock'] : min($min, $row['clock']);
-
-	return $min;
+			if($table_for_numeric = DBfetch(DBselect($sql))){
+				$sql_from_num = ($table_for_numeric['history'] > $table_for_numeric['trends']) ? 'history' : 'trends';
+				$result = time() - (86400 * max($table_for_numeric['history'],$table_for_numeric['trends']));
+			}
+		}
+		foreach($items_by_type as $type => $items) {
+			if(empty($items)) continue;
+			switch($type) {
+				case ITEM_VALUE_TYPE_FLOAT: // 0
+					$sql_from = $sql_from_num;
+				break;
+				case ITEM_VALUE_TYPE_STR: // 1
+					$sql_from = 'history_str';
+				break;
+				case ITEM_VALUE_TYPE_LOG: // 2
+					$sql_from = 'history_log';
+				break;
+				case ITEM_VALUE_TYPE_UINT64: // 3
+					$sql_from = $sql_from_num.'_uint';
+				break;
+				case ITEM_VALUE_TYPE_TEXT: // 4
+					$sql_from = 'history_text';
+				break;
+				default:
+					$sql_from = 'history';
+			}
+			foreach($items as $itemid) {
+				$sql = 'SELECT ht.clock '.
+						' FROM '.$sql_from.' ht '.
+						' WHERE ht.itemid='.$itemid.
+						' ORDER BY ht.itemid, ht.clock ';
+				if($min_tmp = DBfetch(DBselect($sql,1))){
+					$min = (is_null($min)) ? $min_tmp['clock'] : min($min, $min_tmp['clock']);
+				}
+			}			
+		}
+		$result = is_null($min)?$result:$min;
+		
+	return $result;
 	}
 	
 // Show History Graph
 	function show_history($itemid,$from,$stime,$period){
-		$till=date(S_DATE_FORMAT_YMDHMS,time(NULL)-$from*3600);   
+		//$till=date(S_DATE_FORMAT_YMDHMS,time(NULL)-$from*3600);   
 		
-		show_table_header(S_TILL.SPACE.$till.' ( '.zbx_date2age($stime,$stime+$period).' )');
+		//show_table_header(S_TILL.SPACE.$till.' ( '.zbx_date2age($stime,$stime+$period).' )');
 
 		$td = new CCol(get_js_sizeable_graph('graph','chart.php?itemid='.$itemid.
 				url_param($from,false,'from').
 				url_param($stime,false,'stime').
 				url_param($period,false,'period')));
-		$td->AddOption('align','center');
+		$td->addOption('align','center');
 		
 		$tr = new CRow($td);
-		$tr->AddOption('bgcolor','#dddddd');
+		$tr->addOption('bgcolor','#dddddd');
 		
 		$table = new CTable();
-		$table->AddOption('width','100%');
-		$table->AddOption('bgcolor','#cccccc');
-		$table->AddOption('cellspacing','1');
-		$table->AddOption('cellpadding','3');
+		$table->addOption('width','100%');
+		$table->addOption('bgcolor','#cccccc');
+		$table->addOption('cellspacing','1');
+		$table->addOption('cellpadding','3');
 		
-		$table->AddRow($tr);
+		$table->addRow($tr);
 		
-		$table->Show();
+		$table->show();
 		echo SBR;
 	}
 
@@ -364,7 +408,7 @@
 		return	false;
 	}
 
-	function	get_graphs_by_templateid($templateids){
+	function get_graphs_by_templateid($templateids){
 		zbx_value2array($templateids);
 	return DBselect('SELECT * FROM graphs WHERE '.DBcondition('templateid',$templateids));
 	}
@@ -468,7 +512,7 @@
 		$db_item_hosts = DBselect('SELECT DISTINCT h.hostid,h.host,h.status '.
 							' FROM items i, hosts h '.
 							' WHERE h.hostid=i.hostid '.
-								' AND i.itemid in ('.implode(',', $itemid).')');
+								' AND '.DBcondition('i.itemid',$itemid));
 								
 		while($db_item_host = DBfetch($db_item_hosts)){
 			$host_list[] = '"'.$db_item_host['host'].'"';
@@ -670,16 +714,17 @@
 		$result = true;
 		
 		$graphs = array();
-		$host_lists = array();
+		$host_list = array();
 		foreach($graphids as $id => $graphid){
-			$graphs[] = get_graph_by_graphid($graphid);
+			$graphs[$graphid] = get_graph_by_graphid($graphid);
 	
 			$host_list[$graphid] = array();
 			$db_hosts = get_hosts_by_graphid($graphid);
 			while($db_host = DBfetch($db_hosts)){
 				$host_list[$graphid] = '"'.$db_host['host'].'"';
 			}
-		}		
+		}
+
 // firstly remove child graphs 
 		$del_chd_graphs = array();
 		$chd_graphs = get_graphs_by_templateid($graphids);
@@ -700,7 +745,7 @@
 		if($result){
 			foreach($graphs as $graphid => $graph){
 				if(isset($host_list[$graphid]))
-					info('Graph "'.$graph['name'].'" deleted from hosts '.implode(',',$host_list[$graphid]));
+					info('Graph "'.$graph['name'].'" deleted from hosts '.implode(',',$host_list));
 			}
 		}
 
@@ -920,9 +965,9 @@
 	}
 
 	function navigation_bar_calc(){
-		if(!isset($_REQUEST["period"]))	$_REQUEST["period"]=ZBX_PERIOD_DEFAULT;
-		if(!isset($_REQUEST["from"]))	$_REQUEST["from"]=0;
-		if(!isset($_REQUEST["stime"]))	$_REQUEST["stime"]=null;
+		$_REQUEST['period'] = get_request('period', ZBX_PERIOD_DEFAULT);
+		$_REQUEST['from'] = get_request('from', 0);
+		$_REQUEST['stime'] = get_request('stime', null);
 
 		if($_REQUEST['period']<ZBX_MIN_PERIOD){
 			show_message(S_WARNING.'. '.S_TIME_PERIOD.SPACE.S_MIN_VALUE_SMALL.': '.ZBX_MIN_PERIOD.' ('.(int)(ZBX_MIN_PERIOD/3600).'h)');
@@ -934,13 +979,14 @@
 			$_REQUEST['period'] = ZBX_MAX_PERIOD;			
 		}
 
-		if(isset($_REQUEST["stime"])){
+		if(isset($_REQUEST['stime'])){
 			$bstime = $_REQUEST['stime'];
 			$time = mktime(substr($bstime,8,2),substr($bstime,10,2),0,substr($bstime,4,2),substr($bstime,6,2),substr($bstime,0,4));
-			if(($time+$_REQUEST['period']) > time()) unset($_REQUEST['stime']);
+			if(($time+$_REQUEST['period']) > time()) {
+				$_REQUEST['stime'] = date('YmdHi', time()-$_REQUEST['period']);
+			}
 		}
-		
-	return $_REQUEST["period"];
+	return $_REQUEST['period'];
 	}
 
 	function navigation_bar($url,$ext_saved_request=NULL){
