@@ -91,7 +91,7 @@
 							info('Host ['.$data['name'].'] skipped - user rule');
 							break; // case
 						}
-						if(!uint_in_array($host_data['hostid'], $this->available_hosts)){
+						if(!isset($this->available_hosts[$host_data['hostid']])){
 							error('Host ['.$data['name'].'] skipped - Access deny.');
 							break; // case
 						}
@@ -367,12 +367,12 @@
 						break; // case
 					}
 					
-					if(!uint_in_array($group["groupid"], $this->available_groups)){
+					if(!isset($this->available_groups[$group['groupid']])){
 						error('Group ['.$this->element_data.'] skipped - Access deny.');
 						break; // case
 					}
 
-					array_push($this->data[XML_TAG_HOST]['groups'], $group["groupid"]);
+					$this->data[XML_TAG_HOST]['groups'][$group['groupid']] = $group['groupid'];
 
 					break; // case
 				case XML_TAG_DEPENDENCY:
@@ -430,7 +430,7 @@
 						break; // case
 					}
 					
-					if(!uint_in_array($template["hostid"], $this->available_hosts)){
+					if(!isset($this->available_hosts[$template['hostid']])){
 						error('Template ['.$this->element_data.'] skipped - Access deny.');
 						break; // case
 					}
@@ -501,40 +501,15 @@
 
 						if(!isset($data['valuemapid']))
 							$data['valuemapid'] = $item['valuemapid'];
-
-						update_item(
-							$item['itemid'],
-							$data['description'],
-							$data['key'],
-							$this->data[XML_TAG_HOST]['hostid'],
-							$data['delay'],
-							$data['history'],
-							$data['status'],
-							$data['type'],
-							$data['snmp_community'],
-							$data['snmp_oid'],
-							$data['value_type'],
-							$data['trapper_hosts'],
-							$data['snmp_port'],
-							$data['units'],
-							$data['multiplier'],
-							$data['delta'],
-							$data['snmpv3_securityname'],
-							$data['snmpv3_securitylevel'],
-							$data['snmpv3_authpassphrase'],
-							$data['snmpv3_privpassphrase'],
-							$data['formula'],
-							$data['trends'],
-							$data['logtimefmt'],
-							$data['valuemapid'],
-							$data['delay_flex'],
-							$data['params'],
-							$data['ipmi_sensor'],
-							array_unique(array_merge(
-								$data['applications'],
-								get_applications_by_itemid($item['itemid'])
-								)),
-							$item['templateid']);
+	
+							$data['key_'] = $data['key'];
+							$data['hostid'] = $this->data[XML_TAG_HOST]['hostid'];
+							$data['applications'] = array_unique(array_merge($data['applications'],get_applications_by_itemid($item['itemid'])));
+							$data['templateid'] = $item['templateid'];
+							
+							check_db_fields($item, $data);
+							
+						update_item($item['itemid'], $data);
 					}
 					else{ /* missed */
 						if($this->item['missed']==1) /* skip */{
@@ -545,34 +520,10 @@
 						if( !isset($data['valuemapid']) )
 							$data['valuemapid'] = 0;
 
-						add_item(
-							$data['description'],
-							$data['key'],
-							$this->data[XML_TAG_HOST]['hostid'],
-							$data['delay'],
-							$data['history'],
-							$data['status'],
-							$data['type'],
-							$data['snmp_community'],
-							$data['snmp_oid'],
-							$data['value_type'],
-							$data['trapper_hosts'],
-							$data['snmp_port'],
-							$data['units'],
-							$data['multiplier'],
-							$data['delta'],
-							$data['snmpv3_securityname'],
-							$data['snmpv3_securitylevel'],
-							$data['snmpv3_authpassphrase'],
-							$data['snmpv3_privpassphrase'],
-							$data['formula'],
-							$data['trends'],
-							$data['logtimefmt'],
-							$data['valuemapid'],
-							$data['delay_flex'],
-							$data['params'],
-							$data['ipmi_sensor'],
-							$data['applications']);
+						$data['hostid'] = $this->data[XML_TAG_HOST]['hostid'];
+						$data['key_'] = $data['key'];
+						
+						add_item($data);
 					}
 
 					break; // case
@@ -604,7 +555,7 @@
 						}
 					}
 					else{
-						$data['expression'] = str_replace('{HOSTNAME}',$this->data[XML_TAG_HOST]['name'],$data['expression']);
+						$data['expression'] = str_replace('{{HOSTNAME}:','{'.$this->data[XML_TAG_HOST]['name'].':',$data['expression']);
  
 						$result = DBselect('SELECT DISTINCT t.triggerid,t.templateid,t.expression '.
  							' FROM triggers t,functions f,items i '.
@@ -711,24 +662,24 @@
 							}
 
 							$data['graphid'] = $graph['graphid'];
-
-							update_graph(
-								$data['graphid'],
-								$data['name'],
-								$data['width'],
-								$data['height'],
-								$data['yaxistype'],
-								$data['yaxismin'],
-								$data['yaxismax'],
-								$data['show_work_period'],
-								$data['show_triggers'],
-								$data['graphtype'],
-								$data['show_legend'],
-								$data['show_3d'],
-								$data['percent_left'],
-								$data['percent_right'],
-								$graph['templateid']);
-							DBexecute('DELETE FROM graphs_items WHERE graphid='.$data['graphid']);
+					
+							update_graph_with_items(
+									$data['graphid'],
+									$data['name'],
+									$data['width'],
+									$data['height'],
+									$data['yaxistype'],
+									$data['yaxismin'],
+									$data['yaxismax'],
+									$data['show_work_period'],
+									$data['show_triggers'],
+									$data['graphtype'],
+									$data['show_legend'],
+									$data['show_3d'],
+									$data['percent_left'],
+									$data['percent_right'],
+									$data['items'],
+									$graph['templateid']);
 						}
 						else{ /* missed */
 							// continue [add_group]
@@ -740,36 +691,25 @@
 							info('Graph ['.$data['name'].'] skipped - user rule');
 							break; // case
 						}
-
-						$data['graphid'] = add_graph(
-							$data['name'],
-							$data['width'],
-							$data['height'],
-							$data['yaxistype'],
-							$data['yaxismin'],
-							$data['yaxismax'],
-							$data['show_work_period'],
-							$data['show_triggers'],
-							$data['graphtype'],
-							$data['show_legend'],
-							$data['show_3d'],
-							$data['percent_left'],
-							$data['percent_right']
-							);
+						
+						$data['graphid'] = add_graph_with_items(
+												$data['name'],
+												$data['width'],
+												$data['height'],
+												$data['yaxistype'],
+												$data['yaxismin'],
+												$data['yaxismax'],
+												$data['show_work_period'],
+												$data['show_triggers'],
+												$data['graphtype'],
+												$data['show_legend'],
+												$data['show_3d'],
+												$data['percent_left'],
+												$data['percent_right'],
+												$data['items']
+											);
 					}
 
-					foreach($data['items'] as $item){
-						add_item_to_graph(
-							$data['graphid'],
-							$item['itemid'],
-							$item['color'],
-							$item['drawtype'],
-							$item['sortorder'],
-							$item['yaxisside'],
-							$item['calc_fnc'],
-							$item['type'],
-							$item['periods_cnt']);
-					}
 					break; // case
 				case XML_TAG_GRAPH_ELEMENT:
 					if(!isset($this->data[XML_TAG_GRAPH]))
@@ -797,10 +737,7 @@
 					if(!isset($data['type']))		$data['type']		= 0;
 					if(!isset($data['periods_cnt']))	$data['periods_cnt']	= 5;
 
-					if(!($item = DBfetch(DBselect('select i.itemid from items i,hosts h'.
-						' where h.hostid=i.hostid and i.key_='.zbx_dbstr($data['key']).
-						' and h.host='.zbx_dbstr($data['host'])))))
-					{
+					if(!$item = get_item_by_key($data['key'], $data['host'])){
 						$this->data[XML_TAG_GRAPH]['error'] = true;
 
 						error('Missed item ['.$data['key'].'] for host ['.$data['host'].']');
@@ -868,7 +805,7 @@
 			$this->sub_node		= null;
 			$this->data		= null;
 
-			return true;
+			return $this->root;
 		}
 
 		function SetRules($host, $template, $item, $trigger, $graph){
