@@ -66,7 +66,7 @@
 	 */
 	function item_value_type2str($value_type){
 		switch($value_type){
-			case ITEM_VALUE_TYPE_UINT64:	$value_type = S_NUMERIC_UINT64;		break;
+			case ITEM_VALUE_TYPE_UINT64:	$value_type = S_NUMERIC_UNSIGNED;		break;
 			case ITEM_VALUE_TYPE_FLOAT:	$value_type = S_NUMERIC_FLOAT;		break;
 			case ITEM_VALUE_TYPE_STR:	$value_type = S_CHARACTER;		break;
 			case ITEM_VALUE_TYPE_LOG:	$value_type = S_LOG;			break;
@@ -123,14 +123,20 @@
 	}
 	# Update Item definition for selected group
 
-	function	update_item_in_group($groupid,$itemid,$description,$key,$hostid,$delay,$history,$status,$type,$snmp_community,$snmp_oid,$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,$snmpv3_securityname,$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,$formula,$trends,$logtimefmt,$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications)
-	{
-		$sql="select i.itemid,i.hostid from hosts_groups hg,items i where hg.groupid=$groupid and i.key_=".zbx_dbstr($key)." and hg.hostid=i.hostid";
+	function update_item_in_group($groupid,$itemid,$item){
+/*		$description,$key,$hostid,$delay,$history,$status,$type,$snmp_community,$snmp_oid,$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,$snmpv3_securityname,$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,$formula,$trends,$logtimefmt,$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications)
+//*/
+		$sql='SELECT i.itemid,i.hostid '.
+				' FROM hosts_groups hg,items i '.
+				' WHERE hg.groupid='.$groupid.
+					' and i.key_='.zbx_dbstr($item['key_']).
+					' and hg.hostid=i.hostid';
 		$result=DBexecute($sql);
 		while($row=DBfetch($result)){
-			update_item($row["itemid"],$description,$key,$row["hostid"],$delay,$history,$status,$type,$snmp_community,$snmp_oid,$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,$snmpv3_securityname,$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,$formula,$trends,$logtimefmt,$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications);
+			$item['hostid'] = $row['hostid'];
+			update_item($row['itemid'],$item);
 		}
-	return 1;
+	return true;
 	}
 
 	# Delete Item definition from selected group
@@ -162,15 +168,16 @@
 
 	# Add Item definition to selected group
 
-	function	add_item_to_group($groupid,$description,$key,$hostid,$delay,$history,$status,$type,$snmp_community,$snmp_oid,$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,$snmpv3_securityname,$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,$formula,$trends,$logtimefmt,$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications)
-	{
-		$sql="select hostid from hosts_groups where groupid=$groupid";
+	function	add_item_to_group($groupid,$item){
+/*	$description,$key,$hostid,$delay,$history,$status,$type,$snmp_community,$snmp_oid,$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,$snmpv3_securityname,$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,$formula,$trends,$logtimefmt,$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications)
+//*/
+		$sql='SELECT hostid FROM hosts_groups WHERE groupid='.$groupid;
 		$result=DBexecute($sql);
-		while($row=DBfetch($result))
-		{
-			add_item($description,$key,$row["hostid"],$delay,$history,$status,$type,$snmp_community,$snmp_oid,$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,$snmpv3_securityname,$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,$formula,$trends,$logtimefmt,$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications);
+		while($row=DBfetch($result)){
+			$item['hostid'] = $row['hostid'];
+			add_item($item);
 		}
-		return 1;
+	return true;
 	}
 
 	/******************************************************************************
@@ -178,59 +185,94 @@
 	 * Comments: !!! Don't forget sync code with C !!!                            *
 	 *                                                                            *
 	 ******************************************************************************/
-	function	add_item(
-		$description,$key,$hostid,$delay,$history,$status,$type,$snmp_community,$snmp_oid,
-		$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,$snmpv3_securityname,
-		$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,$formula,$trends,$logtimefmt,
-		$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications,$templateid=0)
-	{
-		$host=get_host_by_hostid($hostid);
+	function add_item($item){
+/*
+		$item = array('description','key','hostid','delay','history','status','type',
+		'snmp_community','snmp_oid','value_type','trapper_hosts','snmp_port','units','multiplier','delta',
+		'snmpv3_securityname','snmpv3_securitylevel','snmpv3_authpassphrase','snmpv3_privpassphrase',
+		'formula','trends','logtimefmt','valuemapid','delay_flex','params','ipmi_sensor','applications','templateid');
+//*/
 
-		if(($i = array_search(0,$applications)) !== FALSE)
-			unset($applications[$i]);
+		$item_db_fields = array(
+				'description'	=> null,
+				'key_'			=> null,
+				'hostid'		=> null,
+				'delay'			=> 60,
+				'history'		=> 7,
+				'status'		=> ITEM_STATUS_ACTIVE,
+				'type'			=> ITEM_TYPE_ZABBIX,
+				'snmp_community'=> '',
+				'snmp_oid'		=> '',
+				'value_type'	=> ITEM_VALUE_TYPE_STR,
+				'trapper_hosts'	=> 'localhost',
+				'snmp_port'		=> 161,
+				'units'			=> '',
+				'multiplier'	=> 0,
+				'delta'			=> 0,
+				'snmpv3_securityname'	=> '',
+				'snmpv3_securitylevel'	=> 0,
+				'snmpv3_authpassphrase'	=> '',
+				'snmpv3_privpassphrase'	=> '',
+				'formula'			=> 0,
+				'trends'			=> 365,
+				'logtimefmt'		=> '',
+				'valuemapid'		=> 0,
+				'delay_flex'		=> '',
+				'params'			=> '',
+				'ipmi_sensor'		=> '',
+				'applications'		=> array(),
+				'templateid'		=> 0);
+		
+		if(!check_db_fields($item_db_fields, $item)){
+			error('Incorrect arguments pasted to function [add_item]');
+			return false;
+		}
+		
+		$host=get_host_by_hostid($item['hostid']);
 
-		if( !eregi('^'.ZBX_EREG_ITEM_KEY_FORMAT.'$', $key) ){
+		if(($i = array_search(0,$item['applications'])) !== FALSE)
+			unset($item['applications'][$i]);
+
+		if( !eregi('^'.ZBX_EREG_ITEM_KEY_FORMAT.'$', $item['key_']) ){
 			error("Incorrect key format 'key_name[param1,param2,...]'");
 			return false;
 		}
 
-		if($delay<1){
+		if($item['delay']<1){
 			error("Delay cannot be less than 1 second");
 			return FALSE;
 		}
 
-		if ($delay_flex != '')
-		{
-			$arr_of_delay = explode(';', $delay_flex);
+		if($item['delay_flex'] != ''){
+			$arr_of_delay = explode(';', $item['delay_flex']);
 
-			foreach($arr_of_delay as $one_delay_flex)
-			{
+			foreach($arr_of_delay as $one_delay_flex){
 				$arr = explode('/', $one_delay_flex);
-				if ($arr[0] < 1)
-				{
-					error("Delay cannot be less than 1 second ");
+				if($arr[0] < 1){
+					error('Delay cannot be less than 1 second ');
 					return FALSE;
 				}
 			}
 		}
 
-		if( ($snmp_port<1)||($snmp_port>65535)){
-			error("Invalid SNMP port");
+		if(($item['snmp_port']<1)||($item['snmp_port']>65535)){
+			error('Invalid SNMP port');
 			return FALSE;
 		}
 
-		if($value_type == ITEM_VALUE_TYPE_STR){
-			$delta=0;
+		if($item['value_type'] == ITEM_VALUE_TYPE_STR){
+			$item['delta']=0;
 		}
 
-		if( ($type == ITEM_TYPE_AGGREGATE) && ($value_type != ITEM_VALUE_TYPE_FLOAT)){
-			error("Value type must be Float for aggregate items");
+		if(($item['type'] == ITEM_TYPE_AGGREGATE) && ($item['value_type'] != ITEM_VALUE_TYPE_FLOAT)){
+			error('Value type must be Float for aggregate items');
 			return FALSE;
 		}
-		if($type == ITEM_TYPE_AGGREGATE){
+		
+		if($item['type'] == ITEM_TYPE_AGGREGATE){
 			/* grpfunc('group','key','itemfunc','numeric param') */
 //			if(eregi('^((.)*)(\(\'((.)*)\'\,\'((.)*)\'\,\'((.)*)\'\,\'([0-9]+)\'\))$', $key, $arr))
-			if(eregi('^((.)*)(\[\"((.)*)\"\,\"((.)*)\"\,\"((.)*)\"\,\"([0-9]+)\"\])$', $key, $arr)){
+			if(eregi('^((.)*)(\[\"((.)*)\"\,\"((.)*)\"\,\"((.)*)\"\,\"([0-9]+)\"\])$', $item['key_'], $arr)){
 				$g=$arr[1];
 				if(!str_in_array($g,array("grpmax","grpmin","grpsum","grpavg"))){
 					error("Group function [$g] is not one of [grpmax,grpmin,grpsum,grpavg]");
@@ -257,25 +299,19 @@
 
 		$db_item = DBfetch(DBselect('SELECT itemid,hostid '.
 								' FROM items '.
-								' WHERE hostid='.$hostid.
-									' AND key_='.zbx_dbstr($key)));
-		if($db_item && $templateid == 0){
-			error('An item with the Key ['.$key.'] already exists for host ['.$host['host'].']. The key must be unique.');
+								' WHERE hostid='.$item['hostid'].
+									' AND key_='.zbx_dbstr($item['key_'])));
+		if($db_item && $item['templateid'] == 0){
+			error('An item with the Key ['.$item['key_'].'] already exists for host ['.$host['host'].']. The key must be unique.');
 			return FALSE;
 		} 
-		else if ($db_item && $templateid != 0){
+		else if ($db_item && $item['templateid'] != 0){
+			$item['hostid'] = $db_item['hostid'];
+			$item['applications'] = get_same_applications_for_host($item['applications'], $db_item['hostid']);
 
-			$result = update_item(
-				$db_item['itemid'], $description, $key, $db_item['hostid'],
-				$delay, $history, $status, $type, $snmp_community, $snmp_oid,
-				$value_type, $trapper_hosts, $snmp_port, $units, $multiplier,
-				$delta, $snmpv3_securityname, $snmpv3_securitylevel,
-				$snmpv3_authpassphrase, $snmpv3_privpassphrase, $formula,
-				$trends, $logtimefmt, $valuemapid, $delay_flex, $params,$ipmi_sensor,
-				get_same_applications_for_host($applications, $db_item['hostid']),
-				$templateid);
+			$result = update_item($db_item['itemid'], $item);
 
-			return $result;
+		return $result;
 		}
 
 		// first add mother item
@@ -287,44 +323,43 @@
 					'delta,snmpv3_securityname,snmpv3_securitylevel,snmpv3_authpassphrase,'.
 					'snmpv3_privpassphrase,formula,trends,logtimefmt,valuemapid,'.
 					'delay_flex,params,ipmi_sensor,templateid)'.
-			' VALUES ('.$itemid.','.zbx_dbstr($description).','.zbx_dbstr($key).','.$hostid.','.$delay.','.$history.',0,'.$status.','.$type.','.
-					zbx_dbstr($snmp_community).','.zbx_dbstr($snmp_oid).','.$value_type.','.zbx_dbstr($trapper_hosts).','.
-					$snmp_port.','.zbx_dbstr($units).','.$multiplier.','.
-					$delta.','.zbx_dbstr($snmpv3_securityname).','.$snmpv3_securitylevel.','.zbx_dbstr($snmpv3_authpassphrase).','.
-					zbx_dbstr($snmpv3_privpassphrase).','.zbx_dbstr($formula).','.$trends.','.zbx_dbstr($logtimefmt).','.$valuemapid.','.
-					zbx_dbstr($delay_flex).','.zbx_dbstr($params).','.zbx_dbstr($ipmi_sensor).','.$templateid.')'
+			' VALUES ('.$itemid.','.zbx_dbstr($item['description']).','.zbx_dbstr($item['key_']).','.$item['hostid'].','.
+						$item['delay'].','.$item['history'].',0,'.$item['status'].','.$item['type'].','.
+						zbx_dbstr($item['snmp_community']).','.zbx_dbstr($item['snmp_oid']).','.$item['value_type'].','.
+						zbx_dbstr($item['trapper_hosts']).','.$item['snmp_port'].','.zbx_dbstr($item['units']).','.$item['multiplier'].','.
+						$item['delta'].','.zbx_dbstr($item['snmpv3_securityname']).','.$item['snmpv3_securitylevel'].','.
+						zbx_dbstr($item['snmpv3_authpassphrase']).','.zbx_dbstr($item['snmpv3_privpassphrase']).','.
+						zbx_dbstr($item['formula']).','.$item['trends'].','.zbx_dbstr($item['logtimefmt']).','.$item['valuemapid'].','.
+						zbx_dbstr($item['delay_flex']).','.zbx_dbstr($item['params']).','.zbx_dbstr($item['ipmi_sensor']).','.$item['templateid'].')'
 			);
 
 		if(!$result)
 			return $result;
 
-		foreach($applications as $appid){
+		foreach($item['applications'] as $key => $appid){
 			$itemappid=get_dbid('items_applications','itemappid');
 			DBexecute('INSERT INTO items_applications (itemappid,itemid,applicationid) VALUES('.$itemappid.','.$itemid.','.$appid.')');
 		}
 
-		info('Added new item '.$host['host'].':'.$key);
+		info('Added new item '.$host['host'].':'.$item['key_']);
 
 // add items to child hosts
 
 		$db_hosts = get_hosts_by_templateid($host['hostid']);
 		while($db_host = DBfetch($db_hosts)){
 // recursion
-			$result = add_item($description, $key, $db_host["hostid"],
-				$delay, $history, $status, $type, $snmp_community, $snmp_oid,
-				$value_type, $trapper_hosts, $snmp_port, $units, $multiplier,
-				$delta, $snmpv3_securityname, $snmpv3_securitylevel,
-				$snmpv3_authpassphrase, $snmpv3_privpassphrase, $formula,
-				$trends, $logtimefmt, $valuemapid,$delay_flex, $params, $ipmi_sensor,
-				get_same_applications_for_host($applications, $db_host["hostid"]),
-				$itemid);
-			if(!$result)
-				break;
+			$item['hostid'] = $db_host['hostid'];
+			$item['applications'] = get_same_applications_for_host($item['applications'], $db_host['hostid']);
+			$item['templateid'] = $itemid;
+			
+			$result = add_item($item);
+			if(!$result) break;
 		}
+		
 		if($result)
 			return $itemid;
 
-		if($templateid == 0){
+		if($item['templateid'] == 0){
 			delete_item($itemid);
 		}
 		
@@ -387,119 +422,140 @@
 	 * Comments: !!! Don't forget sync code with C !!!                            *
 	 *                                                                            *
 	 ******************************************************************************/
-	function	update_item($itemid,$description,$key,$hostid,$delay,$history,$status,$type,
-		$snmp_community,$snmp_oid,$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,
-		$snmpv3_securityname,$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,
-		$formula,$trends,$logtimefmt,$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications,$templateid=0)
-	{
-		$host = get_host_by_hostid($hostid);
+	function update_item($itemid,$item){
+/*
+		$item = array('description','key','hostid','delay','history','status','type',
+		'snmp_community','snmp_oid','value_type','trapper_hosts','snmp_port','units','multiplier','delta',
+		'snmpv3_securityname','snmpv3_securitylevel','snmpv3_authpassphrase','snmpv3_privpassphrase',
+		'formula','trends','logtimefmt','valuemapid','delay_flex','params','ipmi_sensor','applications','templateid');
+//*/
+		$item_in_params = $item;
+		
+		$item_data = get_item_by_itemid_limited($itemid);
+		$item_data['applications'] = get_applications_by_itemid($itemid);
+		
+		if(!check_db_fields($item_data, $item)){
+			error('Incorrect arguments pasted to function [update_item]');
+			return false;
+		}
+		
+		$host = get_host_by_hostid($item['hostid']);
 
-		if(($i = array_search(0,$applications)) !== FALSE)
-			unset($applications[$i]);
+		if(($i = array_search(0,$item['applications'])) !== FALSE)
+			unset($item['applications'][$i]);
 
-		if( !eregi('^'.ZBX_EREG_ITEM_KEY_FORMAT.'$', $key) ){
+		if( !eregi('^'.ZBX_EREG_ITEM_KEY_FORMAT.'$', $item['key_']) ){
 			error("Incorrect key format 'key_name[param1,param2,...]'");
 			return false;
 		}
 
-		if($delay<1){
-			error("Delay cannot be less than 1 second");
+		if($item['delay']<1){
+			error('Delay cannot be less than 1 second');
 			return FALSE;
 		}
 
-		if ($delay_flex != '')
-		{
-			$arr_of_delay = explode(';', $delay_flex);
+		if(!zbx_empty($item['delay_flex'])){
+			$arr_of_delay = explode(';', $item['delay_flex']);
 
-			foreach($arr_of_delay as $one_delay_flex)
-			{
+			foreach($arr_of_delay as $one_delay_flex){
 				$arr = explode('/', $one_delay_flex);
-				if ($arr[0] < 1)
-				{
-					error("Delay cannot be less than 1 second ");
+				if ($arr[0] < 1){
+					error('Delay cannot be less than 1 second ');
 					return FALSE;
 				}
 			}
 		}
 
-		if( ($snmp_port<1)||($snmp_port>65535)){
-			error("Invalid SNMP port");
+		if(($item['snmp_port']<1)||($item['snmp_port']>65535)){
+			error('Invalid SNMP port');
 			return FALSE;
 		}
 
-		if($value_type == ITEM_VALUE_TYPE_STR){
-			$delta=0;
+		if($item['value_type'] == ITEM_VALUE_TYPE_STR){
+			$item['delta']=0;
 		}
 
-		$db_item = DBfetch(DBselect("select itemid from items".
-			" where hostid=$hostid and itemid<>$itemid and key_=".zbx_dbstr($key)));
-		if($db_item && $templateid == 0){
-			error("An item with the same Key already exists for host ".$host["host"].".".
-				" The key must be unique.");
+		$db_item = DBfetch(DBselect('SELECT itemid FROM items WHERE hostid='.$item['hostid'].' and itemid<>'.$itemid.' and key_='.zbx_dbstr($item['key_'])));
+		if($db_item && $item['templateid'] == 0){
+			error('An item with the same Key already exists for host '.$host['host'].'. The key must be unique.');
 			return FALSE;
 		}
 
 		 // first update child items
-		$db_tmp_items = DBselect("select itemid, hostid from items where templateid=$itemid");
+		$db_tmp_items = DBselect('SELECT itemid, hostid FROM items WHERE templateid='.$itemid);
 		while($db_tmp_item = DBfetch($db_tmp_items)){
-		// recursion
-			$result = update_item(
-				$db_tmp_item["itemid"], $description, $key, $db_tmp_item["hostid"],
-				$delay, $history, $status, $type, $snmp_community, $snmp_oid,
-				$value_type, $trapper_hosts, $snmp_port, $units, $multiplier,
-				$delta, $snmpv3_securityname, $snmpv3_securitylevel,
-				$snmpv3_authpassphrase, $snmpv3_privpassphrase, $formula,
-				$trends, $logtimefmt, $valuemapid,$delay_flex, $params, $ipmi_sensor,
-				get_same_applications_for_host($applications, $db_tmp_item["hostid"]),
-				$itemid);
-
+			$child_item_params = $item_in_params;
+			
+			$child_item_params['hostid'] = $db_tmp_item['hostid'];
+			$child_item_params['templateid'] = $itemid;
+			$child_item_params['applications'] = get_same_applications_for_host($item['applications'], $db_tmp_item['hostid']);
+			
+			if(!check_db_fields($db_tmp_item, $child_item_params)){
+				error('Incorrect arguments pasted to function [update_item]');
+				return false;
+			}
+			
+			$result = update_item($db_tmp_item['itemid'], $child_item_params);		// recursion!!!
 
 			if(!$result)
 				return $result;
 		}
 
-		if($db_item && $templateid != 0){
-			$result = delete_item($db_item["itemid"]);
+		if($db_item && $item['templateid'] != 0){
+			$result = delete_item($db_item['itemid']);
 			if(!$result) {
-				error("Can't update item '".$host["host"].":$key'");
+				error("Can't update item '".$host["host"].':'.$item['key_']."'");
 				return FALSE;
 			}
 		}
 
-		DBexecute("update items set lastlogsize=0 where itemid=$itemid and key_<>".zbx_dbstr($key));
+		DBexecute('UPDATE items SET lastlogsize=0 WHERE itemid='.$itemid.' AND key_<>'.zbx_dbstr($item['key_']));
 
 		if(isset($_REQUEST['applications_visible'])){	
-			$result = DBexecute("delete from items_applications where itemid=$itemid");
-			foreach($applications as $appid){
-				$itemappid=get_dbid("items_applications","itemappid");
-				DBexecute("insert into items_applications (itemappid,itemid,applicationid) values($itemappid,".$itemid.",".$appid.")");
+			$result = DBexecute('DELETE FROM items_applications WHERE itemid='.$itemid);
+			foreach($item['applications'] as $appid){
+				$itemappid=get_dbid('items_applications','itemappid');
+				DBexecute('INSERT INTO items_applications (itemappid,itemid,applicationid) VALUES ('.$itemappid.','.$itemid.','.$appid.')');
 			}
 		}
 
-		if ($status == ITEM_STATUS_ACTIVE)
-			DBexecute("update items set error='' where itemid=$itemid and status<>$status");
+		if($item['status'] == ITEM_STATUS_ACTIVE)
+			DBexecute("UPDATE items SET error='' WHERE itemid=".$itemid.' and status<>'.$item['status']);
 
 		$result=DBexecute(
 			'UPDATE items '.
-			' SET description='.zbx_dbstr($description).',key_='.zbx_dbstr($key).','.
-				'hostid='.$hostid.',delay='.$delay.',history='.$history.',type='.$type.','.
-				'snmp_community='.zbx_dbstr($snmp_community).",snmp_oid=".zbx_dbstr($snmp_oid).','.
-				'value_type='.$value_type.',trapper_hosts='.zbx_dbstr($trapper_hosts).','.
-				'snmp_port='.$snmp_port.',units='.zbx_dbstr($units).',multiplier='.$multiplier.',delta='.$delta.','.
-				'snmpv3_securityname='.zbx_dbstr($snmpv3_securityname).','.
-				'snmpv3_securitylevel='.$snmpv3_securitylevel.','.
-				'snmpv3_authpassphrase='.zbx_dbstr($snmpv3_authpassphrase).','.
-				'snmpv3_privpassphrase='.zbx_dbstr($snmpv3_privpassphrase).','.
-				'formula='.zbx_dbstr($formula).",trends=$trends,logtimefmt=".zbx_dbstr($logtimefmt).','.
-				'valuemapid='.$valuemapid.',delay_flex='.zbx_dbstr($delay_flex).',params='.zbx_dbstr($params).','.
-				'ipmi_sensor='.zbx_dbstr($ipmi_sensor).','.
-				'templateid='.$templateid.
+			' SET description='.zbx_dbstr($item['description']).','.
+				'key_='.zbx_dbstr($item['key_']).','.
+				'hostid='.$item['hostid'].','.
+				'delay='.$item['delay'].','.
+				'history='.$item['history'].','.
+				'type='.$item['type'].','.
+				'snmp_community='.zbx_dbstr($item['snmp_community']).','.
+				'snmp_oid='.zbx_dbstr($item['snmp_oid']).','.
+				'value_type='.$item['value_type'].','.
+				'trapper_hosts='.zbx_dbstr($item['trapper_hosts']).','.
+				'snmp_port='.$item['snmp_port'].','.
+				'units='.zbx_dbstr($item['units']).','.
+				'multiplier='.$item['multiplier'].','.
+				'delta='.$item['delta'].','.
+				'snmpv3_securityname='.zbx_dbstr($item['snmpv3_securityname']).','.
+				'snmpv3_securitylevel='.$item['snmpv3_securitylevel'].','.
+				'snmpv3_authpassphrase='.zbx_dbstr($item['snmpv3_authpassphrase']).','.
+				'snmpv3_privpassphrase='.zbx_dbstr($item['snmpv3_privpassphrase']).','.
+				'formula='.zbx_dbstr($item['formula']).','.
+				'trends='.$item['trends'].','.
+				'logtimefmt='.zbx_dbstr($item['logtimefmt']).','.
+				'valuemapid='.$item['valuemapid'].','.
+				'delay_flex='.zbx_dbstr($item['delay_flex']).','.
+				'params='.zbx_dbstr($item['params']).','.
+				'ipmi_sensor='.zbx_dbstr($item['ipmi_sensor']).','.
+				'templateid='.$item['templateid'].
 			' WHERE itemid='.$itemid);
 
-		update_item_status($itemid, $status);
+		update_item_status($itemid, $item['status']);
 
 		if($result){
-			info("Item '".$host["host"].":$key' updated");
+			info("Item '".$host['host'].':'.$item['key_']."' updated");
 		}
 		
 	return $result;
@@ -512,71 +568,60 @@
 	 *     Update specified fields of item
 	 *
 	 * Author:
-	 *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
+	 *     Aly
 	 *
 	 * Comments:
 	 *
 	 */
-	function	smart_update_item($itemid,$description,$key,$hostid,$delay,$history,$status,$type,
-		$snmp_community,$snmp_oid,$value_type,$trapper_hosts,$snmp_port,$units,$multiplier,$delta,
-		$snmpv3_securityname,$snmpv3_securitylevel,$snmpv3_authpassphrase,$snmpv3_privpassphrase,
-		$formula,$trends,$logtimefmt,$valuemapid,$delay_flex,$params,$ipmi_sensor,$applications)
-	{
+	function smart_update_item($itemid, $item=array()){		
+		$item_data = get_item_by_itemid_limited($itemid);
+		
 		$restore_rules= array(
-					"description"		=> array(),
-					"key"			=> array( 'db_varname' => 'key_' ),
-					"hostid"		=> array(),
-					"delay"			=> array('template' => 1),
-					"history"		=> array('template' => 1 , 'httptest' => 1),
-					"status"		=> array('template' => 1 , 'httptest' => 1),
-					"type"			=> array(),
-					"snmp_community"	=> array(),
-					"snmp_oid"		=> array(),
-					"value_type"		=> array(),
-					"trapper_hosts"		=> array(),
-					"snmp_port"		=> array(),
-					"units"			=> array(),
-					"multiplier"		=> array(),
-					"delta"		=> array('template' => 1 , 'httptest' => 1),
-					"snmpv3_securityname"	=> array(),
-					"snmpv3_securitylevel"	=> array(),
-					"snmpv3_authpassphrase"	=> array(),
-					"snmpv3_privpassphrase"	=> array(),
-					"formula"		=> array(),
-					"trends"		=> array('template' => 1 , 'httptest' => 1),
-					"logtimefmt"		=> array(),
-					"valuemapid"		=> array('httptest' => 1),
-					"params"		=> array(),
-					"delay_flex"		=> array(),
-					"ipmi_sensor"		=> array());
-
-		$item_data = get_item_by_itemid($itemid);
+					'description'	=> array(),
+					'key_'			=> array(),
+					'hostid'		=> array(),
+					'delay'			=> array('template' => 1),
+					'history'		=> array('template' => 1 , 'httptest' => 1),
+					'status'		=> array('template' => 1 , 'httptest' => 1),
+					'type'			=> array(),
+					'snmp_community'=> array(),
+					'snmp_oid'		=> array(),
+					'value_type'	=> array(),
+					'trapper_hosts'	=> array(),
+					'snmp_port'		=> array(),
+					'units'			=> array(),
+					'multiplier'	=> array(),
+					'delta'			=> array('template' => 1 , 'httptest' => 1),
+					'snmpv3_securityname'	=> array(),
+					'snmpv3_securitylevel'	=> array(),
+					'snmpv3_authpassphrase'	=> array(),
+					'snmpv3_privpassphrase'	=> array(),
+					'formula'		=> array(),
+					'trends'		=> array('template' => 1 , 'httptest' => 1),
+					'logtimefmt'	=> array(),
+					'valuemapid'	=> array('httptest' => 1),
+					'params'		=> array(),
+					'delay_flex'	=> array(),
+					'ipmi_sensor'	=> array());
 
 		foreach($restore_rules as $var_name => $info){
-			if (!isset($info['db_varname'])) $info['db_varname'] = $var_name;
-
-			if ($item_data['type'] == ITEM_TYPE_HTTPTEST && !isset($info['httptest']))
-				$$var_name = $item_data[$info['db_varname']];
-			if (0 !=$item_data['templateid'] && !isset($info['template']))
-				$$var_name = $item_data[$info['db_varname']];
-			if(!isset($$var_name))
-				$$var_name = $item_data[$info['db_varname']];
+			if(($item_data['type'] == ITEM_TYPE_HTTPTEST) && !isset($info['httptest'])){
+				$item[$var_name] = $item_data[$var_name];
+			}
+				
+			if(!isset($info['template']) && (0 != $item_data['templateid'])){
+				$item[$var_name] = $item_data[$var_name];
+			}
+				
+			if(!array_key_exists($var_name,$item)){
+				$item[$var_name] = $item_data[$var_name];
+			}
 		}
 
 		if($item_data['type'] == ITEM_TYPE_HTTPTEST)
-			$applications = get_applications_by_itemid($itemid);
+			$item['applications'] = get_applications_by_itemid($itemid);
 
-		return update_item($itemid,
-			$description,$key,$hostid,$delay,
-			$history,$status,$type,
-			$snmp_community,$snmp_oid,$value_type,
-			$trapper_hosts,$snmp_port,$units,
-			$multiplier,$delta,$snmpv3_securityname,
-			$snmpv3_securitylevel,$snmpv3_authpassphrase,
-			$snmpv3_privpassphrase,$formula,$trends,
-			$logtimefmt,$valuemapid,$delay_flex,$params,
-			$ipmi_sensor,$applications,
-			$item_data['templateid']);
+	return update_item($itemid,$item);
 	}
 
 	/*
@@ -629,37 +674,13 @@
 	 *
 	 */
 	function copy_item_to_host($itemid, $hostid, $copy_mode = false){
-		$db_tmp_item = get_item_by_itemid($itemid);
+		$db_tmp_item = get_item_by_itemid_limited($itemid);
 
-		$result = add_item(
-			$db_tmp_item["description"],
-			$db_tmp_item["key_"],
-			$hostid,
-			$db_tmp_item["delay"],
-			$db_tmp_item["history"],
-			$db_tmp_item["status"],
-			$db_tmp_item["type"],
-			$db_tmp_item["snmp_community"],
-			$db_tmp_item["snmp_oid"],
-			$db_tmp_item["value_type"],
-			$db_tmp_item["trapper_hosts"],
-			$db_tmp_item["snmp_port"],
-			$db_tmp_item["units"],
-			$db_tmp_item["multiplier"],
-			$db_tmp_item["delta"],
-			$db_tmp_item["snmpv3_securityname"],
-			$db_tmp_item["snmpv3_securitylevel"],
-			$db_tmp_item["snmpv3_authpassphrase"],
-			$db_tmp_item["snmpv3_privpassphrase"],
-			$db_tmp_item["formula"],
-			$db_tmp_item["trends"],
-			$db_tmp_item["logtimefmt"],
-			$db_tmp_item["valuemapid"],
-			$db_tmp_item["delay_flex"],
-			$db_tmp_item["params"],
-			$db_tmp_item["ipmi_sensor"],
-			get_same_applications_for_host(get_applications_by_itemid($db_tmp_item["itemid"]),$hostid),
-			$copy_mode ? 0 : $db_tmp_item["itemid"]);
+		$db_tmp_item['hostid'] = $hostid;
+		$db_tmp_item['applications'] = get_same_applications_for_host(get_applications_by_itemid($db_tmp_item['itemid']),$hostid);
+		$db_tmp_item['templateid'] = $copy_mode?0:$db_tmp_item['itemid'];
+		
+		$result = add_item($db_tmp_item);
 			
 	return $result;
 	}
@@ -688,38 +709,12 @@
 		}
 
 		$db_tmp_items = get_items_by_hostid($templateid);
-
-		
 		while($db_tmp_item = DBfetch($db_tmp_items)){
-			add_item(
-				$db_tmp_item["description"],
-				$db_tmp_item["key_"],
-				$hostid,
-				$db_tmp_item["delay"],
-				$db_tmp_item["history"],
-				$db_tmp_item["status"],
-				$db_tmp_item["type"],
-				$db_tmp_item["snmp_community"],
-				$db_tmp_item["snmp_oid"],
-				$db_tmp_item["value_type"],
-				$db_tmp_item["trapper_hosts"],
-				$db_tmp_item["snmp_port"],
-				$db_tmp_item["units"],
-				$db_tmp_item["multiplier"],
-				$db_tmp_item["delta"],
-				$db_tmp_item["snmpv3_securityname"],
-				$db_tmp_item["snmpv3_securitylevel"],
-				$db_tmp_item["snmpv3_authpassphrase"],
-				$db_tmp_item["snmpv3_privpassphrase"],
-				$db_tmp_item["formula"],
-				$db_tmp_item["trends"],
-				$db_tmp_item["logtimefmt"],
-				$db_tmp_item["valuemapid"],
-				$db_tmp_item["delay_flex"],
-				$db_tmp_item["params"],
-				$db_tmp_item["ipmi_sensor"],
-				get_same_applications_for_host(get_applications_by_itemid($db_tmp_item["itemid"]),$hostid),
-				$copy_mode ? 0 : $db_tmp_item["itemid"]);
+			$db_tmp_item['hostid'] = $hostid;
+			$db_tmp_item['applications'] = get_same_applications_for_host(get_applications_by_itemid($db_tmp_item['itemid']),$hostid);
+			$db_tmp_item['templateid'] = $copy_mode?0:$db_tmp_item['itemid'];
+
+			add_item($db_tmp_item);
 		}
 	}
 
@@ -758,6 +753,25 @@
 		return update_item_status($itemids, ITEM_STATUS_DISABLED);
 	}
 
+	function get_item_by_key($key,$host=''){
+		$item = false;
+
+		$sql_from = '';
+		$sql_where = '';
+		if(!empty($host)){
+			$sql_from = ',hosts h ';
+			$sql_where = ' AND h.host='.zbx_dbstr($host).' AND i.hostid=h.hostid ';
+		}
+		$sql = 'SELECT DISTINCT i.* '.
+			' FROM items i '.$sql_from.
+			' WHERE i.key_='.zbx_dbstr($key).
+				$sql_where;
+		if($item = DBfetch(DBselect($sql))){
+			$item = $item;
+		}
+	return $item;
+	}
+
 	function get_items_by_hostid($hostids){
 		zbx_value2array($hostids);
 	return DBselect('SELECT * FROM items WHERE '.DBcondition('hostid',$hostids));
@@ -772,6 +786,21 @@
 	return	FALSE;
 	}
 	
+	function get_item_by_itemid_limited($itemid){
+		$sql = 'SELECT itemid,description,key_,hostid,delay,history,status,type,'.
+					'snmp_community,snmp_oid,value_type,trapper_hosts,snmp_port,units,multiplier,delta,'.
+					'snmpv3_securityname,snmpv3_securitylevel,snmpv3_authpassphrase,snmpv3_privpassphrase,'.
+					'formula,trends,logtimefmt,valuemapid,delay_flex,params,ipmi_sensor,templateid '.
+			' FROM items '.
+			' WHERE itemid='.$itemid;
+		$row = DBfetch(DBselect($sql)); 
+		if($row){
+			return	$row;
+		}
+		error('No item with itemid=['.$itemid.']');
+	return	FALSE;
+	}
+	
 /*
  * Function: get_same_items_for_host
  *
@@ -949,52 +978,41 @@
 	}
 	
 	function get_realhost_by_itemid($itemid){
-		$itme = get_item_by_itemid($itemid);
-		if($itme["templateid"] <> 0)
-			return get_realhost_by_itemid($itme["templateid"]);
+		$item = get_item_by_itemid($itemid);
+		if($item['templateid'] <> 0)
+			return get_realhost_by_itemid($item['templateid']);
 
 	return get_host_by_itemid($itemid);
 	}
 
-	/*
-	 * Function: get_items_data_overview
-	 *
-	 * Description:
-	 *     Retrive overview table object for items
-	 *
-	 * Author:
-	 *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
-	 *
-	 * Comments:
-	 *
-	 */
-	function get_items_data_overview($groupid,$view_style=null){
-		global	$USER_DETAILS;
-		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
+/*
+ * Function: get_items_data_overview
+ *
+ * Description:
+ *     Retrive overview table object for items
+ *
+ * Author:
+ *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
+ *
+ * Comments:
+ *
+ */
+	function get_items_data_overview($hostids,$view_style=null){
 
 		if(is_null($view_style)) $view_style = get_profile('web.overview.view.style',STYLE_TOP);
 		
 		$table = new CTableInfo(S_NO_ITEMS_DEFINED);
 
-		$sql_from = '';
-		$sql_where = '';
-		if($groupid > 0){
-			$sql_from = ', hosts_groups hg ';
-			$sql_where = ' AND hg.groupid='.$groupid.' AND hg.hostid=h.hostid ';							
-		} 
-
 COpt::profiling_start('prepare data');
 		$result = DBselect('SELECT DISTINCT h.hostid, h.host,i.itemid, i.key_, i.value_type, i.lastvalue, i.units, '.
 				' i.description, t.priority, i.valuemapid, t.value as tr_value, t.triggerid '.
 			' FROM hosts h, items i '.
 				' LEFT JOIN functions f on f.itemid=i.itemid '.
 				' LEFT JOIN triggers t on t.triggerid=f.triggerid '.
-				$sql_from.
-			' WHERE '.DBcondition('h.hostid',$available_hosts).
+			' WHERE '.DBcondition('h.hostid',$hostids).
 				' AND h.status='.HOST_STATUS_MONITORED.
 				' AND h.hostid=i.hostid '.
 				' AND i.status='.ITEM_STATUS_ACTIVE.
-				$sql_where.
 			' ORDER BY i.description,i.itemid');
 
 		unset($items);
@@ -1347,4 +1365,109 @@ COpt::profiling_stop('prepare table');
 		}
 		return $value;
 	}
+
+	/*
+	 *
+	 * Function: check_time_period
+	 *
+	 * Purpose: check if current time is within given period
+	 *
+	 * Parameters: period - time period in format [d1-d2,hh:mm-hh:mm]*
+	 *             now    - timestamp for comporation
+	 *
+	 * Return value: 0 - out of period, 1 - within the period
+	 *
+	 * Author: Alexander Vladishev
+	 *
+	 * Comments:
+	 *        !!! Don't forget sync code with PHP !!!
+	 *
+	 */
+	function	check_time_period($period, $now)
+	{
+		$tm = localtime($now, TRUE);
+
+		$day = $tm['tm_wday'];
+		if (0 == $day)
+			$day = 7;
+		$min = 60 * $tm['tm_hour'] + $tm['tm_min'];
+
+		$arr_of_period = explode(';', $period);
+
+		foreach($arr_of_period as $one_period)
+		{
+			list($d1, $d2, $h1, $m1, $h2, $m2) = sscanf($one_period, "%d-%d,%d:%d-%d:%d");
+			if ($day >= $d1 && $day <= $d2 && $min >= 60 * $h1 + $m1 && $min <= 60 * $h2 + $m2)
+			{
+				return 1;
+			}
+		}
+
+		return 0;
+	}
+
+	/*
+	 * Function: calculate_item_nextcheck
+	 *
+	 * Description:
+	 *     calculate nextcheck timespamp for item
+	 *
+	 * Peremeters:
+	 *     itemid - item ID
+	 *     item_type - item type
+	 *     delay - item's refresh rate in sec
+	 *     delay_flex - item's flexible refresh rate
+	 *     now - current timestamp
+	 *
+	 * Author:
+	 *     Alexander Vladishev
+	 *
+	 * Comments:
+	 *     !!! Don't forget sync code with C !!!
+	 *
+	 */
+	function calculate_item_nextcheck($itemid, $item_type, $delay, $delay_flex, $now)
+	{
+		if (0 == $delay)
+		{
+			$delay = 30;
+/*			info('Invalid item update interval ['.$delay.'], using default [30]');*/
+		}
+
+		/* Special processing of active items to see better view in queue */
+		if ($item_type == ITEM_TYPE_ZABBIX_ACTIVE)
+		{
+			return $now + $delay;
+		}
+
+		if (!is_null($delay_flex) && $delay_flex != '')
+		{
+			$arr_of_delay = explode(';', $delay_flex);
+
+			foreach($arr_of_delay as $one_delay_flex)
+			{
+				$arr = explode('/', $one_delay_flex);
+				if (check_time_period($arr[1], $now))
+				{
+					$delay = $arr[0];
+					break;
+				}
+			}
+		}
+
+		if (0 == $delay)
+		{
+/*			info('Invalid item update interval ['.$delay.'], using default [30]');*/
+			$delay = 30;
+		}
+
+		$nextcheck = $delay * floor($now / $delay) + ($itemid % $delay);
+
+		while ($nextcheck <= $now)
+		{
+			$nextcheck += $delay;
+		}
+
+		return $nextcheck;
+	}
 ?>
