@@ -1,5 +1,5 @@
 <?php
-/* 
+/*
 ** ZABBIX
 ** Copyright (C) 2000-2005 SIA Zabbix
 **
@@ -31,7 +31,7 @@
 	'S_DISABLE_SELECTED'=>			'Disable selected',
 	'S_DELETE_SELECTED'=>			'Delete selected',
 	'S_COPY_SELECTED_TO'=>			'Copy selected to ...',
-	
+
 //	dicoveryconf.php
 	'S_HOST_IP'=>				'Host ip',
 	'S_SERVICE_TYPE'=>			'Service type',
@@ -140,7 +140,7 @@
 	'S_POST'=>				'Post',
 	'S_REQUIRED'=>				'Required',
 	'S_STEP_OF_SCENARIO'=>			'Step of scenario',
-	
+
 //	exp_imp.php
 	'S_ELEMENT'=>				'Element',
 	'S_ELEMENTS'=>				'Elements',
@@ -181,7 +181,7 @@
 	'S_INSTALLATION_UPDATE'=>		'Installation/Update',
 	'S_ZABBIX_IS_UNAVAILABLE'=>		'ZABBIX is temporary unavailable',
 	'S_REQUIRE_MB_STRING_MODULE'=>	'Require Multibyte String module to run FrontEnd',
-	
+
 //	node.php
 	'S_TIME_ZONE'=>				'Time zone',
 	'S_DO_NOT_KEEP_HISTORY_OLDER_THAN'=>	'Do not keep history older than (in days)',
@@ -198,7 +198,7 @@
 	'S_CURRENT_NODE'=>			'Current node',
 	'S_CURRENT_NODE_ONLY'=>			'Current node only',
 	'S_WITH_SUBNODES'=>			'With subnodes',
-	
+
 //	acknow.php
 	'S_NO_EVENTS_TO_ACKNOWLEDGE'=>	'No events to acknowledge',
 	'S_ACKNOWLEDGES'=>				'Acknowledges',
@@ -296,7 +296,7 @@
 	'S_RECOVERY_SUBJECT'=>					'Recovery subject',
 	'S_DEFAULT_MESSAGE'=>					'Default message',
 	'S_DEFAULT_SUBJECT'=>					'Default subject',
-	'S_MESSAGE'=>					'Message',	
+	'S_MESSAGE'=>					'Message',
 	'S_ON'=>						'ON',
 	'S_OFF'=>						'OFF',
 	'S_NO_ACTIONS_DEFINED'=>		'No actions defined',
@@ -371,7 +371,7 @@
 	'S_BOLD_LINE'=>				'Bold line',
 	'S_DOT'=>					'Dot',
 	'S_DASHED_LINE'=>			'Dashed line',
-	
+
 //	charts.php
 	'S_CUSTOM_GRAPHS'=>				'Custom graphs',
 	'S_GRAPHS_BIG'=>				'GRAPHS',
@@ -520,14 +520,14 @@
 	'S_INCORRECT_GROUP'=>			'Incorrect group',
 	'S_NOTHING_TO_DO'=>			'Nothing to do',
 	'S_ICORRECT_WORK_PERIOD'=>		'Icorrect work period',
-	
+
 //	nodes.php
 	'S_NODE'=>					'Node',
 	'S_NODES'=>					'Nodes',
 	'S_NODES_BIG'=>				'NODES',
 	'S_NEW_NODE'=>				'New node',
 	'S_NO_NODES_DEFINED'=>		'No nodes defined',
-	
+
 //  Authentication
 	'S_AUTHENTICATION'=>				'Authentication',
 	'S_AUTHENTICATION_TO_ZABBIX'=>		'Authentication to ZABBIX',
@@ -543,7 +543,7 @@
 	'S_HTTP_AUTH'=>						'HTTP Authentication',
 	'S_ZABBIX_INTERNAL_AUTH'=>			'ZABBIX Internal authentication',
 	'S_DEFAULT_AUTHENTICATION'=>		'Default authentication',
-	
+
 
 //	Latest values
 	'S_LATEST_VALUES'=>			'Latest values',
@@ -554,6 +554,7 @@
 	'S_ALL_BIG'=>					'ALL',
 	'S_MINUS_ALL_MINUS'=>			'- all -',
 	'S_MINUS_OTHER_MINUS'=>			'- other -',
+	'S_NOT_SELECTED_SMALL'=>		'not selected',
 	'S_DESCRIPTION_LARGE'=>			'DESCRIPTION',
 	'S_DESCRIPTION_SMALL'=>			'Description',
 	'S_NO_DESCRIPTION'=>			'No description',
@@ -584,6 +585,7 @@
 	'S_UP'=>				'Up',
 	'S_DOWN'=>				'Down',
 	'S_NEW_ITEM_FOR_THE_GRAPH'=>		'New item for the graph',
+	'S_UPD_ITEM_FOR_THE_GRAPH'=>		'Update item for the graph',
 	'S_SORT_ORDER_1_100'=>			'Sort order (0->100)',
 	'S_YAXIS_SIDE'=>			'Y axis side',
 	'S_LEFT'=>				'Left',
@@ -611,6 +613,8 @@
 	'S_CANNOT_UPDATE_GRAPH'=>		'Cannot update graph',
 	'S_GRAPH_DELETED'=>			'Graph deleted',
 	'S_CANNOT_DELETE_GRAPH'=>		'Cannot delete graph',
+	'S_GRAPHS_DELETED'=>			'Graphs deleted',
+	'S_CANNOT_DELETE_GRAPHS'=>		'Cannot delete graphs',
 	'S_CANNOT_ADD_GRAPH'=>			'Cannot add graph',
 	'S_ANOTHER_ITEM_SUM'=>			'Cannot add onemore item with type "Graph sum"',
 	'S_ID'=>				'Id',
@@ -630,7 +634,7 @@
 	'S_LEGEND'=>				'Legend',
 	'S_GRAPH_SUM'=>		'Graph sum',
 	'S_GRAPH_ITEM'=>			'Graph item',
-	'S_REQUIRED_ITEMS_FOR_GRAPH'=>		'Required items for graph',
+	'S_REQUIRED_ITEMS_FOR_GRAPH'=>		'Items required for graph',
 
 //	history.php
 	'S_SECONDS_SMALL'=>				'seconds',
@@ -664,7 +668,7 @@
 	'S_APPLICATION'=>			'Application',
 	'S_APPLICATIONS'=>			'Applications',
 	'S_APPLICATIONS_BIG'=>			'APPLICATIONS',
-	'S_CREATE_APPLICATION'=>		'Create application',	
+	'S_CREATE_APPLICATION'=>		'Create application',
 	'S_DELETE_SELECTED_APPLICATIONS_Q'=>	'Delete selected applications?',
 	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>'Disable items from selected applications?',
 	'S_ACTIVATE_ITEMS'=>			'Activate Items',
@@ -719,6 +723,7 @@
 	'S_DNS'=>				'DNS',
 	'S_IP'=>				'IP',
 	'S_PORT'=>				'Port',
+	'S_AGENT_PORT'=>		'Zabbix agent port',
 	'S_MONITORED'=>				'Monitored',
 	'S_NOT_MONITORED'=>			'Not monitored',
 	'S_UNREACHABLE'=>			'Unreachable',
@@ -772,12 +777,12 @@
 	'S_CREATE_PROXY'=>			'Create Proxy',
 	'S_PROXY_NAME'=>			'Proxy name',
 	'S_LASTSEEN_AGE'=>			'Last seen (age)',
-	
+
 	'S_TRANSACTION'=>			'Transaction',
 	'S_STARTED_BIG'=>			'STARTED!',
 	'S_COMMITED_BIG'=>			'COMMITED!',
 	'S_ROLLBACKED_BIG'=>		'ROLLBACKED!',
-	
+
 //	Host profiles
 	'S_HOST_PROFILE'=>			'Host profile',
 	'S_DEVICE_TYPE'=>			'Device type',
@@ -943,7 +948,7 @@
 	'S_TYPE_OF_INFORMATION'=>		'Type of information',
 	'S_STORE_VALUE'=>			'Store value',
 	'S_SHOW_VALUE'=>			'Show value',
-	'S_NUMERIC_UINT64'=>			'Numeric (integer 64bit)',
+	'S_NUMERIC_UNSIGNED'=>			'Numeric (unsigned)',
 	'S_NUMERIC_FLOAT'=>			'Numeric (float)',
 	'S_CHARACTER'=>				'Character',
 	'S_LOG'=>				'Log',
@@ -1168,8 +1173,10 @@
 	'S_TRENDS_STORED'=>			'Trends stored',
 	'S_NUMBER_OF_TRIGGERS'=>		'Number of triggers (enabled/disabled)[true/unknown/false]',
 	'S_NUMBER_OF_TRIGGERS_SHORT'=>		'Triggers (e/d)[t/u/f]',
+	'S_NUMBER_OF_TRIGGERS_TOOLTIP'=>		'Only triggers assigned to enabled hosts and depending on enabled items are counted',
 	'S_NUMBER_OF_ITEMS'=>			'Number of items (monitored/disabled/not supported)',
 	'S_NUMBER_OF_ITEMS_SHORT'=>		'Items (m/d/n)[t]',
+	'S_NUMBER_OF_ITEMS_TOOLTIP'=>	'Only items assigned to enabled hosts are counted',
 	'S_NUMBER_OF_USERS'=>			'Number of users (online)',
 	'S_NUMBER_OF_USERS_SHORT'=>		'Users (online)',
 	'S_NUMBER_OF_HOSTS'=>			'Number of hosts (monitored/not monitored/templates)',
@@ -1232,7 +1239,7 @@
 	'S_NUMBER_OF_STATUS_CHANGES'=>		'Number of status changes',
 	'S_WEEK'=>				'Week',
 	'S_LAST'=>				'Last',
- 
+
 //	screenconf.php
 	'S_SCREENS'=>				'Screens',
 	'S_SCREEN'=>				'Screen',
@@ -1275,6 +1282,7 @@
 	'S_NO_SLIDES_DEFINED'=>			'No slides defined',
 	'S_SLIDES'=>				'Slides',
 	'S_NEW_SLIDE'=>				'New slide',
+	'S_SHOW_TEXT_AS_HTML'=>		'Show text as HTML',
 
 //	screenedit.php
 	'S_MAP'=>					'Map',
@@ -1350,7 +1358,7 @@
 	'S_STATUS_CALCULATION_ALGORITHM'=>	'Status calculation algorithm',
 	'S_NONE'=>				'None',
 	'S_PROBLEM_IF_AT_LEAST_ONE'=>	'Problem, if at least one child has a problem',
-	'S_PROBLEM_IF_ALL'=>			'Problem, if all children have problems',	
+	'S_PROBLEM_IF_ALL'=>			'Problem, if all children have problems',
 	'S_SERVICE_1'=>				'Service 1',
 	'S_SERVICE_2'=>				'Service 2',
 	'S_SOFT_HARD_LINK'=>			'Soft/hard link',
@@ -1387,7 +1395,6 @@
 	'S_NOTE'=>				'Note',
 	'S_SOFT_LINK'=>				'Soft Link',
 	'S_REMOVE'=>				'Remove',
-	'S_DEPENDS_ON'=>			'Depends on',
 
 	'S_SUNDAY'=>				'Sunday',
 	'S_MONDAY'=>				'Monday',
@@ -1441,6 +1448,7 @@
 	'S_TRIGGER_UPDATED'=>			'Trigger updated',
 	'S_CANNOT_UPDATE_TRIGGER'=>		'Cannot update trigger',
 	'S_DEPENDS_ON'=>			'Depends on',
+	'S_DEPENDENT'=>				'Dependent',
 	'S_URL'=>				'URL',
 	'S_INVALID_URL'=>			'Invalid URL',
 	'S_CREATE_TRIGGER'=>			'Create Trigger',
@@ -1454,12 +1462,12 @@
 	'S_SHOW_DISABLED_TRIGGERS'=>		'Show disabled triggers',
 	'S_HIDE_DISABLED_TRIGGERS'=>		'Hide disabled triggers',
 	'S_THE_TRIGGER_DEPENDS_ON'=>		'The trigger depends on',
-	'S_NO_DEPENDENCES_DEFINED'=>		'No dependences defined',
+	'S_NO_DEPENDENCES_DEFINED'=>		'No dependencies defined',
 	'S_NEW_DEPENDENCY'=>			'New dependency',
 
 	'S_MULTIPLE_EVENTS'=>		'Multiple events',
 	'S_EVENT_GENERATION'=>		'Event generation',
-	
+
 	'S_TRIGGERS_MASSUPDATE'=>	'Triggers massupdate',
 	'S_TRIGGER_DEPENDENCIES'=>	'Trigger dependencies',
 	'S_INCORRECT_DEPENDENCY'=>	'Incorrect dependency',
@@ -1501,6 +1509,7 @@
 	'S_ACK'=>							'Ack',
 	'S_NOT_ACK'=>						'Not Ack',
 	'S_NEVER'=>							'Never',
+	'S_FOUND'=>							'Found',
 
 //	users.php
 	'S_ZABBIX_USER'=>			'ZABBIX User',
@@ -1573,8 +1582,8 @@
 	'S_CHANGE_PASSWORD'=>			'Change password',
 	'S_PASSWORD_ONCE_AGAIN'=>		'Password (once again)',
 	'S_URL_AFTER_LOGIN'=>			'URL (after login)',
-	'S_AUTO_LOGIN'=>				'Auto-login (1 month)',
-	'S_AUTO_LOGOUT'=>		'Auto-logout (0-disable)',
+	'S_AUTO_LOGIN'=>				'Auto-login',
+	'S_AUTO_LOGOUT'=>		'Auto-logout (min 90 seconds)',
 	'S_SCREEN_REFRESH'=>                    'Refresh (in seconds)',
 	'S_CREATE_USER'=>			'Create User',
 	'S_CREATE_GROUP'=>			'Create Group',
@@ -1616,8 +1625,8 @@
 	'S_AUDIT_ACTIONS'=>			'Audit actions',
 	'S_ACTION'=>				'Action',
 	'S_DETAILS'=>				'Details',
-	'S_UNKNOWN_ACTION'=>			'Unknown action',
-	'S_ADDED'=>				'Added',
+	'S_UNKNOWN_ACTION'=>		'Unknown action',
+	'S_ADDED'=>					'Added',
 	'S_UPDATED'=>				'Updated',
 	'S_LOGGED_IN'=>				'Logged in',
 	'S_LOGGED_OUT'=>			'Logged out',
@@ -1645,6 +1654,7 @@
 	'S_CHINESE_CN'=>			'Chinese (CN)',
 	'S_DUTCH_NL'=>				'Dutch (NL)',
 	'S_HUNGARY_HU'=>			'Hungary (HU)',
+	'S_POLISH_PL'=>				'Polish (PL)',
 
 //	index.php
 	'S_ZABBIX_BIG'=>			'ZABBIX',
