@@ -23,12 +23,12 @@
 	{
 		global $ZBX_CURMASTERID;
 
-		if($node_data['nodeid'] == get_current_nodeid(false))		$node_type = ZBX_NODE_LOCAL;
+		if(bccomp($node_data['nodeid'],get_current_nodeid(false)) == 0)		$node_type = ZBX_NODE_LOCAL;
 		else if(bccomp($node_data['nodeid'] ,$ZBX_CURMASTERID)==0)		$node_type = ZBX_NODE_MASTER;
 		else if(bccomp($node_data['masterid'], get_current_nodeid(false))==0)	$node_type = ZBX_NODE_REMOTE;
 		else $node_type = -1;
 
-		return $node_type;
+	return $node_type;
 	}
 
 	function	node_type2str($node_type)
@@ -80,19 +80,17 @@
 				break;
 		}
 
-		if(DBfetch(DBselect('select nodeid from nodes where nodeid='.$new_nodeid)))
-		{
+		if(DBfetch(DBselect('select nodeid from nodes where nodeid='.$new_nodeid))){
 			error('Node with same ID already exist.');
 			return false;
 		}
 
 		$result = DBexecute('insert into nodes (nodeid,name,timezone,ip,port,slave_history,slave_trends,'.
-				'event_lastid,history_lastid,nodetype,masterid) values ('.
+				'nodetype,masterid) values ('.
 				$new_nodeid.','.zbx_dbstr($name).','.$timezone.','.zbx_dbstr($ip).','.$port.','.$slave_history.','.$slave_trends.','.
-				'0,0,'.$nodetype.','.$masterid.')');
+				$nodetype.','.$masterid.')');
 
-		if($result && $node_type == ZBX_NODE_MASTER)
-		{
+		if($result && $node_type == ZBX_NODE_MASTER){
 			DBexecute('update nodes set masterid='.$new_nodeid.' where nodeid='.get_current_nodeid(false));
 			$ZBX_CURMASTERID = $new_nodeid; /* applay Master node for this script */
 		}
@@ -100,10 +98,8 @@
 		return ($result ? $new_nodeid : $result);
 	}
 
-	function	update_node($nodeid,$new_nodeid,$name,$timezone,$ip,$port,$slave_history,$slave_trends)
-	{
-		if( !eregi('^'.ZBX_EREG_NODE_FORMAT.'$', $name) )
-		{
+	function update_node($nodeid,$new_nodeid,$name,$timezone,$ip,$port,$slave_history,$slave_trends){
+		if( !eregi('^'.ZBX_EREG_NODE_FORMAT.'$', $name) ){
 			error("Incorrect characters used for Node name");
 			return false;
 		}
@@ -112,11 +108,10 @@
 				'timezone='.$timezone.',ip='.zbx_dbstr($ip).',port='.$port.','.
 				'slave_history='.$slave_history.',slave_trends='.$slave_trends.
 				' where nodeid='.$nodeid);
-		return $result;
+	return $result;
 	}
 
-	function	delete_node($nodeid)
-	{
+	function delete_node($nodeid){
 		$result = false;
 		$node_data = DBfetch(DBselect('select * from nodes where nodeid='.$nodeid));
 
