@@ -19,6 +19,16 @@
 **/
 ?>
 <?php
+
+function zbx_session_start($userid, $name, $password){
+	$sessionid = md5(time().$password.$name.rand(0,10000000));
+	zbx_setcookie('zbx_sessionid',$sessionid);
+	
+	DBexecute('INSERT INTO sessions (sessionid,userid,lastaccess,status) VALUES ('.zbx_dbstr($sessionid).','.$userid.','.time().','.ZBX_SESSION_ACTIVE.')');
+	
+return $sessionid;
+}
+
 function permission2str($group_permission){
 	$str_perm[PERM_READ_WRITE]	= S_READ_WRITE;
 	$str_perm[PERM_READ_ONLY]	= S_READ_ONLY;
@@ -43,20 +53,20 @@ function check_authorisation(){
 
 	$USER_DETAILS = NULL;
 	$login = FALSE;
-	
-	$sessionid = get_cookie("zbx_sessionid");
 
+	$sessionid = get_cookie('zbx_sessionid');
 	if(!is_null($sessionid)){
-		$login = $USER_DETAILS = DBfetch(DBselect('SELECT u.*,s.* '.
-					' FROM sessions s,users u'.
-					' WHERE s.sessionid='.zbx_dbstr($sessionid).
-						' AND s.status='.ZBX_SESSION_ACTIVE.
-						' AND s.userid=u.userid'.
-						' AND ((s.lastaccess+u.autologout>'.time().') OR (u.autologout=0))'.
-						' AND '.DBin_node('u.userid', $ZBX_LOCALNODEID)));
+		$sql = 'SELECT u.*,s.* '.
+				' FROM sessions s,users u'.
+				' WHERE s.sessionid='.zbx_dbstr($sessionid).
+					' AND s.status='.ZBX_SESSION_ACTIVE.
+					' AND s.userid=u.userid'.
+					' AND ((s.lastaccess+u.autologout>'.time().') OR (u.autologout=0))'.
+					' AND '.DBin_node('u.userid', $ZBX_LOCALNODEID);
 
+		$login = $USER_DETAILS = DBfetch(DBselect($sql));
 		if(!$USER_DETAILS){
-			$incorect_session = true;
+			$incorrect_session = true;
 		}
 		else if($login['attempt_failed']){
 			error(new CScript(array(
@@ -71,34 +81,40 @@ function check_authorisation(){
 		}
 	}
 
-	if(!$USER_DETAILS){
-		$login = $USER_DETAILS = DBfetch(DBselect('SELECT u.* '.
-									' FROM users u '.
-									' WHERE u.alias='.zbx_dbstr(ZBX_GUEST_USER).
-										' AND '.DBin_node('u.userid', $ZBX_LOCALNODEID)));
+	if(!$USER_DETAILS && !isset($_SERVER['PHP_AUTH_USER'])){
+		$sql = 'SELECT u.* '.
+				' FROM users u '.
+				' WHERE u.alias='.zbx_dbstr(ZBX_GUEST_USER).
+					' AND '.DBin_node('u.userid', $ZBX_LOCALNODEID);
+		$login = $USER_DETAILS = DBfetch(DBselect($sql));
 		if(!$USER_DETAILS){
 			$missed_user_guest = true;
 		}
+		else{
+			$sessionid = zbx_session_start($USER_DETAILS['userid'], ZBX_GUEST_USER, '');
+		}
 	}
 
 	if($login){
 		$login = (check_perm2login($USER_DETAILS['userid']) && check_perm2system($USER_DETAILS['userid']));
 	}
-
-	if($login){
-		zbx_setcookie("zbx_sessionid",$sessionid,$USER_DETAILS['autologin']?(time()+86400*31):0);	//1 month
+	
+	if(!$login){
+		$USER_DETAILS = NULL;
+	}
+	
+	if($login && !isset($incorrect_session)){
+		zbx_setcookie('zbx_sessionid',$sessionid,$USER_DETAILS['autologin']?(time()+86400*31):0);	//1 month
 		DBexecute('UPDATE sessions SET lastaccess='.time().' WHERE sessionid='.zbx_dbstr($sessionid));
 	}
 	else{
-		$USER_DETAILS = NULL;
-		
 		zbx_unsetcookie('zbx_sessionid');
 		DBexecute('UPDATE sessions SET status='.ZBX_SESSION_PASSIVE.' WHERE sessionid='.zbx_dbstr($sessionid));
 		unset($sessionid);
 	}
 
 	if($USER_DETAILS){
-		$USER_DETAILS['node'] = DBfetch(DBselect('select * from nodes where nodeid='.id2nodeid($USER_DETAILS['userid'])));
+		$USER_DETAILS['node'] = DBfetch(DBselect('SELECT * FROM nodes WHERE nodeid='.id2nodeid($USER_DETAILS['userid'])));
 		
 		if(empty($USER_DETAILS['node'])){
 			$USER_DETAILS['node']['name'] = '- unknown -';
@@ -107,25 +123,25 @@ function check_authorisation(){
 	}
 	else{
 		$USER_DETAILS = array(
-			"alias"	=>ZBX_GUEST_USER,
-			"userid"=>0,
-			"lang"	=>"en_gb",
-			"type"	=>"0",
-			"node"	=>array(
-				"name"	=>'- unknown -',
-				"nodeid"=>0));
+			'alias'	=>ZBX_GUEST_USER,
+			'userid'=>0,
+			'lang'	=>'en_gb',
+			'type'	=>'0',
+			'node'	=>array(
+				'name'	=>'- unknown -',
+				'nodeid'=>0));
 	}
-	
+
 	if(!$login || isset($incorrect_session) || isset($missed_user_guest)){
 
-		if(isset($incorrect_session))		$message = "Session was ended, please relogin!";
+		if(isset($incorrect_session))	$message = 'Session was ended, please relogin!';
 		else if(isset($missed_user_guest)){
 			$row = DBfetch(DBselect('SELECT count(u.userid) as user_cnt FROM users u'));
 			if(!$row || $row['user_cnt'] == 0){
-				$message = "Table users is empty. Possible database corruption.";
+				$message = 'Table users is empty. Possible database corruption.';
 			}
 		}
-		
+
 		if(!isset($_REQUEST['message']) && isset($message)) $_REQUEST['message'] = $message;
 		
 		include('index.php');
@@ -153,7 +169,7 @@ function ldap_authentication($user,$passwd,$cnf=NULL){
 	
 	$ldap = new CLdap($cnf);
 	$ldap->connect();
-	
+
 	$result = $ldap->checkPass($user,$passwd);
 
 return $result;
@@ -258,18 +274,6 @@ return $result;
 /***********************************************
 	GET ACCESSIBLE RESOURCES BY USERID
 ************************************************/
-function perm_mode2comparator($perm_mode){
-	switch($perm_mode){
-		case PERM_MODE_NE:	$perm_mode = '!='; break;
-		case PERM_MODE_EQ:	$perm_mode = '=='; break;
-		case PERM_MODE_GT:	$perm_mode = '>'; break;
-		case PERM_MODE_LT:	$perm_mode = '<'; break;
-		case PERM_MODE_LE:	$perm_mode = '<='; break;
-		case PERM_MODE_GE:
-		default:		$perm_mode = '>='; break;
-	}
-return $perm_mode;
-}
 
 function get_accessible_hosts_by_user(&$user_data,$perm,$perm_res=null,$nodeid=null,$cache=1){
 //		global $DB;
@@ -353,7 +357,7 @@ COpt::counter_up('perm');
 				$result[$host_data['hostid']] = $host_data; 
 				break;
 			default:
-				$result[$host_data['hostid']] = $host_data["hostid"]; 
+				$result[$host_data['hostid']] = $host_data['hostid']; 
 		}
 	}
 
@@ -367,6 +371,7 @@ COpt::counter_up('perm');
 	}
 
 	$available_hosts[$userid][$perm][$perm_res][$nodeid_str] = $result;
+
 return $result;
 }
 
@@ -385,11 +390,12 @@ function get_accessible_groups_by_user($user_data,$perm,$perm_res=null,$nodeid=n
 COpt::counter_up('perm_group['.$userid.','.$perm.','.$perm_res.','.$nodeid.']');
 COpt::counter_up('perm');
 
+	$processed = array();
 	$where = array();
 
-	if(!is_null($nodeid))
+	if(!is_null($nodeid)){
 		array_push($where, DBin_node('hg.groupid', $nodeid));
-
+	}
 	$where = count($where)?' WHERE '.implode(' AND ',$where):'';
 
 	$sql = 'SELECT n.nodeid as nodeid,n.name as node_name,hg.groupid,hg.name,min(r.permission) as permission,g.userid'.
@@ -400,10 +406,7 @@ COpt::counter_up('perm');
 		$where.
 		' GROUP BY n.nodeid, n.name, hg.groupid, hg.name, g.userid, g.userid '.
 		' ORDER BY node_name, hg.name, permission ';
-
 	$db_groups = DBselect($sql);
-
-	$processed = array();
 	while($group_data = DBfetch($db_groups)){
 		if(zbx_empty($group_data['nodeid'])) $group_data['nodeid'] = id2nodeid($group_data['groupid']);
 
@@ -450,7 +453,7 @@ COpt::counter_up('perm');
 			$result = implode(',',$result);
 	}
 
-	return $result;
+return $result;
 }
 
 function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=null,$cache=1){
@@ -466,12 +469,10 @@ function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=n
 
 	$node_data = array();
 	$result = array();
-	
-//COpt::counter_up('perm_nodes['.$userid.','.$perm.','.$perm_mode.','.$perm_res.','.$nodeid.']');
-//COpt::counter_up('perm');
 
+//COpt::counter_up('perm');
 	if(USER_TYPE_SUPER_ADMIN == $user_type){
-		$nodes = DBselect('SELECT nodeid FROM nodes');// WHERE '.DBcondition('nodeid',$nodeid));
+		$nodes = DBselect('SELECT nodeid FROM nodes WHERE '.DBcondition('nodeid',$ZBX_NODES_IDS));
 		while($node = DBfetch($nodes)){
 			$node_data[$node['nodeid']] = $node;
 			$node_data[$node['nodeid']]['permission'] = PERM_READ_WRITE;
@@ -479,10 +480,11 @@ function get_accessible_nodes_by_user(&$user_data,$perm,$perm_res=null,$nodeid=n
 		if(empty($node_data)) $node_data[0]['nodeid'] = 0;
 	}
 	else{
-		$available_hosts = get_accessible_hosts_by_user($user_data,$perm,PERM_RES_DATA_ARRAY,$nodeid,$cache);	
-		foreach($available_hosts as $id => $host){
-			$nodeid = id2nodeid($host['hostid']);
-			$permission = (isset($node_data[$nodeid]) && ($permission < $node_data[$nodeid]['permission']))?$node_data[$nodeid]['permission']:$host['permission'];
+		$available_groups = get_accessible_groups_by_user($user_data,$perm,PERM_RES_DATA_ARRAY,$nodeid,$cache);	
+
+		foreach($available_groups as $id => $group){
+			$nodeid = id2nodeid($group['groupid']);
+			$permission = (isset($node_data[$nodeid]) && ($permission < $node_data[$nodeid]['permission']))?$node_data[$nodeid]['permission']:$group['permission'];
 
 			$node_data[$nodeid]['nodeid'] = $nodeid;
 			$node_data[$nodeid]['permission'] = $permission;
@@ -685,9 +687,21 @@ function get_accessible_nodes_by_rights(&$rights,$user_type,$perm,$perm_res=null
 	$node_data = array();
 	$result = array();
 	
-//COpt::counter_up('perm_nodes['.$userid.','.$perm.','.$perm_mode.','.$perm_res.','.$nodeid.']');
 //COpt::counter_up('perm');
-//SDI(get_accessible_hosts_by_rights($rights,$user_type,$perm,PERM_RES_DATA_ARRAY,$nodeid));
+//SDI(get_accessible_groups_by_rights($rights,$user_type,$perm,PERM_RES_DATA_ARRAY,$nodeid));
+	$available_groups = get_accessible_groups_by_rights($rights,$user_type,$perm,PERM_RES_DATA_ARRAY,$nodeid);
+	foreach($available_groups as $id => $group){
+		$nodeid = id2nodeid($group['groupid']);
+		$permission = $group['permission'];
+		
+		if(isset($node_data[$nodeid]) && ($permission < $node_data[$nodeid]['permission'])){
+			$permission = $node_data[$nodeid]['permission'];
+		} 
+
+		$node_data[$nodeid]['nodeid'] = $nodeid;
+		$node_data[$nodeid]['permission'] = $permission;
+	}
+	
 	$available_hosts = get_accessible_hosts_by_rights($rights,$user_type,$perm,PERM_RES_DATA_ARRAY,$nodeid);	
 	foreach($available_hosts as $id => $host){
 		$nodeid = id2nodeid($host['hostid']);
