@@ -285,7 +285,6 @@ return $type;
 }
 
 function profile_value_by_type(&$value,$type){
-	
 	if(profile_type($type,'array')){
 		$result = is_array($value)?$value:array($value);
 	}
@@ -310,15 +309,17 @@ function profile_value_by_type(&$value,$type){
 				$result = false;
 		}
 	}
-	else{			
+	else{
 		switch($type){	
 			case PROFILE_TYPE_ID:
+				$result = zbx_ctype_digit($value)?$value:false;
+				break;
 			case PROFILE_TYPE_INT:
 				$result = zbx_numeric($value)?$value:false;
-			break;
+				break;
 			case PROFILE_TYPE_STR:
 				$result = strval($value);
-			break;
+				break;
 			default:
 				$result = false;
 		}
@@ -328,6 +329,7 @@ return $result;
 
 /********** END MISC ***********/
 
+
 /************ CONFIG **************/
 
 function select_config(){
@@ -337,11 +339,10 @@ function select_config(){
 	if($row){
 		return	$row;
 	}
-	else{
-		if($page["title"] != S_INSTALLATION)
+	else if($page['title'] != S_INSTALLATION){
 			error('Unable to select configuration');
 	}
-	return	$row;
+return	$row;
 }
 
 function update_config($configs){
