@@ -30,22 +30,15 @@
 
 		if(DBfetch(DBselect('SELECT screenid FROM screens WHERE screenid='.$screenid.' AND '.DBin_node('screenid', get_current_nodeid($perm))))){
 			$result = true;
-			$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,$perm,PERM_RES_IDS_ARRAY);
+			$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,$perm,PERM_RES_IDS_ARRAY,get_current_nodeid(true));
 			
 			$db_result = DBselect('SELECT * FROM screens_items WHERE screenid='.$screenid);
 			while(($ac_data = DBfetch($db_result)) && $result){
 				switch($ac_data['resourcetype']){
 					case SCREEN_RESOURCE_GRAPH:
-						$itemid = array();
-
-						$db_gitems = DBselect('SELECT DISTINCT itemid '.
-										' FROM graphs_items '.
-										' WHERE graphid='.$ac_data['resourceid']);
-						
-						while($gitem_data = DBfetch($db_gitems)) array_push($itemid, $gitem_data['itemid']);
-						
-						if(count($itemid) == 0) $itemid = array(-1);
-						// break; /* use same processing as items */
+						$graphids = get_accessible_graphs($perm,array(),null,get_current_nodeid(true));
+						$result &= isset($graphids[$ac_data['resourceid']]);
+					break;
 					case SCREEN_RESOURCE_SIMPLE_GRAPH:
 						// break; /* use same processing as items */
 					case SCREEN_RESOURCE_PLAIN_TEXT:
@@ -87,8 +80,7 @@
 		return $result;
 	}
 
-        function        add_screen($name,$hsize,$vsize)
-        {
+	function add_screen($name,$hsize,$vsize){
 		$screenid=get_dbid("screens","screenid");
                 $sql="insert into screens (screenid,name,hsize,vsize) values ($screenid,".zbx_dbstr($name).",$hsize,$vsize)";
                 $result=DBexecute($sql);
@@ -96,56 +88,53 @@
 		if(!$result)
 			return $result;
 
-		return $screenid;
-        }
+	return $screenid;
+	}
 
-        function update_screen($screenid,$name,$hsize,$vsize)
-        {
-                $sql="update screens set name=".zbx_dbstr($name).",hsize=$hsize,vsize=$vsize where screenid=$screenid";
-                return  DBexecute($sql);
-        }
+	function update_screen($screenid,$name,$hsize,$vsize){
+			$sql="update screens set name=".zbx_dbstr($name).",hsize=$hsize,vsize=$vsize where screenid=$screenid";
+			return  DBexecute($sql);
+	}
+	
+	function delete_screen($screenid){
+		$result=DBexecute('DELETE FROM screens_items where screenid='.$screenid);
+		$result&=DBexecute('DELETE FROM screens_items where resourceid='.$screenid.' and resourcetype='.SCREEN_RESOURCE_SCREEN);
+		$result&=DBexecute('DELETE FROM slides where screenid='.$screenid);
+		$result&=DBexecute("DELETE FROM profiles WHERE idx='web.favorite.screenids' AND source='screenid' AND value_id=$screenid");
+		$result&=DBexecute('DELETE FROM screens where screenid='.$screenid);	
+	return	$result;
+	}
+	
+	function add_screen_item($resourcetype,$screenid,$x,$y,$resourceid,$width,$height,$colspan,$rowspan,$elements,$valign,$halign,$style,$url,$dynamic){
+		$sql='DELETE FROM screens_items WHERE screenid='.$screenid.' and x='.$x.' and y='.$y;
+		DBexecute($sql);
+		
+		$screenitemid=get_dbid("screens_items","screenitemid");
+		$result=DBexecute('INSERT INTO screens_items '.
+							'(screenitemid,resourcetype,screenid,x,y,resourceid,width,height,'.
+							' colspan,rowspan,elements,valign,halign,style,url,dynamic) '.
+						' VALUES '.
+							"($screenitemid,$resourcetype,$screenid,$x,$y,$resourceid,$width,$height,$colspan,".
+							"$rowspan,$elements,$valign,$halign,$style,".zbx_dbstr($url).",$dynamic)");
+	
+		if(!$result) return $result;
+	return $screenitemid;
+	}
+	
+	function update_screen_item($screenitemid,$resourcetype,$resourceid,$width,$height,$colspan,$rowspan,$elements,$valign,$halign,$style,$url,$dynamic){
+		return  DBexecute("UPDATE screens_items SET ".
+							"resourcetype=$resourcetype,"."resourceid=$resourceid,"."width=$width,".
+							"height=$height,colspan=$colspan,rowspan=$rowspan,elements=$elements,".
+							"valign=$valign,halign=$halign,style=$style,url=".zbx_dbstr($url).",dynamic=$dynamic".
+						" WHERE screenitemid=$screenitemid");
+	}
+	
+	function delete_screen_item($screenitemid){
+			$sql="DELETE FROM screens_items where screenitemid=$screenitemid";
+			return  DBexecute($sql);
+	}
 
-        function delete_screen($screenid){
-			$result=DBexecute('DELETE FROM screens_items where screenid='.$screenid);
-			$result&=DBexecute('DELETE FROM screens_items where resourceid='.$screenid.' and resourcetype='.SCREEN_RESOURCE_SCREEN);
-			$result&=DBexecute('DELETE FROM slides where screenid='.$screenid);
-			$result&=DBexecute("DELETE FROM profiles WHERE idx='web.favorite.screenids' AND source='screenid' AND value_id=$screenid");
-			$result&=DBexecute('DELETE FROM screens where screenid='.$screenid);	
-		return	$result;
-        }
-
-        function add_screen_item($resourcetype,$screenid,$x,$y,$resourceid,$width,$height,$colspan,$rowspan,$elements,$valign,$halign,$style,$url,$dynamic){
-			$sql='DELETE FROM screens_items WHERE screenid='.$screenid.' and x='.$x.' and y='.$y;
-			DBexecute($sql);
-			
-			$screenitemid=get_dbid("screens_items","screenitemid");
-			$result=DBexecute('INSERT INTO screens_items '.
-								'(screenitemid,resourcetype,screenid,x,y,resourceid,width,height,'.
-								' colspan,rowspan,elements,valign,halign,style,url,dynamic) '.
-							' VALUES '.
-								"($screenitemid,$resourcetype,$screenid,$x,$y,$resourceid,$width,$height,$colspan,".
-								"$rowspan,$elements,$valign,$halign,$style,".zbx_dbstr($url).",$dynamic)");
-
-			if(!$result) return $result;
-		return $screenitemid;
-        }
-
-        function update_screen_item($screenitemid,$resourcetype,$resourceid,$width,$height,$colspan,$rowspan,$elements,$valign,$halign,$style,$url,$dynamic){
-			return  DBexecute("UPDATE screens_items SET ".
-								"resourcetype=$resourcetype,"."resourceid=$resourceid,"."width=$width,".
-								"height=$height,colspan=$colspan,rowspan=$rowspan,elements=$elements,".
-								"valign=$valign,halign=$halign,style=$style,url=".zbx_dbstr($url).",dynamic=$dynamic".
-							" WHERE screenitemid=$screenitemid");
-        }
-
-        function delete_screen_item($screenitemid)
-        {
-                $sql="DELETE FROM screens_items where screenitemid=$screenitemid";
-                return  DBexecute($sql);
-        }
-
-	function	get_screen_by_screenid($screenid)
-	{
+	function get_screen_by_screenid($screenid){
 		$result = DBselect("select * from screens where screenid=$screenid");
 		$row=DBfetch($result);
 		if($row)
@@ -161,8 +150,7 @@
 
 			$db_scr_items = DBselect("select resourceid from screens_items where".
 				" screenid=$child_screenid and resourcetype=".SCREEN_RESOURCE_SCREEN);
-			while($scr_item = DBfetch($db_scr_items))
-			{
+			while($scr_item = DBfetch($db_scr_items)){
 				if(check_screen_recursion($mother_screenid,$scr_item["resourceid"]))
 					return TRUE; 
 			}
@@ -214,12 +202,12 @@
 		$result = false;
 
 		if(DBselect('select slideshowid from slideshows where slideshowid='.$slideshowid.
-			' and '.DBin_node('slideshowid', get_current_nodeid($perm))))
+			' and '.DBin_node('slideshowid', get_current_nodeid(null,$perm))))
 		{
 			$result = true;
 			$db_slides = DBselect('select distinct screenid from slides where slideshowid='.$slideshowid);
 			while($slide_data = DBfetch($db_slides)){
-				if( !($result = screen_accessible($slide_data["screenid"], PERM_READ_ONLY)) ) break;
+				if(!$result = screen_accessible($slide_data["screenid"], PERM_READ_ONLY)) break;
 			}
 		}
 	return $result;
@@ -302,12 +290,12 @@
 	}
 	
 
-	# Show screen cell containing plain text values
-	function get_screen_plaintext($itemid,$elements){
+//Show screen cell containing plain text values
+	function get_screen_plaintext($itemid,$elements,$style=0){
 
 		if($itemid == 0){
 			$table = new CTableInfo(S_ITEM_NOT_EXISTS);
-			$table->SetHeader(array(S_TIMESTAMP,S_ITEM));
+			$table->setHeader(array(S_TIMESTAMP,S_ITEM));
 			return $table;
 		}
 
@@ -348,34 +336,47 @@
 		$host = get_host_by_itemid($itemid);
 		
 		$table = new CTableInfo();
-		$table->SetHeader(array(S_TIMESTAMP,$host['host'].': '.item_description($item)));
+		$table->setHeader(array(S_TIMESTAMP,$host['host'].': '.item_description($item)));
 
 		while($row=DBfetch($result)){
-			switch($item["value_type"]){
+			switch($item['value_type']){
 				case ITEM_VALUE_TYPE_TEXT:	
-					if($DB['TYPE'] == "ORACLE"){
-						if(isset($row["value"])){
-							$row["value"] = $row["value"]->load();
+					if($DB['TYPE'] == 'ORACLE'){
+						if(isset($row['value'])){
+							$row['value'] = $row['value']->load();
 						}
 						else{
-							$row["value"] = "";
+							$row['value'] = '';
 						}
 					}
 					/* do not use break */
-				case ITEM_VALUE_TYPE_STR:	
-					$value = nbsp(htmlspecialchars($row['value']));
-					$value = zbx_nl2br($value);
+				case ITEM_VALUE_TYPE_STR:
+					if($style){
+						$value = new CScript($row['value']);
+					}
+					else{
+						$value = nbsp(htmlspecialchars($row['value']));
+						$value = zbx_nl2br($value);						
+					}
+					break;
+				case ITEM_VALUE_TYPE_LOG:	
+					if($style){
+						$value = new CScript($row['value']);
+					}
+					else{
+						$value = nbsp(htmlspecialchars($row['value']));
+						$value = zbx_nl2br($value);
+					}
 					break;
-				
 				default:
-					$value = $row["value"];
+					$value = $row['value'];
 					break;
 			}
 
-			if($row["valuemapid"] > 0)
-				$value = replace_value_by_map($value, $row["valuemapid"]);
+			if($row['valuemapid'] > 0)
+				$value = replace_value_by_map($value, $row['valuemapid']);
 
-			$table->AddRow(array(date(S_DATE_FORMAT_YMDHMS,$row["clock"]),	$value));
+			$table->AddRow(array(date(S_DATE_FORMAT_YMDHMS,$row['clock']),	$value));
 		}
 		return $table;
 	}
@@ -402,73 +403,74 @@
 	
 	function get_screen_item_form(){
 		global $USER_DETAILS;
-		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
+		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY,get_current_nodeid(true));
 		
 		$form = new CFormTable(S_SCREEN_CELL_CONFIGURATION,'screenedit.php#form');
 		$form->SetHelp('web.screenedit.cell.php');
 
-		if(isset($_REQUEST["screenitemid"])){
+		if(isset($_REQUEST['screenitemid'])){
 			$iresult=DBSelect('SELECT * FROM screens_items'.
 							' WHERE screenid='.$_REQUEST['screenid'].
 								' AND screenitemid='.$_REQUEST['screenitemid']
 							);
 
-			$form->AddVar("screenitemid",$_REQUEST["screenitemid"]);
+			$form->AddVar('screenitemid',$_REQUEST['screenitemid']);
 		} 
 		else{
-			$form->AddVar("x",$_REQUEST["x"]);
-			$form->AddVar("y",$_REQUEST["y"]);
+			$form->AddVar('x',$_REQUEST['x']);
+			$form->AddVar('y',$_REQUEST['y']);
 		}
 
-		if(isset($_REQUEST["screenitemid"]) && !isset($_REQUEST["form_refresh"])){
+		if(isset($_REQUEST['screenitemid']) && !isset($_REQUEST['form_refresh'])){
 		
 			$irow = DBfetch($iresult);
-			$resourcetype	= $irow["resourcetype"];
-			$resourceid	= $irow["resourceid"];
-			$width		= $irow["width"];
-			$height		= $irow["height"];
-			$colspan	= $irow["colspan"];
-			$rowspan	= $irow["rowspan"];
-			$elements	= $irow["elements"];
-			$valign		= $irow["valign"];
-			$halign		= $irow["halign"];
-			$style		= $irow["style"];
-			$url		= $irow["url"];
+			$resourcetype	= $irow['resourcetype'];
+			$resourceid	= $irow['resourceid'];
+			$width		= $irow['width'];
+			$height		= $irow['height'];
+			$colspan	= $irow['colspan'];
+			$rowspan	= $irow['rowspan'];
+			$elements	= $irow['elements'];
+			$valign		= $irow['valign'];
+			$halign		= $irow['halign'];
+			$style		= $irow['style'];
+			$url		= $irow['url'];
 			$dynamic	= $irow['dynamic'];
 		}
 		else{
-			$resourcetype	= get_request("resourcetype",	0);
-			$resourceid	= get_request("resourceid",	0);
-			$width		= get_request("width",		500);
-			$height		= get_request("height",		100);
-			$colspan	= get_request("colspan",	0);
-			$rowspan	= get_request("rowspan",	0);
-			$elements	= get_request("elements",	25);
-			$valign		= get_request("valign",		VALIGN_DEFAULT);
-			$halign		= get_request("halign",		HALIGN_DEFAULT);
-			$style		= get_request("style",		0);
-			$url		= get_request("url",		"");
-			$dynamic	= get_request("dynamic",	SCREEN_SIMPLE_ITEM);
+			$resourcetype	= get_request('resourcetype',	0);
+			$resourceid	= get_request('resourceid',	0);
+			$width		= get_request('width',		500);
+			$height		= get_request('height',		100);
+			$colspan	= get_request('colspan',	0);
+			$rowspan	= get_request('rowspan',	0);
+			$elements	= get_request('elements',	25);
+			$valign		= get_request('valign',		VALIGN_DEFAULT);
+			$halign		= get_request('halign',		HALIGN_DEFAULT);
+			$style		= get_request('style',		0);
+			$url		= get_request('url',		'');
+			$dynamic	= get_request('dynamic',	SCREEN_SIMPLE_ITEM);
 		}
 
-		$form->AddVar("screenid",$_REQUEST["screenid"]);
+		$form->AddVar('screenid',$_REQUEST['screenid']);
 
-		$cmbRes = new CCombobox("resourcetype",$resourcetype,"submit()");
-		$cmbRes->AddItem(SCREEN_RESOURCE_GRAPH,		S_GRAPH);
-		$cmbRes->AddItem(SCREEN_RESOURCE_SIMPLE_GRAPH,	S_SIMPLE_GRAPH);
-		$cmbRes->AddItem(SCREEN_RESOURCE_PLAIN_TEXT,	S_PLAIN_TEXT);
-		$cmbRes->AddItem(SCREEN_RESOURCE_MAP,		S_MAP);
-		$cmbRes->AddItem(SCREEN_RESOURCE_SCREEN,	S_SCREEN);
-		$cmbRes->AddItem(SCREEN_RESOURCE_SERVER_INFO,	S_SERVER_INFO);
-		$cmbRes->AddItem(SCREEN_RESOURCE_HOSTS_INFO,	S_HOSTS_INFO);
-		$cmbRes->AddItem(SCREEN_RESOURCE_TRIGGERS_INFO,	S_TRIGGERS_INFO);
-		$cmbRes->AddItem(SCREEN_RESOURCE_TRIGGERS_OVERVIEW,	S_TRIGGERS_OVERVIEW);
-		$cmbRes->AddItem(SCREEN_RESOURCE_DATA_OVERVIEW,		S_DATA_OVERVIEW);
-		$cmbRes->AddItem(SCREEN_RESOURCE_CLOCK,		S_CLOCK);
-		$cmbRes->AddItem(SCREEN_RESOURCE_URL,		S_URL);
-		$cmbRes->AddItem(SCREEN_RESOURCE_ACTIONS,	S_HISTORY_OF_ACTIONS);
-                $cmbRes->AddItem(SCREEN_RESOURCE_EVENTS,       S_HISTORY_OF_EVENTS);
-		$form->AddRow(S_RESOURCE,$cmbRes);
+		$cmbRes = new CCombobox('resourcetype',$resourcetype,'submit()');
+			$cmbRes->addItem(SCREEN_RESOURCE_GRAPH,		S_GRAPH);
+			$cmbRes->addItem(SCREEN_RESOURCE_SIMPLE_GRAPH,	S_SIMPLE_GRAPH);
+			$cmbRes->addItem(SCREEN_RESOURCE_PLAIN_TEXT,	S_PLAIN_TEXT);
+			$cmbRes->addItem(SCREEN_RESOURCE_MAP,		S_MAP);
+			$cmbRes->addItem(SCREEN_RESOURCE_SCREEN,	S_SCREEN);
+			$cmbRes->addItem(SCREEN_RESOURCE_SERVER_INFO,	S_SERVER_INFO);
+			$cmbRes->addItem(SCREEN_RESOURCE_HOSTS_INFO,	S_HOSTS_INFO);
+			$cmbRes->addItem(SCREEN_RESOURCE_TRIGGERS_INFO,	S_TRIGGERS_INFO);
+			$cmbRes->addItem(SCREEN_RESOURCE_TRIGGERS_OVERVIEW,	S_TRIGGERS_OVERVIEW);
+			$cmbRes->addItem(SCREEN_RESOURCE_DATA_OVERVIEW,		S_DATA_OVERVIEW);
+			$cmbRes->addItem(SCREEN_RESOURCE_CLOCK,		S_CLOCK);
+			$cmbRes->addItem(SCREEN_RESOURCE_URL,		S_URL);
+			$cmbRes->addItem(SCREEN_RESOURCE_ACTIONS,	S_HISTORY_OF_ACTIONS);
+			$cmbRes->addItem(SCREEN_RESOURCE_EVENTS,       S_HISTORY_OF_EVENTS);
+		
+		$form->addRow(S_RESOURCE,$cmbRes);
 
 		if($resourcetype == SCREEN_RESOURCE_GRAPH){
 	// User-defined graph
@@ -487,13 +489,13 @@
 						' WHERE g.graphid='.$resourceid);
 
 				while($row=DBfetch($result)){
-					$row["node_name"] = isset($row["node_name"]) ? "(".$row["node_name"].") " : '';
-					$caption = $row["node_name"].$row["host"].":".$row["name"];
+					$row['node_name'] = isset($row['node_name']) ? '('.$row['node_name'].') ' : '';
+					$caption = $row['node_name'].$row['host'].':'.$row['name'];
 					$id = $resourceid;
 				}
 			}
 
-			$form->AddVar('resourceid',$id);
+			$form->addVar('resourceid',$id);
 			
 			$textfield = new Ctextbox('caption',$caption,75,'yes');
 			$selectbtn = new Cbutton('select',S_SELECT,"javascript: return PopUp('popup.php?dstfrm=".$form->getName()."&dstfld1=resourceid&dstfld2=caption&srctbl=graphs&srcfld1=graphid&srcfld2=name',800,450);");
@@ -591,10 +593,11 @@
 			
 			$textfield = new Ctextbox('caption',$caption,75,'yes');
 			$selectbtn = new Cbutton('select',S_SELECT,"javascript: return PopUp('popup.php?dstfrm=".$form->getName()."&dstfld1=resourceid&dstfld2=caption&srctbl=plain_text&srcfld1=itemid&srcfld2=description',800,450);");
-			$selectbtn->AddOption('onmouseover','javascript: this.style.cursor = "pointer";');
+			$selectbtn->addOption('onmouseover','javascript: this.style.cursor = "pointer";');
 			
-			$form->AddRow(S_PARAMETER,array($textfield,SPACE,$selectbtn));
-			$form->AddRow(S_SHOW_LINES, new CNumericBox('elements',$elements,2));
+			$form->addRow(S_PARAMETER,array($textfield,SPACE,$selectbtn));
+			$form->addRow(S_SHOW_LINES, new CNumericBox('elements',$elements,2));
+			$form->addRow(S_SHOW_TEXT_AS_HTML, new CCheckBox('style',$style,null,1));
 		}
 		else if($resourcetype == SCREEN_RESOURCE_ACTIONS){
 // History of actions
@@ -777,12 +780,12 @@
 
 		$form->AddItemToBottomRow(new CButton("save",S_SAVE));
 		if(isset($_REQUEST["screenitemid"])){
-			$form->AddItemToBottomRow(SPACE);
-			$form->AddItemToBottomRow(new CButtonDelete(null,
+			$form->addItemToBottomRow(SPACE);
+			$form->addItemToBottomRow(new CButtonDelete(null,
 				url_param("form").url_param("screenid").url_param("screenitemid")));
 		}
-		$form->AddItemToBottomRow(SPACE);
-		$form->AddItemToBottomRow(new CButtonCancel(url_param("screenid")));
+		$form->addItemToBottomRow(SPACE);
+		$form->addItemToBottomRow(new CButtonCancel(url_param("screenid")));
 		return $form;
 	}
 
@@ -876,7 +879,7 @@
 					$action = 'screenedit.php?form=update'.url_param('screenid').'&x='.$c.'&y='.$r.'#form';
 				else
 					$action = NULL;
-
+					
 				if($editmode == 1 && isset($_REQUEST["form"]) && 
 					isset($_REQUEST["x"]) && $_REQUEST["x"]==$c &&
 					isset($_REQUEST["y"]) && $_REQUEST["y"]==$r)
@@ -888,8 +891,7 @@
 				{ // click on element
 					$item = get_screen_item_form();
 				}
-				else if( ($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_GRAPH) )
-				{
+				else if( ($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_GRAPH) ){
 					if($editmode == 0)
 						$action = 'charts.php?graphid='.$resourceid.url_param('period').url_param('stime');
 														
@@ -992,8 +994,7 @@
 						$item = &$g_img;
 					}
 				}
-				else if( ($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_SIMPLE_GRAPH) )
-				{
+				else if(($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_SIMPLE_GRAPH)){
 					if($editmode == 0)
 						$action = "history.php?action=showgraph&itemid=$resourceid".
                                                         url_param("period").url_param("inc").url_param("dec");
@@ -1038,7 +1039,7 @@
 						}
 					}
 //-------------
-					$item = array(get_screen_plaintext($resourceid,$elements));
+					$item = array(get_screen_plaintext($resourceid,$elements,$style));
 					if($editmode == 1)	array_push($item,new CLink(S_CHANGE,$action));
 				}
 				else if( ($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_HOSTS_INFO) ){
@@ -1060,12 +1061,20 @@
 					$item = array(get_screen($resourceid, 2, $effectiveperiod));
 					if($editmode == 1)	array_push($item,new CLink(S_CHANGE,$action));
 				}
-				else if( ($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_TRIGGERS_OVERVIEW) ){
-					$item = array(get_triggers_overview($resourceid,$style));
+				else if( ($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_TRIGGERS_OVERVIEW) ){		
+					$hostids = array();
+					$res = DBselect('SELECT DISTINCT hg.hostid FROM hosts_groups hg WHERE hg.groupid='.$resourceid);
+					while($tmp_host = DBfetch($res)) $hostids[$tmp_host['hostid']] = $tmp_host['hostid'];
+
+					$item = array(get_triggers_overview($hostids,$style));
 					if($editmode == 1)	array_push($item,new CLink(S_CHANGE,$action));
 				}
 				else if( ($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_DATA_OVERVIEW) ){
-					$item = array(get_items_data_overview($resourceid,$style));
+					$hostids = array();
+					$res = DBselect('SELECT DISTINCT hg.hostid FROM hosts_groups hg WHERE hg.groupid='.$resourceid);
+					while($tmp_host = DBfetch($res)) $hostids[$tmp_host['hostid']] = $tmp_host['hostid'];
+
+					$item = array(get_items_data_overview($hostids,$style));
 					if($editmode == 1)	array_push($item,new CLink(S_CHANGE,$action));
 				}
 				else if( ($screenitemid!=0) && ($resourcetype==SCREEN_RESOURCE_URL) ){
