@@ -19,16 +19,14 @@
 **/
 ?>
 <?php
-	function zbx_is_callable($var)
-	{
+	function zbx_is_callable($var){
 		foreach($var as $e)
 			if(!is_callable($e)) return false;
 
 		return true;
 	}
 
-	class CSetupWizard extends CForm
-	{
+	class CSetupWizard extends CForm{
 /* protected *//*
 		var $ZBX_CONFIG;
 		var $DISABLE_NEXT_BUTTON;
@@ -36,8 +34,7 @@
 		*/
 
 /* public */	
-		function CSetupWizard(&$ZBX_CONFIG)
-		{
+		function CSetupWizard(&$ZBX_CONFIG){
 			$this->DISABLE_NEXT_BUTTON = false;
 			
 			$this->ZBX_CONFIG = &$ZBX_CONFIG;
@@ -47,10 +44,11 @@
 				1 => array('title' => '2. Licence Agreement'		, 'fnc' => 'Stage1' ),
 				2 => array('title' => '3. Check of pre-requisites'	, 'fnc' => 'Stage2' ),
 				3 => array('title' => '4. Configure DB connection'	, 'fnc' => 'Stage3' ),
+				4 => array('title' => '5. ZABBIX server details'	, 'fnc' => 'Stage4' ),
 				//4 => array('title' => '5. Distributed monitoring'	, 'fnc' => 'Stage4' ),
-				4 => array('title' => '5. Pre-Installation Summary'	, 'fnc' => 'Stage5' ),
-				5 => array('title' => '6. Install'			, 'fnc' => 'Stage6' ),
-				6 => array('title' => '7. Finish'			, 'fnc' => 'Stage7' )
+				5 => array('title' => '6. Pre-Installation Summary'	, 'fnc' => 'Stage5' ),
+				6 => array('title' => '7. Install'			, 'fnc' => 'Stage6' ),
+				7 => array('title' => '8. Finish'			, 'fnc' => 'Stage7' )
 				);
 			
 			$this->EventHandler();
@@ -58,40 +56,35 @@
 			parent::CForm(null, 'post');
 		}
 
-		function GetConfig($name, $default = null)
-		{
+		function getConfig($name, $default = null){
 			return isset($this->ZBX_CONFIG[$name]) ? $this->ZBX_CONFIG[$name] : $default;
 		}
-		function SetConfig($name, $value)
-		{
+		
+		function setConfig($name, $value){
 			return ($this->ZBX_CONFIG[$name] = $value);
 		}
 
-		function GetStep()
-		{
+		function GetStep(){
 			return $this->GetConfig('step', 0);
 		}
-		function DoNext()
-		{
-			if(isset($this->stage[$this->GetStep() + 1]))
-			{
+		
+		function DoNext(){
+			if(isset($this->stage[$this->GetStep() + 1])){
 				$this->ZBX_CONFIG['step']++;
 				return true;
 			}
-			return false;
+		return false;
 		}
-		function DoBack()
-		{
-			if(isset($this->stage[$this->GetStep() - 1]))
-			{
+
+		function DoBack(){
+			if(isset($this->stage[$this->GetStep() - 1])){
 				$this->ZBX_CONFIG['step']--;
 				return true;
 			}
-			return false;
+		return false;
 		}
 
-		function BodyToString($destroy=true)
-		{
+		function BodyToString($destroy=true){
 			$table = new CTable(null, 'setup_wizard');
 			$table->SetAlign('center');
 			$table->SetHeader(array(
@@ -104,13 +97,13 @@
 				new CCol($this->GetState(), 'right')
 				), 'center');
 			
-			$next = new CButton('next['.$this->GetStep().']', S_NEXT);
+			$next = new CButton('next['.$this->GetStep().']', S_NEXT.' >>');
 			if($this->DISABLE_NEXT_BUTTON) $next->SetEnabled(false);
 			
 			$table->SetFooter(array(
 				new CCol(new CButton('cancel',S_CANCEL),'left'), 
 				new CCol(array(
-					isset($this->stage[$this->GetStep()-1]) ? new CButton('back['.$this->GetStep().']', S_PREVIOUS) : null,
+					isset($this->stage[$this->GetStep()-1]) ? new CButton('back['.$this->GetStep().']', '<< '.S_PREVIOUS) : null,
 					isset($this->stage[$this->GetStep()+1]) ? $next: new CButton('finish', S_FINISH)
 					) , 'right')
 				),'footer');
@@ -118,48 +111,42 @@
 			return parent::BodyToString($destroy).$table->ToString();
 		}
 
-		function GetList()
-		{
+		function GetList(){
 			$list = new CList();
-			foreach($this->stage as $id => $data)
-			{
+			foreach($this->stage as $id => $data){
 				if($id < $this->GetStep()) $style = 'completed';
-				elseif($id == $this->GetStep()) $style = 'current';
+				else if($id == $this->GetStep()) $style = 'current';
 				else $style = null;
 				
 				$list->AddItem($data['title'], $style);
 			}
-			return $list->ToString();
+		return $list;
 		}
 
-		function GetState()
-		{
+		function GetState(){
 			$fnc = $this->stage[$this->GetStep()]['fnc'];
 			return  $this->$fnc();
 		}
 
-		function Stage0()
-		{
-
-			return new CTag('div', 'yes', 'Welcome to the ZABBIX frontend installation wizard.'.BR.BR.
-				'This installation wizard will guide you through the installation of ZABBIX frontend'.BR.BR.
+		function Stage0(){			
+			return new CTag('div', 'yes', array('Welcome to the ZABBIX frontend installation wizard.',BR(),BR(),
+				'This installation wizard will guide you through the installation of ZABBIX frontend',BR(),BR(),
 				'Click to "Next" button to proceed to the next screen. If you want to change something '.
-				'on a previous screen, click "Previous" button'.BR.BR.
-				'You may cancel installation at any time by clicking "Cancel" button', 'text');
+				'on a previous screen, click "Previous" button',BR(),BR(),
+				'You may cancel installation at any time by clicking "Cancel" button'), 'text');
 		}
 
-		function Stage1()
-		{
+		function Stage1(){
 			$LICENCE_FILE = 'conf/COPYING';
 
 			$this->DISABLE_NEXT_BUTTON = !$this->GetConfig('agree', false);
 							
 			return array(
 				new CTag('div', 'yes', (file_exists($LICENCE_FILE) ? 
-					nl2br(nbsp(htmlspecialchars(file_get_contents($LICENCE_FILE)))) : 
+					new CScript(nl2br(nbsp(htmlspecialchars(file_get_contents($LICENCE_FILE))))) : 
 					'Missing licence file. See GPL licence.')
 				, 'licence'),
-				BR,
+				BR(),
 				new CTag('div', 'yes',
 					array(
 						new CCheckBox(
@@ -171,8 +158,7 @@
 				);
 		}
 
-		function get_test_result(&$result, $test_name, $test_value, $condition, $fail_message)
-		{
+		function get_test_result(&$result, $test_name, $test_value, $condition, $fail_message){
 			$result &= $condition;
 			
 			$row = new CRow(array(
@@ -188,8 +174,7 @@
 			return $row;
 		}
 
-		function Stage2()
-		{
+		function Stage2(){
 			$final_result = true;
 
 			$table = new CTable(null, 'requirements');
@@ -235,11 +220,11 @@
 				$this->get_test_result(
 					$final_result,
 					'PHP Databases support: ',
-					implode(BR, $ZBX_CONFIG['allowed_db']),
+					new CScript(implode(SBR, $ZBX_CONFIG['allowed_db'])),
 					!isset($ZBX_CONFIG['allowed_db']['no']),
 					'Required any databases support [MySQL or PostgreSQL or Oracle]'));
 
-			/* Check BC math */
+/* Check BC math */
 			$bcmath_fnc_exist = 
 				function_exists('bcadd') &&
 				function_exists('bccomp') &&
@@ -247,7 +232,7 @@
 				function_exists('bcmod') &&
 				function_exists('bcmul') &&
 				function_exists('bcpow') &&
-				/* This function is supported by PHP5 only */
+/* This function is supported by PHP5 only */
 /*				function_exists('bcpowmod') &&*/
 				function_exists('bcscale') &&
 				function_exists('bcsqrt') &&
@@ -259,14 +244,25 @@
 					$bcmath_fnc_exist ? 'yes' : 'no',
 					$bcmath_fnc_exist,
 					'Required bcmath module [configured PHP with --enable-bcmath]'));
+					
+/* Check mb-strings 
+			$mbstrings_fnc_exist = mbstrings_available();
+			$table->AddRow(
+				$this->get_test_result(
+					$final_result,
+					'PHP MB String support',
+					$mbstrings_fnc_exist ? 'yes' : 'no',
+					$mbstrings_fnc_exist,
+					'Required Multibyte String module [configured PHP with --enable-mbstring]'));
+//*/
 
 			/* Check GD existence */
 			$gd_version = S_NO;
-			if(is_callable('gd_info'))
-			{
+			if(is_callable('gd_info')){
 				$gd_info = gd_info();
 				$gd_version = $gd_info['GD Version'];
 			}
+			
 			$table->AddRow(
 				$this->get_test_result(
 					$final_result,
@@ -277,13 +273,12 @@
 
 			/* Check supported image formats */
 			$img_formats = array();
-			if(isset($gd_info))
-			{
+			if(isset($gd_info)){
 				//if($gd_info['JPG Support']) array_push($img_formats, 'JPEG');
 				if($gd_info['PNG Support']) array_push($img_formats, 'PNG');
 			}
-			if(count($img_formats) == 0)
-			{
+			
+			if(count($img_formats) == 0){
 				$img_formats = array(S_NO);
 				$no_img_formats = true;
 			}
@@ -291,12 +286,11 @@
 				$this->get_test_result(
 					$final_result,
 					'Image formats:', 
-					implode(BR, $img_formats),
+					$img_formats,
 					!isset($no_img_formats),
 					'Required images genetarion support [PNG]'));	
 			
-			if(version_compare(phpversion(), '5.1.0RC1', '>='))
-			{
+			if(version_compare(phpversion(), '5.1.0RC1', '>=')){
 				$tmezone = ini_get('date.timezone');
 				$table->AddRow(
 					$this->get_test_result(
@@ -308,41 +302,37 @@
 				unset($tmezone);
 			}
 
-			if(!$final_result)
-			{
+			if(!$final_result){
 				$this->DISABLE_NEXT_BUTTON = true;
 				
 				$this->AddVar('trouble',true);
 				
 				$final_result = array(
 					new CSpan(S_FAIL,'fail'),
-					BR, BR,
+					BR(), BR(),
 					'Please correct all issuse and press "Retry" button',
-					BR, BR,
+					BR(), BR(),
 					new CButton('retry', S_RETRY)
 					);
 			}
-			else
-			{
+			else{
 				$this->DISABLE_NEXT_BUTTON = false;
 				$final_result = new CSpan(S_OK,'ok');
 			}
 			
-			return array($table, BR, $final_result);
+		return array($table, BR(), $final_result);
 		}
 
-		function Stage3()
-		{
-			global $ZBX_CONFIG, $_REQUEST;
+		function Stage3(){
+			global $ZBX_CONFIG;
 
 			$table = new CTable();
 			$table->SetAlign('center');
 			
-			$DB_TYPE = $this->GetConfig('DB_TYPE');
+			$DB['TYPE'] = $this->GetConfig('DB_TYPE');
 
-			$cmbType = new CComboBox('type', $DB_TYPE);
-			foreach($ZBX_CONFIG['allowed_db'] as $id => $name)
-			{
+			$cmbType = new CComboBox('type', $DB['TYPE']);
+			foreach($ZBX_CONFIG['allowed_db'] as $id => $name){
 				$cmbType->AddItem($id, $name);
 			}
 			$table->AddRow(array(S_TYPE, $cmbType));
@@ -353,18 +343,34 @@
 			$table->AddRow(array(S_PASSWORD, new CPassBox('password',	$this->GetConfig('DB_PASSWORD',	''))));
 
 			return array(
-				'Please create database manually.', BR,
+				'Please create database manually.', BR(),
 				'And set the configuration parameters of connection to this database.',
-				BR,BR,
+				BR(),BR(),
 				'And press "Test connection" button.',
-				BR,BR,
+				BR(),BR(),
 				$table,
-				BR,
+				BR(),
 				!$this->DISABLE_NEXT_BUTTON ? new CSpan(S_OK,'ok') :  new CSpan(S_FAIL, 'fail'),
-				BR,
+				BR(),
 				new  CButton('retry', 'Test connection')
 				);
 		}
+
+		function Stage4(){
+			global $ZBX_CONFIG;
+
+			$table = new CTable();
+			$table->SetAlign('center');
+			
+			$table->AddRow(array(S_HOST, new CTextBox('zbx_server',		$this->GetConfig('ZBX_SERVER',		'localhost'))));
+			$table->AddRow(array(S_PORT, new CNumericBox('zbx_server_port',	$this->GetConfig('ZBX_SERVER_PORT',	'10051'),5)));
+
+			return array(
+				'Please enter host name or host IP address', BR(),
+				'and port number of ZABBIX server', BR(), BR(),
+				$table,
+				);
+		}
 		/*
 		function Stage4()
 		{
@@ -404,8 +410,7 @@
 		}
 		*/
 		
-		function Stage5()
-		{
+		function Stage5(){
 			$allowed_db = $this->GetConfig('allowed_db', array());
 			
 			$table = new CTable(null, 'requirements');
@@ -417,32 +422,33 @@
 			$table->AddRow(array('Database user:',		$this->GetConfig('DB_USER',	'unknown')));
 			$table->AddRow(array('Database password:',	ereg_replace('.','*',$this->GetConfig('DB_PASSWORD',	'unknown'))));
 			/* $table->AddRow(array('Distributed monitoring',	$this->GetConfig('distributed', null) ? 'Enabled' : 'Disabled')); */
-			if($this->GetConfig('distributed', null))
-			{
+			
+			if($this->GetConfig('distributed', null)){
 				$table->AddRow(array('Node name',	$this->GetConfig('nodename',	'unknown')));
 				$table->AddRow(array('Node GUID',	$this->GetConfig('nodeid',	'unknown')));
 			}
+
+			$table1 = new CTable(null, 'requirements');
+			$table1->SetAlign('center');
+			$table1->AddRow(array('ZABBIX server:',		$this->GetConfig('ZBX_SERVER',		'unknown')));
+			$table1->AddRow(array('ZABBIX server port:',	$this->GetConfig('ZBX_SERVER_PORT',	'unknown')));
 			return array(
-				'Please check configuration parameters.', BR,
-				'If all correct press "Next" button, or "Previous" button to change configuration parameters.', BR, BR,
-				$table
+				'Please check configuration parameters.', BR(),
+				'If all correct press "Next" button, or "Previous" button to change configuration parameters.', BR(), BR(),
+				$table, BR(),
+				$table1
 				);
 		}
 
-		function Stage6()
-		{
+		function Stage6(){
 			global $_SERVER, $ZBX_CONFIGURATION_FILE;
 
 			show_messages();
 			/* Write the new contents */
-			if($f = @fopen($ZBX_CONFIGURATION_FILE, 'w'))
-			{
-				if(fwrite($f, $this->GetNewConfigurationFileContent()))
-				{
-					if(fclose($f))
-					{
-						if($this->SetConfig('ZBX_CONFIG_FILE_CORRECT', $this->CheckConfigurationFile()))
-						{
+			if($f = @fopen($ZBX_CONFIGURATION_FILE, 'w')){
+				if(fwrite($f, $this->GetNewConfigurationFileContent())){
+					if(fclose($f)){
+						if($this->SetConfig('ZBX_CONFIG_FILE_CORRECT', $this->CheckConfigurationFile())){
 							$this->DISABLE_NEXT_BUTTON = false;
 						}
 					}
@@ -471,83 +477,82 @@
 			*/
 
 			return array(
-				$table, BR,
-				$this->DISABLE_NEXT_BUTTON ? array(new CButton('retry', S_RETRY), BR,BR) : null,
+				$table, BR(),
+				$this->DISABLE_NEXT_BUTTON ? array(new CButton('retry', S_RETRY), BR(),BR()) : null,
 				!$this->GetConfig('ZBX_CONFIG_FILE_CORRECT', false) ? 
-					array('Please install configuration file manualy.',BR,BR,
+					array('Please install configuration file manualy.',BR(),BR(),
 						'By pressing "Save configuration file" button download configuration file ',
-						'and place them into the ',BR,
-						'"'.$ZBX_CONFIGURATION_FILE.'"',BR,BR,
+						'and place them into the ',BR(),
+						'"'.$ZBX_CONFIGURATION_FILE.'"',BR(),BR(),
 						new CButton('save_config',"Save configuration file"),
-						BR,BR
+						BR(),BR()
 						)
 					: null,
 				'Press the '.($this->DISABLE_NEXT_BUTTON ? '"Retry"' : '"Next"').' button'
 				);
 		}
 
-		function Stage7()
-		{
+		function Stage7(){
 			return array(
-				'Congratulation with succesfull instalation of ZABBIX frontend.',BR,BR,
+				'Congratulation with succesfull instalation of ZABBIX frontend.',BR(),BR(),
 				'Press "Finish" button to complete installation'
 				);
 		}
 
-		function CheckConnection()
-		{
-			global $DB, $DB_TYPE, $DB_SERVER, $DB_PORT, $DB_DATABASE, $DB_USER, $DB_PASSWORD;
+		function CheckConnection(){
+			global $DB;
 
-			$old_DB		= $DB;
-			$old_DB_TYPE	= $DB_TYPE;
-			$old_DB_SERVER	= $DB_SERVER;
-			$old_DB_PORT	= $DB_PORT;
-			$old_DB_DATABASE= $DB_DATABASE;
-			$old_DB_USER	= $DB_USER;
-			$old_DB_PASSWORD= $DB_PASSWORD;
+//			$old_DB		= $DB['DB'];
+			if(!empty($DB)){
+				$old_DB			= true;
+				$old_DB_TYPE	= $DB['TYPE'];
+				$old_DB_SERVER	= $DB['SERVER'];
+				$old_DB_PORT	= $DB['PORT'];
+				$old_DB_DATABASE= $DB['DATABASE'];
+				$old_DB_USER	= $DB['USER'];
+				$old_DB_PASSWORD= $DB['PASSWORD'];
+			}
+			
+			$DB['TYPE']	= $this->GetConfig('DB_TYPE');
+			if(is_null($DB['TYPE']))	return false;
 
-			$DB_TYPE	= $this->GetConfig('DB_TYPE');
-			if(is_null($DB_TYPE))	return false;
-
-			$DB_SERVER	= $this->GetConfig('DB_SERVER',		'localhost');
-			$DB_PORT	= $this->GetConfig('DB_PORT',		'0');
-			$DB_DATABASE	= $this->GetConfig('DB_DATABASE',	'zabbix');
-			$DB_USER	= $this->GetConfig('DB_USER',		'root');
-			$DB_PASSWORD	= $this->GetConfig('DB_PASSWORD',	'');
+			$DB['SERVER']	= $this->GetConfig('DB_SERVER',		'localhost');
+			$DB['PORT']		= $this->GetConfig('DB_PORT',		'0');
+			$DB['DATABASE']	= $this->GetConfig('DB_DATABASE',	'zabbix');
+			$DB['USER']		= $this->GetConfig('DB_USER',		'root');
+			$DB['PASSWORD']	= $this->GetConfig('DB_PASSWORD',	'');
 
 			$error = '';
-			if(!($result = DBconnect($error)))
-			{
+			if(!$result = DBconnect($error)){
 				error($error);
 			}
-			else
-			{
-				$result = DBexecute('create table zabbix_installation_test ( test_row integer )');
-				$result &= DBexecute('drop table zabbix_installation_test');
+			else{
+				$result = DBexecute('CREATE table zabbix_installation_test ( test_row integer )');
+				$result &= DBexecute('DROP table zabbix_installation_test');
 			}
 			
 			DBclose();
 
-			if($DB_TYPE == 'SQLITE3' && !zbx_is_callable(array('sem_get','sem_acquire','sem_release','sem_remove')))
-			{
+			if($DB['TYPE'] == 'SQLITE3' && !zbx_is_callable(array('sem_get','sem_acquire','sem_release','sem_remove'))){
 				error('SQLite3 required IPC functions');
 				$result &= false;
 			}
 			
 			/* restore connection */
-			global $DB, $DB_TYPE, $DB_SERVER, $DB_PORT, $DB_DATABASE, $DB_USER, $DB_PASSWORD;
-
-			$DB		= $old_DB;
-			$DB_TYPE	= $old_DB_TYPE;
-			$DB_SERVER	= $old_DB_SERVER;
-			$DB_PORT	= $old_DB_PORT;
-			$DB_DATABASE	= $old_DB_DATABASE;
-			$DB_USER	= $old_DB_USER;
-			$DB_PASSWORD	= $old_DB_PASSWORD;
+			global $DB;
 
+			if(isset($old_DB)){
+				$DB['TYPE']		= $old_DB_TYPE;
+				$DB['SERVER']	= $old_DB_SERVER;
+				$DB['PORT']		= $old_DB_PORT;
+				$DB['DATABASE']	= $old_DB_DATABASE;
+				$DB['USER']		= $old_DB_USER;
+				$DB['PASSWORD']	= $old_DB_PASSWORD;
+			}
+			
 			DBconnect($error);
 
-			return $result;
+		return $result;
 		}
 		
 		/*
@@ -560,7 +565,7 @@
 			{
 				include $ZBX_CONFIGURATION_FILE;
 			
-				switch($DB_TYPE)
+				switch($DB['TYPE'])
 				{
 					case 'MYSQL':		$ZBX_SCHEMA_FILE = 'mysql.sql';		break;
 					case 'POSTGRESQL':	$ZBX_SCHEMA_FILE = 'postgresql.sql';	break;
@@ -638,100 +643,100 @@
 
 		function CheckConfigurationFile()
 		{
-			global $DB, $DB_TYPE, $DB_SERVER, $DB_PORT, $DB_DATABASE, $DB_USER, $DB_PASSWORD;
+			global $DB,$ZBX_SERVER,$ZBX_SERVER_PORT;
 
-			$old_DB		= $DB;
-			$old_DB_TYPE	= $DB_TYPE;
-			$old_DB_SERVER	= $DB_SERVER;
-			$old_DB_PORT	= $DB_PORT;
-			$old_DB_DATABASE= $DB_DATABASE;
-			$old_DB_USER	= $DB_USER;
-			$old_DB_PASSWORD= $DB_PASSWORD;
+			if(!empty($DB)){
+				$old_DB				= true;
+				$old_DB_TYPE		= $DB['TYPE'];
+				$old_DB_SERVER		= $DB['SERVER'];
+				$old_DB_PORT		= $DB['PORT'];
+				$old_DB_DATABASE	= $DB['DATABASE'];
+				$old_DB_USER		= $DB['USER'];
+				$old_DB_PASSWORD	= $DB['PASSWORD'];
+				
+				$old_ZBX_SERVER		= $ZBX_SERVER;
+				$old_ZBX_SERVER_PORT	= $ZBX_SERVER_PORT;
+			}
+			
 
 			$error = null;
 			$error_msg = null;
 
 			global $ZBX_CONFIGURATION_FILE;
 						
-			if(file_exists($ZBX_CONFIGURATION_FILE))
-			{
+			if(file_exists($ZBX_CONFIGURATION_FILE)){
 				include $ZBX_CONFIGURATION_FILE;
 
-				if(	isset($DB_TYPE) && 
-					isset($DB_SERVER) && 
-					isset($DB_DATABASE) && 
-					isset($DB_USER) && 
-					isset($DB_PASSWORD) &&
+				if(	isset($DB['TYPE']) && 
+					isset($DB['SERVER']) && 
+					isset($DB['DATABASE']) && 
+					isset($DB['USER']) && 
+					isset($DB['PASSWORD']) &&
+					isset($ZBX_SERVER) &&
+					isset($ZBX_SERVER_PORT) &&
 					isset($IMAGE_FORMAT_DEFAULT) &&
-					$DB_TYPE		== $this->GetConfig('DB_TYPE',				null) &&
-					$DB_SERVER		== $this->GetConfig('DB_SERVER',			null) &&
-					$DB_PORT		== $this->GetConfig('DB_PORT',				null) &&
-					$DB_DATABASE		== $this->GetConfig('DB_DATABASE',			null) &&
-					$DB_USER		== $this->GetConfig('DB_USER',				null) &&
-					$DB_PASSWORD		== $this->GetConfig('DB_PASSWORD',			null)
+					$DB['TYPE']		== $this->GetConfig('DB_TYPE',				null) &&
+					$DB['SERVER']		== $this->GetConfig('DB_SERVER',			null) &&
+					$DB['PORT']		== $this->GetConfig('DB_PORT',				null) &&
+					$DB['DATABASE']		== $this->GetConfig('DB_DATABASE',			null) &&
+					$DB['USER']		== $this->GetConfig('DB_USER',				null) &&
+					$DB['PASSWORD']		== $this->GetConfig('DB_PASSWORD',			null)
 					)
 				{
-					if(!DBconnect($error_msg))
-					{
+					if(!DBconnect($error_msg)){
 						$error_msg = 'Can not connect to database';
 					}
 				}
-				else
-				{
+				else{
 					$error_msg = 'Incorrect configuration file['.$ZBX_CONFIGURATION_FILE.']';
 				}
 				DBclose();
 			}
-			else
-			{
+			else{
 				$error = 'Missing configuration file['.$ZBX_CONFIGURATION_FILE.']';
 			}
 			
-			if(isset($error_msg))
-			{
+			if(isset($error_msg)){
 				error($error_msg);
 			}
 
 			/* restore connection */
-			global $DB, $DB_TYPE, $DB_PORT, $DB_SERVER, $DB_DATABASE, $DB_USER, $DB_PASSWORD;
+			global $DB;
 
-			$DB		= $old_DB;
-			$DB_TYPE	= $old_DB_TYPE;
-			$DB_SERVER	= $old_DB_SERVER;
-			$DB_PORT	= $old_DB_PORT;
-			$DB_DATABASE	= $old_DB_DATABASE;
-			$DB_USER	= $old_DB_USER;
-			$DB_PASSWORD	= $old_DB_PASSWORD;
+			if(isset($old_DB)){
+				$DB['TYPE']		= $old_DB_TYPE;
+				$DB['SERVER']	= $old_DB_SERVER;
+				$DB['PORT']		= $old_DB_PORT;
+				$DB['DATABASE']	= $old_DB_DATABASE;
+				$DB['USER']		= $old_DB_USER;
+				$DB['PASSWORD']	= $old_DB_PASSWORD;
+				
+				$ZBX_SERVER	= $old_ZBX_SERVER;
+				$ZBX_SERVER_PORT= $old_ZBX_SERVER_PORT;
+			}
 
 			DBconnect($error2);
 
 			return !isset($error)&&!isset($error_msg);
 		}
 		
-		function EventHandler()
-		{
-			global $_REQUEST;
-
+		function EventHandler(){
 			if(isset($_REQUEST['back'][$this->GetStep()]))	$this->DoBack();	
 
-			if($this->GetStep() == 1)
-			{
-				if(!isset($_REQUEST['next'][0]) && !isset($_REQUEST['back'][2]))
-				{
-					$this->SetConfig('agree', isset($_REQUEST['agree']));
+			if($this->GetStep() == 1){
+				if(!isset($_REQUEST['next'][0]) && !isset($_REQUEST['back'][2])){
+					$this->setConfig('agree', isset($_REQUEST['agree']));
 				}
 				
-				if(isset($_REQUEST['next'][$this->GetStep()]) && $this->GetConfig('agree', false))
-				{
+				if(isset($_REQUEST['next'][$this->GetStep()]) && $this->GetConfig('agree', false)){
 					$this->DoNext();
 				}
 			}
-			if($this->GetStep() == 2 && isset($_REQUEST['next'][$this->GetStep()]) && !isset($_REQUEST['trouble']))
-			{
+			
+			if($this->GetStep() == 2 && isset($_REQUEST['next'][$this->GetStep()]) && !isset($_REQUEST['trouble'])){
 				$this->DoNext();
 			}
-			if($this->GetStep() == 3)
-			{
+			if($this->GetStep() == 3){
 				$this->SetConfig('DB_TYPE',	get_request('type',	$this->GetConfig('DB_TYPE')));
 				$this->SetConfig('DB_SERVER',	get_request('server',	$this->GetConfig('DB_SERVER',	'localhost')));
 				$this->SetConfig('DB_PORT',	get_request('port',	$this->GetConfig('DB_PORT',	'0')));
@@ -739,11 +744,17 @@
 				$this->SetConfig('DB_USER',	get_request('user',	$this->GetConfig('DB_USER',	'root')));
 				$this->SetConfig('DB_PASSWORD',	get_request('password',	$this->GetConfig('DB_PASSWORD',	'')));
 		
-				if(!$this->CheckConnection())
-				{
+				if(!$this->CheckConnection()){
 					$this->DISABLE_NEXT_BUTTON = true;
 					unset($_REQUEST['next']);
 				}
+				
+				if(isset($_REQUEST['next'][$this->GetStep()]))		$this->DoNext();
+			}
+			
+			if($this->GetStep() == 4){
+				$this->SetConfig('ZBX_SERVER',		get_request('zbx_server',	$this->GetConfig('ZBX_SERVER',		'localhost')));
+				$this->SetConfig('ZBX_SERVER_PORT',	get_request('zbx_server_port',	$this->GetConfig('ZBX_SERVER_PORT',	'10051')));
 				if(isset($_REQUEST['next'][$this->GetStep()]))		$this->DoNext();
 			}
 
@@ -773,12 +784,12 @@
 			}
 			*/
 
-			if($this->GetStep() == 4 && isset($_REQUEST['next'][$this->GetStep()]))
+			if($this->GetStep() == 5 && isset($_REQUEST['next'][$this->GetStep()]))
 			{
 				$this->DoNext();
 			}
 
-			if($this->GetStep() == 5)
+			if($this->GetStep() == 6)
 			{
 				$this->SetConfig('ZBX_CONFIG_FILE_CORRECT', $this->CheckConfigurationFile());
 				
@@ -838,14 +849,17 @@
 ** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/
 
-global $DB_TYPE, $DB_SERVER, $DB_PORT, $DB_DATABASE, $DB_USER, $DB_PASSWORD, $IMAGE_FORMAT_DEFAULT;
+global $DB;
+
+$DB["TYPE"]		= "'.$this->GetConfig('DB_TYPE'		,'unknown').'";
+$DB["SERVER"]		= "'.$this->GetConfig('DB_SERVER'	,'unknown').'";
+$DB["PORT"]		= "'.$this->GetConfig('DB_PORT'		,'0').'";
+$DB["DATABASE"]		= "'.$this->GetConfig('DB_DATABASE'	,'unknown').'";
+$DB["USER"]		= "'.$this->GetConfig('DB_USER'		,'unknown').'";
+$DB["PASSWORD"]		= "'.$this->GetConfig('DB_PASSWORD'	,'').'";
+$ZBX_SERVER		= "'.$this->GetConfig('ZBX_SERVER'	,'').'";
+$ZBX_SERVER_PORT	= "'.$this->GetConfig('ZBX_SERVER_PORT'	,'0').'";
 
-$DB_TYPE	= "'.$this->GetConfig('DB_TYPE'		,'unknown').'";
-$DB_SERVER	= "'.$this->GetConfig('DB_SERVER'	,'unknown').'";
-$DB_PORT	= "'.$this->GetConfig('DB_PORT'		,'0').'";
-$DB_DATABASE	= "'.$this->GetConfig('DB_DATABASE'	,'unknown').'";
-$DB_USER	= "'.$this->GetConfig('DB_USER'		,'unknown').'";
-$DB_PASSWORD	= "'.$this->GetConfig('DB_PASSWORD'	,'').'";
 
 $IMAGE_FORMAT_DEFAULT	= IMAGE_FORMAT_PNG;
 ?>';
