@@ -19,9 +19,9 @@
 **/
 ?>
 <?php
-	require_once "maps.inc.php";
-	require_once "acknow.inc.php";
-	require_once "services.inc.php";
+	require_once('maps.inc.php');
+	require_once('acknow.inc.php');
+	require_once('services.inc.php');
 
 	/*
 	 * Function: INIT_TRIGGER_EXPRESSION_STRUCTURES
@@ -103,7 +103,8 @@
 		$ZBX_TR_EXPR_ALLOWED_FUNCTIONS['iregexp']= array('args' => array( 0 => array('type' => 'str','mandat' => true) ),
 			'item_types' => array(
 				ITEM_VALUE_TYPE_STR,
-				ITEM_VALUE_TYPE_LOG
+				ITEM_VALUE_TYPE_LOG,
+				ITEM_VALUE_TYPE_TEXT
 				)
 			);
 		$ZBX_TR_EXPR_ALLOWED_FUNCTIONS['last']	= array('args' => null,
@@ -139,7 +140,8 @@
 		$ZBX_TR_EXPR_ALLOWED_FUNCTIONS['str']	= array('args' => array( 0 => array('type' => 'str','mandat' => true) ),
 			'item_types' => array(
 				ITEM_VALUE_TYPE_STR,
-				ITEM_VALUE_TYPE_LOG
+				ITEM_VALUE_TYPE_LOG,
+				ITEM_VALUE_TYPE_TEXT
 				)
 			);
 
@@ -164,7 +166,8 @@
 		$ZBX_TR_EXPR_ALLOWED_FUNCTIONS['regexp']= array('args' => array( 0 => array('type' => 'str','mandat' => true) ),
 			'item_types' => array(
 				ITEM_VALUE_TYPE_STR,
-				ITEM_VALUE_TYPE_LOG
+				ITEM_VALUE_TYPE_LOG,
+				ITEM_VALUE_TYPE_TEXT
 				)
 			);
 		$ZBX_TR_EXPR_ALLOWED_FUNCTIONS['time']	= array('args' => null, 'item_types' => null );
@@ -182,17 +185,19 @@
  *     Aly
  *
  */		
-	function get_accessible_triggers($perm,$perm_res=null,$nodeid=null,$hostid=null,$cache=1){
+	function get_accessible_triggers($perm,$hostids,$perm_res=null,$nodeid=null,$cache=1){
 		global $USER_DETAILS;
 		static $available_triggers;
+		zbx_value2array($hostids);
 		
 		$result = array();
 		if(is_null($perm_res)) $perm_res = PERM_RES_IDS_ARRAY;
 		$nodeid_str =(is_array($nodeid))?implode('',$nodeid):strval($nodeid);
-		$hostid_str =(is_array($hostid))?implode('',$hostid):strval($hostid);
-			
-		if($cache && isset($available_triggers[$perm][$perm_res][$nodeid_str][$hostid_str])){
-			return $available_triggers[$perm][$perm_res][$nodeid_str][$hostid_str];
+		$hostid_str = implode('',$hostids);
+
+		$cache_hash = md5($perm.$perm_res.$nodeid_str.$hostid_str);
+		if($cache && isset($available_triggers[$cache_hash])){
+			return $available_triggers[$cache_hash];
 		}
 
 		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, $perm, PERM_RES_IDS_ARRAY, $nodeid);
@@ -200,23 +205,30 @@
 		$denied_triggers = array();
 		$available_triggers = array();
 		
+		$sql_where = '';
+		if(!empty($hostids)){
+			$sql_where.= ' AND '.DBcondition('i.hostid',$hostids);
+		}		
 		$sql = 	'SELECT DISTINCT t.triggerid '.
 				' FROM triggers t, functions f, items i '.
 				' WHERE t.triggerid=f.triggerid '.
 					' AND f.itemid=i.itemid'.
-					(!empty($hostid)?' AND i.hostid='.$hostid:'').
-					' AND '.DBcondition('i.hostid',$available_hosts,true);
+					' AND '.DBcondition('i.hostid',$available_hosts,true).
+					$sql_where;
 		$db_triggers = DBselect($sql);
 		while($trigger = DBfetch($db_triggers)){
 			$denied_triggers[] = $trigger['triggerid'];
 		}
 
+		if(!empty($denied_triggers)){
+			$sql_where.= ' AND '.DBcondition('t.triggerid',$denied_triggers,true);
+		}
+
 		$sql = 	'SELECT DISTINCT t.triggerid '.
 				' FROM triggers t, functions f, items i '.
 				' WHERE t.triggerid=f.triggerid '.
 					' AND f.itemid=i.itemid'.
-					(!empty($hostid)?' AND i.hostid='.$hostid:'').
-					(!empty($denied_triggers)?' AND '.DBcondition('t.triggerid',$denied_triggers,true):'');
+					$sql_where;
 		$db_triggers = DBselect($sql);
 		while($trigger = DBfetch($db_triggers)){
 			$result[$trigger['triggerid']] = $trigger['triggerid'];
@@ -229,7 +241,7 @@
 				$result = implode(',',$result);
 		}
 		
-		$available_triggers[$perm][$perm_res][$nodeid_str][$hostid_str] = $result;
+		$available_triggers[$cache_hash] = $result;
 		
 	return $result;
 	}
@@ -1148,7 +1160,7 @@
 			}
 		}
 
-	return $description;
+		return $description;
 	}
 	/*
 	 * Function: expand_trigger_description_by_data
@@ -1166,45 +1178,51 @@
 		if($row){
 			$description = expand_trigger_description_constants($row['description'], $row);
 
-			if(is_null($row["host"])) $row["host"] = "{HOSTNAME}";
-			$description = str_replace("{HOSTNAME}", $row["host"],$description);
+			if(is_null($row['host'])) $row['host'] = '{HOSTNAME}';
+			$description = str_replace('{HOSTNAME}', $row['host'],$description);
 
-			if(zbx_strstr($description,"{ITEM.LASTVALUE}")){
-				$row2=DBfetch(DBselect('SELECT i.lastvalue, i.value_type, i.itemid '.
-										' FROM items i, triggers t, functions f '.
-										' WHERE i.itemid=f.itemid '.
-											' AND f.triggerid=t.triggerid '.
-											' AND t.triggerid='.$row['triggerid']));
+			if(zbx_strstr($description,'{ITEM.LASTVALUE}')){
+			
+				$functionid=trigger_get_N_functionid($row['expression'], 1);
 
-				if($row2['value_type']!=ITEM_VALUE_TYPE_LOG){
-					$description = str_replace('{ITEM.LASTVALUE}', $row2['lastvalue'],$description);
-				}
-				else{
-					$row3=DBfetch(DBselect("select max(clock) as max from history_log where itemid=".$row2["itemid"]));
-					if($row3 && !is_null($row3["max"])){
-						$row4=DBfetch(DBselect("select value from history_log where itemid=".$row2["itemid"]." and clock=".$row3["max"]));
-						$description = str_replace("{ITEM.LASTVALUE}", $row4["value"],$description);
+				if(isset($functionid)){
+					$sql = 'SELECT i.lastvalue, i.value_type, i.itemid '.
+							' FROM items i, functions f '.
+							' WHERE i.itemid=f.itemid '.
+								' AND f.functionid='.$functionid;
+					$row2=DBfetch(DBselect($sql));
+					if($row2['value_type']!=ITEM_VALUE_TYPE_LOG){
+						$description = str_replace('{ITEM.LASTVALUE}', $row2['lastvalue'], $description);
+					}
+					else{
+						$sql = 'SELECT MAX(clock) as max FROM history_log WHERE itemid='.$row2['itemid'];
+						$row3=DBfetch(DBselect($sql));
+						if($row3 && !is_null($row3['max'])){
+							$sql = 'SELECT value FROM history_log WHERE itemid='.$row2['itemid'].' AND clock='.$row3['max'];
+							$row4=DBfetch(DBselect($sql));
+							$description = str_replace('{ITEM.LASTVALUE}', $row4['value'], $description);
+						}
 					}
 				}
 			}
 
 			if(zbx_strstr($description,'{ITEM.VALUE}')){
 				$value=($flag==ZBX_FLAG_TRIGGER)?
-						trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,1,1):
-						trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,1,$row['clock']);
+						trigger_get_func_value($row['expression'],ZBX_FLAG_TRIGGER,1,1):
+						trigger_get_func_value($row['expression'],ZBX_FLAG_EVENT,1,$row['clock']);
 						
-				$description = str_replace("{ITEM.VALUE}",
+				$description = str_replace('{ITEM.VALUE}',
 						$value,
 						$description);
 			}
 
 			for($i=1; $i<10; $i++){
-				if(zbx_strstr($description,"{ITEM.VALUE$i}")){
+				if(zbx_strstr($description,'{ITEM.VALUE'.$i.'}')){
 					$value=($flag==ZBX_FLAG_TRIGGER)?
-							trigger_get_func_value($row["expression"],ZBX_FLAG_TRIGGER,$i,1):
-							trigger_get_func_value($row["expression"],ZBX_FLAG_EVENT,$i,$row['clock']);
+							trigger_get_func_value($row['expression'],ZBX_FLAG_TRIGGER,$i,1):
+							trigger_get_func_value($row['expression'],ZBX_FLAG_EVENT,$i,$row['clock']);
 							
-					$description = str_replace("{ITEM.VALUE$i}",
+					$description = str_replace('{ITEM.VALUE'.$i.'}',
 							$value,
 							$description);
 				}
@@ -1212,29 +1230,25 @@
 			}
 		}
 		else{
-			$description = "*ERROR*";
+			$description = '*ERROR*';
 		}
 	return $description;
 	}
 	
 	function expand_trigger_description_simple($triggerid){
-		return expand_trigger_description_by_data(
-			DBfetch(
-				DBselect('SELECT DISTINCT t.description,h.host,t.expression,t.triggerid '.
-					' FROM triggers t '.
-						' LEFT JOIN functions f on t.triggerid=f.triggerid '.
-						' LEFT JOIN items i on f.itemid=i.itemid '.
-						' LEFT JOIN hosts h on i.hostid=h.hostid '.
-					' WHERE t.triggerid='.$triggerid)
-				)
-			);
+		$sql = 'SELECT DISTINCT t.description,h.host,t.expression,t.triggerid '.
+				' FROM triggers t '.
+					' LEFT JOIN functions f on t.triggerid=f.triggerid '.
+					' LEFT JOIN items i on f.itemid=i.itemid '.
+					' LEFT JOIN hosts h on i.hostid=h.hostid '.
+				' WHERE t.triggerid='.$triggerid;
+		return expand_trigger_description_by_data(DBfetch(DBselect($sql)));
 	}
 
 	function expand_trigger_description($triggerid){
 		$description=expand_trigger_description_simple($triggerid);
 		$description=htmlspecialchars($description);
-
-	return $description;
+		return $description;
 	}
 
 	function update_trigger_value_to_unknown_by_hostid($hostids){
@@ -1397,7 +1411,7 @@
 	return $result;
 	}
 
-	# Update Trigger definition
+// Update Trigger definition
 
 	/******************************************************************************
 	 *                                                                            *
@@ -1510,13 +1524,12 @@
 	}
 
 	function check_right_on_trigger_by_expression($permission,$expression){
-	
 		global $USER_DETAILS;
 		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, $permission, null, get_current_nodeid(true));
 
 		$db_hosts = get_hosts_by_expression($expression);
 		while($host_data = DBfetch($db_hosts)){
-			if(!uint_in_array($host_data['hostid'], $available_hosts)) return false;
+			if(!isset($available_hosts[$host_data['hostid']])) return false;
 		}
 
 		return true;
@@ -1822,36 +1835,28 @@
 		}
 	}
 
-	/*
-	 * Function: get_triggers_overview
-	 *
-	 * Description: 
-	 *     Retrive table with overview of triggers
-	 *     
-	 * Author: 
-	 *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
-	 *
-	 * Comments: !!! Don't forget sync code with C !!!
-	 *
-	 */
-	function get_triggers_overview($groupid,$view_style=null){
-		global $USER_DETAILS;
-		
-		$available_triggers = get_accessible_triggers(PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
+/*
+ * Function: get_triggers_overview
+ *
+ * Description: 
+ *     Retrive table with overview of triggers
+ *     
+ * Author: 
+ *     Eugene Grigorjev (eugene.grigorjev@zabbix.com)
+ *
+ * Comments: !!! Don't forget sync code with C !!!
+ *
+ */
+	function get_triggers_overview($hostids,$view_style=null){		
+		$available_triggers = get_accessible_triggers(PERM_READ_ONLY,$hostids);
 		
 		if(is_null($view_style)) $view_style = get_profile('web.overview.view.style',STYLE_TOP);
 		
 		$table = new CTableInfo(S_NO_TRIGGERS_DEFINED);
-		if($groupid > 0){
-			$group_where = ',hosts_groups hg WHERE hg.groupid='.$groupid.' AND hg.hostid=h.hostid AND ';
-		} 
-		else {
-			$group_where = ' WHERE ';
-		}
 
 		$result=DBselect('SELECT DISTINCT t.triggerid,t.description,t.expression,t.value,t.priority,t.lastchange,h.hostid,h.host'.
 			' FROM hosts h,items i,triggers t, functions f '.
-			$group_where.' h.status='.HOST_STATUS_MONITORED.
+			' WHERE h.status='.HOST_STATUS_MONITORED.
 				' AND h.hostid=i.hostid '.
 				' AND i.itemid=f.itemid '.
 				' AND f.triggerid=t.triggerid'.
