@@ -21,14 +21,17 @@
 var agt = navigator.userAgent.toLowerCase();
 var OP = (agt.indexOf("opera") != -1) && window.opera;
 var IE = (agt.indexOf("msie") != -1) && document.all && !OP;
+var CR = (agt.indexOf('chrome') != -1);
 var SF = (agt.indexOf("safari") != -1);
 var KQ = (agt.indexOf("khtml") != -1) && (!SF);
 var GK = (agt.indexOf("gecko") != -1) && !KQ && !SF;
 var MC = (agt.indexOf('mac') != -1)
 
+
 function checkBrowser(){
 	if(OP) SDI('Opera');
 	if(IE) SDI('IE');
+	if(CR) SDI('Chrome');
 	if(SF) SDI('Safari');
 	if(KQ) SDI('Konqueror');
 	if(MC) SDI('Mac');
@@ -60,7 +63,7 @@ function is_string(obj){
 
 function is_array(obj) {
 	return obj != null && typeof obj == "object" &&
-      'splice' in obj && 'join' in obj;	  
+      'splice' in obj && 'join' in obj;
 }
 
 function SDI(msg){
@@ -70,11 +73,11 @@ function SDI(msg){
 		var div_help = document.createElement('div');
 		var doc_body = document.getElementsByTagName('body')[0];
 		doc_body.appendChild(div_help);
-		
+
 		div_help.setAttribute('id','div_help');
-		div_help.setAttribute('style','position: absolute; left: 10px; top: 10px; border: 1px red solid; width: 500px; height: 400px; background-color: white; overflow: auto; z-index: 20;');
+		div_help.setAttribute('style','position: absolute; left: 10px; top: 100px; border: 1px red solid; width: 500px; height: 400px; background-color: white; overflow: auto; z-index: 20;');
 	}
-	
+
 	div_help.appendChild(document.createTextNode("DEBUG INFO: "));
 	div_help.appendChild(document.createElement("br"));
 	div_help.appendChild(document.createTextNode(msg));
@@ -82,27 +85,38 @@ function SDI(msg){
 	div_help.appendChild(document.createElement("br"));
 }
 
+function SDJ(obj){
+	var debug = '';
+	for(var key in obj) {
+		var value = obj[key];
+		debug+=key+': '+value+'\n';
+	}
+	SDI('\n'+debug);
+}
+
+
 /// Alpha-Betic sorting
 
 function addListener(element, eventname, expression, bubbling){
 	bubbling = bubbling || false;
-	
-	if(window.addEventListener)	{
+
+	if(window.addEventListener){
 		element.addEventListener(eventname, expression, bubbling);
 		return true;
-	} 
-	else if(window.attachEvent) {
+	}
+	else if(window.attachEvent){
 		element.attachEvent('on'+eventname, expression);
 		return true;
-	} 
+	}
 	else return false;
 }
 
+
 function add_variable(o_el, s_name, x_value, s_formname, o_document){
 	var form;
-	
+
 	if(!o_document)	o_document = document;
-	
+
 	if(s_formname){
 		if( !(form = o_document.forms[s_formname]) )
 			 throw "Missed form with name '"+s_formname+"'.";
@@ -115,23 +129,23 @@ function add_variable(o_el, s_name, x_value, s_formname, o_document){
 		if( !(form = this.form) )
 			throw "Missed form in 'this' object";
 	}
-	
+
 	var o_variable = o_document.createElement('input');
-	
+
 	if( !o_variable )	throw "Can't create element";
-	
+
 	o_variable.type = 'hidden';
 	o_variable.name = s_name;
 	o_variable.id = s_name;
 	o_variable.value = x_value;
 
 	form.appendChild(o_variable);
-	
+
 return true;
 }
 
 function cancelEvent(e){
-	if (!e) var e = window.event;	
+	if (!e) var e = window.event;
 //SDI(e);
 	if(e){
 		if(IE){
@@ -160,7 +174,7 @@ function CheckAll(form_name, chkMain, shkName){
 }
 
 function close_window(){
-	
+
 	window.setTimeout("window.close()", 500); /* Solve bug for Internet Explorer */
 	return false;
 }
@@ -173,7 +187,7 @@ function Confirm(msg){
 }
 
 function create_var(form_name, var_name, var_val, subm){
-	
+
 	var frmForm = (is_string(form_name))?document.forms[form_name]:form_name;
 	if(!frmForm) return false;
 
@@ -183,17 +197,16 @@ function create_var(form_name, var_name, var_val, subm){
 	if(is_null(objVar)){
 		objVar = document.createElement('input');
 		objVar.setAttribute('type', 	'hidden');
-		
+
 		if(!objVar) return false;
 
 		frmForm.appendChild(objVar);
-		
+
 		objVar.setAttribute('name', 	var_name);
 		objVar.setAttribute('id', 		var_name);
 	}
-	
-	objVar.value = var_val;
 
+	objVar.value = var_val;
 	if(subm)
 		frmForm.submit();
 
@@ -205,7 +218,7 @@ function deselectAll(){
 	if(IE){
 		document.selection.empty();
 	}
-	else if(!KQ){	
+	else if(!KQ){
 		var sel = window.getSelection();
 		sel.removeAllRanges();
 	}
@@ -214,31 +227,31 @@ function deselectAll(){
 function empty_form(id){
 	id = $(id);
 	var count = 0;
-	
+
 	var inputs = id.getElementsByTagName('input');
 	for(var i=0; i<inputs.length;i++){
 		if((inputs[i].type == 'text') && (typeof(inputs[i].hidden) == 'undefined') && !empty(inputs[i].value)) return false;
 		if((inputs[i].type == 'checkbox') && (inputs[i].checked)) return false;
 	}
-	
+
 	var selects = id.getElementsByTagName('select');
 	for(var i=0; i<selects.length;i++){
 		if((typeof(selects[i].hidden) == 'undefined') && (selects[i].selectedIndex)) return false;
 	}
-	
+
 return true;
 }
 
 function eventTarget(e){
 	var targ = false;
-	
+
 	if (!e) var e = window.event;
 	if (e.target) targ = e.target;
 	else if (e.srcElement) targ = e.srcElement;
-	
+
 // defeat Safari bug
 	if (targ.nodeType == 3) targ = targ.parentNode;
-	
+
 return targ;
 }
 
@@ -292,13 +305,13 @@ function get_cursor_position(e){
 	if(e.pageX || e.pageY){
 		cursor.x = e.pageX;
 		cursor.y = e.pageY;
-	} 
+	}
 	else {
 		var de = document.documentElement;
 		var b = document.body;
-		cursor.x = e.clientX + 
+		cursor.x = e.clientX +
 		(de.scrollLeft || b.scrollLeft) - (de.clientLeft || 0);
-		cursor.y = e.clientY + 
+		cursor.y = e.clientY +
 		(de.scrollTop || b.scrollTop) - (de.clientTop || 0);
 	}
 	return cursor;
@@ -326,6 +339,9 @@ function get_scroll_pos(){
 
 
 function openWinCentered(loc, winname, iwidth, iheight, params){
+		var uri = new url(loc);
+		loc = uri.getUrl();
+
 		tp=Math.ceil((screen.height-iheight)/2);
 		lf=Math.ceil((screen.width-iwidth)/2);
 		if (params.length > 0){
@@ -341,19 +357,21 @@ function PopUp(url,width,height,form_name){
 	if(!height) height = 450;
 	if(!form_name) form_name = 'zbx_popup';
 
-	var left = (screen.width-(width+150))/2; 
+	var left = (screen.width-(width+150))/2;
 	var top = (screen.height-(height+150))/2;
-	
+
 	var popup = window.open(url,form_name,'width=' + width +',height=' + height + ',top='+ top +',left='+ left +
 			',resizable=yes,scrollbars=yes,location=no,menubar=no');
 
 	popup.focus();
-	
+
 	return false;
 }
 
-function redirect(url) {
-	window.location = url;
+function redirect(uri) {
+	uri = new url(uri);
+	var loc = uri.getUrl();
+	window.location = loc;
 	return false;
 }
 
@@ -364,7 +382,7 @@ function remove_childs(form_name,rmvbyname,tag){
 		if(frmForm.elements[i].type != 'checkbox') continue;
 		if(frmForm.elements[i].disabled == true) continue;
 		if(frmForm.elements[i].checked != true) continue;
-		
+
 		var splt = frmForm.elements[i].name.split('[');
 		var name = splt[0];
 		var serviceid = splt[1];
@@ -382,10 +400,10 @@ function remove_element(elmnt,tag){
 	if(!is_null(elmnt)){
 		if(('undefined' != typeof(elmnt.nodeName)) && (elmnt.nodeName.toLowerCase() == tag.toLowerCase())){
 			elmnt.parentNode.removeChild(elmnt);
-		} 
+		}
 		else if(elmnt.nodeType == 9){
 			return false;
-		} 
+		}
 		else {
 			remove_element(elmnt.parentNode,tag);
 		}
@@ -400,13 +418,13 @@ function resizeiframe(id){
 	if(typeof(indoc) == 'undefined') return;
 	var height = parseInt(indoc.getElementsByTagName('body')[0].scrollHeight);
 	var height2 = parseInt(indoc.getElementsByTagName('body')[0].offsetHeight);
-	
+
 	if(height2 > height){
 		height = height2;
 	}
 
 	iframe.style.height = (height)+'px';
-	
+
 	if(!is_null($('scroll')) && showgraphmenu){
 		showgraphmenu('iframe');
 	}
@@ -418,7 +436,7 @@ function ShowHide(obj,style){
 	if(is_string(obj))
 		obj = document.getElementById(obj);
 	if(!obj){
-		throw 'ShowHide(): Object not foun.';
+		throw 'ShowHide(): Object not found.';
 		return false;
 	}
 
@@ -430,7 +448,6 @@ function ShowHide(obj,style){
 		obj.style.display = style;
 		return 1;
 	}
-return false;
 }
 
 function switchElementsClass(obj,class1,class2){
@@ -462,8 +479,170 @@ function ScaleChartToParenElement(obj_name){
 	}
 }
 
+function insert_in_element(element_name, text){
+	var elems = document.getElementsByName(element_name);
+	
+	for(var key=0; key < elems.length; key++){
+		if((typeof(elems[key]) != 'undefined') && !is_null(elems[key])){
+			$(elems[key]).update(text);
+		}
+	}
+}
+
 function insert_sizeable_graph(graph_id,url){
 	if((typeof(ZBX_G_WIDTH) != 'undefined')) url += "&amp;width="+ZBX_G_WIDTH;
 
 	document.write('<img id="'+graph_id+'" src="'+url+'" alt="graph" /><br />');
-}
\ No newline at end of file
+}
+
+/************************************************************************************/
+/*									MAIN MENU stuff									*/
+/************************************************************************************/
+// Author: Aly
+
+var MMenu = {
+menus:			{'empty': 0, 'view': 0, 'cm': 0, 'reports': 0, 'config': 0, 'admin': 0},
+def_label:		null,
+sub_active: 	false,
+timeout: 		null,
+
+mouseOver: function(show_label){
+	clearTimeout(this.timeout);
+	MMenu.showSubMenu(show_label);
+},
+
+submenu_mouseOver: function(){
+	clearTimeout(this.timeout);
+},
+
+mouseOut: function(){
+	this.timeout = setTimeout('MMenu.showSubMenu("'+this.def_label+'")', 2000);
+},
+
+showSubMenu: function(show_label){
+	var menu_div  = $('sub_'+show_label);
+	if(!is_null(menu_div)){
+		$(show_label).className = 'active';
+		menu_div.show();
+		for(var key in this.menus){
+			if(key == show_label) continue;
+
+			var menu_cell = $(key);
+			if(!is_null(menu_cell)) menu_cell.className = '';
+
+			var sub_menu_cell = $('sub_'+key);
+			if(!is_null(sub_menu_cell)) sub_menu_cell.hide();
+		}
+	}
+}
+}
+
+
+/************************************************************************************/
+/*						Automatic checkbox range selection 							*/
+/************************************************************************************/
+// Author: Aly
+
+var chkbx_range_ext = {
+startbox: 			null,			// start checkbox obj
+startbox_name: 		null,			// start checkbox name
+chkboxes:			new Array(),	// ckbx list
+
+init: function(){
+	var chk_bx = document.getElementsByTagName('input');
+	for(var i=0; i < chk_bx.length; i++){
+		if((typeof(chk_bx[i]) != 'undefined') && (chk_bx[i].type.toLowerCase() == 'checkbox')){
+			this.implement(chk_bx[i]);
+		}
+	}
+},
+
+implement: function(obj){
+	var obj_name = obj.name.split('[')[0];
+
+	if(typeof(this.chkboxes[obj_name]) == 'undefined') this.chkboxes[obj_name] = new Array();
+	this.chkboxes[obj_name].push(obj);
+
+	addListener(obj, 'click', this.check.bindAsEventListener(this), false);
+},
+
+check: function(e){
+	var e = e || window.event;
+	if(!e.ctrlKey) return true;
+	var obj = eventTarget(e);
+
+	if((typeof(obj) != 'undefined') && (obj.type.toLowerCase() == 'checkbox')){
+		var obj_name = obj.name.split('[')[0];
+
+		if(!is_null(this.startbox) && (this.startbox_name == obj_name) && (obj.name != this.startbox.name)){
+			var chkbx_list = this.chkboxes[obj_name];
+			var flag = false;
+			
+			for(var i=0; i < chkbx_list.length; i++){
+				if(typeof(chkbx_list[i]) !='undefined'){
+//alert(obj.name+' == '+chkbx_list[i].name);
+					if(flag){
+						chkbx_list[i].checked = this.startbox.checked;
+					}
+					
+					if(obj.name == chkbx_list[i].name) break;
+					if(this.startbox.name == chkbx_list[i].name) flag = true;
+				}
+			}
+			if(flag){
+				this.startbox = null;
+				this.startbox_name = null;
+				return true;
+			}
+			else{
+				for(var i=chkbx_list.length-1; i >= 0; i--){
+					if(typeof(chkbx_list[i]) !='undefined'){
+//alert(obj.name+' == '+chkbx_list[i].name);			
+						if(flag){
+							chkbx_list[i].checked = this.startbox.checked;
+						}
+						
+						if(obj.name == chkbx_list[i].name){
+							this.startbox = null;
+							this.startbox_name = null;
+							return true;
+						}
+						if(this.startbox.name == chkbx_list[i].name) flag = true;
+					}
+				}	
+			}
+
+		}
+		else{
+			if(!is_null(this.startbox)) this.startbox.checked = !this.startbox.checked;
+			
+			this.startbox = obj;
+			this.startbox_name = obj_name;
+		}
+	}
+}
+}
+/************************************************************************************/
+/*						Replace Standart Blink functionality						*/
+/************************************************************************************/
+// Author: Aly
+var blink = {
+	blinkobjs: new Array(),
+	
+	init: function(){
+		this.blinkobjs = document.getElementsByName("blink");
+		if(this.blinkobjs.length > 0) this.view();
+	},
+	hide: function(){
+		for(var id=0; id<this.blinkobjs.length; id++){
+			this.blinkobjs[id].style.visibility = 'hidden';
+		}
+		setTimeout('blink.view()',500);
+	},
+	view: function(){
+		for(var id=0; id<this.blinkobjs.length; id++){
+			this.blinkobjs[id].style.visibility = 'visible'
+		}
+		setTimeout('blink.hide()',1000);
+	}
+}
