@@ -34,6 +34,7 @@
 		case 'templates':
 			$page["title"] = "S_TEMPLATES_BIG";
 			$min_user_type = USER_TYPE_ZABBIX_ADMIN;
+			$templated_hosts = true;
 			break;
 		case 'hosts':
 			$page["title"] = "S_HOSTS_BIG";
@@ -165,17 +166,16 @@ include_once "include/page_header.php";
 
 	check_fields($fields);
 
-	$dstfrm		= get_request("dstfrm",  '');	// destination form
-	$dstfld1	= get_request("dstfld1", '');	// output field on destination form
-	$dstfld2	= get_request("dstfld2", '');	// second output field on destination form
-	$srcfld1	= get_request("srcfld1", '');	// source table field [can be different from fields of source table]
-	$srcfld2	= get_request("srcfld2", null);	// second source table field [can be different from fields of source table]
-	
-	$monitored_hosts	= get_request("monitored_hosts", 0);
-	$real_hosts			= get_request("real_hosts", 0);
-	$only_hostid		= get_request("only_hostid", null);
+	$dstfrm		= get_request("dstfrm",  '');	// destination form	
+	$dstfld1	= get_request("dstfld1", '');	// output field on destination form	
+	$dstfld2	= get_request("dstfld2", '');	// second output field on destination form	
+	$srcfld1	= get_request("srcfld1", '');	// source table field [can be different from fields of source table]	
+	$srcfld2	= get_request("srcfld2", null);	// second source table field [can be different from fields of source table]		
+	$monitored_hosts	= get_request('monitored_hosts', 0);
+	$real_hosts			= get_request('real_hosts', 0);
+	$only_hostid		= get_request('only_hostid', null);
 
-	$host_status		= array();
+	$host_status = array();
 	if ($monitored_hosts)
 		array_push($host_status, HOST_STATUS_MONITORED);
 	else if ($real_hosts)
@@ -189,6 +189,7 @@ include_once "include/page_header.php";
 	if($min_user_type > $USER_DETAILS['type']){
 		access_deny();
 	}
+
 ?>
 <?php
 	function get_window_opener($frame, $field, $value){
@@ -209,49 +210,57 @@ include_once "include/page_header.php";
 	$frmTitle = new CForm();
 		
 	if($monitored_hosts)
-		$frmTitle->AddVar('monitored_hosts', 1);
+		$frmTitle->addVar('monitored_hosts', 1);
 
 	if($real_hosts)
-		$frmTitle->AddVar('real_hosts', 1);
+		$frmTitle->addVar('real_hosts', 1);
 
-	$frmTitle->AddVar("dstfrm",	$dstfrm);
-	$frmTitle->AddVar("dstfld1",	$dstfld1);
-	$frmTitle->AddVar("dstfld2",	$dstfld2);
-	$frmTitle->AddVar("srctbl",	$srctbl);
-	$frmTitle->AddVar("srcfld1",	$srcfld1);
-	$frmTitle->AddVar("srcfld2",	$srcfld2);
+	$frmTitle->addVar('dstfrm',	$dstfrm);
+	$frmTitle->addVar('dstfld1',	$dstfld1);
+	$frmTitle->addVar('dstfld2',	$dstfld2);
+	$frmTitle->addVar('srctbl',	$srctbl);
+	$frmTitle->addVar('srcfld1',	$srcfld1);
+	$frmTitle->addVar('srcfld2',	$srcfld2);
 	if(isset($_REQUEST['reference']))
-		$frmTitle->AddVar("reference",	$_REQUEST['reference']);
+		$frmTitle->addVar('reference',	$_REQUEST['reference']);
 
 	if(isset($only_hostid)){
 		$_REQUEST['hostid'] = $only_hostid;
-		$frmTitle->AddVar("only_hostid",$only_hostid);
-		unset($_REQUEST["groupid"],$_REQUEST["nodeid"]);
+		$frmTitle->addVar('only_hostid',$only_hostid);
+		unset($_REQUEST['groupid'],$_REQUEST['nodeid']);
 	}
 	
-	$validation_param = array('allow_all_hosts','always_select_first_host');
+	$validation_param = array();
+	if($monitored_hosts) array_push($validation_param, 'monitored_hosts');
+	if($real_hosts) 	array_push($validation_param, 'real_hosts');
+	if(isset($templated_hosts)) array_push($validation_param, 'templated_hosts');
 
-	if($monitored_hosts)
-		array_push($validation_param, 'monitored_hosts');
-		
-	if($real_hosts)
-		array_push($validation_param, 'real_hosts');
-		
-	if(str_in_array($srctbl,array("graphs","screens","triggers","logitems","items"))){
-		array_push($validation_param, "always_select_first_host");
-		validate_group_with_host(PERM_READ_LIST,$validation_param);
-	}
-	else if(str_in_array($srctbl,array('hosts','templates','host_templates'))){
-		validate_group(PERM_READ_LIST,$validation_param);
-	}
+	$nodeid = get_request('nodeid', get_current_nodeid());
 
-	$nodeid 			= get_request('nodeid', get_current_nodeid());
-	$available_hosts	= get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY,$nodeid);
-	$available_nodes	= get_accessible_nodes_by_user($USER_DETAILS,PERM_READ_LIST,PERM_RES_IDS_ARRAY);
+	$params = array();
+	foreach($validation_param as  $option) $params[$option] = 1;
+	$PAGE_GROUPS = get_viewed_groups(PERM_READ_ONLY, $params, $nodeid);
+	$PAGE_HOSTS = get_viewed_hosts(PERM_READ_ONLY, $PAGE_GROUPS['selected'], $params, $nodeid);
+
+	if(str_in_array($srctbl, array('graphs','applications','screens','triggers','logitems','items','simple_graph','plain_text'))){
+		validate_group_with_host($PAGE_GROUPS,$PAGE_HOSTS);
+	}
+	else if(str_in_array($srctbl,array('host_group','hosts','templates','host_templates'))){
+		validate_group($PAGE_GROUPS, $PAGE_HOSTS);
+	}
+	
+	$groupid = 0;
+	$hostid = 0;
+	
+	$available_nodes	= get_accessible_nodes_by_user($USER_DETAILS, PERM_READ_LIST);
+	$available_groups	= $PAGE_GROUPS['groupids'];
+	$available_hosts	= $PAGE_HOSTS['hostids'];
 
 	if(isset($only_hostid)){
-		if(!isset($_REQUEST["hostid"]) || (bccomp($_REQUEST["hostid"], $only_hostid) != 0)) access_deny();
-		$hostid = $only_hostid;
+		$available_hosts = get_accessible_hosts_by_user($USER_DETAILS, PERM_READ_ONLY);
+		if(!isset($available_hosts[$only_hostid])) access_deny();
+
+		$hostid = $_REQUEST['hostid'] = $only_hostid;
 	}
 	else{
 		if(str_in_array($srctbl,array('hosts','host_group','triggers','logitems','items',
@@ -263,10 +272,10 @@ include_once "include/page_header.php";
 
 				$db_nodes = DBselect('SELECT * FROM nodes WHERE '.DBcondition('nodeid',$available_nodes));
 				while($node_data = DBfetch($db_nodes)){
-					$cmbNode->AddItem($node_data['nodeid'], $node_data['name']);
+					$cmbNode->addItem($node_data['nodeid'], $node_data['name']);
 					if((bccomp($nodeid , $node_data['nodeid']) == 0)) $ok = true;
 				}
-				$frmTitle->AddItem(array(SPACE,S_NODE,SPACE,$cmbNode));
+				$frmTitle->addItem(array(SPACE,S_NODE,SPACE,$cmbNode));
 			}
 		}
 		
@@ -274,101 +283,70 @@ include_once "include/page_header.php";
 		unset($ok);
 
 		if(str_in_array($srctbl,array('hosts','templates','triggers','logitems','items','applications','host_templates','graphs','simple_graph','plain_text'))){
-			$groupid = get_request('groupid',get_profile('web.popup.groupid',0));
-
-			$cmbGroups = new CComboBox('groupid',$groupid,'submit()');
-			$cmbGroups->AddItem(0,S_ALL_SMALL);
-			$db_groups = DBselect('SELECT DISTINCT g.groupid,g.name '.
-								' FROM groups g, hosts_groups hg, hosts h '.
-								' WHERE '.DBin_node('g.groupid', $nodeid).
-									' AND g.groupid=hg.groupid '.
-									' AND hg.hostid=h.hostid'.
-									' AND '.DBcondition('h.hostid',$available_hosts).
-									' AND h.status in ('.implode(',', $host_status).')'.
-								' ORDER BY name');
-								
-			while($group = DBfetch($db_groups)){
-				$cmbGroups->AddItem($group["groupid"],$group["name"]);
-				if((bccomp($groupid , $group["groupid"]) == 0)) $ok = true;
+		
+			$groupid = $PAGE_GROUPS['selected'];
+			$cmbGroups = new CComboBox('groupid',$groupid,'javascript: submit();');		
+			foreach($PAGE_GROUPS['groups'] as $slct_groupid => $name){
+				$cmbGroups->addItem($slct_groupid, get_node_name_by_elid($slct_groupid).$name);
 			}
-			$frmTitle->AddItem(array(S_GROUP,SPACE,$cmbGroups));
-			update_profile("web.popup.groupid",$groupid);
-			if(!isset($ok) || $groupid == 0) unset($groupid);
-			unset($ok);
+			
+			$frmTitle->addItem(array(S_GROUP,SPACE,$cmbGroups));
+			update_profile('web.popup.groupid',$groupid);
 		}
 		
-		if(str_in_array($srctbl,array("help_items"))){
-			$itemtype = get_request("itemtype",get_profile("web.popup.itemtype",0));
-			$cmbTypes = new CComboBox("itemtype",$itemtype,"submit()");
+		if(str_in_array($srctbl,array('help_items'))){
+			$itemtype = get_request('itemtype',get_profile('web.popup.itemtype',0));
+			$cmbTypes = new CComboBox('itemtype',$itemtype,'javascript: submit();');
 			foreach($allowed_item_types as $type)
-				$cmbTypes->AddItem($type, item_type2str($type));
-			$frmTitle->AddItem(array(S_TYPE,SPACE,$cmbTypes));
-		}
-		
-		if(str_in_array($srctbl,array("triggers","logitems","items",'applications','graphs','simple_graph','plain_text'))){
-			$hostid = get_request("hostid",get_profile("web.popup.hostid",0));
-			$cmbHosts = new CComboBox("hostid",$hostid,"submit()");
-			
-			$sql = 'SELECT DISTINCT h.hostid,h.host FROM hosts h';
-			if(isset($groupid)){
-				$sql .= ',hosts_groups hg WHERE '.
-					' h.hostid=hg.hostid AND hg.groupid='.$groupid.' AND ';
-			}
-			else{
-				$sql .= ' WHERE ';
-				$cmbHosts->AddItem(0,S_ALL_SMALL);
-			}
-
-			$sql .= DBin_node('h.hostid', $nodeid).
-					' and '.DBcondition('h.hostid',$available_hosts).
-					' and h.status in ('.implode(',', $host_status).')'.
-				' order by host,h.hostid';
-
-			$db_hosts = DBselect($sql);
-			
-			while($host = DBfetch($db_hosts)){
-				$cmbHosts->AddItem($host["hostid"],$host["host"]);
-				if(bccomp($hostid , $host["hostid"]) == 0) $ok = true;
-			}
-			
-			$frmTitle->AddItem(array(SPACE,S_HOST,SPACE,$cmbHosts));
-			update_profile("web.popup.hostid",$hostid);
-			if(!isset($ok) || $hostid == 0) unset($hostid);
-			unset($ok);
+				$cmbTypes->addItem($type, item_type2str($type));
+			$frmTitle->addItem(array(S_TYPE,SPACE,$cmbTypes));
 		}
 
-		if(str_in_array($srctbl,array("triggers","hosts"))){
-			$btnEmpty = new CButton("empty",S_EMPTY,
+		if(str_in_array($srctbl,array('triggers','logitems','items','applications','graphs','simple_graph','plain_text'))){
+			$hostid = $PAGE_HOSTS['selected'];
+
+			$cmbHosts = new CComboBox('hostid',$hostid,'javascript: submit();');
+			foreach($PAGE_HOSTS['hosts'] as $tmp_hostid => $name){
+				$cmbHosts->addItem($tmp_hostid, get_node_name_by_elid($tmp_hostid).$name);
+			}
+
+			$frmTitle->addItem(array(SPACE,S_HOST,SPACE,$cmbHosts));
+			update_profile('web.popup.hostid',$hostid);
+		}
+
+		if(str_in_array($srctbl,array('triggers','hosts'))){
+			$btnEmpty = new CButton('empty',S_EMPTY,
 				get_window_opener($dstfrm, $dstfld1, 0).
 				get_window_opener($dstfrm, $dstfld2, '').
 				((isset($_REQUEST['reference']) && ($_REQUEST['reference'] =='dashboard'))?"window.opener.setTimeout('add2favorites();', 1000);":'').
 				" close_window(); return false;");
 
-			$frmTitle->AddItem(array(SPACE,$btnEmpty));
+			$frmTitle->addItem(array(SPACE,$btnEmpty));
 		}
 	}
 
-	show_table_header($page["title"], $frmTitle);
+	show_table_header($page['title'], $frmTitle);
 ?>
 <?php
-	if($srctbl == "hosts"){
+	if($srctbl == 'hosts'){
 		$table = new CTableInfo(S_NO_HOSTS_DEFINED);
-		$table->SetHeader(array(S_HOST,S_DNS,S_IP,S_PORT,S_STATUS,S_AVAILABILITY));
-
-		$sql = 'SELECT DISTINCT h.* FROM hosts h';
-				
-		if(isset($groupid))
-			$sql .= ',hosts_groups hg WHERE hg.groupid='.$groupid.
-				' AND h.hostid=hg.hostid AND ';
-		else
-			$sql .= ' WHERE ';
-
-		$sql .= DBin_node('h.hostid', $nodeid).
-					' and '.DBcondition('h.hostid',$available_hosts).
-					' and h.status in ('.implode(',', $host_status).')'.
-				' order by h.host,h.hostid';
+		$table->setHeader(array(S_HOST,S_DNS,S_IP,S_PORT,S_STATUS,S_AVAILABILITY));
 
+		$sql_from = '';
+		$sql_where = '';
+		if($groupid>0){
+			$sql_from.= ',hosts_groups hg ';
+			$sql_where.= ' AND hg.groupid='.$groupid.
+					 ' AND h.hostid=hg.hostid ';
+		}
 
+		$sql = 'SELECT DISTINCT h.* '.
+				' FROM hosts h'.$sql_from.
+				' WHERE '.DBin_node('h.hostid', $nodeid).
+					' AND '.DBcondition('h.hostid',$available_hosts).
+					' AND h.status in ('.implode(',', $host_status).')'.
+					$sql_where.
+				' ORDER BY h.host,h.hostid';
 		$db_hosts = DBselect($sql);
 		while($host = DBfetch($db_hosts)){
 		
@@ -419,7 +397,7 @@ include_once "include/page_header.php";
 
 			}
 
-			$table->AddRow(array(
+			$table->addRow(array(
 				$name,
 				$dns,
 				$ip,
@@ -432,8 +410,9 @@ include_once "include/page_header.php";
 		}
 		$table->Show();
 	}
-	else if($srctbl == "templates"){
+	else if($srctbl == 'templates'){
 		$existed_templates = get_request('existed_templates', array());
+		
 		$templates = get_request('templates', array());
 		$templates = $templates + $existed_templates;
 
@@ -443,8 +422,7 @@ include_once "include/page_header.php";
 		else if(isset($_REQUEST['select'])){
 			$new_templates = array_diff($templates, $existed_templates);
 			if(count($new_templates) > 0) {
-				foreach($new_templates as $id => $name)
-				{
+				foreach($new_templates as $id => $name){
 ?>
 
 <script language="JavaScript" type="text/javascript">
@@ -473,49 +451,50 @@ include_once "include/page_header.php";
 		$table = new CTableInfo(S_NO_TEMPLATES_DEFINED);
 		$table->SetHeader(array(S_NAME));
 
-		$sql = "SELECT DISTINCT h.* from hosts h";
-		if(isset($groupid))
-			$sql .= ",hosts_groups hg where hg.groupid=".$groupid.
-				" AND h.hostid=hg.hostid AND ";
-		else
-			$sql .= " where ";
-
-		$sql .= DBin_node('h.hostid', $nodeid).
-				' AND '.DBcondition('h.hostid',$available_hosts).
-				' AND h.status='.HOST_STATUS_TEMPLATE.
-				' order by h.host,h.hostid';
-
+		$sql_from = '';
+		$sql_where = '';
+		if($groupid > 0){
+			$sql_from.= ',hosts_groups hg ';
+			$sql_where.=' AND hg.groupid='.$groupid.
+						' AND h.hostid=hg.hostid ';
+		}
+		$sql = 'SELECT DISTINCT h.* '.
+				' FROM hosts h'.$sql_from.
+				' WHERE '.DBin_node('h.hostid', $nodeid).
+					' AND '.DBcondition('h.hostid',$available_hosts).
+					' AND h.status='.HOST_STATUS_TEMPLATE.
+					$sql_where.
+				' ORDER BY h.host,h.hostid';
 		$db_hosts = DBselect($sql);
-		while($host = DBfetch($db_hosts))
-		{
-			$chk = new CCheckBox('templates['.$host["hostid"].']',isset($templates[$host["hostid"]]),
-					null,$host["host"]);
-			$chk->SetEnabled(!isset($existed_templates[$host["hostid"]]));
+		while($host = DBfetch($db_hosts)){
+			$chk = new CCheckBox('templates['.$host['hostid'].']',isset($templates[$host['hostid']]),
+					null,$host['host']);
+			$chk->setEnabled(!isset($existed_templates[$host['hostid']]));
 
-			$table->AddRow(array(
+			$table->addRow(array(
 				array(
 					$chk,
-					$host["host"])
+					$host['host'])
 				));
 
 			unset($host);
 		}
 		$table->SetFooter(new CButton('select',S_SELECT));
 		$form = new CForm();
-		$form->AddVar('existed_templates',$existed_templates);
+		$form->addVar('existed_templates',$existed_templates);
 		
 		if($monitored_hosts)
-			$form->AddVar('monitored_hosts', 1);
+			$form->addVar('monitored_hosts', 1);
 			
 		if($real_hosts)
-			$form->AddVar('real_hosts', 1);
+			$form->addVar('real_hosts', 1);
 
-		$form->AddVar('dstfrm',$dstfrm);
-		$form->AddVar('dstfld1',$dstfld1);
-		$form->AddVar('srctbl',$srctbl);
-		$form->AddVar('srcfld1',$srcfld1);
-		$form->AddVar('srcfld2',$srcfld2);
-		$form->AddItem($table);
+		$form->addVar('dstfrm',$dstfrm);
+		$form->addVar('dstfld1',$dstfld1);
+		$form->addVar('srctbl',$srctbl);
+		$form->addVar('srcfld1',$srcfld1);
+		$form->addVar('srcfld2',$srcfld2);
+		$form->addItem($table);
 		$form->Show();
 	}
 	else if(str_in_array($srctbl,array('host_group'))){
@@ -544,7 +523,7 @@ include_once "include/page_header.php";
 			
 			$name->SetAction($action." close_window(); return false;");
 
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
 		$table->Show();
 	}
@@ -552,17 +531,20 @@ include_once "include/page_header.php";
 		$table = new CTableInfo(S_NO_TEMPLATES_DEFINED);
 		$table->SetHeader(array(S_NAME));
 
-		$sql = 'SELECT DISTINCT h.* from hosts h';
-		if(isset($groupid))
-			$sql .= ',hosts_groups hg where hg.groupid='.$groupid.
-				' AND h.hostid=hg.hostid AND ';
-		else
-			$sql .= ' WHERE ';
-
-		$sql .= DBin_node('h.hostid',$nodeid).
-					' AND h.status='.HOST_STATUS_TEMPLATE.
+		$sql_from = '';
+		$sql_where = '';
+		if($groupid > 0){
+			$sql_from.= ',hosts_groups hg ';
+			$sql_where.=' AND hg.groupid='.$groupid.
+						' AND h.hostid=hg.hostid ';
+		}
+		$sql = 'SELECT DISTINCT h.* '.
+				' FROM hosts h'.$sql_from.
+				' WHERE '.DBin_node('h.hostid', $nodeid).
 					' AND '.DBcondition('h.hostid',$available_hosts).
-				' ORDER BY h.host,h.hostid';
+					' AND h.status='.HOST_STATUS_TEMPLATE.
+					$sql_where.
+				' ORDER BY h.host,h.hostid';				
 		$db_hosts = DBselect($sql);
 		while($row = DBfetch($db_hosts)){
 			$name = new CLink($row['host'],'#','action');
@@ -576,15 +558,15 @@ include_once "include/page_header.php";
 				(isset($srcfld2) ? get_window_opener($dstfrm, $dstfld2, $row[$srcfld2]) : '');
 			}
 			
-			$name->SetAction($action." close_window(); return false;");
+			$name->setAction($action." close_window(); return false;");
 
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
-		$table->Show();
+		$table->show();
 	}
 	else if($srctbl == "usrgrp"){
 		$table = new CTableInfo(S_NO_GROUPS_DEFINED);
-		$table->SetHeader(array(S_NAME));
+		$table->setHeader(array(S_NAME));
 
 		$result = DBselect('select * from usrgrp where '.DBin_node('usrgrpid').' order by name');
 		while($row = DBfetch($result)){
@@ -604,15 +586,15 @@ include_once "include/page_header.php";
 				(isset($srcfld2) ? get_window_opener($dstfrm, $dstfld2, $row[$srcfld2]) : '');
 			}
 			
-			$name->SetAction($action." close_window(); return false;");			
+			$name->setAction($action." close_window(); return false;");			
 
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
-		$table->Show();
+		$table->show();
 	}
 	else if($srctbl == "users"){
 		$table = new CTableInfo(S_NO_USERS_DEFINED);
-		$table->SetHeader(array(S_NAME));
+		$table->setHeader(array(S_NAME));
 
 		$result = DBselect('select * from users where '.DBin_node('userid').' order by name');
 		while($row = DBfetch($result)){
@@ -633,7 +615,7 @@ include_once "include/page_header.php";
 			
 			$name->SetAction($action." close_window(); return false;");
 
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
 		$table->Show();
 	}
@@ -657,15 +639,15 @@ include_once "include/page_header.php";
 			
 			$name->SetAction($action." close_window(); return false;");
 
-			$table->AddRow(array(
+			$table->addRow(array(
 				$name,
 				$row["description"]
 				));
 		}
 		$table->Show();
 	}
-	else if($srctbl == "triggers"){
-		$available_triggers = get_accessible_triggers(PERM_READ_ONLY, PERM_RES_IDS_ARRAY, $nodeid);
+	else if($srctbl == 'triggers'){
+		$available_triggers = get_accessible_triggers(PERM_READ_ONLY, $available_hosts, PERM_RES_IDS_ARRAY, $nodeid);
 			
 		$table = new CTableInfo(S_NO_TRIGGERS_DEFINED);
 		$table->SetHeader(array(
@@ -675,7 +657,7 @@ include_once "include/page_header.php";
 
 		$sql = 'SELECT h.host,t.triggerid,t.description,t.expression,t.priority,t.status,count(d.triggerid_up) as dep_count '.
 				' FROM hosts h,items i,functions f, triggers t'.
-				' LEFT JOIN trigger_depends d ON d.triggerid_down=t.triggerid '.
+					' LEFT JOIN trigger_depends d ON d.triggerid_down=t.triggerid '.
 				' WHERE f.itemid=i.itemid '.
 					' AND h.hostid=i.hostid '.
 					' AND t.triggerid=f.triggerid'.
@@ -683,16 +665,16 @@ include_once "include/page_header.php";
 					' AND '.DBcondition('t.triggerid',$available_triggers).
 					' AND h.status in ('.implode(',', $host_status).')';
 
-		if(isset($hostid)) 
+		if($hostid>0) 
 			$sql .= ' AND h.hostid='.$hostid;
 
 		$sql .= ' GROUP BY h.host, t.triggerid, t.description, t.expression, t.priority, t.status'.
-			' ORDER BY h.host,t.description';
+				' ORDER BY h.host,t.description';
 
 		$result=DBselect($sql);
 		while($row=DBfetch($result)){			
 			$exp_desc = expand_trigger_description_by_data($row);
-			$description = new CLink($exp_desc,"#","action");
+			$description = new CLink($exp_desc,'#','action');
 			
 			if(isset($_REQUEST['reference']) && ($_REQUEST['reference'] =='dashboard')){
 				$action = get_window_opener($dstfrm, $dstfld1, $srcfld2).
@@ -733,7 +715,7 @@ include_once "include/page_header.php";
 
 			if($row["error"]=="")		$row["error"]=SPACE;
 
-			$table->AddRow(array(
+			$table->addRow(array(
 				$description,
 				new CCol(get_severity_description($row['priority']),get_severity_style($row['priority'])),
 				$status,
@@ -750,34 +732,32 @@ include_once "include/page_header.php";
 		$table = new CTableInfo(S_NO_ITEMS_DEFINED);
 
 		$table->SetHeader(array(
-			!isset($hostid) ? S_HOST : null,
-			S_DESCRIPTION,S_KEY,nbsp(S_UPDATE_INTERVAL),
-			S_STATUS));
+			($hostid>0)?null:S_HOST, S_DESCRIPTION, S_KEY,nbsp(S_UPDATE_INTERVAL), S_STATUS));
 
 		$db_items = DBselect('SELECT DISTINCT h.host,i.* '.
 					' FROM items i,hosts h'.
 					' WHERE i.value_type='.ITEM_VALUE_TYPE_LOG.
 						' AND h.hostid=i.hostid '.
 						' AND '.DBin_node('i.itemid', $nodeid).
-						(isset($hostid)?' AND '.$hostid.'=i.hostid ':'').
+						(($hostid>0)?' AND '.$hostid.'=i.hostid ':'').
 						' and '.DBcondition('h.hostid',$available_hosts).
 						' and h.status in ('.implode(',', $host_status).')'.
 					' ORDER BY h.host,i.description, i.key_, i.itemid');
 
 		while($db_item = DBfetch($db_items))
 		{
-			$description = new CLink(item_description($db_item),"#","action");
-			$description->SetAction("return add_item_variable('".$dstfrm."','".$db_item["itemid"]."');");
-
+			$description = new CSpan(item_description($db_item),'link');
+			$description->onClick("return add_item_variable('".$dstfrm."','".$db_item["itemid"]."');");
+			
 			switch($db_item["status"]){
 				case 0: $status=new CCol(S_ACTIVE,"enabled");		break;
 				case 1: $status=new CCol(S_DISABLED,"disabled");	break;
 				case 3: $status=new CCol(S_NOT_SUPPORTED,"unknown");	break;
 				default:$status=S_UNKNOWN;
 			}
-
-			$table->AddRow(array(
-				!isset($hostid) ? $db_item["host"] : null,
+			
+			$table->addRow(array(
+				($hostid>0)?null:$db_item['host'],
 				$description,
 				$db_item["key_"],
 				$db_item["delay"],
@@ -792,7 +772,7 @@ include_once "include/page_header.php";
 	{
 		$table = new CTableInfo(S_NO_GROUPS_DEFINED);
 		$table->SetHeader(array(
-			(isset($hostid) ? null : S_HOST),
+			($hostid>0)?null:S_HOST,
 			S_DESCRIPTION,
 			S_TYPE,
 			S_TYPE_OF_INFORMATION,
@@ -804,21 +784,17 @@ include_once "include/page_header.php";
 					' AND '.DBin_node('i.itemid', $nodeid).
 					' AND '.DBcondition('h.hostid',$available_hosts).
 					' AND h.status in ('.implode(',', $host_status).')';
-
-		if(isset($hostid)) 
+		if($hostid > 0) 
 			$sql .= ' AND h.hostid='.$hostid;
 
 		$sql .= " order by h.host, i.description, i.key_, i.itemid";
 			
 		$result = DBselect($sql);
-		while($row = DBfetch($result))
-		{
+		while($row = DBfetch($result)){
 			$row["description"] = item_description($row);
 			
 			$description = new CLink($row["description"],"#","action");
-
-			$row["description"] = $row['host'].':'.$row["description"];
-
+			
 			if(isset($_REQUEST['reference']) && ($_REQUEST['reference'] =='dashboard')){
 				$action = get_window_opener($dstfrm, $dstfld1, $srcfld2).
 					get_window_opener($dstfrm, $dstfld2, $row[$srcfld2]).
@@ -829,36 +805,38 @@ include_once "include/page_header.php";
 				(isset($srcfld2) ? get_window_opener($dstfrm, $dstfld2, $row[$srcfld2]) : '');
 			}
 			
-			$description->SetAction($action." close_window(); return false;");
+			$description->setAction($action." close_window(); return false;");
 			
-			$table->AddRow(array(
-				(isset($hostid) ? null : $row['host']),
+			$table->addRow(array(
+				($hostid>0)?null:$row['host'],
 				$description,
 				item_type2str($row['type']),
 				item_value_type2str($row['value_type']),
 				new CSpan(item_status2str($row['status']),item_status2style($row['status']))
 				));
 		}
-		$table->Show();
+		$table->show();
 	}
-	else if($srctbl == "applications"){
+	else if($srctbl == 'applications'){
 		$table = new CTableInfo(S_NO_APPLICATIONS_DEFINED);
-		$table->SetHeader(array(
-			(isset($hostid) ? null : S_HOST),
+		$table->setHeader(array(
+			($hostid>0)?null:S_HOST,
 			S_NAME));
 
+		$sql_where = '';
+		if($hostid>0){
+			$sql_where = ' AND h.hostid='.$hostid;
+		}
 		$sql = 'SELECT DISTINCT h.host,a.* '.
 				' FROM hosts h,applications a '.
 				' WHERE h.hostid=a.hostid '.
 					' AND '.DBin_node('a.applicationid', $nodeid).
-					' and '.DBcondition('h.hostid',$available_hosts).
-					' and h.status in ('.implode(',', $host_status).')';
+					' AND '.DBcondition('h.hostid',$available_hosts).
+					' AND h.status in ('.implode(',', $host_status).')'.
+					$sql_where.
+					' ORDER BY h.host,a.name';
 
-		if(isset($hostid)) 
-			$sql .= ' AND h.hostid='.$hostid;
 
-		$sql .= " order by h.host,a.name";
-			
 		$result = DBselect($sql);
 		while($row = DBfetch($result)){
 			$name = new CLink($row["name"],"#","action");
@@ -875,7 +853,7 @@ include_once "include/page_header.php";
 			
 			$name->SetAction($action." close_window(); return false;");
 			
-			$table->AddRow(array(isset($hostid) ? null : $row['host'], $name));
+			$table->addRow(array(($hostid>0)?null:$row['host'], $name));
 		}
 		$table->Show();
 	}
@@ -899,7 +877,7 @@ include_once "include/page_header.php";
 			
 			$name->SetAction($action." close_window(); return false;");
 			
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
 		$table->Show();
 	}
@@ -907,12 +885,12 @@ include_once "include/page_header.php";
 	
 		$table = new CTableInfo(S_NO_GRAPHS_DEFINED);
 		$table->SetHeader(array(
-			isset($hostid)?null:S_HOST,
+			($hostid>0)?null:S_HOST,
 			S_NAME,
 			S_GRAPH_TYPE
 		));
 		
-		$available_graphs = get_accessible_graphs(PERM_READ_ONLY, PERM_RES_IDS_ARRAY, get_current_nodeid(true));
+		$available_graphs = get_accessible_graphs(PERM_READ_ONLY, $available_hosts, PERM_RES_IDS_ARRAY, get_current_nodeid(true));
 		$sql = 'SELECT DISTINCT g.graphid,g.name,g.graphtype,h.host '.
 			' FROM graphs g,graphs_items gi,items i,hosts h '.
 			' WHERE gi.graphid=g.graphid '.
@@ -922,7 +900,7 @@ include_once "include/page_header.php";
 				' AND h.status='.HOST_STATUS_MONITORED.
 				' AND '.DBcondition('g.graphid',$available_graphs);
 
-		if(isset($hostid)) 
+		if($hostid>0) 
 			$sql .= ' AND h.hostid='.$hostid;
 
 		$sql .= ' ORDER BY h.host,g.name';
@@ -960,8 +938,8 @@ include_once "include/page_header.php";
 					break;
 			}
 			
-			$table->AddRow(array(
-				isset($hostid)?null:$row['host'],
+			$table->addRow(array(
+				($hostid>0)?null:$row['host'],
 				$description,
 				$graphtype
 			));
@@ -974,7 +952,7 @@ include_once "include/page_header.php";
 	
 		$table = new CTableInfo(S_NO_ITEMS_DEFINED);
 		$table->SetHeader(array(
-			(isset($hostid) ? null : S_HOST),
+			($hostid>0)?null:S_HOST,
 			S_DESCRIPTION,
 			S_TYPE,
 			S_TYPE_OF_INFORMATION,
@@ -991,7 +969,7 @@ include_once "include/page_header.php";
 					' AND '.DBin_node('i.itemid', $nodeid).
 					' AND '.DBcondition('h.hostid',$available_hosts);
 
-		if(isset($hostid)) 
+		if($hostid>0) 
 			$sql .= ' AND h.hostid='.$hostid;
 
 		$sql .= ' ORDER BY h.host, i.description, i.key_, i.itemid';
@@ -1017,8 +995,8 @@ include_once "include/page_header.php";
 			
 			$description->SetAction($action.' close_window(); return false;');
 			
-			$table->AddRow(array(
-				(isset($hostid) ? null : $row['host']),
+			$table->addRow(array(
+				($hostid>0)?null:$row['host'],
 				$description,
 				item_type2str($row['type']),
 				item_value_type2str($row['value_type']),
@@ -1060,7 +1038,7 @@ include_once "include/page_header.php";
 			
 			$description->SetAction($action.' close_window(); return false;');
 			
-			$table->AddRow($description);
+			$table->addRow($description);
 
 			unset($description);
 		}
@@ -1070,7 +1048,7 @@ include_once "include/page_header.php";
 	
 		$table = new CTableInfo(S_NO_ITEMS_DEFINED);
 		$table->SetHeader(array(
-			(isset($hostid) ? null : S_HOST),
+			($hostid>0)?null:S_HOST,
 			S_DESCRIPTION,
 			S_TYPE,
 			S_TYPE_OF_INFORMATION,
@@ -1086,7 +1064,7 @@ include_once "include/page_header.php";
 					' AND '.DBin_node('i.itemid', $nodeid).
 					' AND '.DBcondition('h.hostid',$available_hosts);
 
-		if(isset($hostid)) 
+		if($hostid>0) 
 			$sql .= ' AND h.hostid='.$hostid;
 
 		$sql .= ' ORDER BY h.host, i.description, i.key_, i.itemid';
@@ -1113,8 +1091,8 @@ include_once "include/page_header.php";
 			
 			$description->SetAction($action.' close_window(); return false;');
 			
-			$table->AddRow(array(
-				(isset($hostid) ? null : $row['host']),
+			$table->addRow(array(
+				($hostid>0)?null:$row['host'],
 				$description,
 				item_type2str($row['type']),
 				item_value_type2str($row['value_type']),
@@ -1149,7 +1127,7 @@ include_once "include/page_header.php";
 			
 			$name->SetAction($action." close_window(); return false;");
 			
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
 
 		$table->Show();
@@ -1181,7 +1159,7 @@ include_once "include/page_header.php";
 			
 			$name->SetAction($action." close_window(); return false;");
 			
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
 
 		$table->Show();
@@ -1220,13 +1198,12 @@ include_once "include/page_header.php";
 			
 			$name->SetAction($action." close_window(); return false;");
 			
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
 
 		$table->Show();
 	}
-	else if($srctbl == "overview")
-	{
+	else if($srctbl == 'overview'){
 		$table = new CTableInfo(S_NO_GROUPS_DEFINED);
 		$table->SetHeader(S_NAME);
 
@@ -1238,8 +1215,7 @@ include_once "include/page_header.php";
 							' AND hg.hostid=h.hostid '.
 							' AND h.status='.HOST_STATUS_MONITORED.
 						' ORDER BY g.name');
-		while($row=DBfetch($result))
-		{
+		while($row=DBfetch($result)){
 			$row['node_name'] = isset($row['node_name']) ? '('.$row['node_name'].') ' : '';
 
 			$name = new CLink($row['name'],'#','action');			
@@ -1255,9 +1231,9 @@ include_once "include/page_header.php";
 				(isset($srcfld2) ? get_window_opener($dstfrm, $dstfld2, $row[$srcfld2]) : '');
 			}
 			
-			$name->SetAction($action." close_window(); return false;");
+			$name->setAction($action." close_window(); return false;");
 			
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
 
 		$table->Show();
@@ -1266,7 +1242,7 @@ include_once "include/page_header.php";
 		$available_groups	= get_accessible_groups_by_user($USER_DETAILS,PERM_READ_ONLY,null,$nodeid);
 
 		$table = new CTableInfo(S_NO_GROUPS_DEFINED);
-		$table->SetHeader(array(S_NAME));
+		$table->setHeader(array(S_NAME));
 
 		$db_groups = DBselect('SELECT DISTINCT n.name as node_name,g.groupid,g.name,n.nodeid '.
 						' FROM hosts_groups hg, groups g '.
@@ -1277,8 +1253,7 @@ include_once "include/page_header.php";
 		
 		$all = false;
 		
-		while($row = DBfetch($db_groups))
-		{
+		while($row = DBfetch($db_groups)){
 			$row['node_name'] = isset($row['node_name'])?'('.$row['node_name'].') ':'';
 			
 			if(!$all){
@@ -1295,24 +1270,24 @@ include_once "include/page_header.php";
 
 				}
 				
-				$name->SetAction($action." close_window(); return false;");
+				$name->setAction($action." close_window(); return false;");
 				
-				$table->AddRow($name);
+				$table->addRow($name);
 				$all = true;
 			}
 
 			$name = new CLink($row['name'],'#','action');			
 			$row['name'] = $row['node_name'].$row['name'];
 			
-			$name->SetAction(
+			$name->setAction(
 				get_window_opener($dstfrm, $dstfld1, $row[$srcfld1]).
 				get_window_opener($dstfrm, $dstfld2, $row[$srcfld2]).
 				((isset($_REQUEST['reference']) && ($_REQUEST['reference'] =='dashboard'))?"window.opener.setTimeout('add2favorites();', 1000);":'').
 				' return close_window();');
 
-			$table->AddRow($name);
+			$table->addRow($name);
 		}
-		$table->Show();
+		$table->show();
 	}
 ?>
 <?php
