@@ -25,12 +25,13 @@
 
 	$page["title"] = "S_USER_PROFILE";
 	$page["file"] = "profile.php";
+	$page['hist_arg'] = array();
 
 include_once "include/page_header.php";
 
 ?>
 <?php
-	if($USER_DETAILS["alias"]=="guest")
+	if($USER_DETAILS["alias"]==ZBX_GUEST_USER)
 	{
 		access_deny();
 	}
@@ -41,7 +42,9 @@ include_once "include/page_header.php";
 		"password1"=>	array(T_ZBX_STR, O_OPT,	null,	null,		'isset({save})&&isset({form})&&({form}!="update")&&isset({change_password})'),
 		"password2"=>	array(T_ZBX_STR, O_OPT,	null,	null,		'isset({save})&&isset({form})&&({form}!="update")&&isset({change_password})'),
 		"lang"=>	array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'isset({save})'),
-		"autologout"=>  array(T_ZBX_INT, O_OPT, null,   BETWEEN(0,3600),'isset({save})'),
+		"theme"=>		array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'isset({save})'),
+		'autologin'=>	array(T_ZBX_INT, O_OPT,	null,	IN('0,1'),	null),
+		"autologout"=>  array(T_ZBX_INT, O_OPT, null,   BETWEEN(90,10000), null),
 		"url"=>		array(T_ZBX_STR, O_OPT,	null,	null,		'isset({save})'),
 		"refresh"=>	array(T_ZBX_INT, O_OPT,	null,	BETWEEN(0,3600),'isset({save})'),
 		"change_password"=>	array(T_ZBX_STR, O_OPT,	null,	null,	null),
@@ -57,22 +60,23 @@ include_once "include/page_header.php";
 	check_fields($fields);
 ?>
 <?php
-	if(isset($_REQUEST["cancel"]))
-	{
-		Redirect('index.php');
+	if(isset($_REQUEST["cancel"])){
+		$url = get_profile('web.menu.view.last', 'index.php');
+		redirect($url);
 	}
-	elseif(isset($_REQUEST["save"]))
-	{
+	else if(isset($_REQUEST["save"])){
 		$_REQUEST["password1"] = get_request("password1", null);
 		$_REQUEST["password2"] = get_request("password2", null);
 
-		if(isset($_REQUEST["password1"]) && $_REQUEST["password1"] == "")
-		{
+		if(isset($_REQUEST["password1"]) && $_REQUEST["password1"] == ""){
 			show_error_message(S_ONLY_FOR_GUEST_ALLOWED_EMPTY_PASSWORD);
 		}
-		elseif($_REQUEST["password1"]==$_REQUEST["password2"])
-		{
-			$result=update_user_profile($USER_DETAILS["userid"],$_REQUEST["password1"],$_REQUEST["url"],$_REQUEST["autologout"],$_REQUEST["lang"],$_REQUEST["refresh"]);
+		else if($_REQUEST["password1"]==$_REQUEST["password2"]){
+			$result=update_user_profile($USER_DETAILS["userid"],$_REQUEST["password1"],
+									$_REQUEST["url"],get_request("autologin",0),get_request("autologout",0),
+									$_REQUEST["lang"],$_REQUEST['theme'],$_REQUEST["refresh"]
+					);
+					
 			show_messages($result, S_USER_UPDATED, S_CANNOT_UPDATE_USER);
 			if($result)
 				add_audit(AUDIT_ACTION_UPDATE,AUDIT_RESOURCE_USER,
