@@ -24,7 +24,7 @@
 
 	$page["title"] = "S_QUEUE_BIG";
 	$page["file"] = "queue.php";
-	$page['hist_arg'] = array('show');
+	$page['hist_arg'] = array('config');
 	
 	define('ZBX_PAGE_DO_REFRESH', 1);
 
@@ -34,7 +34,7 @@ include_once "include/page_header.php";
 <?php
 //		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
 	$fields=array(
-		"show"=>		array(T_ZBX_INT, O_OPT,	P_SYS,	IN("0,1,2"),	NULL)
+		"config"=>		array(T_ZBX_INT, O_OPT,	P_SYS,	IN("0,1,2"),	NULL)
 	);
 
 	check_fields($fields);
@@ -43,12 +43,13 @@ include_once "include/page_header.php";
 ?>
 
 <?php
-	$_REQUEST["show"] = get_request("show", 0);
+	$_REQUEST['config'] = get_request('config', get_profile('web.queue.config', 0));
+	update_profile('web.queue.config',$_REQUEST['config'], PROFILE_TYPE_INT);
 
 	$form = new CForm();
 	$form->SetMethod('get');
 	
-	$cmbMode = new CComboBox("show", $_REQUEST["show"], "submit();");
+	$cmbMode = new CComboBox("config", $_REQUEST["config"], "submit();");
 	$cmbMode->AddItem(0, S_OVERVIEW);
 	$cmbMode->AddItem(1, S_OVERVIEW_BY_PROXY);
 	$cmbMode->AddItem(2, S_DETAILS);
@@ -73,23 +74,23 @@ include_once "include/page_header.php";
 			//ITEM_TYPE_HTTPTEST,
 			ITEM_TYPE_EXTERNAL);
 
-	$result = DBselect('SELECT i.itemid,i.nextcheck,i.description,i.key_,i.type,h.host,h.hostid,h.proxy_hostid '.
+	$result = DBselect('SELECT i.itemid,i.lastclock,i.description,i.key_,i.type,h.host,h.hostid,h.proxy_hostid,i.delay,i.delay_flex '.
 		' FROM items i,hosts h '.
 		' WHERE i.status='.ITEM_STATUS_ACTIVE.
 			' AND i.type in ('.implode(',',$item_types).') '.
 			' AND ((h.status='.HOST_STATUS_MONITORED.' AND h.available != '.HOST_AVAILABLE_FALSE.') '.
 				' OR (h.status='.HOST_STATUS_MONITORED.' AND h.available='.HOST_AVAILABLE_FALSE.' AND h.disable_until<='.$now.')) '.
 			' AND i.hostid=h.hostid '.
-			' AND i.nextcheck + 5 <'.$now.
+/*			' AND i.nextcheck + 5 <'.$now.*/
 			' AND i.key_ NOT IN ('.zbx_dbstr('status').','.zbx_dbstr('icmpping').','.zbx_dbstr('icmppingsec').','.zbx_dbstr('zabbix[log]').') '.
 			' AND i.value_type not in ('.ITEM_VALUE_TYPE_LOG.') '.
 			' AND '.DBcondition('h.hostid',$available_hosts).
 			' AND '.DBin_node('h.hostid', get_current_nodeid()).
-		' ORDER BY i.nextcheck,h.host,i.description,i.key_');
+		' ORDER BY i.lastclock,h.host,i.description,i.key_');
 
 	$table = new CTableInfo(S_THE_QUEUE_IS_EMPTY);
 
-	if($_REQUEST["show"]==0){
+	if($_REQUEST["config"]==0){
 
 		foreach($item_types as $type){
 			$sec_10[$type]=0;
@@ -101,12 +102,18 @@ include_once "include/page_header.php";
 		}
 
 		while($row=DBfetch($result)){
-			if($now-$row["nextcheck"]<=10)			$sec_10[$row["type"]]++;
-			else if($now-$row["nextcheck"]<=30)		$sec_30[$row["type"]]++;
-			else if($now-$row["nextcheck"]<=60)		$sec_60[$row["type"]]++;
-			else if($now-$row["nextcheck"]<=300)		$sec_300[$row["type"]]++;
-			else if($now-$row["nextcheck"]<=600)		$sec_600[$row["type"]]++;
-			else	$sec_rest[$row["type"]]++;
+			$nextcheck = is_null($row['lastclock']) ? 0 : calculate_item_nextcheck($row['itemid'], $row['type'],
+					$row['delay'], $row['delay_flex'], $row['lastclock']);
+			$diff = $now - $nextcheck;
+			if ($diff <= 5)
+				continue;
+
+			if ($diff <= 10)	$sec_10[$row['type']]++;
+			else if ($diff <= 30)	$sec_30[$row['type']]++;
+			else if ($diff <= 60)	$sec_60[$row['type']]++;
+			else if ($diff <= 300)	$sec_300[$row['type']]++;
+			else if ($diff <= 600)	$sec_600[$row['type']]++;
+			else	$sec_rest[$row['type']]++;
 
 		}
 		
@@ -125,7 +132,7 @@ include_once "include/page_header.php";
 			$table->addRow($elements);
 		}
 	}
-	else if ($_REQUEST["show"] == 1)
+	else if ($_REQUEST["config"] == 1)
 	{
 		$db_proxies = DBselect('select hostid from hosts where status='.HOST_STATUS_PROXY);
 
@@ -147,7 +154,11 @@ include_once "include/page_header.php";
 
 		while ($row = DBfetch($result))
 		{
-			$diff = $now - $row['nextcheck'];
+			$nextcheck = is_null($row['lastclock']) ? 0 : calculate_item_nextcheck($row['itemid'], $row['type'],
+					$row['delay'], $row['delay_flex'], $row['lastclock']);
+			$diff = $now - $nextcheck;
+			if ($diff <= 5)
+				continue;
 
 			if ($diff <= 10)	$sec_10[$row['proxy_hostid']]++;
 			else if ($diff <= 30)	$sec_30[$row['proxy_hostid']]++;
@@ -185,8 +196,10 @@ include_once "include/page_header.php";
 		);
 		$table->addRow($elements);
 	}
-	else if ($_REQUEST["show"] == 2)
+	else if ($_REQUEST["config"] == 2)
 	{
+		$arr = array();
+
 		$table->SetHeader(array(
 				S_NEXT_CHECK,
 				is_show_subnodes() ? S_NODE : null,
@@ -194,19 +207,30 @@ include_once "include/page_header.php";
 				S_DESCRIPTION
 				));
 		while($row=DBfetch($result)){
+			$nextcheck = is_null($row['lastclock']) ? 0 : calculate_item_nextcheck($row['itemid'], $row['type'],
+					$row['delay'], $row['delay_flex'], $row['lastclock']);
+			$diff = $now - $nextcheck;
+			if ($diff <= 5)
+				continue;
+
+			array_push($arr, array($nextcheck, $row['hostid'], $row['host'], item_description($row)));
+		}
+
+		sort($arr);
+		foreach($arr as $r){
 			$table->AddRow(array(
 				date("m.d.Y H:i:s",
-					$row["nextcheck"]),
-				get_node_name_by_elid($row['hostid']),
-				$row['host'],
-				item_description($row)
+					$r[0]),
+				get_node_name_by_elid($r[1]),
+				$r[2],
+				$r[3]
 				));
 		}
 	}
 
 	$table->Show();
 
-	if($_REQUEST["show"]!=0){
+	if($_REQUEST["config"]!=0){
 		show_table_header(S_TOTAL.": ".$table->GetNumRows());
 	}
 ?>
