@@ -64,11 +64,11 @@ include_once "include/page_header.php";
 			));
 
 	switch($_REQUEST["period"]){
-		case "week":	$time_dif=7*24*3600;	break;
-		case "month":	$time_dif=10*24*3600;	break;
-		case "year":	$time_dif=365*24*3600;	break;
+		case "week":	$time_dif=7*86400;	break;
+		case "month":	$time_dif=30*86400;	break;
+		case "year":	$time_dif=365*86400;	break;
 		case "day":
-		default:	$time_dif=24*3600;	break;
+		default:	$time_dif=86400;	break;
 	}
 
 	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
@@ -84,9 +84,7 @@ include_once "include/page_header.php";
 							' and '.DBin_node('t.triggerid').
 						' GROUP BY h.host,t.triggerid,t.description,t.expression,t.priority '.
 						' ORDER BY cnt_event desc, h.host, t.description, t.triggerid';
-
         $result=DBselect($sql, 100);
-
         while($row=DBfetch($result)){
 			if(!check_right_on_trigger_by_triggerid(null, $row['triggerid'], $available_hosts))
 				continue;
