@@ -25,6 +25,7 @@
 	
 	$page["title"] = "S_IT_SERVICES";
 	$page["file"] = "services_form.php";
+	$page['scripts'] = array('services.js','calendar.js');
 
 	define('ZBX_PAGE_NO_MENU', 1);
 
@@ -87,23 +88,19 @@ include_once "include/page_header.php";
 
 //----------------------------------------------------------------------
 
-	$denyed_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_WRITE,PERM_MODE_LT);
+	$available_hosts = get_accessible_hosts_by_user($USER_DETAILS,PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, array(), PERM_RES_IDS_ARRAY);
 
 	if(isset($_REQUEST['serviceid']) && $_REQUEST['serviceid'] > 0){
-		$query = "select s.* from services s ".
-			" LEFT JOIN triggers t on s.triggerid=t.triggerid ".
-			" LEFT JOIN functions f on t.triggerid=f.triggerid ".
-			" LEFT JOIN items i on f.itemid=i.itemid ".
-			" where (i.hostid is null or i.hostid not in (".$denyed_hosts.")) ".
-			' and '.DBin_node('s.serviceid').
-			" and s.serviceid=".$_REQUEST["serviceid"];
-			
-		if( !($service = DBFetch(DBSelect($query))) ){
+		$sql = 'SELECT s.* '.
+					' FROM services s '.
+					' WHERE (s.triggerid IS NULL OR '.DBcondition('s.triggerid',$available_triggers).') '.
+						' AND s.serviceid='.$_REQUEST['serviceid'];
+		if(!$service = DBfetch(DBselect($sql))){
 			access_deny();
-		}
+		} 		
 	}
 
-echo '<script type="text/javascript" src="js/services.js"></script>';
 /*-------------------------------------------- ACTIONS --------------------------------------------*/
 if(isset($_REQUEST['saction'])){
 
@@ -116,28 +113,36 @@ if(isset($_REQUEST['saction'])){
 		show_messages($result, S_SERVICE_DELETED, S_CANNOT_DELETE_SERVICE);
 		add_audit_if($result,AUDIT_ACTION_DELETE,AUDIT_RESOURCE_IT_SERVICE,' Name ['.$service["name"].'] id ['.$service['serviceid'].']');
 		unset($service);
-	} elseif(isset($_REQUEST["save_service"])){
+	} 
+	else if(isset($_REQUEST["save_service"])){
 	
 		$service_times = get_request('service_times',array());
 		$childs = get_request('childs',array());
 
 		$triggerid = (isset($_REQUEST["linktrigger"]))?($_REQUEST["triggerid"]):(null);
 
+		DBstart();
 		if(isset($service["serviceid"])){
 			$result = update_service($service["serviceid"],
 				$_REQUEST["name"],$triggerid,$_REQUEST["algorithm"],
 				$_REQUEST["showsla"],$_REQUEST["goodsla"],$_REQUEST["sortorder"],
-				$service_times,$_REQUEST['parentid'],$childs);
-				
-			show_messages($result, S_SERVICE_UPDATED, S_CANNOT_UPDATE_SERVICE);
-			$serviceid = $service["serviceid"];
-			$audit_acrion = AUDIT_ACTION_UPDATE;
-			
-		} else {
+				$service_times,$_REQUEST['parentid'],$childs);			
+		} 
+		else {
 			$result = add_service(
 				$_REQUEST["name"],$triggerid,$_REQUEST["algorithm"],
 				$_REQUEST["showsla"],$_REQUEST["goodsla"],$_REQUEST["sortorder"],
 				$service_times,$_REQUEST['parentid'],$childs);
+		}
+		
+		$result = DBend()?$result:false;
+		
+		if(isset($serrvice['serviceid'])){
+			show_messages($result, S_SERVICE_UPDATED, S_CANNOT_UPDATE_SERVICE);
+			$serviceid = $service["serviceid"];
+			$audit_acrion = AUDIT_ACTION_UPDATE;
+		}
+		else{
 			show_messages($result, S_SERVICE_ADDED, S_CANNOT_ADD_SERVICE);
 			$serviceid = $result;
 			$audit_acrion = AUDIT_ACTION_ADD;
@@ -145,8 +150,14 @@ if(isset($_REQUEST['saction'])){
 		
 		add_audit_if($result,$audit_acrion,AUDIT_RESOURCE_IT_SERVICE,' Name ['.$_REQUEST["name"].'] id ['.$serviceid.']');
 			
-	} elseif(isset($_REQUEST["add_server"])){
-		if(!($host_data = DBfetch(DBselect('select h.* from hosts h where '.DBin_node('h.hostid').' and h.hostid not in ('.$denyed_hosts.') and h.hostid='.$_REQUEST["serverid"])))){
+	} 
+	else if(isset($_REQUEST["add_server"])){
+		$sql = 'SELECT h.* '.
+				' FROM hosts h '.
+				' WHERE '.DBin_node('h.hostid').
+					' AND '.DBcondition('h.hostid',$available_hosts).
+					' AND h.hostid='.$_REQUEST["serverid"];
+		if(!$host_data = DBfetch(DBselect($sql))){
 			access_deny();
 		}
 		
@@ -201,28 +212,19 @@ if(isset($_REQUEST['pservices'])){
 		
 		$query = 'SELECT DISTINCT s.* '.
 				' FROM services s '.
-					' LEFT JOIN triggers t ON s.triggerid=t.triggerid '.
-					' LEFT JOIN functions f ON t.triggerid=f.triggerid '.
-					' LEFT JOIN items i ON f.itemid=i.itemid '.
-					' LEFT JOIN services_links sl ON s.serviceid=sl.servicedownid '.
-				' WHERE (i.hostid IS null OR i.hostid NOT IN ('.$denyed_hosts.')) '.
-					' AND '.DBin_node('s.serviceid').
+				' WHERE '.DBin_node('s.serviceid').
+					' AND (s.triggerid IS NULL OR '.DBcondition('s.triggerid',$available_triggers).') '.
 					' AND s.serviceid NOT IN ('.$childs_str.$service['serviceid'].') '.
 				' ORDER BY s.sortorder,s.name';
-	} else {
+	} 
+	else {
 		$query = 'SELECT DISTINCT s.* '.
 			' FROM services s '.
-				' LEFT JOIN triggers t ON s.triggerid=t.triggerid '.
-				' LEFT JOIN functions f ON t.triggerid=f.triggerid '.
-				' LEFT JOIN items i ON f.itemid=i.itemid '.
-				' LEFT JOIN services_links sl ON s.serviceid=sl.servicedownid '.
-			' WHERE (i.hostid IS null '.
-					' OR i.hostid NOT IN ('.$denyed_hosts.') '.
-					' ) '.
-				' AND '.DBin_node('s.serviceid').
+			' WHERE '.DBin_node('s.serviceid').
+				' AND (s.triggerid IS NULL OR '.DBcondition('s.triggerid',$available_triggers).') '.
 			' ORDER BY s.sortorder,s.name';
 	}	
-	
+
 	$db_services = DBselect($query);
 	
 	while($db_service_data = DBfetch($db_services)){
@@ -280,24 +282,16 @@ if(isset($_REQUEST['cservices'])){
 	
 		$query = 'SELECT DISTINCT s.* '.
 				' FROM services s '.
-					' LEFT JOIN triggers t ON s.triggerid=t.triggerid '.
-					' LEFT JOIN functions f ON t.triggerid=f.triggerid '.
-					' LEFT JOIN items i on f.itemid=i.itemid '.
-					' LEFT JOIN services_links sl on s.serviceid=sl.servicedownid '.
-				' WHERE (i.hostid is null or i.hostid not in ('.$denyed_hosts.')) '.
-					' AND '.DBin_node('s.serviceid').
+				' WHERE '.DBin_node('s.serviceid').
+					' AND (s.triggerid IS NULL OR '.DBcondition('s.triggerid',$available_triggers).') '.
 					' AND s.serviceid NOT IN ('.$childs_str.$service['serviceid'].') '.
 				' ORDER BY s.sortorder,s.name';
 		
 	} else {
 		$query = 'SELECT DISTINCT s.* '.
 				' FROM services s '.
-					' LEFT JOIN triggers t ON s.triggerid=t.triggerid '.
-					' LEFT JOIN functions f ON t.triggerid=f.triggerid '.
-					' LEFT JOIN items i on f.itemid=i.itemid '.
-					' LEFT JOIN services_links sl on s.serviceid=sl.servicedownid '.
-				' WHERE (i.hostid is null or i.hostid not in ('.$denyed_hosts.')) '.
-					' AND '.DBin_node('s.serviceid').
+				' WHERE '.DBin_node('s.serviceid').
+					' AND (s.triggerid IS NULL OR '.DBcondition('s.triggerid',$available_triggers).') '.
 				' ORDER BY s.sortorder,s.name';
 	}
 	
@@ -346,25 +340,24 @@ if(isset($_REQUEST['sform'])){
 		$new_service_time['type'] = $_REQUEST["new_service_time"]['type'];
 
 		if($_REQUEST["new_service_time"]['type'] == SERVICE_TIME_TYPE_ONETIME_DOWNTIME){
-			$new_service_time['from'] = strtotime($_REQUEST["new_service_time"]['from']);
-			$new_service_time['to'] = strtotime($_REQUEST["new_service_time"]['to']);
+			$new_service_time['from'] = $_REQUEST['new_service_time']['from'];
+			$new_service_time['to'] = $_REQUEST['new_service_time']['to'];
 			$new_service_time['note'] = $_REQUEST["new_service_time"]['note'];
-		}else{
-			$new_service_time['from'] = strtotime(
-				$_REQUEST["new_service_time"]['from_week'].' '.$_REQUEST["new_service_time"]['from']
-				);
-			$new_service_time['to'] = strtotime(
-				$_REQUEST["new_service_time"]['to_week'].' '.$_REQUEST["new_service_time"]['to']
-				);
+		}
+		else{
+			$new_service_time['from'] = strtotime($_REQUEST["new_service_time"]['from_week'].' '.$_REQUEST["new_service_time"]['from']);
+			$new_service_time['to'] = strtotime($_REQUEST["new_service_time"]['to_week'].' '.$_REQUEST["new_service_time"]['to']);
 			$new_service_time['note'] = $_REQUEST["new_service_time"]['note'];
 		}
 		
-		while($new_service_time['to'] && ($new_service_time['to'] <= $new_service_time['from'])) $new_service_time['to'] += 7*24*3600;
+		while($new_service_time['to'] && ($new_service_time['to'] <= $new_service_time['from'])) 
+			$new_service_time['to'] += 7*24*3600;
 
 
 		if($new_service_time['to'] && !str_in_array($_REQUEST['service_times'], $new_service_time))
 			array_push($_REQUEST['service_times'],$new_service_time);
-	} elseif(isset($_REQUEST["del_service_times"]) && isset($_REQUEST["rem_service_times"])){
+	}
+	else if(isset($_REQUEST["del_service_times"]) && isset($_REQUEST["rem_service_times"])){
 		$_REQUEST["service_times"] = get_request("service_times",array());
 		foreach($_REQUEST["rem_service_times"] as $val){
 			unset($_REQUEST["service_times"][$val]);
@@ -403,8 +396,7 @@ if(isset($_REQUEST['sform'])){
 			array_push($service_times, $stime);
 		}
 //links
-		$query = 'SELECT DISTINCT '.
-					' sl.linkid, sl.soft, sl.serviceupid, sl.servicedownid, '.
+		$query = 'SELECT DISTINCT sl.linkid, sl.soft, sl.serviceupid, sl.servicedownid, '.
 					' s1.name as serviceupname, s2.name as servicedownname '.
 				' FROM services s1, services s2, services_links sl '.
 				' WHERE sl.serviceupid=s1.serviceid '.
@@ -422,10 +414,7 @@ if(isset($_REQUEST['sform'])){
 		
 		$query = 'SELECT DISTINCT s.*, sl.soft '.
 				' FROM services s1, services s2, services_links sl, services s '.
-					' LEFT JOIN triggers t ON s.triggerid=t.triggerid '.
-					' LEFT JOIN functions f ON t.triggerid=f.triggerid '.
-					' LEFT JOIN items i ON f.itemid=i.itemid '.
-				' WHERE (i.hostid is null or i.hostid not in ('.$denyed_hosts.')) '.
+				' WHERE (s.triggerid IS NULL OR '.DBcondition('s.triggerid',$available_triggers).') '.
 					' AND '.DBin_node('s.serviceid').
 					' AND sl.serviceupid=s1.serviceid '.
 					' AND sl.servicedownid=s2.serviceid '.
@@ -448,36 +437,37 @@ if(isset($_REQUEST['sform'])){
 			array_push($childs,$child);
 		}
 //---
-	}else{
-		$name		= get_request("name","");
-		$showsla	= get_request("showsla",0);
-		$goodsla	= get_request("goodsla",99.05);
-		$sortorder	= get_request("sortorder",0);
-		$algorithm	= get_request("algorithm",0);
-		$triggerid	= get_request("triggerid",0);
-		$linktrigger	= get_request("linktrigger",0);
+	}
+	else{
+		$name		= get_request('name','');
+		$showsla	= get_request('showsla',0);
+		$goodsla	= get_request('goodsla',99.05);
+		$sortorder	= get_request('sortorder',0);
+		$algorithm	= get_request('algorithm',SERVICE_ALGORITHM_MAX);
+		$triggerid	= get_request('triggerid',0);
+		$linktrigger	= get_request('linktrigger',0);
 //links
-		$parentid = get_request("parentid",0);
-		$parentname = get_request("parentname",'');
+		$parentid = get_request('parentid',0);
+		$parentname = get_request('parentname','');
 
 		$childs = get_request('childs',array());
 //-----
 	}
 
 	if(isset($service)){
-		$frmService->AddVar("serviceid",$service["serviceid"]);
+		$frmService->AddVar('serviceid',$service['serviceid']);
 	}
 	
-	$frmService->AddRow(S_NAME,new CTextBox("name",$name));
+	$frmService->AddRow(S_NAME,new CTextBox('name',$name,60));
 	
 //link
 //-------------------------------------------- <LINK> --------------------------------------------
 //parent link
-	$ctb = new CTextBox("parent_name",$parentname);
+	$ctb = new CTextBox('parent_name',$parentname,60);
 	$ctb->Addoption('disabled','disabled');
 
-	$frmService->AddVar("parentname",$parentname);
-	$frmService->AddVar("parentid",$parentid);
+	$frmService->AddVar('parentname',$parentname);
+	$frmService->AddVar('parentid',$parentid);
 
 	$cb = new CButton('select_parent',S_CHANGE);
 	$cb->SetType('button');
@@ -498,23 +488,23 @@ if(isset($_REQUEST['sform'])){
 	$table->headerClass = 'header';
 	$table->footerClass = 'footer';
 	
-	$table->SetHeader(array(new CCheckBox("all_child_services",null,"check_childs('".$frmService->GetName()."','childs','all_child_services');"),S_SERVICES,S_SOFT_LINK,S_TRIGGER));
+	$table->SetHeader(array(new CCheckBox('all_child_services',null,"check_childs('".$frmService->GetName()."','childs','all_child_services');"),S_SERVICES,S_SOFT,S_TRIGGER));
 
 	$table->AddOption('id','service_childs');
 
 	foreach($childs as $id => $child){
 		$prefix	 = null;
-		$trigger = "-";
+		$trigger = '-';
 		
 		$description = new CLink($child['name'],'services_form.php?sform=1&serviceid='.$child['serviceid'],'action');
 
-		if(isset($child["triggerid"]) && !empty($child["triggerid"])){
-			$trigger = expand_trigger_description($child["triggerid"]);
+		if(isset($child['triggerid']) && !empty($child['triggerid'])){
+			$trigger = expand_trigger_description($child['triggerid']);
 		}
 
 		$table->AddRow(array(
 				array(
-					new CCheckBox('childs['.$child['serviceid'].'][serviceid]',null,null,$child['serviceid']),
+					new CCheckBox('childs_to_del['.$child['serviceid'].'][serviceid]',null,null,$child['serviceid']),
 					new CVar('childs['.$child['serviceid'].'][serviceid]', $child['serviceid'])
 					),
 				array(
@@ -522,7 +512,7 @@ if(isset($_REQUEST['sform'])){
 					new CVar('childs['.$child['serviceid'].'][name]', $child['name'])
 					),
 				new CCheckBox(
-					'childs['.$child["serviceid"].'][soft]',
+					'childs['.$child['serviceid'].'][soft]',
 					(isset($child['soft']) && !empty($child['soft']))?('checked'):('no'),null,
 					(isset($child['soft']) && !empty($child['soft']))?(1):(0)
 					),
@@ -539,21 +529,21 @@ if(isset($_REQUEST['sform'])){
 	
 	$cb2 = new CButton('del_child_service',S_REMOVE);
 	$cb2->SetType('button');
-	$cb2->SetAction("javascript: remove_childs('".$frmService->GetName()."','childs','tr');");
+	$cb2->SetAction("javascript: remove_childs('".$frmService->GetName()."','childs_to_del','tr');");
 
-	$frmService->AddRow(S_DEPENDS_ON,array($table,BR,$cb,$cb2));
+	$frmService->AddRow(S_DEPENDS_ON,array($table,BR(),$cb,$cb2));
 //----------
 //--------------------------------------------- </LINK> -------------------------------------------
 	
 //algorithm
-	$cmbAlg = new CComboBox("algorithm",$algorithm);
-	foreach(array(SERVICE_ALGORITHM_NONE, SERVICE_ALGORITHM_MAX, SERVICE_ALGORITHM_MIN) as $val)
+	$cmbAlg = new CComboBox('algorithm',$algorithm);
+	foreach(array(SERVICE_ALGORITHM_MAX, SERVICE_ALGORITHM_MIN, SERVICE_ALGORITHM_NONE) as $val)
 		$cmbAlg->AddItem($val,algorithm2str($val));
 	$frmService->AddRow(S_STATUS_CALCULATION_ALGORITHM, $cmbAlg);
 //-------
 
 //SLA
-	$frmService->AddRow(S_SHOW_SLA, new CCheckBox("showsla",$showsla,"javascript: display_element('sla_row');",1));
+	$frmService->AddRow(S_CALCULATE_SLA, new CCheckBox('showsla',$showsla,"javascript: display_element('sla_row');",1));
 
 	$row = new CRow(array(
 						new CCol(S_ACCEPTABLE_SLA_IN_PERCENT,'form_row_l'),
@@ -593,7 +583,7 @@ if(isset($_REQUEST['sform'])){
 		}
 		array_push($stime_el, array(new CCheckBox("rem_service_times[]", 'no', null,$i), 
 			$type,':'.SPACE, $from, SPACE.'-'.SPACE, $to,
-			(!empty($val['note']) ? BR.'['.htmlspecialchars($val['note']).']' : '' ),BR));
+			(!empty($val['note'])?(array(BR(),'['.htmlspecialchars($val['note']).']')):('')),BR()));
 
 		
 		$frmService->AddVar('service_times['.$i.'][type]',	$val['type']);
@@ -623,10 +613,82 @@ if(isset($_REQUEST['sform'])){
 	$div = new Ctag('div','yes');
 	
 	if($new_service_time['type'] == SERVICE_TIME_TYPE_ONETIME_DOWNTIME){
-		$time_param->AddRow(array(S_NOTE, new CTextBox('new_service_time[note]','<short description>',40)));
-		$time_param->AddRow(array(S_FROM, new CTextBox('new_service_time[from]','d M Y H:i',20)));
-		$time_param->AddRow(array(S_TILL, new CTextBox('new_service_time[to]','d M Y H:i',20)));
-	}else{
+//		$time_param->AddRow(array(S_NOTE, new CTextBox('new_service_time[note]','<short description>',40)));
+//		$time_param->AddRow(array(S_FROM, new CTextBox('new_service_time[from]','d M Y H:i',20)));
+//		$time_param->AddRow(array(S_TILL, new CTextBox('new_service_time[to]','d M Y H:i',20)));
+		
+
+
+		$script = new CScript("javascript: if(CLNDR['downtime_since'].clndr.setSDateFromOuterObj()){".
+								"$('new_service_time[from]').value = parseInt(CLNDR['downtime_since'].clndr.sdt.getTime()/1000);}".
+							"if(CLNDR['downtime_till'].clndr.setSDateFromOuterObj()){". 
+								"$('new_service_time[to]').value = parseInt(CLNDR['downtime_till'].clndr.sdt.getTime()/1000);}"
+							);
+		$frmService->AddAction('onsubmit',$script);
+		$frmService->AddVar('new_service_time[from]','');
+		$frmService->AddVar('new_service_time[to]','');
+		
+		$clndr_icon = new CImg('images/general/bar/cal.gif','calendar', 16, 12, 'pointer');
+		$clndr_icon->AddAction('onclick','javascript: var pos = getPosition(this);'.
+											' pos.top-=203; pos.left+=16; '.
+											" CLNDR['downtime_since'].clndr.clndrshow(pos.top,pos.left);"
+								);
+				
+		$filtertimetab = new CTable(null,'calendar');
+		$filtertimetab->AddOption('width','10%');
+		
+		$filtertimetab->SetCellPadding(0);
+		$filtertimetab->SetCellSpacing(0);
+	
+		$td_tmp = new CCol(new CTextBox('new_service_time[note]','<short description>',40));
+		$td_tmp->SetColSpan(10);
+		$filtertimetab->AddRow(array(S_NOTE, $td_tmp));
+		
+		$filtertimetab->AddRow(array(
+								S_FROM, 
+								new CNumericBox('downtime_since_day','',2),
+								'/',
+								new CNumericBox('downtime_since_month','',2),
+								'/',
+								new CNumericBox('downtime_since_year','',4),
+								SPACE,
+								new CNumericBox('downtime_since_hour','',2),
+								':',
+								new CNumericBox('downtime_since_minute','',2),
+								$clndr_icon
+						));
+		zbx_add_post_js('create_calendar('.
+							'null,'.
+							'["downtime_since_day","downtime_since_month","downtime_since_year","downtime_since_hour","downtime_since_minute"],'.
+							'"downtime_since");'
+						);
+
+		$clndr_icon->AddAction('onclick','javascript: var pos = getPosition(this);'.
+											' pos.top-=203; pos.left+=16; '.
+											" CLNDR['downtime_till'].clndr.clndrshow(pos.top,pos.left);"
+								);
+		$filtertimetab->AddRow(array(
+								S_TILL, 
+								new CNumericBox('downtime_till_day','',2),
+								'/',
+								new CNumericBox('downtime_till_month','',2),
+								'/',
+								new CNumericBox('downtime_till_year','',4),
+								SPACE,
+								new CNumericBox('downtime_till_hour','',2),
+								':',
+								new CNumericBox('downtime_till_minute','',2),
+								$clndr_icon
+						));
+		zbx_add_post_js('create_calendar('.
+							'null,'.
+							'["downtime_till_day","downtime_till_month","downtime_till_year","downtime_till_hour","downtime_till_minute"],'.
+							'"downtime_till");'
+						);
+		
+		$time_param->AddRow($filtertimetab);
+	}
+	else{
 		$cmbWeekFrom = new CComboBox('new_service_time[from_week]','Sunday');
 		$cmbWeekTo = new CComboBox('new_service_time[to_week]','Sunday');
 		foreach(array(
@@ -649,8 +711,8 @@ if(isset($_REQUEST['sform'])){
 	}
 
 	$frmService->AddRow(S_NEW_SERVICE_TIME, array(
-			$cmbTimeType, BR, 
-			$time_param, BR,
+			$cmbTimeType, BR(), 
+			$time_param,
 			new CButton('add_service_time','add','javascript: document.forms[0].action += \'?sform=1\'; submit();')
 		));
 //trigger
@@ -658,14 +720,15 @@ if(isset($_REQUEST['sform'])){
 
 	if($triggerid > 0){
 		$trigger = expand_trigger_description($triggerid);
-	} else{
+	} 
+	else{
 		$trigger = "";
 	}
 	
 	$row = new CRow(array(
 						new CCol(S_TRIGGER,'form_row_l'),
 						new CCol(array(
-									new CTextBox("trigger",$trigger,32,'yes'),
+									new CTextBox("trigger",$trigger,64,'yes'),
 									new CButton("btn1",S_SELECT,"return PopUp('popup.php?"."dstfrm=".$frmService->GetName()."&dstfld1=triggerid&dstfld2=trigger"."&srctbl=triggers&srcfld1=triggerid&srcfld2=description&real_hosts=1');",'T')
 								),'form_row_r')
 							));
