@@ -24,8 +24,8 @@ require_once('include/setup.inc.php');
 
 /* ******** */
 
-$page["title"] = "S_INSTALLATION";
-$page["file"] = "setup.php";
+$page['title'] = "S_INSTALLATION";
+$page['file'] = 'setup.php';
 
 if(!defined("PAGE_HEADER_LOADED"))
 	define('ZBX_PAGE_NO_MENU', 1);
@@ -54,12 +54,12 @@ if(!defined("PAGE_HEADER_LOADED"))
 		"nodename"=>		array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,		null),
 		"nodeid"=>		array(T_ZBX_INT, O_OPT,	null,	BETWEEN(0,999),		null),
 /* actions */
-		"save_config"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
-		"retry"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
-		"cancel"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
-		"finish"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
-		"next"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
-		"back"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	NULL,	NULL),
+		"save_config"=>		array(T_ZBX_STR, O_OPT, P_SYS,	NULL,	NULL),
+		"retry"=>		array(T_ZBX_STR, O_OPT, P_SYS,	NULL,	NULL),
+		"cancel"=>		array(T_ZBX_STR, O_OPT, P_SYS,	NULL,	NULL),
+		"finish"=>		array(T_ZBX_STR, O_OPT, P_SYS,	NULL,	NULL),
+		"next"=>		array(T_ZBX_STR, O_OPT, P_SYS,	NULL,	NULL),
+		"back"=>		array(T_ZBX_STR, O_OPT, P_SYS,	NULL,	NULL),
 /* other */
 		"form"=>		array(T_ZBX_STR, O_OPT, P_SYS,	NULL,	NULL),
 		"form_refresh"=>	array(T_ZBX_INT, O_OPT,	NULL,	NULL,	NULL)
@@ -83,29 +83,31 @@ if(!defined("PAGE_HEADER_LOADED"))
 	if(!isset($ZBX_CONFIG['agree'])) $ZBX_CONFIG['agree'] = false;
 
 	$ZBX_CONFIG['allowed_db'] = array();
-	/* MYSQL */	if(zbx_is_callable(array('mysql_pconnect', 'mysql_select_db', 'mysql_error', 'mysql_select_db',
-		'mysql_query', 'mysql_fetch_array', 'mysql_fetch_row', 'mysql_data_seek','mysql_insert_id'
-		)))
+	
+	/* MYSQL */	
+	if(zbx_is_callable(array('mysql_pconnect', 'mysql_select_db', 'mysql_error', 'mysql_select_db','mysql_query', 'mysql_fetch_array', 'mysql_fetch_row', 'mysql_data_seek','mysql_insert_id')))
 	{
 		$ZBX_CONFIG['allowed_db']['MYSQL'] = 'MySQL';
 	}
-	/* POSTGRESQL */if(zbx_is_callable(array('pg_pconnect', 'pg_fetch_array', 'pg_fetch_row', 'pg_exec', 'pg_getlastoid')))
-	{
+	
+	/* POSTGRESQL */
+	if(zbx_is_callable(array('pg_pconnect', 'pg_fetch_array', 'pg_fetch_row', 'pg_exec', 'pg_getlastoid'))){
 		$ZBX_CONFIG['allowed_db']['POSTGRESQL'] = 'PostgreSQL';
 	}
-	/* ORACLE */	if(zbx_is_callable(array('ocilogon', 'ocierror', 'ociparse', 'ociexecute', 'ocifetchinto')))
-	{
+	
+	/* ORACLE */	
+	if(zbx_is_callable(array('ocilogon', 'ocierror', 'ociparse', 'ociexecute', 'ocifetchinto'))){
 		$ZBX_CONFIG['allowed_db']['ORACLE'] = 'Oracle';
 	}
-	/* SQLITE3 */	if(zbx_is_callable(array('sqlite3_open', 'sqlite3_close', 'sqlite3_query', 'sqlite3_error', 'sqlite3_fetch_array', 'sqlite3_query_close', 'sqlite3_exec')))
-	{
+
+	/* SQLITE3 */
+	if(zbx_is_callable(array('sqlite3_open', 'sqlite3_close', 'sqlite3_query', 'sqlite3_error', 'sqlite3_fetch_array', 'sqlite3_query_close', 'sqlite3_exec'))){
 		$ZBX_CONFIG['allowed_db']['SQLITE3'] = 'SQLite3';
 	}
 	
 	if(count($ZBX_CONFIG['allowed_db']) == 0){
 		$ZBX_CONFIG['allowed_db']['no'] = 'No';
 	}
-
 ?>
 <?php
 	global $ZBX_SETUP_WIZARD;
