@@ -34,7 +34,7 @@ include_once "include/page_header.php";
 //		VAR			TYPE	OPTIONAL FLAGS	VALIDATION	EXCEPTION
 	$fields=array(
 		"triggerid"=>	array(T_ZBX_INT, O_MAND, P_SYS,	DB_ID, null),
-		"comments"=>	array(T_ZBX_STR, O_OPT,  null,	NOT_EMPTY,'isset({save})'),
+		"comments"=>	array(T_ZBX_STR, O_OPT,  null,	null, 'isset({save})'),
 
 /* actions */
 		"save"=>		array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
@@ -51,18 +51,21 @@ include_once "include/page_header.php";
 ?>
 <?php
 
-	$available_triggers = get_accessible_triggers(PERM_READ_ONLY,PERM_RES_IDS_ARRAY);
+	$sql = 'SELECT * '.
+			' FROM items i, functions f '.
+			' WHERE i.itemid=f.itemid '.
+				' AND f.triggerid='.$_REQUEST['triggerid'].
+				' AND '.DBin_node('f.triggerid');				
+	if(!$db_data = DBfetch(DBselect($sql))){
+		fatal_error(S_NO_TRIGGER_DEFINED);
+	}
 	
-	if(!$db_data = DBfetch(DBselect('SELECT * '.
-							' FROM items i, functions f '.
-	                        ' WHERE i.itemid=f.itemid '.
-								' AND f.triggerid='.$_REQUEST["triggerid"].
-								' AND '.DBcondition('f.triggerid',$available_triggers).
-								' AND '.DBin_node('f.triggerid')
-				)))
-	{
+	$available_triggers = get_accessible_triggers(PERM_READ_ONLY, array($db_data['hostid']));
+	
+	if(!isset($available_triggers[$_REQUEST['triggerid']])){
 		access_deny();
 	}
+	
 	$trigger_hostid = $db_data['hostid'];
 	
 	if(isset($_REQUEST["save"])){
