@@ -1,7 +1,7 @@
 <?php
 /* 
 ** ZABBIX
-** Copyright (C) 2000-2005 SIA Zabbix
+** Copyright (C) 2000-2009 SIA Zabbix
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 	require_once('include/media.inc.php');
 	require_once('include/users.inc.php');
 	require_once('include/forms.inc.php');
+	require_once('include/classes/curl.inc.php');
 	require_once('include/js.inc.php');
 
 	$page['title'] = 'S_USERS';
@@ -32,7 +33,6 @@
 	$page['scripts'] = array('menu_scripts.js');
 
 include_once('include/page_header.php');
-
 ?>
 <?php
 	$_REQUEST['config']=get_request('config',get_profile('web.users.config',0));
@@ -65,7 +65,7 @@ include_once('include/page_header.php');
 		'lang'=>		array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'(isset({config})&&({config}==0))&&isset({save})'),
 		'theme'=>		array(T_ZBX_STR, O_OPT,	null,	NOT_EMPTY,	'(isset({config})&&({config}==0))&&isset({save})'),
 		'autologin'=>	array(T_ZBX_INT, O_OPT,	null,	IN('0,1'),	null),
-		'autologout'=>	array(T_ZBX_INT, O_OPT,	null,	BETWEEN(0,3600),'(isset({config})&&({config}==0))&&isset({save})'),
+		'autologout'=>	array(T_ZBX_INT, O_OPT,	null,	BETWEEN(90,10000), null),
 		'url'=>			array(T_ZBX_STR, O_OPT,	null,	null,		'(isset({config})&&({config}==0))&&isset({save})'),
 		'refresh'=>		array(T_ZBX_INT, O_OPT,	null,	BETWEEN(0,3600),'(isset({config})&&({config}==0))&&isset({save})'),
 
@@ -94,8 +94,7 @@ include_once('include/page_header.php');
 		'set_gui_access'=>		array(T_ZBX_INT, O_OPT,	null,	IN('0,1,2'), null),
 
 /* actions */
-		'register'=>	array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	
-					IN('"add permission","delete permission"'), null),
+		'register'=>	array(T_ZBX_STR, O_OPT, P_SYS|P_ACT, IN('"add permission","delete permission"'), null),
 
 		'save'=>	array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
 		'delete'=>	array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
@@ -120,9 +119,8 @@ include_once('include/page_header.php');
 		'form_refresh'=>array(T_ZBX_STR, O_OPT, null,	null,	null)
 	);
 
-
 	check_fields($fields);
-	validate_sort_and_sortorder('u.alias',ZBX_SORT_UP);	
+	validate_sort_and_sortorder('u.alias',ZBX_SORT_UP);
 ?>
 <?php
 	if($_REQUEST['config']==0){
@@ -157,7 +155,7 @@ include_once('include/page_header.php');
 			if(($config['authentication_type'] != ZBX_AUTH_INTERNAL) && zbx_empty($_REQUEST['password1'])){
 				if(($config['authentication_type'] == ZBX_AUTH_LDAP) && isset($_REQUEST['userid'])){
 					if(GROUP_GUI_ACCESS_INTERNAL != get_user_auth($_REQUEST['userid'])){
-						$_REQUEST['password1'] = $_REQUEST['password2'] = 'zabbix';
+//						$_REQUEST['password1'] = $_REQUEST['password2'] = 'zabbix';
 					}
 				}
 				else{
@@ -183,7 +181,7 @@ include_once('include/page_header.php');
 					DBstart();
 					$result=update_user($_REQUEST['userid'],
 						$_REQUEST['name'],$_REQUEST['surname'],$_REQUEST['alias'],
-						$_REQUEST['password1'],$_REQUEST['url'],get_request('autologin',0),$_REQUEST['autologout'],
+						$_REQUEST['password1'],$_REQUEST['url'],get_request('autologin',0),get_request('autologout',0),
 						$_REQUEST['lang'],$_REQUEST['theme'],$_REQUEST['refresh'],$_REQUEST['user_type'],
 						$user_groups, $user_medias);
 						
@@ -196,7 +194,7 @@ include_once('include/page_header.php');
 					DBstart();
 					$result=add_user(
 						$_REQUEST['name'],$_REQUEST['surname'],$_REQUEST['alias'],
-						$_REQUEST['password1'],$_REQUEST['url'],get_request('autologin',0),$_REQUEST['autologout'],
+						$_REQUEST['password1'],$_REQUEST['url'],get_request('autologin',0),get_request('autologout',0),
 						$_REQUEST['lang'],$_REQUEST['theme'],$_REQUEST['refresh'],$_REQUEST['user_type'],
 						$user_groups, $user_medias);
 						
@@ -439,11 +437,9 @@ include_once('include/page_header.php');
 ?>
 <?php
 	$_REQUEST['filter_usrgrpid'] = get_request('filter_usrgrpid',get_profile('web.users.filter.usrgrpid',0));
-	update_profile('web.users.filter.usrgrpid',$_REQUEST['filter_usrgrpid'],PROFILE_TYPE_ID);
-	
+	update_profile('web.users.filter.usrgrpid', $_REQUEST['filter_usrgrpid'], PROFILE_TYPE_ID);
 	$frmForm = new CForm();
 	$frmForm->SetMethod('get');
-	
 	$cmbConf = new CComboBox('config',$_REQUEST['config'],'submit()');
 	$cmbConf->AddItem(0,S_USERS);
 	$cmbConf->AddItem(1,S_USER_GROUPS);
@@ -467,6 +463,7 @@ include_once('include/page_header.php');
 	echo SBR; 
 ?>
 <?php
+	$row_count = 0;
 	if($_REQUEST['config']==0){
 		if(isset($_REQUEST['form'])){
 			insert_user_form(get_request('userid',null));
@@ -474,8 +471,15 @@ include_once('include/page_header.php');
 		else{
 			$form = new CForm(null,'post');
 			$form->SetName('users');
+		
+			$numrows = new CSpan(null,'info');
+			$numrows->addOption('name','numrows');	
+			$header = get_table_header(array(S_USERS_BIG,
+							new CSpan(SPACE.SPACE.'|'.SPACE.SPACE, 'divider'),
+							S_FOUND.': ',$numrows,)
+							);			
+			show_table_header($header);
 
-			show_table_header(S_USERS_BIG);
 			$table=new CTableInfo(S_NO_USERS_DEFINED);
 			$table->setHeader(array(
 				array(new CCheckBox('all_users',NULL,
@@ -584,6 +588,7 @@ include_once('include/page_header.php');
 					$users_status,
 					$action
 					));
+				$row_count++;
 			}
 			$table->SetFooter(new CCol(new CButtonQMessage('delete_selected',S_DELETE_SELECTED,S_DELETE_SELECTED_USERS_Q)));
 
@@ -601,7 +606,13 @@ include_once('include/page_header.php');
 			insert_usergroups_form();
 		}
 		else{
-			show_table_header(S_USER_GROUPS_BIG);
+			$numrows = new CSpan(null,'info');
+			$numrows->addOption('name','numrows');	
+			$header = get_table_header(array(S_USER_GROUPS_BIG,
+							new CSpan(SPACE.SPACE.'|'.SPACE.SPACE, 'divider'),
+							S_FOUND.': ',$numrows,)
+							);			
+			show_table_header($header);
 			$form = new CForm();
 
 			$table = new CTableInfo(S_NO_USER_GROUPS_DEFINED);
@@ -672,6 +683,7 @@ include_once('include/page_header.php');
 					),
 					new CCol($users,'wraptext')
 					));
+				$row_count++;
 			}
 			$table->SetFooter(new CCol(new CButtonQMessage('delete_selected',S_DELETE_SELECTED,S_DELETE_SELECTED_GROUPS_Q)));
 
@@ -679,6 +691,8 @@ include_once('include/page_header.php');
 			$form->Show();
 		}
 	}
+	zbx_add_post_js('insert_in_element("numrows","'.$row_count.'");');
+
 ?>
 <?php
 
