@@ -121,8 +121,8 @@
 #define OFF	0
 
 #define	APPLICATION_NAME	"ZABBIX Agent"
-#define	ZABBIX_REVDATE		"16 January 2009"
-#define	ZABBIX_VERSION		"1.6.2"
+#define	ZABBIX_REVDATE		"3 April 2009"
+#define	ZABBIX_VERSION		"1.6.4"
 
 #if defined(_WINDOWS)
 extern char ZABBIX_SERVICE_NAME[64];
@@ -313,7 +313,8 @@ typedef enum
 	SYSMAP_ELEMENT_TYPE_HOST = 0,
 	SYSMAP_ELEMENT_TYPE_MAP,
 	SYSMAP_ELEMENT_TYPE_TRIGGER,
-	SYSMAP_ELEMENT_TYPE_HOST_GROUP
+	SYSMAP_ELEMENT_TYPE_HOST_GROUP,
+	SYSMAP_ELEMENT_TYPE_IMAGE
 } zbx_sysmap_element_types_t;
 
 /* Special item key used for storing server status */
@@ -640,7 +641,7 @@ int	zbx_binary2hex(const u_char *input, int ilen, char **output, int *olen);
 int     zbx_hex2binary(char *io);
 void	zbx_hex2octal(const char *input, char **output, int *olen);
 #ifdef HAVE_POSTGRESQL
-void	zbx_pg_escape_bytea(const u_char *input, int ilen, char **output, int *olen);
+int	zbx_pg_escape_bytea(const u_char *input, int ilen, char **output, int *olen);
 int	zbx_pg_unescape_bytea(u_char *io);
 #endif
 int	zbx_get_next_field(const char **line, char **output, int *olen, char separator);
