@@ -115,6 +115,8 @@ typedef enum {
 #define TRIGGER_EXPRESSION_LEN_MAX	TRIGGER_EXPRESSION_LEN+1
 #define TRIGGER_URL_LEN			255
 #define TRIGGER_URL_LEN_MAX		TRIGGER_URL_LEN+1
+#define TRIGGER_ERROR_LEN		128
+#define TRIGGER_ERROR_LEN_MAX		TRIGGER_ERROR_LEN+1
 
 #define CONDITION_VALUE_LEN		255
 #define CONDITION_VALUE_LEN_MAX		CONDITION_VALUE_LEN+1
@@ -136,10 +138,55 @@ typedef enum {
 
 #define ITEM_KEY_LEN			255
 #define ITEM_KEY_LEN_MAX		ITEM_KEY_LEN+1
+#define ITEM_DESCRIPTION_LEN		255
+#define ITEM_DESCRIPTION_LEN_MAX	ITEM_DESCRIPTION_LEN+1
+#define ITEM_SNMP_COMMUNITY_LEN		64
+#define ITEM_SNMP_COMMUNITY_LEN_MAX	ITEM_SNMP_COMMUNITY_LEN+1
+#define ITEM_SNMP_OID_LEN		255
+#define ITEM_SNMP_OID_LEN_MAX		ITEM_SNMP_OID_LEN+1
 #define ITEM_LASTVALUE_LEN		255
 #define ITEM_LASTVALUE_LEN_MAX		ITEM_LASTVALUE_LEN+1
 #define ITEM_ERROR_LEN			128
 #define ITEM_ERROR_LEN_MAX		ITEM_ERROR_LEN+1
+#define ITEM_TRAPPER_HOSTS_LEN		255
+#define ITEM_TRAPPER_HOSTS_LEN_MAX	ITEM_TRAPPER_HOSTS_LEN+1
+#define ITEM_UNITS_LEN			10
+#define ITEM_UNITS_LEN_MAX		ITEM_UNITS_LEN+1
+#define ITEM_SNMPV3_SECURITYNAME_LEN		64
+#define ITEM_SNMPV3_SECURITYNAME_LEN_MAX	ITEM_SNMPV3_SECURITYNAME_LEN+1
+#define ITEM_SNMPV3_AUTHPASSPHRASE_LEN		64
+#define ITEM_SNMPV3_AUTHPASSPHRASE_LEN_MAX	ITEM_SNMPV3_AUTHPASSPHRASE_LEN+1
+#define ITEM_SNMPV3_PRIVPASSPHRASE_LEN		64
+#define ITEM_SNMPV3_PRIVPASSPHRASE_LEN_MAX	ITEM_SNMPV3_PRIVPASSPHRASE_LEN+1
+#define ITEM_FORMULA_LEN		255
+#define ITEM_FORMULA_LEN_MAX		ITEM_FORMULA_LEN+1
+#define ITEM_LOGTIMEFMT_LEN		64
+#define ITEM_LOGTIMEFMT_LEN_MAX		ITEM_LOGTIMEFMT_LEN+1
+#define ITEM_DELAY_FLEX_LEN		255
+#define ITEM_DELAY_FLEX_LEN_MAX		ITEM_DELAY_FLEX_LEN+1
+
+#define FUNCTION_LASTVALUE_LEN		255
+#define FUNCTION_LASTVALUE_LEN_MAX	FUNCTION_LASTVALUE_LEN+1
+#define FUNCTION_FUNCTION_LEN		12
+#define FUNCTION_FUNCTION_LEN_MAX	FUNCTION_FUNCTION_LEN+1
+#define FUNCTION_PARAMETER_LEN		255
+#define FUNCTION_PARAMETER_LEN_MAX	FUNCTION_PARAMETER_LEN+1
+
+#define HISTORY_STR_VALUE_LEN		255
+#define HISTORY_STR_VALUE_LEN_MAX	HISTORY_STR_VALUE_LEN+1
+
+#define HISTORY_LOG_SOURCE_LEN		64
+#define HISTORY_LOG_SOURCE_LEN_MAX	HISTORY_LOG_SOURCE_LEN+1
+
+#define ALERT_SENDTO_LEN		100
+#define ALERT_SENDTO_LEN_MAX		ALERT_SENDTO_LEN+1
+#define ALERT_SUBJECT_LEN		255
+#define ALERT_SUBJECT_LEN_MAX		ALERT_SUBJECT_LEN+1
+#define ALERT_ERROR_LEN			128
+#define ALERT_ERROR_LEN_MAX		ALERT_ERROR_LEN+1
+
+#define APPLICATION_NAME_LEN		255
+#define APPLICATION_NAME_LEN_MAX	APPLICATION_NAME_LEN+1
 
 #define GRAPH_NAME_LEN			128
 #define GRAPH_NAME_LEN_MAX		GRAPH_NAME_LEN+1
@@ -150,9 +197,24 @@ typedef enum {
 #define ACTION_SUBJECT_LEN		255
 #define ACTION_SUBJECT_LEN_MAX		ACTION_SUBJECT_LEN+1
 
+#define DHOST_IP_LEN			39
+#define DHOST_IP_LEN_MAX		DHOST_IP_LEN+1
+
+#define DSERVICE_KEY_LEN		255
+#define DSERVICE_KEY_LEN_MAX		DSERVICE_KEY_LEN+1
 #define DSERVICE_VALUE_LEN		255
 #define DSERVICE_VALUE_LEN_MAX		DSERVICE_VALUE_LEN+1
 
+#define PROXY_DHISTORY_IP_LEN		39
+#define PROXY_DHISTORY_IP_LEN_MAX	PROXY_DHISTORY_IP_LEN+1
+#define PROXY_DHISTORY_KEY_LEN		255
+#define PROXY_DHISTORY_KEY_LEN_MAX	PROXY_DHISTORY_KEY_LEN+1
+#define PROXY_DHISTORY_VALUE_LEN	255
+#define PROXY_DHISTORY_VALUE_LEN_MAX	PROXY_DHISTORY_VALUE_LEN+1
+
+#define HTTPTEST_ERROR_LEN		255
+#define HTTPTEST_ERROR_LEN_MAX		HTTPTEST_ERROR_LEN+1
+
 #define HTTPSTEP_STATUS_LEN		255
 #define HTTPSTEP_STATUS_LEN_MAX		HTTPSTEP_STATUS_LEN+1
 
@@ -563,6 +625,7 @@ zbx_uint64_t DBget_proxy_lastaccess(const char *hostname);
 
 void    DBescape_string(const char *from, char *to, int maxlen);
 char*   DBdyn_escape_string(const char *str);
+char*	DBdyn_escape_string_len(const char *src, int max_src_len);
 
 void    DBget_item_from_db(DB_ITEM *item,DB_ROW row);
 
@@ -614,6 +677,9 @@ void	DBupdate_services(
 	);
 
 /* History related functions */
+int	DBadd_trend(zbx_uint64_t itemid, double value, int clock);
+int	DBadd_trend_uint(zbx_uint64_t itemid, zbx_uint64_t value, int clock);
+
 int	DBadd_history(zbx_uint64_t itemid, double value, int clock);
 int	DBadd_history_log(zbx_uint64_t itemid, char *value, int clock, int timestamp, char *source, int severity, int lastlogsize);
 int	DBadd_history_str(zbx_uint64_t itemid, char *value, int clock);
