@@ -25,12 +25,15 @@
 #define ZBX_DC_HISTORY struct zbx_dc_history_type
 #define ZBX_DC_TREND struct zbx_dc_trend_type
 #define ZBX_DC_NEXTCHECK struct zbx_dc_nextcheck_type
+#define ZBX_DC_ID struct zbx_dc_id_type
+#define ZBX_DC_IDS struct zbx_dc_ids_type
 
 #define	ZBX_HISTORY_SIZE	100000
 /* Must be less than ZBX_HISTORY_SIZE */
 #define	ZBX_SYNC_MAX		1000
 #define	ZBX_TREND_SIZE		100000
 #define	ZBX_TEXTBUFFER_SIZE	16384*1024
+#define ZBX_IDS_SIZE		6
 
 #define ZBX_SYNC_PARTIAL	0
 #define	ZBX_SYNC_FULL		1
@@ -43,6 +46,17 @@ typedef union{
 	char		*value_str;
 } history_value_t;
 
+ZBX_DC_ID
+{
+	char		table_name[64], field_name[64];
+	zbx_uint64_t	lastid;
+};
+
+ZBX_DC_IDS
+{
+	ZBX_DC_ID	id[ZBX_IDS_SIZE];
+};
+
 ZBX_DC_HISTORY
 {
 	zbx_uint64_t	itemid;
@@ -57,6 +71,7 @@ ZBX_DC_HISTORY
 	int		lastlogsize;
 	int		keep_history;
 	int		keep_trends;
+	int		functions;
 };
 
 ZBX_DC_TREND
@@ -103,4 +118,6 @@ void	DCinit_nextchecks();
 void	DCadd_nextcheck(DB_ITEM *item, time_t now, time_t timediff, const char *error_msg);
 void	DCflush_nextchecks();
 
+zbx_uint64_t	DCget_nextid(const char *table_name, const char *field_name, int num);
+
 #endif
