@@ -32,6 +32,15 @@
 #define LOG_TYPE_SYSLOG		1
 #define LOG_TYPE_FILE		2
 
+typedef enum {
+	ERR_Z3001 = 3001,
+	ERR_Z3002,
+	ERR_Z3003,
+	ERR_Z3004,
+	ERR_Z3005,
+	ERR_Z3006
+} zbx_err_codes_t;
+
 extern int	CONFIG_LOG_FILE_SIZE;
 
 /* Type - 0 (syslog), 1 - file */
@@ -42,6 +51,7 @@ int zabbix_open_log(int type,int level, const char *filename);
 #else
 #	define zabbix_log __zbx_zabbix_log
 #endif /* HAVE___VA_ARGS__ */
+void zabbix_errlog(zbx_err_codes_t err, ...);
 void __zbx_zabbix_log(int level, const char *fmt, ...);
 
 void zabbix_close_log(void);
