@@ -33,6 +33,8 @@
 #define PCI_PROCESSOR_TIME		(6)
 #define PCI_PROCESSOR_QUEUE_LENGTH	(44)
 #define PCI_SYSTEM_UP_TIME		(674)
+#define PCI_TERMINAL_SERVICES		(2176)
+#define PCI_TOTAL_SESSIONS		(2178)
 
 //
 // Performance Countername structure
@@ -55,5 +57,6 @@ typedef struct perfcounter PERFCOUNTER;
 extern PERFCOUNTER *PerfCounterList;
 
 char *GetCounterName(unsigned long index);
+int check_counter_path(char *counterPath);
 
 #endif /* ZABBIX_PERFMON_H */
