@@ -27,6 +27,8 @@
 #define	ZBX_DB_FAIL	(-1)
 #define	ZBX_DB_DOWN	(-2)
 
+#define ZBX_MAX_SQL_SIZE	262144	/* 256KB */
+
 #ifdef HAVE_MYSQL
 #	include "mysql.h"
 #	include "errmsg.h"
@@ -113,6 +115,7 @@ void	PG_DBfree_result(DB_RESULT result);
 #endif
 
 int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *dbsocket, int port);
+void	zbx_db_init(char *host, char *user, char *password, char *dbname, char *dbsocket, int port);
 
 void    zbx_db_close(void);
 void    zbx_db_vacuum(void);
