@@ -21,16 +21,62 @@
 #include "cfg.h"
 #include "log.h"
 
-
 char	*CONFIG_FILE			= NULL;
-int	CONFIG_ZABBIX_FORKS		= 5;
-
+int	CONFIG_ZABBIX_FORKS		= 3;
 
 char	*CONFIG_LOG_FILE		= NULL;
 int	CONFIG_LOG_FILE_SIZE		= 1;
 char	CONFIG_ALLOW_ROOT		= 0;
 int	CONFIG_TIMEOUT			= AGENT_TIMEOUT;
 
+static int	__parse_cfg_file(const char *cfg_file, struct cfg_line *cfg, int level);
+
+static int	parse_cfg_object(const char *cfg_file, struct cfg_line *cfg, int level)
+{
+#ifdef _WINDOWS
+	return __parse_cfg_file(cfg_file, cfg, level);
+#else
+	DIR		*dir;
+	struct stat	sb;
+	struct dirent	*d;
+	char		*incl_file = NULL;
+	int		result = SUCCEED;
+
+	if (stat(cfg_file, &sb) == -1) {
+		zbx_error("%s: %s\n", cfg_file, strerror(errno));
+		return FAIL;
+	}
+
+	if (!S_ISDIR(sb.st_mode))
+		return __parse_cfg_file(cfg_file, cfg, level);
+
+	if (NULL == (dir = opendir(cfg_file))) {
+		zbx_error("%s: %s\n", cfg_file, strerror(errno));
+		return FAIL;
+	}
+
+	while (NULL != (d = readdir(dir))) {
+		incl_file = zbx_dsprintf(incl_file, "%s/%s", cfg_file, d->d_name);
+
+		if (stat(incl_file, &sb) == -1 || !S_ISREG(sb.st_mode))
+			continue;
+
+		if (__parse_cfg_file(incl_file, cfg, level) == FAIL) {
+			result = FAIL;
+			break;
+		}
+	}
+	zbx_free(incl_file);
+
+	if (closedir(dir) == -1) {
+		zbx_error("%s: %s\n", cfg_file, strerror(errno));
+		return FAIL;
+	}
+
+	return result;
+#endif
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: parse_cfg_file                                                   *
@@ -49,12 +95,10 @@ int	CONFIG_TIMEOUT			= AGENT_TIMEOUT;
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-int	parse_cfg_file(const char *cfg_file,struct cfg_line *cfg)
+static int	__parse_cfg_file(const char *cfg_file, struct cfg_line *cfg, int level)
 {
 	FILE	*file;
 
-	static int level = 0;
-
 #define ZBX_MAX_INCLUDE_LEVEL 10
 
 #define ZBX_CFG_LTRIM_CHARS "\t "
@@ -74,10 +118,10 @@ int	parse_cfg_file(const char *cfg_file,struct cfg_line *cfg)
 
 	assert(cfg);
 
-	if(++level > ZBX_MAX_INCLUDE_LEVEL)
+	if (++level > ZBX_MAX_INCLUDE_LEVEL)
 	{
-		/* Ignore include files of depth 10 */
-		return result;
+		zbx_error("Recursion detected! Skipped processing of '%s'", cfg_file);
+		return FAIL;
 	}
 
 	if(cfg_file)
@@ -117,7 +161,8 @@ int	parse_cfg_file(const char *cfg_file,struct cfg_line *cfg)
 
 				if(strcmp(parameter, "Include") == 0)
 				{
-					parse_cfg_file(value, cfg);
+					if (FAIL == (result = parse_cfg_object(value, cfg, level)))
+						break;
 				}
 
 				for(i = 0; value[i] != '\0'; i++)
@@ -180,7 +225,7 @@ int	parse_cfg_file(const char *cfg_file,struct cfg_line *cfg)
 		}
 	}
 
-	return	SUCCEED;
+	return	result;
 
 lbl_cannot_open:
 	zbx_error("Cannot open config file [%s] [%s].",cfg_file,strerror(errno));
@@ -194,3 +239,8 @@ lbl_incorrect_config:
 	zbx_error("Wrong value of [%s] in line %d.", cfg[i].parameter, lineno);
 	exit(1);
 }
+
+int	parse_cfg_file(const char *cfg_file,struct cfg_line *cfg)
+{
+	return __parse_cfg_file(cfg_file, cfg, 0);
+}
