@@ -55,7 +55,7 @@ void	zbx_db_close(void)
 #endif
 #ifdef	HAVE_ORACLE
 	if (SQLO_SUCCESS != sqlo_finish(oracle))
-		zabbix_log(LOG_LEVEL_ERR, "Cannot finish ORACLE session");
+		zabbix_errlog(ERR_Z3004, 0, "sqlo_finish");
 #endif
 #ifdef	HAVE_SQLITE3
 	sqlite_transaction_started = 0;
@@ -73,55 +73,46 @@ void	zbx_db_close(void)
 int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *dbsocket, int port)
 {
 	int	ret = ZBX_DB_OK;
+#ifdef	HAVE_SQLITE3
+	char	*p, *path;
+#endif /* HAVE_SQLITE3 */
 
-	/*	zabbix_log(LOG_LEVEL_ERR, "[%s] [%s] [%s]\n",dbname, dbuser, dbpassword ); */
 #ifdef	HAVE_MYSQL
 	/* For MySQL >3.22.00 */
 	/*	if( ! mysql_connect( conn, NULL, dbuser, dbpassword ) )*/
 
 	conn = mysql_init(NULL);
 
-	if( ! mysql_real_connect( conn, host, user, password, dbname, port, dbsocket,0 ) )
+	if (!mysql_real_connect(conn, host, user, password, dbname, port, dbsocket, CLIENT_MULTI_STATEMENTS))
 	{
-		zabbix_log(LOG_LEVEL_ERR, "Failed to connect to database: Error: %s [%d]",
-			mysql_error(conn), mysql_errno(conn));
+		zabbix_errlog(ERR_Z3001, dbname, mysql_errno(conn), mysql_error(conn));
 		ret = ZBX_DB_FAIL;
 	}
 
-	if(ZBX_DB_OK == ret)
+	if (ZBX_DB_OK == ret)
 	{
-		if( mysql_select_db( conn, dbname ) != 0 )
+		if (0 != mysql_select_db(conn, dbname))
 		{
-			zabbix_log(LOG_LEVEL_ERR, "Failed to select database: Error: %s [%d]",
-				mysql_error(conn), mysql_errno(conn));
+			zabbix_errlog(ERR_Z3001, dbname, mysql_errno(conn), mysql_error(conn));
 			ret = ZBX_DB_FAIL;
 		}
 	}
 
-	if(ZBX_DB_OK == ret)
-	{
-#ifdef HAVE_MYSQL_AUTOCOMMIT
-		if(mysql_autocommit(conn, 1) != 0)
-		{
-			zabbix_log(LOG_LEVEL_ERR, "Failed to set autocommit to 1: Error: %s [%d]",
-				mysql_error(conn), mysql_errno(conn));
-			ret = ZBX_DB_FAIL;
-		}
-#endif /* HAVE_MYSQL_AUTOCOMMIT */
-	}
+	if (ZBX_DB_OK == ret)
+		DBexecute("SET CHARACTER SET utf8");
 
-	if(ZBX_DB_FAIL  == ret)
+	if (ZBX_DB_FAIL == ret)
 	{
-		switch(mysql_errno(conn)) {
-			case	CR_SERVER_GONE_ERROR:
-			case	CR_CONNECTION_ERROR:
-			case	CR_SERVER_LOST:
-			case	ER_SERVER_SHUTDOWN:
-			case	ER_UNKNOWN_ERROR:
-				ret = ZBX_DB_DOWN;
-				break;
-			default:
-				break;
+		switch (mysql_errno(conn)) {
+		case CR_SERVER_GONE_ERROR:
+		case CR_CONNECTION_ERROR:
+		case CR_SERVER_LOST:
+		case ER_SERVER_SHUTDOWN:
+		case ER_UNKNOWN_ERROR:
+			ret = ZBX_DB_DOWN;
+			break;
+		default:
+			break;
 		}
 	}
 
@@ -138,14 +129,14 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 
 	zbx_free(cport);
 
-/* check to see that the backend connection was successfully made */
+	/* check to see that the backend connection was successfully made */
 	if (PQstatus(conn) != CONNECTION_OK)
 	{
-		zabbix_log(LOG_LEVEL_ERR, "Connection to database '%s' failed: %s", dbname, PQerrorMessage(conn));
+		zabbix_errlog(ERR_Z3001, dbname, 0, PQerrorMessage(conn));
 		ret = ZBX_DB_FAIL;
 	}
 
-	result = DBselect("select oid from pg_type where typname = 'bytea'" );
+	result = DBselect("select oid from pg_type where typname = 'bytea'");
 	row = DBfetch(result);
 	if(row)
 	{
@@ -158,65 +149,88 @@ int	zbx_db_connect(char *host, char *user, char *password, char *dbname, char *d
 #ifdef	HAVE_ORACLE
 	char	connect[MAX_STRING_LEN];
 
-	if (SQLO_SUCCESS != sqlo_init(SQLO_OFF, 1, 100)) {
-		zabbix_log(LOG_LEVEL_ERR, "Failed to init libsqlora8");
+	zbx_strlcpy(connect, user, sizeof(connect));
 
+	if (password && *password) {
+		zbx_strlcat(connect, "/", sizeof(connect));
+		zbx_strlcat(connect, password, sizeof(connect));
+
+		if (dbname && *dbname) {
+			zbx_strlcat(connect, "@", sizeof(connect));
+			zbx_strlcat(connect, dbname, sizeof(connect));
+		}
+	}
+
+	if (SQLO_SUCCESS != sqlo_init(SQLO_OFF, 1, 100)) {
+		zabbix_errlog(ERR_Z3001, connect, 0, "Failed to init libsqlora8");
 		ret = ZBX_DB_FAIL;
 	}
 
 	if (ZBX_DB_OK == ret) {
-		zbx_strlcpy(connect, user, sizeof(connect));
-
-		if (password && *password) {
-			zbx_strlcat(connect, "/", sizeof(connect));
-			zbx_strlcat(connect, password, sizeof(connect));
-
-			if (dbname && *dbname) {
-				zbx_strlcat(connect, "@", sizeof(connect));
-				zbx_strlcat(connect, dbname, sizeof(connect));
-			}
-		}
-
 		/* login */ /* TODO: how to use port??? */
 		if (SQLO_SUCCESS != sqlo_connect(&oracle, connect)) {
-			zabbix_log(LOG_LEVEL_ERR, "Cannot login with %s",
-					connect);
-
+			zabbix_errlog(ERR_Z3001, connect, 0, "sqlo_connect");
 			ret = ZBX_DB_FAIL;
 		}
 	}
 
 	if (ZBX_DB_OK == ret)
-		sqlo_autocommit_on(oracle);
+		sqlo_autocommit_off(oracle);
 
 	return ret;
 #endif
 #ifdef	HAVE_SQLITE3
-	ret = sqlite3_open(dbname, &conn);
-
-/* check to see that the backend connection was successfully made */
-	if(ret)
-	{
-		zabbix_log(LOG_LEVEL_ERR, "Can't open database [%s]: %s\n", dbname, sqlite3_errmsg(conn));
-		DBclose();
+	/* check to see that the backend connection was successfully made */
+	if (SQLITE_OK != (ret = sqlite3_open(dbname, &conn))) {
+		zabbix_errlog(ERR_Z3001, dbname, 0, sqlite3_errmsg(conn));
 		exit(FAIL);
 	}
 
 	/* Do not return SQLITE_BUSY immediately, wait for N ms */
 	sqlite3_busy_timeout(conn, 60*1000);
 
-/*	if(ZBX_MUTEX_ERROR == php_sem_get(&sqlite_access, dbname))
-	{
-		zbx_error("Unable to create mutex for sqlite");
-		exit(FAIL);
-	}*/
-
 	sqlite_transaction_started = 0;
 
+	path = strdup(dbname);
+	if (NULL != (p = strrchr(path, '/')))
+		*++p = '\0';
+	else
+		*path = '\0';
+
+	DBexecute("PRAGMA synchronous = 0"); /* OFF */
+	DBexecute("PRAGMA temp_store = 2"); /* MEMORY */
+	DBexecute("PRAGMA temp_store_directory = '%s'", path);
+
+	zbx_free(path);
+
 	return ret;
 #endif
 }
 
+void	zbx_db_init(char *host, char *user, char *password, char *dbname, char *dbsocket, int port)
+{
+#ifdef	HAVE_SQLITE3
+	int		ret;
+	struct stat	buf;
+#endif
+
+#ifdef	HAVE_SQLITE3
+	if (0 != stat(dbname, &buf)) {
+		zabbix_log(LOG_LEVEL_WARNING, "Cannot open database file \"%s\": %s", dbname, strerror(errno));
+		zabbix_log(LOG_LEVEL_WARNING, "Creating database ...");
+
+		ret = sqlite3_open(dbname, &conn);
+		if (SQLITE_OK != ret) {
+			zabbix_errlog(ERR_Z3002, dbname, 0, sqlite3_errmsg(conn));
+			exit(FAIL);
+		}
+
+		DBexecute("%s", db_schema);
+		DBclose();
+	}
+#endif
+}
+
 int __zbx_zbx_db_execute(const char *fmt, ...)
 {
 	va_list args;
@@ -309,6 +323,9 @@ void zbx_db_commit(void)
 #ifdef	HAVE_POSTGRESQL
 	zbx_db_execute("%s","commit;");
 #endif
+#ifdef	HAVE_ORACLE
+	zbx_db_execute("%s","commit");
+#endif
 #ifdef	HAVE_SQLITE3
 
 	if(sqlite_transaction_started > 1)
@@ -351,6 +368,9 @@ void zbx_db_rollback(void)
 #ifdef	HAVE_POSTGRESQL
 	zbx_db_execute("rollback;");
 #endif
+#ifdef	HAVE_ORACLE
+	zbx_db_execute("rollback");
+#endif
 #ifdef	HAVE_SQLITE3
 
 	if(sqlite_transaction_started > 1)
@@ -379,19 +399,20 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 	char	*sql = NULL;
 	int	ret = ZBX_DB_OK;
 
-/* suseconds_t is not defined under UP-UX */
-/*	struct timeval tv;
-	suseconds_t    msec;*/
+/*	double	sec;*/
 
 #ifdef	HAVE_POSTGRESQL
 	PGresult	*result;
+	char		*error = NULL;
 #endif
 #ifdef	HAVE_SQLITE3
 	char *error=0;
 #endif
+#ifdef HAVE_MYSQL
+	int		status;
+#endif
 
-/*	gettimeofday(&tv, NULL);
-	msec = tv.tv_usec;*/
+/*	sec = zbx_time();*/
 
 	sql = zbx_dvsprintf(sql, fmt, args);
 
@@ -399,15 +420,14 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 #ifdef	HAVE_MYSQL
 	if(!conn)
 	{
-		zabbix_log( LOG_LEVEL_ERR, "Query executing require connection to database!");
+		zabbix_errlog(ERR_Z3003);
 		ret = ZBX_DB_FAIL;
 	}
 	else
 	{
-		if(mysql_query(conn,sql) != 0)
+		if (0 != (status = mysql_query(conn,sql)))
 		{
-			zabbix_log(LOG_LEVEL_ERR, "Query failed: [%s] %s [%d]",
-				sql, mysql_error(conn), mysql_errno(conn) );
+			zabbix_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
 			switch(mysql_errno(conn)) {
 				case	CR_SERVER_GONE_ERROR:
 				case	CR_CONNECTION_ERROR:
@@ -423,7 +443,23 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 		}
 		else
 		{
-			ret = (int)mysql_affected_rows(conn);
+			do {
+				if (mysql_field_count(conn) == 0)
+				{
+/*					zabbix_log(LOG_LEVEL_DEBUG, ZBX_FS_UI64 " rows affected",
+							(zbx_uint64_t)mysql_affected_rows(conn));*/
+					ret += (int)mysql_affected_rows(conn);
+				}
+				else  /* some error occurred */
+				{
+					zabbix_log(LOG_LEVEL_DEBUG, "Could not retrieve result set");
+					break;
+				}
+
+				/* more results? -1 = no, >0 = error, 0 = yes (keep looping) */
+			        if ((status = mysql_next_result(conn)) > 0)
+					zabbix_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
+			} while (status == 0);
 		}
 	}
 #endif
@@ -432,16 +468,16 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 
 	if( result==NULL)
 	{
-		zabbix_log( LOG_LEVEL_ERR, "Query::%s",sql);
-		zabbix_log(LOG_LEVEL_ERR, "Query failed:%s", "Result is NULL" );
+		zabbix_errlog(ERR_Z3005, 0, "Result is NULL", sql);
 		ret = ZBX_DB_FAIL;
 	}
 	else if( PQresultStatus(result) != PGRES_COMMAND_OK)
 	{
-		zabbix_log( LOG_LEVEL_ERR, "Query::%s",sql);
-		zabbix_log(LOG_LEVEL_ERR, "Query failed:%s:%s",
+		error = zbx_dsprintf(error, "%s:%s",
 				PQresStatus(PQresultStatus(result)),
-			 	PQresultErrorMessage(result));
+				PQresultErrorMessage(result));
+		zabbix_errlog(ERR_Z3005, 0, error, sql);
+		zbx_free(error);
 		ret = ZBX_DB_FAIL;
 	}
 
@@ -454,50 +490,44 @@ int zbx_db_vexecute(const char *fmt, va_list args)
 #ifdef	HAVE_ORACLE
 	if ((ret = sqlo_exec(oracle, sql))<0)
 	{
-		zabbix_log( LOG_LEVEL_ERR, "Query::%s",sql);
-		zabbix_log(LOG_LEVEL_ERR, "Query failed:%s", sqlo_geterror(oracle) );
-		zbx_error("Query::%s.",sql);
-		zbx_error("Query failed:%s.", sqlo_geterror(oracle) );
+		zabbix_errlog(ERR_Z3005, 0, sqlo_geterror(oracle), sql);
 		ret = ZBX_DB_FAIL;
 	}
 #endif
 #ifdef	HAVE_SQLITE3
-	if(!sqlite_transaction_started)
+	if (!sqlite_transaction_started)
 	{
 		php_sem_acquire(&sqlite_access);
 	}
 	
 lbl_exec:
-	if(SQLITE_OK != (ret = sqlite3_exec(conn, sql, NULL, 0, &error)))
+	if (SQLITE_OK != (ret = sqlite3_exec(conn, sql, NULL, 0, &error)))
 	{
-		if(ret == SQLITE_BUSY) goto lbl_exec; /* attention deadlock!!! */
-		
-		zabbix_log(LOG_LEVEL_ERR, "Query::%s",sql);
-		zabbix_log(LOG_LEVEL_ERR, "Query failed [%i]:%s", ret, error);
+		if (ret == SQLITE_BUSY)
+			goto lbl_exec; /* attention deadlock!!! */
+
+		zabbix_errlog(ERR_Z3005, 0, error, sql);
 		sqlite3_free(error);
-/*		if(!sqlite_transaction_started)
-		{
-			php_sem_release(&sqlite_access);
-		}*/
 		ret = ZBX_DB_FAIL;
 	}
 
-	if(ret == ZBX_DB_OK)
+	if (ret == ZBX_DB_OK)
 	{
 		ret = sqlite3_changes(conn);
 	}
 
-	if(!sqlite_transaction_started)
+	if (!sqlite_transaction_started)
 	{
 		php_sem_release(&sqlite_access);
 	}
 #endif
-	
-/*	gettimeofday(&tv, NULL);
-	if((double)(tv.tv_usec-msec)/1000000 > 0.1)
-		zabbix_log( LOG_LEVEL_WARNING, "Long query: " ZBX_FS_DBL " sec, query %s", (double)(tv.tv_usec-msec)/1000000, sql );*/
+
+/*	sec = zbx_time() - sec;	
+	if(sec > 0.1)
+		zabbix_log( LOG_LEVEL_WARNING, "Long query: " ZBX_FS_DBL " sec, \"%s\"", sec, sql);*/
 
 	zbx_free(sql);
+
 	return ret;
 }
 
@@ -609,7 +639,7 @@ DB_ROW	zbx_db_fetch(DB_RESULT result)
 		return NULL;
 	}
 
-	zabbix_log( LOG_LEVEL_ERR, "Fetch failed:%s\n", sqlo_geterror(oracle) );
+	zabbix_errlog(ERR_Z3006, 0, sqlo_geterror(oracle));
 	exit(FAIL);
 	return NULL;
 #endif
@@ -640,9 +670,7 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 	char	*sql = NULL;
 	DB_RESULT result;
 
-/* suseconds_t is not defined under HP=UX */
-/*	struct timeval tv;
-	suseconds_t    msec;*/
+/*	double	sec;*/
 
 #ifdef	HAVE_ORACLE
 	sqlo_stmt_handle_t sth;
@@ -651,9 +679,11 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 	int ret = FAIL;
 	char *error=NULL;
 #endif
+#ifdef	HAVE_POSTGRESQL
+	char	*error = NULL;
+#endif
 
-/*	gettimeofday(&tv, NULL);
-	msec = tv.tv_usec;*/
+/*	sec = zbx_time();*/
 
 	sql = zbx_dvsprintf(sql, fmt, args);
 
@@ -662,15 +692,14 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 #ifdef	HAVE_MYSQL
 	if(!conn)
 	{
-		zabbix_log( LOG_LEVEL_ERR, "Query executing require connection to database!");
+		zabbix_errlog(ERR_Z3003);
 		result = NULL;
 	}
 	else
 	{
 		if(mysql_query(conn,sql) != 0)
 		{
-			zabbix_log( LOG_LEVEL_ERR, "Query::%s",sql);
-			zabbix_log(LOG_LEVEL_ERR, "Query failed:%s [%d]", mysql_error(conn), mysql_errno(conn) );
+			zabbix_errlog(ERR_Z3005, mysql_errno(conn), mysql_error(conn), sql);
 			switch(mysql_errno(conn)) {
 				case	CR_SERVER_GONE_ERROR:
 				case	CR_CONNECTION_ERROR:
@@ -698,17 +727,17 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 
 	if(result->pg_result==NULL)
 	{
-		zabbix_log(LOG_LEVEL_ERR, "Query::%s",sql);
-		zabbix_log(LOG_LEVEL_ERR, "Query failed:%s", "Result is NULL" );
-		exit( FAIL );
+		zabbix_errlog(ERR_Z3005, 0, "Result is NULL", sql);
+		exit(FAIL);
 	}
 	if( PQresultStatus(result->pg_result) != PGRES_TUPLES_OK)
 	{
-		zabbix_log(LOG_LEVEL_ERR, "Query::%s",sql);
-		zabbix_log(LOG_LEVEL_ERR, "Query failed:%s:%s",
+		error = zbx_dsprintf(error, "%s:%s",
 				PQresStatus(PQresultStatus(result->pg_result)),
 			 	PQresultErrorMessage(result->pg_result));
-		exit( FAIL );
+		zabbix_errlog(ERR_Z3005, 0, error, sql);
+		zbx_free(error);
+		exit(FAIL);
 	}
 	
 	/* init rownum */	
@@ -718,8 +747,7 @@ DB_RESULT zbx_db_vselect(const char *fmt, va_list args)
 #ifdef	HAVE_ORACLE
 	if(0 > (sth = (sqlo_open(oracle, sql,0,NULL))))
 	{
-		zabbix_log(LOG_LEVEL_ERR, "Query::%s",sql);
-		zabbix_log(LOG_LEVEL_ERR, "Query failed:%s", sqlo_geterror(oracle));
+		zabbix_errlog(ERR_Z3005, 0, sqlo_geterror(oracle), sql);
 		exit(FAIL);
 	}
 	result = sth;
@@ -737,9 +765,8 @@ lbl_get_table:
 	if(SQLITE_OK != (ret = sqlite3_get_table(conn,sql,&result->data,&result->nrow, &result->ncolumn, &error)))
 	{
 		if(ret == SQLITE_BUSY) goto lbl_get_table; /* attention deadlock!!! */
-		
-		zabbix_log( LOG_LEVEL_ERR, "Query::%s",sql);
-		zabbix_log(LOG_LEVEL_ERR, "Query failed [%i]:%s", ret, error);
+
+		zabbix_errlog(ERR_Z3005, 0, error, sql);
 		sqlite3_free(error);
 		if(!sqlite_transaction_started)
 		{
@@ -754,9 +781,9 @@ lbl_get_table:
 	}
 #endif
 
-/*	gettimeofday(&tv, NULL);
-	if((double)(tv.tv_usec-msec)/1000000 > 0.1)
-		zabbix_log( LOG_LEVEL_WARNING, "Long query: " ZBX_FS_DBL " sec, query %s", (double)(tv.tv_usec-msec)/1000000, sql );*/
+/*	sec = zbx_time() - sec;	
+	if(sec > 0.1)
+		zabbix_log( LOG_LEVEL_WARNING, "Long query: " ZBX_FS_DBL " sec, \"%s\"", sec, sql);*/
 
 	zbx_free(sql);
 	return result;
