@@ -36,10 +36,11 @@
 #include "events.h"
 #include "threads.h"
 #include "zbxserver.h"
+#include "dbcache.h"
 
 const char *DBnode(const char *fieldid, const int nodeid)
 {
-	static char	dbnode[256];
+	static char	dbnode[128];
 
 	if (nodeid == -1)
 		*dbnode = '\0';
@@ -555,6 +556,7 @@ int	DBupdate_trigger_value(DB_TRIGGER *trigger, int new_value, int now, const ch
 	int		event_last_status;
 	int		event_prev_status;
 	int		update_status;
+	char		*reason_esc;
 
 	if(reason==NULL)
 	{
@@ -612,11 +614,13 @@ int	DBupdate_trigger_value(DB_TRIGGER *trigger, int new_value, int now, const ch
 			}
 			else
 			{
+				reason_esc = DBdyn_escape_string_len(reason, TRIGGER_ERROR_LEN);
 				DBexecute("update triggers set value=%d,lastchange=%d,error='%s' where triggerid=" ZBX_FS_UI64,
 					new_value,
 					now,
-					reason,
+					reason_esc,
 					trigger->triggerid);
+				zbx_free(reason_esc);
 			}
 		}
 
@@ -809,7 +813,7 @@ void DBupdate_triggers_status_after_restart(void)
 
 void DBupdate_host_availability(DB_ITEM *item, int available, int clock, const char *error)
 {
-	char	error_esc[MAX_STRING_LEN], error_msg[MAX_STRING_LEN];
+	char	*error_esc, error_msg[MAX_STRING_LEN];
 	int	log_level = LOG_LEVEL_WARNING;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In update_host_availability()");
@@ -818,11 +822,12 @@ void DBupdate_host_availability(DB_ITEM *item, int available, int clock, const c
 	{
 		if (available == HOST_AVAILABLE_FALSE)
 		{
-			DBescape_string(error, error_esc, sizeof(error_esc));
+			error_esc = DBdyn_escape_string_len(error, HOST_ERROR_LEN);
 			DBexecute("update hosts set error='%s',disable_until=%d where hostid=" ZBX_FS_UI64,
 					error_esc,
 					clock + CONFIG_UNAVAILABLE_DELAY,
 					item->hostid);
+			zbx_free(error_esc);
 		}
 		return;
 	}
@@ -845,12 +850,13 @@ void DBupdate_host_availability(DB_ITEM *item, int available, int clock, const c
 				item->host_name,
 				CONFIG_UNAVAILABLE_DELAY);
 
-		DBescape_string(error, error_esc, sizeof(error_esc));
+		error_esc = DBdyn_escape_string_len(error, HOST_ERROR_LEN);
 		DBexecute("update hosts set available=%d,error='%s',disable_until=%d where hostid=" ZBX_FS_UI64,
 				available,
 				error_esc,
 				clock + CONFIG_UNAVAILABLE_DELAY,
 				item->hostid);
+		zbx_free(error_esc);
 
 		update_triggers_status_to_unknown(item->hostid, clock, "Host is unavailable.");
 	}
@@ -921,24 +927,24 @@ void	DBproxy_update_host_availability(DB_ITEM *item, int available, int clock)
 
 int	DBupdate_item_status_to_notsupported(DB_ITEM *item, int clock, const char *error)
 {
-	char		error_esc[MAX_STRING_LEN];
+	char		*error_esc;
 	DB_RESULT	result;
 	DB_ROW		row;
 	DB_TRIGGER	trigger;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In DBupdate_item_status_to_notsupported()");
 
-	DBescape_string(error, error_esc, sizeof(error_esc));
-
 	item->status	= ITEM_STATUS_NOTSUPPORTED;
 	item->nextcheck	= clock + CONFIG_REFRESH_UNSUPPORTED;
 
+	error_esc = DBdyn_escape_string_len(error, ITEM_ERROR_LEN);
 	DBexecute("update items set status=%d,lastclock=%d,nextcheck=%d,error='%s' where itemid=" ZBX_FS_UI64,
 			item->status,
 			clock,
 			item->nextcheck,
 			error_esc,
 			item->itemid);
+	zbx_free(error_esc);
 
 	result = DBselect("select t.triggerid,t.expression,t.description,t.url,t.comments,t.status,t.value,t.priority"
 			" from triggers t,functions f,items i"
@@ -970,7 +976,7 @@ int	DBupdate_item_status_to_notsupported(DB_ITEM *item, int clock, const char *e
 	return SUCCEED;
 }
 
-static int	DBadd_trend(zbx_uint64_t itemid, double value, int clock)
+int	DBadd_trend(zbx_uint64_t itemid, double value, int clock)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
@@ -1024,7 +1030,7 @@ static int	DBadd_trend(zbx_uint64_t itemid, double value, int clock)
 	return SUCCEED;
 }
 
-static int	DBadd_trend_uint(zbx_uint64_t itemid, zbx_uint64_t value, int clock)
+int	DBadd_trend_uint(zbx_uint64_t itemid, zbx_uint64_t value, int clock)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
@@ -1124,12 +1130,11 @@ int	DBadd_history_uint(zbx_uint64_t itemid, zbx_uint64_t value, int clock)
 
 int	DBadd_history_str(zbx_uint64_t itemid, char *value, int clock)
 {
-	char	value_esc[MAX_STRING_LEN];
+	char	*value_esc;
 
 	zabbix_log(LOG_LEVEL_DEBUG,"In add_history_str()");
 
-	DBescape_string(value,value_esc,MAX_STRING_LEN);
-
+	value_esc = DBdyn_escape_string_len(value, HISTORY_STR_VALUE_LEN);
 	DBexecute("insert into history_str (clock,itemid,value) values (%d," ZBX_FS_UI64 ",'%s')",
 			clock,
 			itemid,
@@ -1143,6 +1148,7 @@ int	DBadd_history_str(zbx_uint64_t itemid, char *value, int clock)
 				itemid,
 				value_esc);
 	}
+	zbx_free(value_esc);
 
 	return SUCCEED;
 }
@@ -1151,14 +1157,11 @@ int	DBadd_history_text(zbx_uint64_t itemid, char *value, int clock)
 {
 #ifdef HAVE_ORACLE
 	char		sql[MAX_STRING_LEN];
-	char		*value_esc = NULL;
-	int		value_esc_max_len = 0;
+	int		value_esc_max_len;
 	int		ret = FAIL;
-	zbx_uint64_t	id;
-#else
-	char		*value_esc = NULL;
-	zbx_uint64_t	id;
 #endif
+	char		*value_esc;
+	zbx_uint64_t	id;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In add_history_text()");
 
@@ -1168,10 +1171,7 @@ int	DBadd_history_text(zbx_uint64_t itemid, char *value, int clock)
 
 	sqlo_autocommit_off(oracle);
 
-	value_esc_max_len = strlen(value)+1024;
-	value_esc = zbx_malloc(value_esc, value_esc_max_len);
-
-	DBescape_string(value, value_esc, value_esc_max_len-1);
+	value_esc = DBdyn_escape_string(value);
 	value_esc_max_len = strlen(value_esc);
 
 	/* alloate the lob descriptor */
@@ -1259,12 +1259,12 @@ lbl_exit:
 
 int	DBadd_history_log(zbx_uint64_t itemid, char *value, int clock, int timestamp, char *source, int severity, int lastlogsize)
 {
-	char		*value_esc = NULL, source_esc[MAX_STRING_LEN];
+	char		*value_esc, *source_esc;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In add_history_log()");
 
 	value_esc = DBdyn_escape_string(value);
-	DBescape_string(source, source_esc, sizeof(source_esc));
+	source_esc = DBdyn_escape_string_len(source, HISTORY_LOG_SOURCE_LEN);
 
 	DBexecute("insert into history_log (id,clock,itemid,timestamp,value,source,severity)"
 			" values (" ZBX_FS_UI64 ",%d," ZBX_FS_UI64 ",%d,'%s','%s',%d)",
@@ -1276,6 +1276,7 @@ int	DBadd_history_log(zbx_uint64_t itemid, char *value, int clock, int timestamp
 			source_esc,
 			severity);
 
+	zbx_free(source_esc);
 	zbx_free(value_esc);
 
 	return SUCCEED;
@@ -1512,12 +1513,15 @@ zbx_uint64_t DBget_proxy_lastaccess(const char *hostname)
 	zbx_uint64_t	res;
 	DB_RESULT	result;
 	DB_ROW		row;
+	char		*host_esc;
 
-	zabbix_log(LOG_LEVEL_DEBUG,"In D()");
+	zabbix_log(LOG_LEVEL_DEBUG,"In DBget_proxy_lastaccess()");
 
+	host_esc = DBdyn_escape_string(hostname);
 	result = DBselect("select lastaccess from hosts where host='%s' and status in (%d)",
-			hostname,
+			host_esc,
 			HOST_STATUS_PROXY);
+	zbx_free(host_esc);
 
 	if (NULL == (row = DBfetch(result)) || SUCCEED == DBis_null(row[0])) {
 		zabbix_log(LOG_LEVEL_ERR, "Proxy \"%s\" not exists",
@@ -1538,33 +1542,17 @@ zbx_uint64_t DBget_proxy_lastaccess(const char *hostname)
 int	DBadd_alert(zbx_uint64_t actionid, zbx_uint64_t userid, zbx_uint64_t eventid,  zbx_uint64_t mediatypeid, char *sendto, char *subject, char *message)
 {
 	int	now;
-	
-	char	*sendto_esc	= NULL;
-	char	*subject_esc	= NULL;
-	char	*message_esc	= NULL;
-	
-	int	size;
+	char	*sendto_esc, *subject_esc, *message_esc;
 
 	zabbix_log(LOG_LEVEL_DEBUG,"In add_alert(eventid:" ZBX_FS_UI64 ")",
 		eventid);
 
 	now = time(NULL);
 
-	size = strlen(sendto) * 3 / 2 + 1;
-	sendto_esc = zbx_malloc(sendto_esc, size);
-	memset(sendto_esc, 0, size);
-	DBescape_string(sendto, sendto_esc, size);
+	sendto_esc = DBdyn_escape_string_len(sendto, ALERT_SENDTO_LEN);
+	subject_esc = DBdyn_escape_string_len(subject, ALERT_SUBJECT_LEN);
+	message_esc = DBdyn_escape_string(message);
 
-	size = strlen(subject) * 3 / 2 + 1;
-	subject_esc = zbx_malloc(subject_esc, size);
-	memset(subject_esc, 0, size);
-	DBescape_string(subject,subject_esc,size);
-	
-	size = strlen(message) * 3 / 2 + 1;
-	message_esc = zbx_malloc(message_esc,size);
-	memset(message_esc, 0, size);
-	DBescape_string(message,message_esc,size);
-	
 	DBexecute("insert into alerts (alertid,actionid,eventid,userid,clock,mediatypeid,sendto,subject,message,status,retries)"
 		" values (" ZBX_FS_UI64 "," ZBX_FS_UI64 "," ZBX_FS_UI64 "," ZBX_FS_UI64 ",%d," ZBX_FS_UI64 ",'%s','%s','%s',0,0)",
 		DBget_maxid("alerts","alertid"),
@@ -1716,6 +1704,56 @@ char*	DBdyn_escape_string(const char *src)
 	return dst;
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: DBdyn_escape_string_len                                          *
+ *                                                                            *
+ * Purpose:                                                                   *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value: escaped string                                               *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments: sync changes with 'DBdyn_escape_string'                          *
+ *                                                                            *
+ ******************************************************************************/
+char*	DBdyn_escape_string_len(const char *src, int max_src_len)
+{
+	const char	*s;
+	char		*dst = NULL;
+	int		len = 0;
+
+	len++;	/* '\0' */
+
+	for (s = src; s && *s; s++)
+	{
+		if (max_src_len <= 0)
+			break;
+
+		if (*s == '\r')
+			continue;
+
+		if (*s == '\'' 
+#if !defined(HAVE_ORACLE) && !defined(HAVE_SQLITE3)
+			|| *s == '\\'
+#endif
+			)
+		{
+			len++;
+		}
+		len++;
+		max_src_len--;
+	}
+
+	dst = zbx_malloc(dst, len);
+
+	DBescape_string(src, dst, len);
+
+	return dst;
+}
+
 void	DBget_item_from_db(DB_ITEM *item,DB_ROW row)
 {
 	char		*s;
@@ -1724,6 +1762,7 @@ void	DBget_item_from_db(DB_ITEM *item,DB_ROW row)
 
 	ZBX_STR2UINT64(item->itemid, row[0]);
 /*	item->itemid=atoi(row[0]); */
+	item->key	= row[1];
 	item->key_orig=row[1];
 	item->host_name=row[2];
 	item->port=atoi(row[3]);
@@ -1851,16 +1890,16 @@ void	DBget_item_from_db(DB_ITEM *item,DB_ROW row)
 		case ITEM_TYPE_SIMPLE:
 		case ITEM_TYPE_EXTERNAL:
 			key = zbx_dsprintf(key, "%s", item->key_orig);
-			substitute_simple_macros(NULL, NULL, item, &key, MACRO_TYPE_ITEM_KEY);
+			substitute_simple_macros(NULL, NULL, item, NULL, &key, MACRO_TYPE_ITEM_KEY);
 			item->key	= key;
 			break;
 		case ITEM_TYPE_IPMI:
 			ipmi_ip = zbx_dsprintf(ipmi_ip, "%s", item->ipmi_ip);
-			substitute_simple_macros(NULL, NULL, item, &ipmi_ip, MACRO_TYPE_HOST_IPMI_IP);
+			substitute_simple_macros(NULL, NULL, item, NULL, &ipmi_ip, MACRO_TYPE_HOST_IPMI_IP);
 			item->ipmi_ip	= ipmi_ip;
 			break;
 		default:
-			item->key	= item->key_orig;
+			/* nothing */;
 	}
 }
 
@@ -1935,10 +1974,18 @@ zbx_uint64_t DBget_maxid_num(char *tablename, char *fieldname, int num)
 	int		found  = FAIL, dbres, nodeid;
 	const ZBX_TABLE	*table;
 
-	zabbix_log(LOG_LEVEL_DEBUG,"In DBget_maxid \"%s\".\"%s\"",
+	zabbix_log(LOG_LEVEL_DEBUG,"In DBget_maxid %s.%s",
 			tablename,
 			fieldname);
 
+	if ((0 == strcmp(tablename, "history_log") && 0 == strcmp(fieldname, "id")) ||
+			(0 == strcmp(tablename, "history_text") && 0 == strcmp(fieldname, "id")) ||
+			(0 == strcmp(tablename, "dservices") && 0 == strcmp(fieldname, "dserviceid")) ||
+			(0 == strcmp(tablename, "dhosts") && 0 == strcmp(fieldname, "dhostid")) ||
+			(0 == strcmp(tablename, "alerts") && 0 == strcmp(fieldname, "alertid")) ||
+			(0 == strcmp(tablename, "escalations") && 0 == strcmp(fieldname, "escalationid")))
+		return DCget_nextid(tablename, fieldname, num);
+
 	table = DBget_table(tablename);
 	nodeid = CONFIG_NODEID >= 0 ? CONFIG_NODEID : 0;
 
@@ -2103,16 +2150,18 @@ void	DBproxy_add_history_uint(zbx_uint64_t itemid, zbx_uint64_t value, int clock
 
 void	DBproxy_add_history_str(zbx_uint64_t itemid, char *value, int clock)
 {
-	char	value_esc[MAX_STRING_LEN];
+	char	*value_esc;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In proxy_add_history_str()");
 
-	DBescape_string(value, value_esc, sizeof(value_esc));
+	value_esc = DBdyn_escape_string(value);
 
 	DBexecute("insert into proxy_history (itemid,clock,value) values (" ZBX_FS_UI64 ",%d,'%s')",
 			itemid,
 			clock,
 			value_esc);
+
+	zbx_free(value_esc);
 }
 
 void	DBproxy_add_history_text(zbx_uint64_t itemid, char *value, int clock)
@@ -2133,11 +2182,11 @@ void	DBproxy_add_history_text(zbx_uint64_t itemid, char *value, int clock)
 
 void	DBproxy_add_history_log(zbx_uint64_t itemid, char *value, int clock, int timestamp, char *source, int severity, int lastlogsize)
 {
-	char		source_esc[MAX_STRING_LEN], *value_esc;
+	char		*source_esc, *value_esc;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In proxy_add_history_log()");
 
-	DBescape_string(source, source_esc, sizeof(source_esc));
+	source_esc = DBdyn_escape_string_len(source, HISTORY_LOG_SOURCE_LEN);
 	value_esc = DBdyn_escape_string(value);
 
 	DBexecute("insert into proxy_history (itemid,clock,timestamp,source,severity,value)"
@@ -2150,6 +2199,7 @@ void	DBproxy_add_history_log(zbx_uint64_t itemid, char *value, int clock, int ti
 			value_esc);
 
 	zbx_free(value_esc);
+	zbx_free(source_esc);
 }
 
 void	DBadd_condition_alloc(char **sql, int *sql_alloc, int *sql_offset, const char *fieldname, const zbx_uint64_t *values, const int num)
@@ -2187,8 +2237,23 @@ void	DBadd_condition_alloc(char **sql, int *sql_alloc, int *sql_offset, const ch
 		zbx_snprintf_alloc(sql, sql_alloc, sql_offset, 2, ")");
 }
 
-static char	string[128];
+static char	string[640];
 
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_host_key_string                                              *
+ *                                                                            *
+ * Purpose:                                                                   *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value: <host>:<key> or "???" if item not found                      *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments:                                                                  * 
+ *                                                                            *
+ ******************************************************************************/
 char	*zbx_host_key_string(zbx_uint64_t itemid)
 {
 	DB_RESULT	result;
@@ -2203,9 +2268,26 @@ char	*zbx_host_key_string(zbx_uint64_t itemid)
 	else
 		zbx_snprintf(string, sizeof(string), "???");
 
+	DBfree_result(result);
+
 	return string;
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_host_key_string_by_item                                      *
+ *                                                                            *
+ * Purpose:                                                                   *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value: <host>:<key>                                                 *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments:                                                                  * 
+ *                                                                            *
+ ******************************************************************************/
 char	*zbx_host_key_string_by_item(DB_ITEM *item)
 {
 	zbx_snprintf(string, sizeof(string), "%s:%s", item->host_name, item->key);
@@ -2213,6 +2295,23 @@ char	*zbx_host_key_string_by_item(DB_ITEM *item)
 	return string;
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_host_key_function_string                                     *
+ *                                                                            *
+ * Purpose:                                                                   *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value: function name in format:                                     *
+ *                                    <host>:<key>.<function>(<parameters>)   *
+ *                             or "???" if function not found                 *
+ *                                                                            *
+ * Author: Aleksander Vladishev                                               *
+ *                                                                            *
+ * Comments:                                                                  * 
+ *                                                                            *
+ ******************************************************************************/
 char	*zbx_host_key_function_string(zbx_uint64_t functionid)
 {
 	DB_RESULT	result;
@@ -2227,6 +2326,8 @@ char	*zbx_host_key_function_string(zbx_uint64_t functionid)
 	else
 		zbx_snprintf(string, sizeof(string), "???");
 
+	DBfree_result(result);
+
 	return string;
 }
 
