@@ -62,7 +62,7 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 
 	zabbix_log( LOG_LEVEL_DEBUG, "In send_email[smtp_server:%s]", smtp_server);
 
-	if(FAIL == zbx_tcp_connect(&s, smtp_server, 25, 0))
+	if(FAIL == zbx_tcp_connect(&s, CONFIG_SOURCE_IP, smtp_server, 25, 0))
 	{
 		zbx_snprintf(error,max_error_len,"Cannot connect to SMTP server [%s] [%s]", smtp_server, zbx_tcp_strerror());
 		zabbix_log(LOG_LEVEL_DEBUG, "%s", error);
@@ -230,7 +230,9 @@ int	send_email(char *smtp_server,char *smtp_helo,char *smtp_email,char *mailto,c
 	time(&email_time);
 	local_time = localtime(&email_time);
 	strftime( str_time, MAX_STRING_LEN, "%a, %d %b %Y %H:%M:%S %z", local_time );
-	cp = zbx_dsprintf(cp,"From:<%s>\r\nTo:<%s>\r\nDate: %s\r\nSubject: %s\r\n\r\n%s",smtp_email,mailto,str_time,mailsubject, mailbody);
+	cp = zbx_dsprintf(cp, "From:<%s>\r\nTo:<%s>\r\nDate: %s\r\nSubject: %s\r\n"
+			"Content-Type: text/plain; charset=\"UTF-8\"\r\n\r\n%s",
+			smtp_email, mailto, str_time, mailsubject, mailbody);
 	e=write(s.socket,cp,strlen(cp)); 
 	zbx_free(cp);
 	zbx_free(mailsubject);
