@@ -53,7 +53,7 @@ static int	evaluate_LOGSOURCE(char *value, DB_ITEM *item, char *parameter)
 	if (item->value_type != ITEM_VALUE_TYPE_LOG)
 		return FAIL;
 
-	zbx_snprintf(sql, sizeof(sql), "select source from history_log where itemid=" ZBX_FS_UI64 " order by clock desc",
+	zbx_snprintf(sql, sizeof(sql), "select source from history_log where itemid=" ZBX_FS_UI64 " order by id desc",
 			item->itemid);
 
 	result = DBselectN(sql, 1);
@@ -105,7 +105,7 @@ static int	evaluate_LOGSEVERITY(char *value, DB_ITEM *item, char *parameter)
 	if (item->value_type != ITEM_VALUE_TYPE_LOG)
 		return	FAIL;
 
-	zbx_snprintf(sql, sizeof(sql), "select severity from history_log where itemid=" ZBX_FS_UI64 " order by clock desc",
+	zbx_snprintf(sql, sizeof(sql), "select severity from history_log where itemid=" ZBX_FS_UI64 " order by id desc",
 			item->itemid);
 
 	result = DBselectN(sql, 1);
@@ -1082,18 +1082,21 @@ static int	evaluate_DELTA(char *value, DB_ITEM *item, int parameter, int flag, t
  ******************************************************************************/
 static int	evaluate_NODATA(char *value, DB_ITEM *item, int parameter, time_t now)
 {
-	int	res = SUCCEED;
-
 	zabbix_log(LOG_LEVEL_DEBUG, "In evaluate_NODATA()");
 
-	if (CONFIG_SERVER_STARTUP_TIME + parameter > now || item->lastclock + parameter > now)
+	if (item->lastclock + parameter > now)
 		strcpy(value,"0");
 	else
+	{
+		if (CONFIG_SERVER_STARTUP_TIME + parameter > now)
+			return FAIL;
+
 		strcpy(value,"1");
+	}
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of evaluate_NODATA()");
 
-	return res;
+	return SUCCEED;
 }
 
 /******************************************************************************
@@ -1230,24 +1233,21 @@ static int	evaluate_STR(char *value, DB_ITEM *item, char *function, char *parame
 
 	char		*table = NULL;
 	char		*key = NULL;
-	char		table_str[] = "history_str", key_str[] = "clock";
-	char		table_text[] = "history_text", key_text[] = "id";
-	char		table_log[] = "history_log", key_log[] = "id";
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In evaluate_STR()");
 
 	switch (item->value_type) {
 		case ITEM_VALUE_TYPE_STR:
-			table = table_str;
-			key = key_str;
+			table = "history_str";
+			key = "clock";
 			break;
 		case ITEM_VALUE_TYPE_TEXT:
-			table = table_text;
-			key = key_text;
+			table = "history_text";
+			key = "id";
 			break;
 		case ITEM_VALUE_TYPE_LOG:
-			table = table_log;
-			key = key_log;
+			table = "history_log";
+			key = "id";
 			break;
 		default:
 			return FAIL;
@@ -1909,7 +1909,7 @@ int	replace_value_by_map(char *value, zbx_uint64_t valuemapid)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
-	char		new_value[MAX_STRING_LEN], orig_value[MAX_STRING_LEN];
+	char		new_value[MAX_STRING_LEN], orig_value[MAX_STRING_LEN], *value_esc;
 	int		ret = FAIL;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In replace_value_by_map()");
@@ -1917,9 +1917,11 @@ int	replace_value_by_map(char *value, zbx_uint64_t valuemapid)
 	if (valuemapid == 0)
 		return FAIL;
 
+	value_esc = DBdyn_escape_string(value);
 	result = DBselect("select newvalue from mappings where valuemapid=" ZBX_FS_UI64 " and value='%s'",
 			valuemapid,
-			value);
+			value_esc);
+	zbx_free(value_esc);
 	if (NULL != (row = DBfetch(result)) && FAIL == DBis_null(row[0]))
 	{
 		strcpy(new_value, row[0]);
