@@ -23,16 +23,26 @@
 
 static int	VM_MEMORY_CACHED(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-#ifdef HAVE_PROC
+#if defined(HAVE_LIBPERFSTAT)
+	/* AIX 6.1 */
+	perfstat_memory_total_t	m;
+	zbx_uint64_t		value;
+
+	if (-1 == perfstat_memory_total(NULL, &m, sizeof(m), 1))
+		return SYSINFO_RET_FAIL;
+
+	value = (zbx_uint64_t)m.numperm;	/* number of frames used for files (in 4KB pages) */
+	value <<= 12;
+
+	SET_UI64_RESULT(result, value);
+
+	return SYSINFO_RET_OK;
+#elif defined(HAVE_PROC)
         FILE    *f = NULL;
         char    *t;
         char    c[MAX_STRING_LEN];
         zbx_uint64_t    res = 0;
 
-        assert(result);
-
-        init_result(result);
-
         if( NULL == ( f = fopen("/proc/meminfo","r")))
         {
                 return  SYSINFO_RET_FAIL;
@@ -59,23 +69,15 @@ static int	VM_MEMORY_CACHED(const char *cmd, const char *param, unsigned flags,
         SET_UI64_RESULT(result, res);
         return SYSINFO_RET_OK;
 #else
-	assert(result);
-
-        init_result(result);
-		
 	return SYSINFO_RET_FAIL;
 #endif
 }
 
 static int	VM_MEMORY_BUFFERS(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-#ifdef HAVE_SYSINFO_BUFFERRAM
-	struct sysinfo info;
+#if defined(HAVE_SYSINFO_BUFFERRAM)
+	struct sysinfo	info;
 
-	assert(result);
-
-        init_result(result);
-		
 	if( 0 == sysinfo(&info))
 	{
 #ifdef HAVE_SYSINFO_MEM_UNIT
@@ -90,10 +92,6 @@ static int	VM_MEMORY_BUFFERS(const char *cmd, const char *param, unsigned flags,
 		return SYSINFO_RET_FAIL;
 	}
 #else
-	assert(result);
-
-        init_result(result);
-		
 	return	SYSINFO_RET_FAIL;
 #endif
 }
@@ -103,10 +101,6 @@ static int	VM_MEMORY_SHARED(const char *cmd, const char *param, unsigned flags,
 #ifdef HAVE_SYSINFO_SHAREDRAM
 	struct sysinfo info;
 
-	assert(result);
-
-        init_result(result);
-		
 	if( 0 == sysinfo(&info))
 	{
 #ifdef HAVE_SYSINFO_MEM_UNIT
@@ -124,10 +118,6 @@ static int	VM_MEMORY_SHARED(const char *cmd, const char *param, unsigned flags,
 	int mib[2],len;
 	struct vmtotal v;
 
-	assert(result);
-
-        init_result(result);
-		
 	len=sizeof(struct vmtotal);
 	mib[0]=CTL_VM;
 	mib[1]=VM_METER;
@@ -143,14 +133,24 @@ static int	VM_MEMORY_SHARED(const char *cmd, const char *param, unsigned flags,
 
 static int	VM_MEMORY_TOTAL(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-#if defined(HAVE_SYS_PSTAT_H)
+#if defined(HAVE_LIBPERFSTAT)
+	/* AIX 6.1 */
+	perfstat_memory_total_t	m;
+	zbx_uint64_t		value;
+
+	if (-1 == perfstat_memory_total(NULL, &m, sizeof(m), 1))
+		return SYSINFO_RET_FAIL;
+
+	value = (zbx_uint64_t)m.real_total;	/* total real memory (in 4KB pages) */
+	value <<= 12;
+
+	SET_UI64_RESULT(result, value);
+
+	return SYSINFO_RET_OK;
+#elif defined(HAVE_SYS_PSTAT_H)
 	struct	pst_static pst;
 	long	page;
 
-	assert(result);
-
-        init_result(result);
-		
 	if(pstat_getstatic(&pst, sizeof(pst), (size_t)1, 0) == -1)
 	{
 		return SYSINFO_RET_FAIL;
@@ -166,10 +166,6 @@ static int	VM_MEMORY_TOTAL(const char *cmd, const char *param, unsigned flags, A
 #elif defined(HAVE_SYSINFO_TOTALRAM)
 	struct sysinfo info;
 
-	assert(result);
-
-        init_result(result);
-		
 	if( 0 == sysinfo(&info))
 	{
 #ifdef HAVE_SYSINFO_MEM_UNIT
@@ -187,10 +183,6 @@ static int	VM_MEMORY_TOTAL(const char *cmd, const char *param, unsigned flags, A
 	int mib[2],len;
 	struct vmtotal v;
 
-	assert(result);
-
-        init_result(result);
-		
 	len=sizeof(struct vmtotal);
 	mib[0]=CTL_VM;
 	mib[1]=VM_METER;
@@ -204,11 +196,7 @@ static int	VM_MEMORY_TOTAL(const char *cmd, const char *param, unsigned flags, A
 	size_t len;
 	unsigned int memory;
 	int ret;
-	
-	assert(result);
 
-        init_result(result);
-		
 	len=sizeof(memory);
 
 	if(0==sysctl(mib,2,&memory,&len,NULL,0))
@@ -222,25 +210,31 @@ static int	VM_MEMORY_TOTAL(const char *cmd, const char *param, unsigned flags, A
 	}
 	return ret;
 #else
-	assert(result);
-
-        init_result(result);
-		
 	return	SYSINFO_RET_FAIL;
 #endif
 }
 
 static int	VM_MEMORY_FREE(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-#if defined(HAVE_SYS_PSTAT_H)
+#if defined(HAVE_LIBPERFSTAT)
+	/* AIX 6.1 */
+	perfstat_memory_total_t	m;
+	zbx_uint64_t		value;
+
+	if (-1 == perfstat_memory_total(NULL, &m, sizeof(m), 1))
+		return SYSINFO_RET_FAIL;
+
+	value = (zbx_uint64_t)m.real_free;	/* free real memory (in 4KB pages) */
+	value <<= 12;
+
+	SET_UI64_RESULT(result, value);
+
+	return SYSINFO_RET_OK;
+#elif defined(HAVE_SYS_PSTAT_H)
 	struct	pst_static pst;
 	struct	pst_dynamic dyn;
 	long	page;
 
-	assert(result);
-
-        init_result(result);
-		
 	if(pstat_getstatic(&pst, sizeof(pst), (size_t)1, 0) == -1)
 	{
 		return SYSINFO_RET_FAIL;
@@ -276,10 +270,6 @@ static int	VM_MEMORY_FREE(const char *cmd, const char *param, unsigned flags, AG
 #elif defined(HAVE_SYSINFO_FREERAM)
 	struct sysinfo info;
 
-	assert(result);
-
-        init_result(result);
-		
 	if( 0 == sysinfo(&info))
 	{
 #ifdef HAVE_SYSINFO_MEM_UNIT
@@ -297,10 +287,6 @@ static int	VM_MEMORY_FREE(const char *cmd, const char *param, unsigned flags, AG
 	int mib[2],len;
 	struct vmtotal v;
 
-	assert(result);
-
-        init_result(result);
-		
 	len=sizeof(struct vmtotal);
 	mib[0]=CTL_VM;
 	mib[1]=VM_METER;
@@ -316,11 +302,7 @@ static int	VM_MEMORY_FREE(const char *cmd, const char *param, unsigned flags, AG
 	mach_msg_type_number_t count;
 	kern_return_t kret;
 	int ret;
-	
-	assert(result);
 
-        init_result(result);
-		
 	pagesize = 0;
 	kret = host_page_size (mach_host_self(), &pagesize);
 
@@ -347,24 +329,20 @@ static int	VM_MEMORY_FREE(const char *cmd, const char *param, unsigned flags, AG
 	}
 	return ret;
 #else
-	assert(result);
-
-        init_result(result);
-		
 	return	SYSINFO_RET_FAIL;
 #endif
 }
 
-int     VM_MEMORY_SIZE(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
+int	VM_MEMORY_SIZE(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
 #define MEM_FNCLIST struct mem_fnclist_s
 MEM_FNCLIST
 {
-	char *mode;
-	int (*function)();
+	char	*mode;
+	int	(*function)();
 };
 
-	MEM_FNCLIST fl[] = 
+	MEM_FNCLIST fl[] =
 	{
 		{"free",	VM_MEMORY_FREE},
 		{"shared",	VM_MEMORY_SHARED},
@@ -373,37 +351,26 @@ MEM_FNCLIST
 		{"cached",	VM_MEMORY_CACHED},
 		{0,	0}
 	};
-        char    mode[MAX_STRING_LEN];
-	int i;
+	char	mode[MAX_STRING_LEN];
+	int	i;
 
         assert(result);
 
         init_result(result);
 
-        if(num_param(param) > 1)
-        {
-                return SYSINFO_RET_FAIL;
-        }
+	if (num_param(param) > 1)
+		return SYSINFO_RET_FAIL;
 
-        if(get_param(param, 1, mode, sizeof(mode)) != 0)
-        {
-                mode[0] = '\0';
-        }
+	if (0 != get_param(param, 1, mode, sizeof(mode)) != 0)
+		*mode = '\0';
 
-        if(mode[0] == '\0')
-	{
-		/* default parameter */
+	if (*mode == '\0')	/* default parameter */
 		zbx_snprintf(mode, sizeof(mode), "total");
-	}
-	
-	for(i=0; fl[i].mode!=0; i++)
-	{
-		if(strncmp(mode, fl[i].mode, MAX_STRING_LEN)==0)
-		{
+
+	for (i = 0; fl[i].mode != 0; i++)
+		if (0 == strcmp(mode, fl[i].mode))
 			return (fl[i].function)(cmd, param, flags, result);
-		}
-	}
-	
+
 	return SYSINFO_RET_FAIL;
 }
 
