@@ -40,7 +40,7 @@ static int	get_http_page(char *host, char *param, unsigned short port, char *buf
 
 	assert(buffer);
 
-	if (SUCCEED == (ret = zbx_tcp_connect(&s, host, port, 0))) {
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, host, port, 0))) {
 		zbx_snprintf(request, sizeof(request), "GET /%s HTTP/1.1\r\nHost: %s\r\nConnection: close\r\n\r\n",
 			param,
 			host);
