@@ -35,10 +35,10 @@ ZBX_METRIC	parameters_specific[]=
 
 	{"net.tcp.listen",      CF_USEUPARAM,   NET_TCP_LISTEN, 	0,      "80"},	
 
-	{"net.if.in",		CF_USEUPARAM,	NET_IF_IN,		0,	"lo,bytes"},
-	{"net.if.out",		CF_USEUPARAM,	NET_IF_OUT,		0,	"lo,bytes"},
-	{"net.if.total",	CF_USEUPARAM,	NET_IF_TOTAL,		0,	"lo,bytes"},
-        {"net.if.collisions",   CF_USEUPARAM,   NET_IF_COLLISIONS,      0,      "lo"},
+	{"net.if.in",		CF_USEUPARAM,	NET_IF_IN,		0,	"lo0,bytes"},
+	{"net.if.out",		CF_USEUPARAM,	NET_IF_OUT,		0,	"lo0,bytes"},
+	{"net.if.total",	CF_USEUPARAM,	NET_IF_TOTAL,		0,	"lo0,bytes"},
+	{"net.if.collisions",   CF_USEUPARAM,   NET_IF_COLLISIONS,      0,      "lo0"},
 
 	{"vm.memory.size",	CF_USEUPARAM,	VM_MEMORY_SIZE,		0,	"free"},
 
@@ -49,12 +49,14 @@ ZBX_METRIC	parameters_specific[]=
 	{"system.cpu.intr",     0,              SYSTEM_CPU_INTR,        0,      0},
 	{"system.cpu.util",	CF_USEUPARAM,	SYSTEM_CPU_UTIL,	0,	"all,user,avg1"},
 	{"system.cpu.load",	CF_USEUPARAM,	SYSTEM_CPU_LOAD,	0,	"all,avg1"},
+	{"system.cpu.num",	CF_USEUPARAM,	SYSTEM_CPU_NUM,		0,	"online"},
 
 	{"system.swap.size",	CF_USEUPARAM,	SYSTEM_SWAP_SIZE,	0,	"all,free"},
 	{"system.swap.in",      CF_USEUPARAM,   SYSTEM_SWAP_IN,		0,      "all"},
 	{"system.swap.out",     CF_USEUPARAM,   SYSTEM_SWAP_OUT,	0,      "all,count"},	
 
 	{"system.uptime",	0,		SYSTEM_UPTIME,		0,	0},
+	{"system.boottime",     0,      	SYSTEM_BOOTTIME,        0,      0},
 
 	{0}
 	};
