@@ -23,32 +23,32 @@
 
 int	SYSTEM_UPTIME(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-    kstat_ctl_t   *kc;
-    kstat_t       *kp;
-    kstat_named_t *kn;
+	kstat_ctl_t	*kc;
+	kstat_t		*kp;
+	kstat_named_t	*kn;
+	time_t		now;
+	int		ret = SYSINFO_RET_FAIL;
 
-    time_t now;
-    
-    int ret = SYSINFO_RET_FAIL;
+	assert(result);
 
-    assert(result);
+	init_result(result);
 
-    init_result(result);
+	if (NULL == (kc = kstat_open()))
+		return ret;
 
-    kc = kstat_open();
-
-    if (kc)
-    {
-	kp = kstat_lookup(kc, "unix", 0, "system_misc");
-        if ((kp) && (kstat_read(kc, kp, 0) != -1))
+	if (NULL != (kp = kstat_lookup(kc, "unix", 0, "system_misc")))
 	{
-		kn = (kstat_named_t*) kstat_data_lookup(kp, "boot_time");
-		time(&now);
-		SET_UI64_RESULT(result, difftime(now, (time_t) kn->value.ul));
-		ret = SYSINFO_RET_OK;
-        }
+		if (-1 != kstat_read(kc, kp, 0))
+		{
+			if (NULL != (kn = (kstat_named_t*)kstat_data_lookup(kp, "boot_time")))
+			{
+				time(&now);
+				SET_UI64_RESULT(result, difftime(now, (time_t) kn->value.ul));
+				ret = SYSINFO_RET_OK;
+			}
+		}
+	}
 	kstat_close(kc);
-    }
-    return ret;
-}
 
+	return ret;
+}
