@@ -53,34 +53,56 @@ int	USER_PERFCOUNTER(const char *cmd, const char *param, unsigned flags, AGENT_R
 
 int	PERF_MONITOR(const char *cmd, const char *param, unsigned flags, AGENT_RESULT *result)
 {
-	HQUERY		query;
-	HCOUNTER	counter;
-	PDH_STATUS	status;
+	HQUERY				query;
+	HCOUNTER			counter;
+	PDH_STATUS			status;
+	PDH_RAW_COUNTER			rawData, rawData2;
+	PDH_FMT_COUNTERVALUE		counterValue;
+	char				counter_path[PDH_MAX_COUNTER_PATH],
+					tmp[MAX_STRING_LEN];
+	int				ret = SYSINFO_RET_FAIL, interval;
+	PERF_COUNTERS *perfs;
 
-	PDH_RAW_COUNTER		rawData, rawData2;
-	PDH_FMT_COUNTERVALUE	counterValue;
-
-	char	counter_name[MAX_STRING_LEN];
-
-	int	ret = SYSINFO_RET_FAIL;
-
-	if(num_param(param) > 1)
-	{
+	if (num_param(param) > 2)
 		return SYSINFO_RET_FAIL;
-	}
 
-	if(get_param(param, 1, counter_name, sizeof(counter_name)) != 0)
-	{
-		counter_name[0] = '\0';
-	}
-	if(counter_name[0] == '\0')
-	{
+	if (0 != get_param(param, 1, counter_path, sizeof(counter_path)))
+		*counter_path = '\0';
+
+	if (*counter_path == '\0')
 		return SYSINFO_RET_FAIL;
+
+	if (0 != get_param(param, 2, tmp, sizeof(tmp)))
+		*tmp = '\0';
+
+	if (*tmp != '\0' && FAIL == is_uint(tmp))
+		return SYSINFO_RET_FAIL;
+
+	interval = *tmp == '\0' ? 1 : atoi(tmp);
+
+	if (FAIL == check_counter_path(counter_path))
+		return SYSINFO_RET_FAIL;
+
+	if (interval > 1) {
+		if ( !PERF_COLLECTOR_STARTED(collector) ) {
+			SET_MSG_RESULT(result, strdup("Collector is not started!"));
+			return SYSINFO_RET_OK;
+		}
+
+		for (perfs = collector->perfs.pPerfCounterList; perfs != NULL; perfs = perfs->next) {
+			if (0 == strcmp(perfs->counterPath, counter_path) && perfs->interval == interval) {
+				SET_DBL_RESULT(result, perfs->lastValue);
+				return SYSINFO_RET_OK;
+			}
+		}
+
+		if (FAIL == add_perf_counter("", counter_path, interval))
+			return SYSINFO_RET_FAIL;
 	}
 
-	if (ERROR_SUCCESS == PdhOpenQuery(NULL,0,&query))
+	if (ERROR_SUCCESS == (status = PdhOpenQuery(NULL, 0, &query)))
 	{
-		if (ERROR_SUCCESS == (status = PdhAddCounter(query,counter_name,0,&counter)))
+		if (ERROR_SUCCESS == (status = PdhAddCounter(query,counter_path,0,&counter)))
 		{
 			if (ERROR_SUCCESS == (status = PdhCollectQueryData(query)))
 			{
@@ -107,37 +129,32 @@ int	PERF_MONITOR(const char *cmd, const char *param, unsigned flags, AGENT_RESUL
 
 					}
 
-					if(ERROR_SUCCESS == status)
-					{
+					if(ERROR_SUCCESS == status) {
 						SET_DBL_RESULT(result, counterValue.doubleValue);
 						ret = SYSINFO_RET_OK;
-					}
-					else
-					{
-						zabbix_log(LOG_LEVEL_DEBUG, "Can't format counter value [%s] [%s]", counter_name, strerror_from_module(status,"PDH.DLL"));
-					}
-				}
-				else
-				{
-					if(ERROR_SUCCESS == status) status = rawData.CStatus;
+					} else
+						zabbix_log(LOG_LEVEL_DEBUG, "Can't format counter value \"%s\": %s",
+								counter_path, strerror_from_module(status, "PDH.DLL"));
+				} else {
+					if (ERROR_SUCCESS == status)
+						status = rawData.CStatus;
 
-					zabbix_log(LOG_LEVEL_DEBUG, "Can't get counter value [%s] [%s]", counter_name, strerror_from_module(status,"PDH.DLL"));
+					zabbix_log(LOG_LEVEL_DEBUG, "Can't get counter value \"%s\": %s",
+							counter_path, strerror_from_module(status, "PDH.DLL"));
 				}
-			}
-			else
-			{
-				zabbix_log(LOG_LEVEL_DEBUG, "Can't collect data [%s] [%s]", counter_name, strerror_from_module(status,"PDH.DLL"));
-			}
+			} else
+				zabbix_log(LOG_LEVEL_DEBUG, "Can't collect data \"%s\": %s",
+						counter_path, strerror_from_module(status, "PDH.DLL"));
+
 			PdhRemoveCounter(&counter);
-		}
-		else
-		{
-			zabbix_log(LOG_LEVEL_DEBUG, "Can't add counter [%s] [%s]", counter_name, strerror_from_module(status,"PDH.DLL"));
-		}
-
+		} else
+			zabbix_log(LOG_LEVEL_DEBUG, "Can't add counter \"%s\": %s",
+					counter_path, strerror_from_module(status, "PDH.DLL"));
 
 		PdhCloseQuery(query);
-	}
+	} else
+		zabbix_log(LOG_LEVEL_DEBUG, "Can't initialize performance counters \"%s\": %s",
+				counter_path, strerror_from_module(status, "PDH.DLL"));
 
 	return ret;
 }
