@@ -191,40 +191,44 @@ static int	parse_list_of_checks(char *str)
 
 	disable_all_metrics();
 
-	if(SUCCEED == ret && SUCCEED != zbx_json_open(str, &jp))
+	if (SUCCEED == ret && SUCCEED != zbx_json_open(str, &jp))
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "Can't open jason object");
 		ret = FAIL;
 	}
 
-	if(SUCCEED == ret && SUCCEED != zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_RESPONSE, result, sizeof(result)))
+	if (SUCCEED == ret && SUCCEED != zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_RESPONSE, result, sizeof(result)))
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "%s",
 			zbx_json_strerror());
 		ret = FAIL;
 	}
 
-	if(SUCCEED == ret && 0 != strcmp(result,ZBX_PROTO_VALUE_SUCCESS))
+	if (SUCCEED == ret && 0 != strcmp(result, ZBX_PROTO_VALUE_SUCCESS))
 	{
-		zabbix_log(LOG_LEVEL_WARNING, "Unsucesfull response received from server");
+		if (SUCCEED == zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_INFO, result, sizeof(result)))
+			zabbix_log(LOG_LEVEL_WARNING, "No active checks on server: %s",
+					result);
+		else
+			zabbix_log(LOG_LEVEL_WARNING, "No active checks on server");
 		ret = FAIL;
 	}
 
-	if(SUCCEED == ret && NULL == (p = zbx_json_pair_by_name(&jp, ZBX_PROTO_TAG_DATA)))
+	if (SUCCEED == ret && NULL == (p = zbx_json_pair_by_name(&jp, ZBX_PROTO_TAG_DATA)))
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "Can't find \"%s\" tag",
 			ZBX_PROTO_TAG_DATA);
 		ret = FAIL;
 	}
 
-	if(SUCCEED == ret && FAIL == zbx_json_brackets_open(p, &jp_data))
+	if (SUCCEED == ret && FAIL == zbx_json_brackets_open(p, &jp_data))
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "Can't proceed jason request. %s",
 				zbx_json_strerror());
 		ret = FAIL;
 	}
 
-	if(SUCCEED == ret)
+	if (SUCCEED == ret)
 	{
 	 	p = NULL;
 		while (SUCCEED == ret && NULL != (p = zbx_json_next(&jp_data, p)))
@@ -308,7 +312,7 @@ static int	refresh_active_checks(
 
 	zabbix_log( LOG_LEVEL_DEBUG, "refresh_active_checks('%s',%u)", host, port);
 
-	zbx_json_init(&json, 8*1024);
+	zbx_json_init(&json, ZBX_JSON_STAT_BUF_LEN);
 
 	zbx_json_addstring(&json, ZBX_PROTO_TAG_REQUEST, ZBX_PROTO_VALUE_GET_ACTIVE_CHECKS, ZBX_JSON_TYPE_STRING);
 	zbx_json_addstring(&json, ZBX_PROTO_TAG_HOST, CONFIG_HOSTNAME, ZBX_JSON_TYPE_STRING);
@@ -384,7 +388,7 @@ static int	check_response(char *response)
 	{
 		if(SUCCEED == zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_INFO, info, sizeof(info)))
 		{
-			zabbix_log(LOG_LEVEL_WARNING, "Info from server: %s",
+			zabbix_log(LOG_LEVEL_DEBUG, "Info from server: %s",
 				info);
 		}
 	}
@@ -444,7 +448,7 @@ static int	send_buffer(
 		return ret;
 	}
 
-	zbx_json_init(&json, 8*1024);
+	zbx_json_init(&json, ZBX_JSON_STAT_BUF_LEN);
 
 	zbx_json_addstring(&json, ZBX_PROTO_TAG_REQUEST, ZBX_PROTO_VALUE_AGENT_DATA, ZBX_JSON_TYPE_STRING);
 
@@ -483,15 +487,15 @@ static int	send_buffer(
 		{
 			if( SUCCEED == (ret = zbx_tcp_recv(&s, &buf)) )
 			{
-				zabbix_log( LOG_LEVEL_DEBUG, "JSON back [%s]",
-					buf);
+				zabbix_log(LOG_LEVEL_DEBUG, "JSON back [%s]",
+						buf);
 				if( !buf || check_response(buf) != SUCCEED )
 				{
-					zabbix_log( LOG_LEVEL_WARNING, "NOT OK");
+					zabbix_log(LOG_LEVEL_DEBUG, "NOT OK");
 				}
 				else
 				{
-					zabbix_log( LOG_LEVEL_WARNING, "OK");
+					zabbix_log(LOG_LEVEL_DEBUG, "OK");
 				}
 			} else
 				zabbix_log(LOG_LEVEL_DEBUG, "Send value error: [recv] %s", zbx_tcp_strerror());
