@@ -45,9 +45,6 @@
 #include "datasender/datasender.h"
 #include "heart/heart.h"
 
-/*
-#define       LISTENQ 1024
-*/
 char *progname = NULL;
 char title_message[] = "ZABBIX Proxy (daemon)";
 char usage_message[] = "[-hV] [-c <file>]";
@@ -113,7 +110,7 @@ int	CONFIG_DISCOVERER_FORKS		= 1;
 int	CONFIG_HOUSEKEEPER_FORKS	= 1;
 int	CONFIG_PINGER_FORKS		= 1;
 int	CONFIG_POLLER_FORKS		= 5;
-int	CONFIG_HTTPPOLLER_FORKS		= 5;
+int	CONFIG_HTTPPOLLER_FORKS		= 1;
 int	CONFIG_IPMIPOLLER_FORKS		= 0;
 int	CONFIG_TRAPPERD_FORKS		= 5;
 int	CONFIG_UNREACHABLE_POLLER_FORKS	= 1;
@@ -366,11 +363,6 @@ int main(int argc, char **argv)
 	init_ipmi_handler();
 #endif
 
-	if(CONFIG_DBSYNCER_FORKS!=0)
-	{
-		init_database_cache(ZBX_PROCESS_PROXY);
-	}
-
 	return daemon_start(CONFIG_ALLOW_ROOT);
 }
 
@@ -432,6 +424,8 @@ int MAIN_ZABBIX_ENTRY(void)
 
 	DBinit();
 
+	init_database_cache(ZBX_PROCESS_PROXY);
+
 	threads = calloc(1 + CONFIG_CONFSYNCER_FORKS + CONFIG_DATASENDER_FORKS + CONFIG_POLLER_FORKS
 			+ CONFIG_TRAPPERD_FORKS + CONFIG_PINGER_FORKS + CONFIG_HOUSEKEEPER_FORKS
 			+ CONFIG_UNREACHABLE_POLLER_FORKS + CONFIG_HTTPPOLLER_FORKS + CONFIG_DISCOVERER_FORKS
@@ -595,6 +589,7 @@ int MAIN_ZABBIX_ENTRY(void)
 
 void	zbx_on_exit()
 {
+	zabbix_log(LOG_LEVEL_INFORMATION, "zbx_on_exit()");
 #if !defined(_WINDOWS)
 	
 	int i = 0;
@@ -611,6 +606,7 @@ void	zbx_on_exit()
 				threads[i] = (ZBX_THREAD_HANDLE)0;
 			}
 		}
+		zbx_free(threads);
 	}
 	
 #endif /* not _WINDOWS */
@@ -626,11 +622,7 @@ void	zbx_on_exit()
 	zbx_sleep(2); /* wait for all threads closing */
 
 	DBconnect(ZBX_DB_CONNECT_EXIT);
-	
-	if(CONFIG_DBSYNCER_FORKS!=0)
-	{
-		free_database_cache();
-	}
+	free_database_cache();
 	DBclose();
 /*	zbx_mutex_destroy(&node_sync_access);*/
 
@@ -644,7 +636,7 @@ void	zbx_on_exit()
 	php_sem_remove(&sqlite_access);
 #endif /* HAVE_SQLITE3 */
 
-	zabbix_log(LOG_LEVEL_INFORMATION, "ZABBIX Server stopped. ZABBIX %s.", ZABBIX_VERSION);
+	zabbix_log(LOG_LEVEL_INFORMATION, "ZABBIX Proxy stopped. ZABBIX %s.", ZABBIX_VERSION);
 
 	exit(SUCCEED);
 }
