@@ -24,21 +24,23 @@
 #include "cfg.h"
 #include "log.h"
 #include "zbxgetopt.h"
+#include "zbxjson.h"
 
 char *progname = NULL;
 
 char title_message[] = "ZABBIX send";
 
-char usage_message[] = "[-Vhv] {[-zps] -ko | -i <file>} [-c <file>]";
+char usage_message[] = "[-Vhv] {[-zpsI] -ko | [-zpI] -i <file>} [-c <file>]";
 
 #ifdef HAVE_GETOPT_LONG
 char *help_message[] = {
 	"Options:",
-	"  -c --config <File>                   Specify configuration file"
+	"  -c --config <File>                   Specify configuration file",
 	"",
 	"  -z --zabbix-server <Server>          Hostname or IP address of ZABBIX Server",
 	"  -p --port <Server port>              Specify port number of server trapper running on the server. Default is 10051",
 	"  -s --host <Hostname>                 Specify host name. Host IP address and DNS name will not work.",
+	"  -I --source-address <ip address>     Specify source IP address",
 	"",
 	"  -k --key <Key>                       Specify metric name (key) we want to send",
 	"  -o --value <Key value>               Specify value of the key",
@@ -56,11 +58,12 @@ char *help_message[] = {
 #else
 char *help_message[] = {
 	"Options:",
-	"  -c <File>                    Specify configuration file"
+	"  -c <File>                    Specify configuration file",
 	"",
 	"  -z <Server>                  Hostname or IP address of ZABBIX Server.",
 	"  -p <Server port>             Specify port number of server trapper running on the server. Default is 10051.",
 	"  -s <Hostname>                Specify hostname or IP address of a host.",
+	"  -I <ip address>              Specify source IP address",
 	"",
 	"  -k <Key>                     Specify metric name (key) we want to send.",
 	"  -o <Key value>               Specify value of the key.",
@@ -87,6 +90,7 @@ static struct zbx_option longopts[] =
 	{"zabbix-server",	1,	NULL,	'z'},
 	{"port",		1,	NULL,	'p'},
 	{"host",		1,	NULL,	's'},
+	{"source-address",	1,	NULL,	'I'},
 	{"key",			1,	NULL,	'k'},
 	{"value",		1,	NULL,	'o'},
 	{"input-file",		1,	NULL,	'i'},
@@ -98,7 +102,7 @@ static struct zbx_option longopts[] =
 
 /* short options */
 
-static char     shortopts[] = "c:z:p:s:k:o:i:vhV";
+static char     shortopts[] = "c:I:z:p:s:k:o:i:vhV";
 
 /* end of COMMAND LINE OPTIONS*/
 
@@ -106,6 +110,7 @@ static int	CONFIG_LOG_LEVEL = LOG_LEVEL_CRIT;
 
 static char*	INPUT_FILE = NULL;
 
+static char*	CONFIG_SOURCE_IP = NULL;
 static char*	ZABBIX_SERVER = NULL;
 unsigned short	ZABBIX_SERVER_PORT = 0;
 static char*	ZABBIX_HOSTNAME = NULL;
@@ -133,19 +138,69 @@ static void    send_signal_handler( int sig )
 
 typedef struct zbx_active_metric_type
 {
-	char*	server;
+	char		*source_ip, *server;
 	unsigned short	port;
-	char*	hostname;
-	char*	key;
-	char*	key_value;
+	struct zbx_json	json;
 } ZBX_THREAD_SENDVAL_ARGS;
 
+/******************************************************************************
+ *                                                                            *
+ * Function: check_response                                                   *
+ *                                                                            *
+ * Purpose: Check if json response is SUCCEED                                 *
+ *                                                                            *
+ * Parameters: result SUCCEED or FAIL                                         *
+ *                                                                            *
+ * Return value:  SUCCEED - processed successfully                            *
+ *                FAIL - an error occured                                     *
+ *                                                                            *
+ * Author: Alexei Vladishev                                                   *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+static int	check_response(char *response)
+{
+	struct 		zbx_json_parse jp;
+	const char 	*p;
+	char		value[MAX_STRING_LEN];
+	char		info[MAX_STRING_LEN];
+
+	int	ret = SUCCEED;
+
+	ret = zbx_json_open(response, &jp);
+
+	if(SUCCEED == ret)
+	{
+		if (NULL == (p = zbx_json_pair_by_name(&jp, ZBX_PROTO_TAG_RESPONSE))
+				|| NULL == zbx_json_decodevalue(p, value, sizeof(value)))
+		{
+			ret = FAIL;
+		}
+	}
+
+	if(SUCCEED == ret)
+	{
+		if(strcmp(value, ZBX_PROTO_VALUE_SUCCESS) != 0)
+		{
+			ret = FAIL;
+		}
+	}
+
+	if (NULL != (p = zbx_json_pair_by_name(&jp, ZBX_PROTO_TAG_INFO))
+			&& NULL != zbx_json_decodevalue(p, info, sizeof(info)))
+	{
+		printf("Info from server: \"%s\"\n",
+			info);
+	}
+
+	return ret;
+}
+
 static ZBX_THREAD_ENTRY(send_value, args)
 {
 	ZBX_THREAD_SENDVAL_ARGS *sentdval_args;
 
-	char	*tosend = NULL;
-
 	zbx_sock_t	sock;
 
 	char	*answer = NULL;
@@ -156,36 +211,22 @@ static ZBX_THREAD_ENTRY(send_value, args)
 
 	sentdval_args = ((ZBX_THREAD_SENDVAL_ARGS *)args);
 
-	zabbix_log( LOG_LEVEL_DEBUG, "Send to: '%s:%i' As: '%s' Key: '%s' Value: '%s'", 
-		sentdval_args->server,
-		sentdval_args->port,
-		sentdval_args->hostname,
-		sentdval_args->key,
-		sentdval_args->key_value
-		);
-
 #if !defined(_WINDOWS)
 	signal( SIGINT,  send_signal_handler );
 	signal( SIGTERM, send_signal_handler );
 	signal( SIGQUIT, send_signal_handler );
 	signal( SIGALRM, send_signal_handler );
 #endif /* NOT _WINDOWS */
-	
-	if (SUCCEED == (tcp_ret = zbx_tcp_connect(&sock, sentdval_args->server, sentdval_args->port, SENDER_TIMEOUT))) {
-		tosend = comms_create_request(sentdval_args->hostname, sentdval_args->key, sentdval_args->key_value,
-			NULL, NULL, NULL, NULL);
 
-		zabbix_log( LOG_LEVEL_DEBUG, "Send data: '%s'", tosend);
-
-		tcp_ret = zbx_tcp_send(&sock, tosend);
-
-		zbx_free(tosend);
+	if (SUCCEED == (tcp_ret = zbx_tcp_connect(&sock, CONFIG_SOURCE_IP, sentdval_args->server, sentdval_args->port, SENDER_TIMEOUT))) {
+		tcp_ret = zbx_tcp_send(&sock, sentdval_args->json.buffer);
 
 		if( SUCCEED == tcp_ret )
 		{
 			if( SUCCEED == (tcp_ret = zbx_tcp_recv(&sock, &answer)) )
 			{
-				if( !answer || strcmp(answer,"OK") )
+				zabbix_log( LOG_LEVEL_DEBUG, "Answer [%s]", answer);
+				if( !answer || check_response(answer) != SUCCEED )
 				{
 					zabbix_log( LOG_LEVEL_WARNING, "Incorrect answer from server [%s]", answer);
 				}
@@ -209,6 +250,7 @@ static ZBX_THREAD_ENTRY(send_value, args)
 
 static void    init_config(const char* config_file)
 {
+	char*	config_source_ip_from_conf = NULL;
 	char*	zabbix_server_from_conf = NULL;
 	int	zabbix_server_port_from_conf = 0;
 	char*	zabbix_hostname_from_conf = NULL;
@@ -217,6 +259,7 @@ static void    init_config(const char* config_file)
 	struct cfg_line cfg[]=
 	{
 		/* PARAMETER	,VAR				,FUNC	,TYPE(0i,1s)	,MANDATORY	,MIN			,MAX		*/
+		{"SourceIP"	,&config_source_ip_from_conf	,0	,TYPE_STRING	,PARM_OPT	,0			,0		},
 		{"Server"	,&zabbix_server_from_conf	,0	,TYPE_STRING	,PARM_OPT	,0			,0		},
 		{"ServerPort"	,&zabbix_server_port_from_conf	,0	,TYPE_INT	,PARM_OPT	,MIN_ZABBIX_PORT	,MAX_ZABBIX_PORT},
 		{"Hostname"	,&zabbix_hostname_from_conf	,0	,TYPE_STRING	,PARM_OPT	,0			,0		},
@@ -227,6 +270,15 @@ static void    init_config(const char* config_file)
 	{
 		parse_cfg_file(config_file, cfg);
 
+		if (NULL != config_source_ip_from_conf)
+		{
+			if (NULL == CONFIG_SOURCE_IP)	/* apply parameter only if unsetted */
+			{
+				CONFIG_SOURCE_IP = strdup(config_source_ip_from_conf);
+			}
+			zbx_free(config_source_ip_from_conf);
+		}
+
 		if( zabbix_server_from_conf )
 		{
 			if( !ZABBIX_SERVER )
@@ -275,6 +327,9 @@ static zbx_task_t parse_commandline(int argc, char **argv)
 				version();
 				exit(-1);
 				break;
+			case 'I': 
+				CONFIG_SOURCE_IP = strdup(zbx_optarg);
+				break;
 			case 'z': 
 				ZABBIX_SERVER = strdup(zbx_optarg);
 				break;
@@ -305,6 +360,12 @@ static zbx_task_t parse_commandline(int argc, char **argv)
 				break;
 		}
 
+	if (NULL == ZABBIX_SERVER && NULL == CONFIG_FILE)
+	{
+		usage();
+		exit(FAIL);
+	}
+
 	return task;
 }
 
@@ -313,8 +374,10 @@ int main(int argc, char **argv)
 	FILE	*in;
 
 	char	in_line[MAX_STRING_LEN],
-		*str_port,
-		*s;
+		*s,
+		*hostname,
+		*key,
+		*key_value;
 
 	int	task = ZBX_TASK_START,
 		total_count = 0,
@@ -331,57 +394,59 @@ int main(int argc, char **argv)
 
 	zabbix_open_log(LOG_TYPE_UNDEFINED, CONFIG_LOG_LEVEL, NULL);
 
+	if (NULL == ZABBIX_SERVER)
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "'Server' parameter required");
+		goto exit;
+	}
+	if (0 == ZABBIX_SERVER_PORT)
+		ZABBIX_SERVER_PORT = 10051;
+
+	if (MIN_ZABBIX_PORT > ZABBIX_SERVER_PORT)
+	{
+		zabbix_log(LOG_LEVEL_WARNING, "Incorrect port number [%d]. Allowed [%d:%d]",
+				(int)ZABBIX_SERVER_PORT, (int)MIN_ZABBIX_PORT, (int)MAX_ZABBIX_PORT);
+		goto exit;
+	}
+
+	sentdval_args.server	= ZABBIX_SERVER;
+	sentdval_args.port	= ZABBIX_SERVER_PORT;
+
+	zbx_json_init(&sentdval_args.json, ZBX_JSON_STAT_BUF_LEN);
+	zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_REQUEST, ZBX_PROTO_VALUE_SENDER_DATA, ZBX_JSON_TYPE_STRING);
+	zbx_json_addarray(&sentdval_args.json, ZBX_PROTO_TAG_DATA);
+
 	if( INPUT_FILE )
 	{
-		if( !(in = fopen(INPUT_FILE, "r")) )
+		if (NULL == (in = fopen(INPUT_FILE, "r")) )
 		{
-			zabbix_log( LOG_LEVEL_WARNING, "Cannot open [%s] [%s]", INPUT_FILE, strerror(errno));
+			zabbix_log(LOG_LEVEL_WARNING, "Cannot open [%s] [%s]", INPUT_FILE, strerror(errno));
 			return FAIL;
-		}	
+		}
 
-		while(fgets(in_line, sizeof(in_line), in) != NULL)
-		{ /* <zabbix_server> <hostname> <port> <key> <value> */
+		while (NULL != fgets(in_line, sizeof(in_line), in))	/* <hostname> <key> <value> */
+		{
 			total_count++; /* also used as inputline */
-	
-			sentdval_args.server = in_line;
 
-			if( !(sentdval_args.hostname = strchr(sentdval_args.server, ' ')) )
+			hostname = in_line;
+
+			if (NULL == (key = strchr(hostname, ' ')))
 			{
-				zabbix_log( LOG_LEVEL_WARNING, "[line %i] 'Server' required", total_count);
+				zabbix_log(LOG_LEVEL_WARNING, "[line %d] 'Key' required", total_count);
 				continue;
 			}
 
-			*sentdval_args.hostname = '\0';
-			sentdval_args.hostname++;
+			*key++ = '\0';
 
-			if( !(str_port = strchr(sentdval_args.hostname, ' ')) )
+			if (NULL == (key_value = strchr(key, ' ')))
 			{
-				zabbix_log( LOG_LEVEL_WARNING, "[line %i] 'Server port' required", total_count);
+				zabbix_log(LOG_LEVEL_WARNING, "[line %d] 'Key value' required", total_count);
 				continue;
 			}
 
-			*str_port = '\0';
-			str_port++;
+			*key_value++ = '\0';
 
-			if( !(sentdval_args.key = strchr(str_port, ' ')) )
-			{
-				zabbix_log( LOG_LEVEL_WARNING, "[line %i] 'Key' required", total_count);
-				continue;
-			}
-
-			*sentdval_args.key = '\0';
-			sentdval_args.key++;
-
-			if( !(sentdval_args.key_value = strchr(sentdval_args.key, ' ')) )
-			{
-				zabbix_log( LOG_LEVEL_WARNING, "[line %i] 'Key value' required", total_count);
-				continue;
-			}
-
-			*sentdval_args.key_value = '\0';
-			sentdval_args.key_value++;
-
-			for(s = sentdval_args.key_value; s && *s; s++)
+			for (s = key_value; s && *s; s++)
 			{
 				if(*s == '\r' || *s == '\n' )
 				{
@@ -390,32 +455,13 @@ int main(int argc, char **argv)
 				}
 			}
 
-			if( ZABBIX_SERVER )		sentdval_args.server	= ZABBIX_SERVER;
-			if( ZABBIX_HOSTNAME )		sentdval_args.hostname	= ZABBIX_HOSTNAME;
-			if( ZABBIX_KEY )		sentdval_args.key	= ZABBIX_KEY;
-			if( ZABBIX_KEY_VALUE )		sentdval_args.key_value	= ZABBIX_KEY_VALUE;
-
-			if( ZABBIX_SERVER_PORT )
-				sentdval_args.port	= ZABBIX_SERVER_PORT;
-			else
-				sentdval_args.port	= (unsigned short)atoi(str_port);
-
-			if( MIN_ZABBIX_PORT > sentdval_args.port /* || sentdval_args.port > MAX_ZABBIX_PORT (MAX_ZABBIX_PORT == max unsigned short) */)
-			{
-				zabbix_log( LOG_LEVEL_WARNING, "[line %i] Incorrect port number [%i]. Allowed [%i:%i]",
-					total_count, sentdval_args.port, MIN_ZABBIX_PORT, MAX_ZABBIX_PORT);
-				continue;
-			}
-			
-			if( SUCCEED == zbx_thread_wait(
-				zbx_thread_start(
-					send_value,
-					&sentdval_args
-					)
-				)
-			)
-				succeed_count++;
+			zbx_json_addobject(&sentdval_args.json, NULL);
+			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_HOST, hostname, ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_KEY, key, ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_VALUE, key_value, ZBX_JSON_TYPE_STRING);
+			zbx_json_close(&sentdval_args.json);
 
+			succeed_count++;
 		}
 
 		fclose(in);
@@ -426,40 +472,51 @@ int main(int argc, char **argv)
 
 		do /* try block simulation */
 		{
-			if( !ZABBIX_SERVER ) {		zabbix_log( LOG_LEVEL_WARNING, "'Server' parameter required"); break; }
-			if( !ZABBIX_HOSTNAME ) {	zabbix_log( LOG_LEVEL_WARNING, "'Hostname' parameter required"); break; }
-			if( !ZABBIX_KEY ) {		zabbix_log( LOG_LEVEL_WARNING, "Key required"); break; }
-			if( !ZABBIX_KEY_VALUE ) {	zabbix_log( LOG_LEVEL_WARNING, "Key value required"); break; }
-
-			if( !ZABBIX_SERVER_PORT )	ZABBIX_SERVER_PORT = 10051;
-
-			if( MIN_ZABBIX_PORT > ZABBIX_SERVER_PORT /* || ZABBIX_SERVER_PORT > MAX_ZABBIX_PORT (MAX_ZABBIX_PORT == max unsigned short) */)
+			if (NULL == ZABBIX_HOSTNAME)
 			{
-				zabbix_log( LOG_LEVEL_WARNING, "Incorrect port number [%i]. Allowed [%i:%i]",
-					ZABBIX_SERVER_PORT, MIN_ZABBIX_PORT, MAX_ZABBIX_PORT);
+				zabbix_log(LOG_LEVEL_WARNING, "'Hostname' parameter required");
+				break;
+			}
+			if (NULL == ZABBIX_KEY)
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "Key required");
+				break;
+			}
+			if (NULL == ZABBIX_KEY_VALUE)
+			{
+				zabbix_log(LOG_LEVEL_WARNING, "Key value required");
 				break;
 			}
 
-			sentdval_args.server	= ZABBIX_SERVER;
-			sentdval_args.port	= ZABBIX_SERVER_PORT;
-			sentdval_args.hostname	= ZABBIX_HOSTNAME;
-			sentdval_args.key	= ZABBIX_KEY;
-			sentdval_args.key_value	= ZABBIX_KEY_VALUE;
+			hostname	= ZABBIX_HOSTNAME;
+			key		= ZABBIX_KEY;
+			key_value	= ZABBIX_KEY_VALUE;
 
-			if( SUCCEED == zbx_thread_wait(
-				zbx_thread_start(
-					send_value,
-					&sentdval_args
-					)
-				)
-			)
-				succeed_count++;
+			zbx_json_addobject(&sentdval_args.json, NULL);
+			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_HOST, hostname, ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_KEY, key, ZBX_JSON_TYPE_STRING);
+			zbx_json_addstring(&sentdval_args.json, ZBX_PROTO_TAG_VALUE, key_value, ZBX_JSON_TYPE_STRING);
+			zbx_json_close(&sentdval_args.json);
+
+			succeed_count++;
 		}
 		while(0); /* try block simulation */
 	}
 
-	printf("sent: %i; failed: %i; total: %i\n", succeed_count, (total_count - succeed_count), total_count);
+	if (succeed_count > 0)
+	{
+		if (SUCCEED == zbx_thread_wait(zbx_thread_start(send_value, &sentdval_args)))
+		{
+			printf("sent: %d; skipped: %d; total: %d\n", succeed_count, (total_count - succeed_count), total_count);
+		}
+		else
+		{
+			printf("Sending failed. Use option -vv for more detailed output.\n");
+		}
+	}
 
+	zbx_json_free(&sentdval_args.json);
+exit:
 	zabbix_close_log();
 
 	return ret;
