@@ -21,27 +21,24 @@
 
 #include "cfg.h"
 #include "db.h"
-#include "../functions.h"
 #include "log.h"
 #include "zlog.h"
-#include "threads.h"
+#include "sysinfo.h"
+#include "zbxserver.h"
+#include "zbxicmpping.h"
 
 #include "pinger.h"
+#include "dbcache.h"
 
-int pinger_num;
+static zbx_process_t	zbx_process;
+static int		pinger_num;
 
-#define ZBX_FPING_HOST struct zbx_fipng_host
-ZBX_FPING_HOST
-{
-	char		ip[HOST_IP_LEN_MAX];
-	char		dns[HOST_DNS_LEN_MAX];
-	int		alive, useip;
-	double		mseconds;
-};
+static ZBX_FPING_HOST	*hosts = NULL;
+static int		hosts_allocated = 4;
 
 /******************************************************************************
  *                                                                            *
- * Function: process_new_value                                                *
+ * Function: process_value                                                    *
  *                                                                            *
  * Purpose: process new item value                                            *
  *                                                                            *
@@ -57,42 +54,147 @@ ZBX_FPING_HOST
  * Comments: can be done in process_data()                                    *
  *                                                                            *
  ******************************************************************************/
-static int process_value(char *key, ZBX_FPING_HOST *host, AGENT_RESULT *value)
+static void process_value(char *key, ZBX_FPING_HOST *host, zbx_uint64_t *value_ui64, double *value_dbl, int now, int *items, int ping_result, const char *error)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
 	DB_ITEM		item;
+	AGENT_RESULT	value;
+	char		istatus[16];
+
+	assert(value_ui64 || value_dbl);
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In process_value(%s@%s)",
 			key,
-			host->useip ? host->ip : host->dns);
+			host->addr);
+
+	if (0 != CONFIG_REFRESH_UNSUPPORTED)
+		zbx_snprintf(istatus, sizeof(istatus), "%d,%d",
+				ITEM_STATUS_ACTIVE,
+				ITEM_STATUS_NOTSUPPORTED);
+	else
+		zbx_snprintf(istatus, sizeof(istatus), "%d",
+				ITEM_STATUS_ACTIVE);
 
 	result = DBselect("select %s where " ZBX_SQL_MOD(h.hostid,%d) "=%d and h.status=%d and h.hostid=i.hostid"
-			" and h.useip=%d and h.%s='%s' and i.key_='%s' and i.status=%d"
-			" and i.type=%d and" ZBX_COND_NODEID,
+			" and h.proxy_hostid=0 and h.useip=%d and h.%s='%s' and i.key_='%s' and i.status in (%s)"
+			" and i.type=%d and i.nextcheck<=%d" DB_NODE,
 			ZBX_SQL_ITEM_SELECT,
 			CONFIG_PINGER_FORKS,
 			pinger_num - 1,
 			HOST_STATUS_MONITORED,
 			host->useip,
 			host->useip ? "ip" : "dns",
-			host->useip ? host->ip : host->dns,
+			host->addr,
 			key,
-			ITEM_STATUS_ACTIVE,
+			istatus,
 			ITEM_TYPE_SIMPLE,
-			LOCAL_NODE("h.hostid"));
+			now,
+			DBnode_local("h.hostid"));
 
 	while (NULL != (row = DBfetch(result))) {
 		DBget_item_from_db(&item, row);
 
-		DBbegin();
-		process_new_value(&item, value);
-		update_triggers(item.itemid);
-		DBcommit();
+		if (ping_result == NOTSUPPORTED)
+		{
+			if (0 == CONFIG_DBSYNCER_FORKS)
+			{
+				DBbegin();
+		
+				DBupdate_item_status_to_notsupported(&item, now, error);
+
+				DBcommit();
+			}
+			else
+				DCadd_nextcheck(&item, now, 0, error);
+		}
+		else
+		{
+			init_result(&value);
+
+			if (NULL != value_ui64)
+			{
+				SET_UI64_RESULT(&value, *value_ui64);
+			}
+			else
+			{
+				SET_DBL_RESULT(&value, *value_dbl);
+			}
+
+			if (0 == CONFIG_DBSYNCER_FORKS)
+				DBbegin();
+
+			switch (zbx_process) {
+			case ZBX_PROCESS_SERVER:
+				process_new_value(&item, &value, now);
+				break;
+			case ZBX_PROCESS_PROXY:
+				proxy_process_new_value(&item, &value, now);
+				break;
+			}
+
+			if (0 == CONFIG_DBSYNCER_FORKS)
+				DBcommit();
+
+			if (0 != CONFIG_DBSYNCER_FORKS)
+				DCadd_nextcheck(&item, now, 0, NULL);
+
+			free_result(&value);
+		}
+
+		(*items)++;
 	}
 	DBfree_result(result);
+}
 
-	return SUCCEED;
+/******************************************************************************
+ *                                                                            *
+ * Function: process_values                                                   *
+ *                                                                            *
+ * Purpose: process new item value                                            *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value: successfully processed items                                 *
+ *                                                                            *
+ * Author: Alexei Vladishev                                                   *
+ *                                                                            *
+ * Comments: can be done in process_data()                                    *
+ *                                                                            *
+ ******************************************************************************/
+static int process_values(ZBX_FPING_HOST *hosts, int hosts_count, int now)
+{
+	int		i, items = 0, ping_result;
+	char		error[ITEM_ERROR_LEN_MAX];
+
+	zabbix_log(LOG_LEVEL_DEBUG, "In process_values()");
+
+	zbx_setproctitle("pinger [pinging hosts]");
+
+	ping_result = do_ping(hosts, hosts_count, error, sizeof(error));
+
+	if (0 != CONFIG_DBSYNCER_FORKS)
+		DCinit_nextchecks();
+
+	for (i = 0; i < hosts_count; i++) {
+		if (ping_result == NOTSUPPORTED)
+			zabbix_log(LOG_LEVEL_DEBUG, "Host [%s] %s",
+					hosts[i].addr,
+					error);
+		else
+			zabbix_log(LOG_LEVEL_DEBUG, "Host [%s] alive [" ZBX_FS_UI64 "] " ZBX_FS_DBL " sec.",
+					hosts[i].addr,
+					hosts[i].alive,
+					hosts[i].sec);
+
+		process_value(SERVER_ICMPPING_KEY, &hosts[i], &hosts[i].alive, NULL, now, &items, ping_result, error);
+		process_value(SERVER_ICMPPINGSEC_KEY, &hosts[i], NULL, &hosts[i].sec, now, &items, ping_result, error);
+	}
+
+	if (0 != CONFIG_DBSYNCER_FORKS)
+		DCflush_nextchecks();
+
+	return items;
 }
 
 /******************************************************************************
@@ -111,202 +213,148 @@ static int process_value(char *key, ZBX_FPING_HOST *host, AGENT_RESULT *value)
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int get_pinger_hosts(ZBX_FPING_HOST **hosts, int *hosts_allocated, int *hosts_count)
+static int	get_pinger_hosts(int now)
 {
 	DB_RESULT	result;
 	DB_ROW		row;
-	ZBX_FPING_HOST	*host;
+	int		hosts_count = 0;
+	char		istatus[16];
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In get_pinger_hosts()");
 
+	if (0 != CONFIG_REFRESH_UNSUPPORTED)
+		zbx_snprintf(istatus, sizeof(istatus), "%d,%d",
+				ITEM_STATUS_ACTIVE,
+				ITEM_STATUS_NOTSUPPORTED);
+	else
+		zbx_snprintf(istatus, sizeof(istatus), "%d",
+				ITEM_STATUS_ACTIVE);
+
 	/* Select hosts monitored by IP */
 	result = DBselect("select distinct h.ip from hosts h,items i where " ZBX_SQL_MOD(h.hostid,%d) "=%d"
-			" and i.hostid=h.hostid and h.status=%d and (i.key_='%s' or i.key_='%s')"
-			" and i.type=%d and i.status=%d and h.useip=1 and" ZBX_COND_NODEID,
+			" and i.hostid=h.hostid and h.proxy_hostid=0 and h.status=%d and i.key_ in ('%s','%s')"
+			" and i.type=%d and i.status in (%s) and h.useip=1 and i.nextcheck<=%d" DB_NODE, 
 			CONFIG_PINGER_FORKS,
 			pinger_num - 1,
 			HOST_STATUS_MONITORED,
-			SERVER_ICMPPING_KEY,
-			SERVER_ICMPPINGSEC_KEY,
+			SERVER_ICMPPING_KEY, SERVER_ICMPPINGSEC_KEY,
 			ITEM_TYPE_SIMPLE,
-			ITEM_STATUS_ACTIVE,
-			LOCAL_NODE("h.hostid"));
+			istatus,
+			now,
+			DBnode_local("h.hostid"));
 
 	while (NULL != (row = DBfetch(result))) {
-		if (*hosts_count == *hosts_allocated) {
-			*hosts_allocated *= 2;
-			*hosts = zbx_realloc(*hosts, *hosts_allocated * sizeof(ZBX_FPING_HOST));
+		if (hosts_count == hosts_allocated) {
+			hosts_allocated *= 2;
+			hosts = zbx_realloc(hosts, hosts_allocated * sizeof(ZBX_FPING_HOST));
 		}
 
-		host = &(*hosts)[*hosts_count];
+		memset(&hosts[hosts_count], '\0', sizeof(ZBX_FPING_HOST));
+		strscpy(hosts[hosts_count].addr, row[0]);
+		hosts[hosts_count].useip = 1;
 
-		memset(host, '\0', sizeof(ZBX_FPING_HOST));
-		strscpy(host->ip, row[0]);
-		host->useip = 1;
+		zabbix_log(LOG_LEVEL_DEBUG, "IP [%s]", hosts[hosts_count].addr);
 
-		(*hosts_count)++;
-
-		zabbix_log(LOG_LEVEL_DEBUG, "IP [%s]", host->ip);
+		hosts_count++;
 	}
 	DBfree_result(result);
 
 	/* Select hosts monitored by hostname */
 	result = DBselect("select distinct h.dns from hosts h,items i where " ZBX_SQL_MOD(h.hostid,%d) "=%d"
-			" and i.hostid=h.hostid and h.status=%d and (i.key_='%s' or i.key_='%s')"
-			" and i.type=%d and i.status=%d and h.useip=0 and" ZBX_COND_NODEID,
+			" and i.hostid=h.hostid and h.proxy_hostid=0 and h.status=%d and i.key_ in ('%s','%s')"
+			" and i.type=%d and i.status in (%s) and h.useip=0 and i.nextcheck<=%d" DB_NODE,
 			CONFIG_PINGER_FORKS,
 			pinger_num - 1,
 			HOST_STATUS_MONITORED,
-			SERVER_ICMPPING_KEY,
-			SERVER_ICMPPINGSEC_KEY,
+			SERVER_ICMPPING_KEY, SERVER_ICMPPINGSEC_KEY,
 			ITEM_TYPE_SIMPLE,
-			ITEM_STATUS_ACTIVE,
-			LOCAL_NODE("h.hostid"));
+			istatus,
+			now,
+			DBnode_local("h.hostid"));
 
 	while (NULL != (row = DBfetch(result))) {
-		if (*hosts_count == *hosts_allocated) {
-			*hosts_allocated *= 2;
-			*hosts = zbx_realloc(*hosts, *hosts_allocated * sizeof(ZBX_FPING_HOST));
+		if (hosts_count == hosts_allocated) {
+			hosts_allocated *= 2;
+			hosts = zbx_realloc(hosts, hosts_allocated * sizeof(ZBX_FPING_HOST));
 		}
 
-		host = &(*hosts)[*hosts_count];
+		memset(&hosts[hosts_count], '\0', sizeof(ZBX_FPING_HOST));
+		strscpy(hosts[hosts_count].addr, row[0]);
+		hosts[hosts_count].useip = 0;
 
-		memset(host, '\0', sizeof(ZBX_FPING_HOST));
-		strscpy(host->dns, row[0]);
-		host->useip = 0;
+		zabbix_log(LOG_LEVEL_DEBUG, "DNS name [%s]", hosts[hosts_count].addr);
 
-		(*hosts_count)++;
-
-		zabbix_log(LOG_LEVEL_DEBUG, "DNS name [%s]", host->dns);
+		hosts_count++;
 	}
 	DBfree_result(result);
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of get_pinger_hosts()");
+	zabbix_log(LOG_LEVEL_DEBUG, "End of get_pinger_hosts():%d", hosts_count);
 
-	return SUCCEED;
+	return hosts_count;
 }
 
-
 /******************************************************************************
  *                                                                            *
- * Function: do_ping                                                          *
+ * Function: get_minnextcheck                                                 *
  *                                                                            *
- * Purpose: ping hosts listed in the host files                               *
+ * Purpose: calculate when we have to process earliest simple check           *
  *                                                                            *
- * Parameters:                                                                *
+ * Parameters: now - current timestamp                                        *
  *                                                                            *
- * Return value: SUCCEED - successfully processed                             *
- *               FAIL - otherwise                                             *
+ * Return value: timestamp of earliest check or -1 if not found               *
  *                                                                            *
- * Author: Alexei Vladishev                                                   *
+ * Author: Aleksander Vladishev                                               *
  *                                                                            *
- * Comments: use external binary 'fping' to avoid superuser priviledges       *
+ * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int do_ping(ZBX_FPING_HOST *hosts, int hosts_count)
+static int get_minnextcheck()
 {
-	FILE		*f;
-	char		filename[MAX_STRING_LEN];
-	char		tmp[MAX_STRING_LEN];
-	int		i;
-	char		*c;
-	ZBX_FPING_HOST	*host;
-	AGENT_RESULT	value;
+	DB_RESULT	result;
+	DB_ROW		row;
+	int		res;
+	char		istatus[16];
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In do_ping() [hosts_count:%d]",
-			hosts_count);
+	zabbix_log(LOG_LEVEL_DEBUG, "In get_minnextcheck()");
 
-	zbx_snprintf(filename, sizeof(filename), "/tmp/zabbix_server_%li.pinger",
-			zbx_get_thread_id());
+	if (0 != CONFIG_REFRESH_UNSUPPORTED)
+		zbx_snprintf(istatus, sizeof(istatus), "%d,%d",
+				ITEM_STATUS_ACTIVE,
+				ITEM_STATUS_NOTSUPPORTED);
+	else
+		zbx_snprintf(istatus, sizeof(istatus), "%d",
+				ITEM_STATUS_ACTIVE);
 
-	if (NULL == (f = fopen(filename, "w"))) {
-		zabbix_log(LOG_LEVEL_ERR, "Cannot open file [%s] [%s]",
-				filename,
-				strerror(errno));
-		zabbix_syslog("Cannot open file [%s] [%s]",
-				filename,
-				strerror(errno));
-		return FAIL;
+	result = DBselect("select count(*),min(i.nextcheck) from items i,hosts h where " ZBX_SQL_MOD(h.hostid,%d) "=%d"
+			" and h.status=%d and h.hostid=i.hostid and h.proxy_hostid=0 and i.key_ in ('%s','%s')"
+			" and i.type=%d and i.status in (%s)" DB_NODE, 
+			CONFIG_PINGER_FORKS,
+			pinger_num - 1,
+			HOST_STATUS_MONITORED,
+			SERVER_ICMPPING_KEY, SERVER_ICMPPINGSEC_KEY,
+			ITEM_TYPE_SIMPLE,
+			istatus,
+			DBnode_local("h.hostid"));
+
+	if (NULL == (row = DBfetch(result)) || DBis_null(row[0]) == SUCCEED || DBis_null(row[1]) == SUCCEED)
+	{
+		zabbix_log(LOG_LEVEL_DEBUG, "No items to update for minnextcheck.");
+		res = FAIL; 
 	}
-
-	for (i = 0; i < hosts_count; i++)
-		fprintf(f, "%s\n", hosts[i].useip ? hosts[i].ip : hosts[i].dns);
-
-	fclose(f);
-
-#ifdef HAVE_IPV6
-	zbx_snprintf(tmp, sizeof(tmp), "%s -e 2>/dev/null <%s;%s -e 2>/dev/null <%s",
-			CONFIG_FPING_LOCATION,
-			filename,
-			CONFIG_FPING6_LOCATION,
-			filename);
-#else /* HAVE_IPV6 */
-	zbx_snprintf(tmp, sizeof(tmp), "%s -e 2>/dev/null <%s",
-			CONFIG_FPING_LOCATION,
-			filename);
-#endif /* HAVE_IPV6 */
-
-	if (0 == (f = popen(tmp, "r"))) {
-		zabbix_log(LOG_LEVEL_ERR, "Cannot execute [%s] [%s]",
-				CONFIG_FPING_LOCATION,
-				strerror(errno));
-		zabbix_syslog("Cannot execute [%s] [%s]",
-				CONFIG_FPING_LOCATION,
-				strerror(errno));
-		return FAIL;
-	}
-
-	while (NULL != fgets(tmp, sizeof(tmp), f)) {
-		zabbix_log(LOG_LEVEL_DEBUG, "Update IP [%s]",
-				tmp);
-
-		host = NULL;
-
-		c = strchr(tmp, ' ');
-		if (c != NULL) {
-			*c = '\0';
-			for (i = 0; i < hosts_count; i++)
-				if (0 == strcmp(tmp, hosts[i].useip ? hosts[i].ip : hosts[i].dns)) {
-					host = &hosts[i];
-					break;
-				}
+	else
+	{
+		if (atoi(row[0]) == 0)
+		{
+			res = FAIL;
 		}
-
-		if (NULL != host) {
-			c++;
-			
-			if (strstr(c, "alive") != NULL) {
-				host->alive = 1;
-				sscanf(c, "is alive (%lf ms)",
-						&host->mseconds);
-				zabbix_log(LOG_LEVEL_DEBUG, "Mseconds [%lf]",
-						host->mseconds);
-			}
+		else
+		{
+			res = atoi(row[1]);
 		}
 	}
-	pclose(f);
+	DBfree_result(result);
 
-	unlink(filename);
-
-	for (i = 0; i < hosts_count; i++) {
-		zabbix_log(LOG_LEVEL_DEBUG, "Host [%s] alive [%d]",
-				hosts[i].useip ? hosts[i].ip : hosts[i].dns,
-				hosts[i].alive);
-
-		init_result(&value);
-		SET_UI64_RESULT(&value, hosts[i].alive);
-		process_value(SERVER_ICMPPING_KEY, &hosts[i], &value);
-		free_result(&value);
-				
-		init_result(&value);
-		SET_DBL_RESULT(&value, hosts[i].mseconds/1000);
-		process_value(SERVER_ICMPPINGSEC_KEY, &hosts[i], &value);
-		free_result(&value);
-	}
-
-	zabbix_log(LOG_LEVEL_DEBUG, "End of do_ping()");
-
-	return SUCCEED;
+	return res;
 }
 
 /******************************************************************************
@@ -324,45 +372,62 @@ static int do_ping(ZBX_FPING_HOST *hosts, int hosts_count)
  * Comments: never returns                                                    *
  *                                                                            *
  ******************************************************************************/
-void main_pinger_loop(int num)
+void main_pinger_loop(zbx_process_t p, int num)
 {
-	int		start, sleeptime;
-	ZBX_FPING_HOST	*hosts = NULL;
-	int		hosts_allocated = 16, hosts_count;
+	int		now, nextcheck, sleeptime;
+	int		hosts_count, items;
+	double		sec;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In main_pinger_loop(num:%d)",
 			num);
 
+	zbx_process = p;
 	pinger_num = num;
 
 	hosts = zbx_malloc(hosts, hosts_allocated * sizeof(ZBX_FPING_HOST));
 
-	for (;;) {
-		start = time(NULL);
+	zbx_setproctitle("pinger [connecting to the database]");
 
-		zbx_setproctitle("connecting to the database");
+	DBconnect(ZBX_DB_CONNECT_NORMAL);
 
-		DBconnect(ZBX_DB_CONNECT_NORMAL);
+	for (;;)
+	{
+		now = time(NULL);
+		sec = zbx_time();
+
+		items = 0;
+		if (0 < (hosts_count = get_pinger_hosts(now)))
+			items = process_values(hosts, hosts_count, now); 
 	
-		hosts_count = 0;
-		if (SUCCEED == get_pinger_hosts(&hosts, &hosts_allocated, &hosts_count)) {
-			zbx_setproctitle("pinging hosts");
+		sec = zbx_time() - sec;
 
-			do_ping(hosts, hosts_count);
+		nextcheck = get_minnextcheck();
+
+		if (FAIL == nextcheck)
+			sleeptime = CONFIG_PINGER_FREQUENCY;
+		else
+		{
+			sleeptime = nextcheck - time(NULL);
+			if (sleeptime < 0)
+				sleeptime = 0;
+			else if (sleeptime > CONFIG_PINGER_FREQUENCY)
+				sleeptime = CONFIG_PINGER_FREQUENCY;
 		}
-	
-		DBclose();
 
-		sleeptime = CONFIG_PINGER_FREQUENCY - (time(NULL) - start);
+		zabbix_log(LOG_LEVEL_DEBUG, "Pinger spent " ZBX_FS_DBL " seconds while processing %d items."
+				" Nextcheck after %d sec.",
+				sec,
+				items,
+				sleeptime);
 
 		if (sleeptime > 0) {
-			zbx_setproctitle("pinger [sleeping for %d seconds]",
-					sleeptime);
-			zabbix_log(LOG_LEVEL_DEBUG, "Sleeping for %d seconds",
+			zbx_setproctitle("pinger [sleeping for %d seconds]", 
 					sleeptime);
+
 			sleep(sleeptime);
 		}
 	}
 
 	/* Never reached */
+	DBclose();
 }
