@@ -45,13 +45,8 @@
 int	get_value_agent(DB_ITEM *item, AGENT_RESULT *result)
 {
 	zbx_sock_t	s;
-
-	char	*addr,
-		*buf,
-		packet[MAX_STRING_LEN],
-		error[MAX_STRING_LEN];
-
-	int	ret = SUCCEED;
+	char		*addr, *buf, buffer[MAX_STRING_LEN];
+	int		ret = SUCCEED;
 
 	init_result(result);
 
@@ -61,72 +56,52 @@ int	get_value_agent(DB_ITEM *item, AGENT_RESULT *result)
 			addr,
 			item->key);
 
-	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, addr, item->port, 0))) {
-		zbx_snprintf(packet, sizeof(packet), "%s\n",item->key);
-		zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]", packet);
+	if (SUCCEED == (ret = zbx_tcp_connect(&s, CONFIG_SOURCE_IP, addr, item->port, 0)))
+	{
+		zbx_snprintf(buffer, sizeof(buffer), "%s\n", item->key);
+		zabbix_log(LOG_LEVEL_DEBUG, "Sending [%s]", buffer);
 
 		/* Send requests using old protocol */
-		if( SUCCEED == (ret = zbx_tcp_send_raw(&s, packet)) )
-		{
+		if (SUCCEED == (ret = zbx_tcp_send_raw(&s, buffer)))
 			ret = zbx_tcp_recv_ext(&s, &buf, ZBX_TCP_READ_UNTIL_CLOSE);
-		}
 	}
 
-	if( SUCCEED == ret )
+	if (SUCCEED == ret)
 	{
-		zbx_rtrim(buf, " \r\n\0");
+		zbx_rtrim(buf, " \r\n");
 		zbx_ltrim(buf, " ");
 
-		if( strcmp(buf,"ZBX_NOTSUPPORTED") == 0)
+		zabbix_log(LOG_LEVEL_DEBUG, "Get value from agent result: '%s'", buf);
+
+		if (0 == strcmp(buf, "ZBX_NOTSUPPORTED"))
 		{
-			zbx_snprintf(error,sizeof(error),"Not supported by ZABBIX agent");
-			SET_MSG_RESULT(result, strdup(error));
+			zbx_snprintf(buffer, sizeof(buffer), "Not supported by ZABBIX agent");
+			SET_MSG_RESULT(result, strdup(buffer));
 			ret = NOTSUPPORTED;
 		}
-		else if( strcmp(buf,"ZBX_ERROR") == 0)
+		else if (0 == strcmp(buf, "ZBX_ERROR"))
 		{
-			zbx_snprintf(error,sizeof(error),"ZABBIX agent non-critical error");
-			SET_MSG_RESULT(result, strdup(error));
+			zbx_snprintf(buffer, sizeof(buffer), "ZABBIX agent non-critical error");
+			SET_MSG_RESULT(result, strdup(buffer));
 			ret = AGENT_ERROR;
 		}
-		/* The section should be improved */
-		else if(buf[0]==0)
+		else if ('\0' == *buf)	/* The section should be improved */
 		{
-			zbx_snprintf(error,sizeof(error),"Got empty string from [%s] IP [%s] Parameter [%s]",
-				item->host_name,
-				item->host_ip,
-				item->key);
-			zabbix_log( LOG_LEVEL_WARNING, "%s",
-				error);
-			zabbix_log( LOG_LEVEL_WARNING, "Assuming that agent dropped connection because of access permissions");
-			SET_MSG_RESULT(result, strdup(error));
+			zbx_snprintf(buffer, sizeof(buffer), "Got empty string from [%s]. Assuming that agent dropped connection because of access permissions",
+					item->useip ? item->host_ip : item->host_dns);
+			SET_MSG_RESULT(result, strdup(buffer));
 			ret = NETWORK_ERROR;
 		}
-		else if(set_result_type(result, item->value_type, buf) == FAIL)
-		{
-			zbx_snprintf(error,sizeof(error), "Type of received value [%s] is not sutable for [%s@%s] having type [%d]",
-				buf,
-				item->key,
-				item->host_name,
-				item->value_type);
-			zabbix_log( LOG_LEVEL_WARNING, "%s",
-				error);
-			zabbix_log( LOG_LEVEL_WARNING, "Returning NOTSUPPORTED");
-			result->msg=strdup(error);
+		else if (SUCCEED != set_result_type(result, item->value_type, buf))
 			ret = NOTSUPPORTED;
-		}
-
-		zabbix_log( LOG_LEVEL_DEBUG, "End get_value_agent(result:%s)",
-			buf);
-
 	}
 	else
 	{
-		zabbix_log(LOG_LEVEL_WARNING, "Get value from agent failed. Error: %s", zbx_tcp_strerror());
-		SET_MSG_RESULT(result, strdup(zbx_tcp_strerror()));
+		zbx_snprintf(buffer, sizeof(buffer), "Get value from agent failed: %s",
+				zbx_tcp_strerror());
+		SET_MSG_RESULT(result, strdup(buffer));
 		ret = NETWORK_ERROR;
-
-	}	
+	}
 	zbx_tcp_close(&s);
 
 	return ret;
