@@ -18,6 +18,8 @@
 **/
 
 #include "common.h"
+#include "log.h"
+
 #include "checks_external.h"
 
 /******************************************************************************
@@ -43,7 +45,6 @@ int     get_value_external(DB_ITEM *item, AGENT_RESULT *result)
 	char    scriptname[MAX_STRING_LEN];
 	char    key[MAX_STRING_LEN];
 	char    params[MAX_STRING_LEN];
-	char    error[MAX_STRING_LEN];
 	char    cmd[MAX_STRING_LEN];
 	char    msg[MAX_STRING_LEN];
 	char    *p,*p2;
@@ -78,11 +79,10 @@ int     get_value_external(DB_ITEM *item, AGENT_RESULT *result)
 		}
 		else    ret = NOTSUPPORTED;
 	}
-	else
+
+	if (ret == NOTSUPPORTED)
 	{
-		zbx_snprintf(error,MAX_STRING_LEN-1,"External check [%s] is not supported", item->key);
-		zabbix_log( LOG_LEVEL_DEBUG, "%s", error);
-		SET_STR_RESULT(result, strdup(error));
+		SET_MSG_RESULT(result, strdup("External check is not supported"));
 		return NOTSUPPORTED;
 	}
 
@@ -95,9 +95,7 @@ int     get_value_external(DB_ITEM *item, AGENT_RESULT *result)
 	zabbix_log( LOG_LEVEL_DEBUG, "%s", cmd );
 	if (NULL == (fp = popen(cmd, "r"))) 
 	{
-		zbx_snprintf(error,MAX_STRING_LEN-1,"External check [%s] is not supported, failed execution", item->key);
-		zabbix_log( LOG_LEVEL_DEBUG, "%s", error);
-		SET_STR_RESULT(result, strdup(error));
+		SET_MSG_RESULT(result, strdup("External check is not supported, failed execution"));
 		return NOTSUPPORTED;
 	}
 
@@ -115,15 +113,14 @@ int     get_value_external(DB_ITEM *item, AGENT_RESULT *result)
 		}
 		zabbix_log( LOG_LEVEL_DEBUG, "Result [%s]", msg);
 
-		set_result_type(result,item->value_type,strdup(msg));
+		if (SUCCEED != set_result_type(result, item->value_type, msg))
+			ret = NOTSUPPORTED;
 	}
 	else
 	{
-		zbx_snprintf(error,MAX_STRING_LEN-1,"Script %s/%s returned nothing.",
-			CONFIG_EXTERNALSCRIPTS,
-			scriptname);
-		zabbix_log( LOG_LEVEL_WARNING, "%s", error);
-		SET_STR_RESULT(result, strdup(error));
+		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Script %s/%s returned nothing.",
+				CONFIG_EXTERNALSCRIPTS,
+				scriptname));
 		ret = NOTSUPPORTED;
 	}
 
