@@ -50,8 +50,6 @@
 #include "utils/nodechange.h"
 #include "escalator/escalator.h"
 
-#define       LISTENQ 1024
-
 #ifdef ZABBIX_TEST
 #include <time.h>
 #endif
@@ -124,7 +122,7 @@ int	CONFIG_HOUSEKEEPER_FORKS	= 1;
 int	CONFIG_NODEWATCHER_FORKS	= 1;
 int	CONFIG_PINGER_FORKS		= 1;
 int	CONFIG_POLLER_FORKS		= 5;
-int	CONFIG_HTTPPOLLER_FORKS		= 5;
+int	CONFIG_HTTPPOLLER_FORKS		= 1;
 int	CONFIG_IPMIPOLLER_FORKS		= 0;
 int	CONFIG_TIMER_FORKS		= 1;
 int	CONFIG_TRAPPERD_FORKS		= 5;
@@ -1080,8 +1078,7 @@ int MAIN_ZABBIX_ENTRY(void)
 		exit(FAIL);
 	}
 
-	if (CONFIG_DBSYNCER_FORKS != 0)
-		init_database_cache(ZBX_PROCESS_SERVER);
+	init_database_cache(ZBX_PROCESS_SERVER);
 
 /*#define CALC_TREND*/
 
@@ -1289,6 +1286,7 @@ void	zbx_on_exit()
 				threads[i] = (ZBX_THREAD_HANDLE)0;
 			}
 		}
+		zbx_free(threads);
 	}
 	
 #endif /* not _WINDOWS */
@@ -1304,11 +1302,7 @@ void	zbx_on_exit()
 	zbx_sleep(2); /* wait for all threads closing */
 
 	DBconnect(ZBX_DB_CONNECT_EXIT);
-	
-	if(CONFIG_DBSYNCER_FORKS!=0)
-	{
-		free_database_cache();
-	}
+	free_database_cache();
 	DBclose();
 
 	zbx_mutex_destroy(&node_sync_access);
