@@ -61,7 +61,6 @@ void main_timer_loop()
 
 		DBconnect(ZBX_DB_CONNECT_NORMAL);
 
-		now=time(NULL);
 /*
 #ifdef HAVE_POSTGRESQL
 		zbx_snprintf(sql,sizeof(sql),"select distinct f.itemid,f.functionid,f.parameter from functions f, items i,hosts h where h.hostid=i.hostid and h.status=%d and i.itemid=f.itemid and f.function in ('nodata','date','dayofweek','time','now') and i.lastclock+f.parameter::text::integer<=%d and i.status=%d", HOST_STATUS_MONITORED, now, ITEM_STATUS_ACTIVE);
@@ -81,8 +80,10 @@ void main_timer_loop()
 		while (NULL != (row = DBfetch(result))) {
 			DBget_item_from_db(&item,row);
 
+			now = (int)time(NULL);
+
 			DBbegin();
-			update_functions(&item);
+			update_functions(&item, now);
 			update_triggers(item.itemid);
 			DBcommit();
 		}
