@@ -28,6 +28,9 @@
 #include "../events.h"
 #include "../nodewatcher/nodecomms.h"
 
+static char	*buffer = NULL, *tmp = NULL;
+static int	buffer_allocated, tmp_allocated;
+
 /******************************************************************************
  *                                                                            *
  * Function: send_history_last_id                                             *
@@ -50,161 +53,71 @@ int	send_history_last_id(zbx_sock_t *sock, const char *data)
 	DB_RESULT	result;
 	DB_ROW		row;
 	const char	*r;
-	char		*tmp = NULL, tablename[MAX_STRING_LEN], fieldname[MAX_STRING_LEN];
-	int		tmp_allocated = 256, tmp_offset;
+	char		tablename[MAX_STRING_LEN], fieldname[MAX_STRING_LEN];
+	int		buffer_offset;
 	int		sender_nodeid, nodeid, res;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In send_list_of_history_ids()");
 
-	tmp = zbx_malloc(tmp, tmp_allocated);
+	buffer_allocated = 256;
+	buffer = zbx_malloc(buffer, buffer_allocated);
 
 	r = data;
 	if (NULL == r)
 		goto error;
 
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* constant 'ZBX_GET_HISTORY_LAST_ID' */
+	zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER); /* constant 'ZBX_GET_HISTORY_LAST_ID' */
 	if (NULL == r)
 		goto error;
 
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* sender_nodeid */
-	sender_nodeid=atoi(tmp);
+	zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER); /* sender_nodeid */
+	sender_nodeid=atoi(buffer);
 	if (NULL == r)
 		goto error;
 
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, '\n'); /* nodeid */
-	nodeid=atoi(tmp);
+	zbx_get_next_field(&r, &buffer, &buffer_allocated, '\n'); /* nodeid */
+	nodeid=atoi(buffer);
 	if (NULL == r)
 		goto error;
 
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* table name */
-	zbx_strlcpy(tablename, tmp, sizeof(tablename));
+	zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER); /* table name */
+	zbx_strlcpy(tablename, buffer, sizeof(tablename));
 
 	if (NULL == r)
 		goto error;
 
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* field name */
-	zbx_strlcpy(fieldname, tmp, sizeof(fieldname));
+	zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER); /* field name */
+	zbx_strlcpy(fieldname, buffer, sizeof(fieldname));
 
-	tmp_offset= 0;
-	zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 256, "select MAX(%s) "
+	buffer_offset= 0;
+	zbx_snprintf_alloc(&buffer, &buffer_allocated, &buffer_offset, 256, "select MAX(%s) "
 		"from %s where 1=1" DB_NODE,
 		fieldname,
 		tablename,
 		DBnode(fieldname, nodeid));
 
-	tmp_offset= 0;
-	result = DBselect("%s", tmp);
+	buffer_offset= 0;
+	result = DBselect("%s", buffer);
 	if (NULL != (row = DBfetch(result)))
-		zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 128, "%s",
+		zbx_snprintf_alloc(&buffer, &buffer_allocated, &buffer_offset, 128, "%s",
 			SUCCEED == DBis_null(row[0]) ? "0" : row[0]);
 	DBfree_result(result);
 
-	if (tmp_offset == 0)
+	if (buffer_offset == 0)
 		goto error;
 
-	res = send_data_to_node(sender_nodeid, sock, tmp);
+	res = send_data_to_node(sender_nodeid, sock, buffer);
 
-	zbx_free(tmp);
+	zbx_free(buffer);
 
 	return  res;
 error:
-	tmp_offset= 0;
-	zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 128, "FAIL");
+	buffer_offset= 0;
+	zbx_snprintf_alloc(&buffer, &buffer_allocated, &buffer_offset, 128, "FAIL");
 
-	res = send_data_to_node(sender_nodeid, sock, tmp);
+	res = send_data_to_node(sender_nodeid, sock, buffer);
 
-	zbx_free(tmp);
-
-	zabbix_log( LOG_LEVEL_ERR, "NODE %d: Received invalid record from node %d for node %d [%s]",
-		CONFIG_NODEID,
-		sender_nodeid,
-		nodeid,
-		data);
-
-	return FAIL;
-}
-
-/******************************************************************************
- *                                                                            *
- * Function: send_trends_last_id                                              *
- *                                                                            *
- * Purpose: send last historical tables ids                                   *
- *                                                                            *
- * Parameters: sock - opened socket of node-node connection                   *
- *             record                                                         *
- *                                                                            *
- * Return value:  SUCCEED - sent succesfully                                  *
- *                FAIL - an error occured                                     *
- *                                                                            *
- * Author: Aleksander Vladishev                                               *
- *                                                                            *
- * Comments:                                                                  *
- *                                                                            *
- ******************************************************************************/
-int	send_trends_last_id(zbx_sock_t *sock, const char *data)
-{
-	DB_RESULT	result;
-	DB_ROW		row;
-	const char	*r;
-	char		*tmp = NULL, tablename[MAX_STRING_LEN];
-	int		tmp_allocated = 256, tmp_offset;
-	int		sender_nodeid, nodeid, res;
-
-	zabbix_log(LOG_LEVEL_DEBUG, "In send_list_of_history_ids()");
-
-	tmp = zbx_malloc(tmp, tmp_allocated);
-
-	r = data;
-	if (NULL == r)
-		goto error;
-
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* constant 'ZBX_GET_HISTORY_LAST_ID' */
-	if (NULL == r)
-		goto error;
-
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* sender_nodeid */
-	sender_nodeid=atoi(tmp);
-	if (NULL == r)
-		goto error;
-
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, '\n'); /* nodeid */
-	nodeid=atoi(tmp);
-	if (NULL == r)
-		goto error;
-
-	zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* table name */
-	zbx_strlcpy(tablename, tmp, sizeof(tablename));
-
-	tmp_offset= 0;
-	zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 256, "select itemid,clock "
-		"from %s where 1=1" DB_NODE " order by itemid desc,clock desc",
-		tablename,
-		DBnode("itemid", nodeid));
-
-	tmp_offset= 0;
-	result = DBselectN(tmp, 1);
-	if (NULL == (row = DBfetch(result)))
-		zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 64, "0%c0",
-			ZBX_DM_DELIMITER);
-	else
-		zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 128, "%s%c%s",
-			SUCCEED == DBis_null(row[0]) ? "0" : row[0],
-			ZBX_DM_DELIMITER,
-			SUCCEED == DBis_null(row[1]) ? "0" : row[1]);
-	DBfree_result(result);
-
-	res = send_data_to_node(sender_nodeid, sock, tmp);
-
-	zbx_free(tmp);
-
-	return  res;
-error:
-	tmp_offset= 0;
-	zbx_snprintf_alloc(&tmp, &tmp_allocated, &tmp_offset, 128, "FAIL");
-
-	res = send_data_to_node(sender_nodeid, sock, tmp);
-
-	zbx_free(tmp);
+	zbx_free(buffer);
 
 	zabbix_log( LOG_LEVEL_ERR, "NODE %d: Received invalid record from node %d for node %d [%s]",
 		CONFIG_NODEID,
@@ -231,13 +144,13 @@ error:
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int	process_record_event(int sender_nodeid, int nodeid, const ZBX_TABLE *table, const char *record, char **tmp, int *tmp_allocated)
+static int	process_record_event(int sender_nodeid, int nodeid, const ZBX_TABLE *table, const char *record)
 {
 	const char	*r;
 	int		f, len;
 	DB_EVENT	event;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In process_record_event ()");
+	zabbix_log(LOG_LEVEL_DEBUG, "In process_record_event()");
 
 	memset(&event, 0, sizeof(event));
 
@@ -246,22 +159,22 @@ static int	process_record_event(int sender_nodeid, int nodeid, const ZBX_TABLE *
 		if (NULL == r)
 			goto error;
 
-		len = zbx_get_next_field(&r, tmp, tmp_allocated, ZBX_DM_DELIMITER);
+		len = zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
 
 		if (0 == strcmp(table->fields[f].name, "eventid")) {
-			ZBX_STR2UINT64(event.eventid, *tmp);
+			ZBX_STR2UINT64(event.eventid, buffer);
 		} else if (0 == strcmp(table->fields[f].name, "source")) {
-			event.source = atoi(*tmp);
+			event.source = atoi(buffer);
 		} else if (0 == strcmp(table->fields[f].name, "object")) {
-			event.object = atoi(*tmp);
+			event.object = atoi(buffer);
 		} else if (0 == strcmp(table->fields[f].name, "objectid")) {
-			ZBX_STR2UINT64(event.objectid, *tmp);
+			ZBX_STR2UINT64(event.objectid, buffer);
 		} else if (0 == strcmp(table->fields[f].name, "clock")) {
-			event.clock=atoi(*tmp);
+			event.clock=atoi(buffer);
 		} else if (0 == strcmp(table->fields[f].name, "value")) {
-			event.value=atoi(*tmp);
+			event.value=atoi(buffer);
 		} else if (0 == strcmp(table->fields[f].name, "acknowledged")) {
-			event.acknowledged=atoi(*tmp);
+			event.acknowledged=atoi(buffer);
 		}
 	}
 
@@ -276,6 +189,28 @@ error:
 	return FAIL;
 }
 
+static void	begin_history_sql(char **sql, int *sql_allocated, int *sql_offset, const ZBX_TABLE *table)
+{
+	int	f;
+
+	zbx_snprintf_alloc(sql, sql_allocated, sql_offset, ZBX_TABLENAME_LEN + 16, "insert into %s (",
+			table->table);
+
+	if (0 != (table->flags & ZBX_HISTORY_SYNC))
+		zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 8, "nodeid,");
+
+	for (f = 0; table->fields[f].name != 0; f++) {
+		if (0 != (table->flags & ZBX_HISTORY_SYNC) && 0 == (table->fields[f].flags & ZBX_HISTORY_SYNC))
+			continue;
+
+		zbx_snprintf_alloc(sql, sql_allocated, sql_offset, ZBX_FIELDNAME_LEN + 2, "%s,",
+				table->fields[f].name);
+	}
+
+	(*sql_offset)--;
+	zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 10, ") values ");
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: process_record                                                   *
@@ -292,77 +227,224 @@ error:
  * Comments:                                                                  *
  *                                                                            *
  ******************************************************************************/
-static int	process_record(int sender_nodeid, int nodeid, const ZBX_TABLE *table, const char *record, char **tmp, int *tmp_allocated, char **sql, int *sql_allocated, int lastrecord)
+static int	process_record(char **sql, int *sql_allocated, int *sql_offset, int sender_nodeid, int nodeid, const ZBX_TABLE *table,
+		const char *record, int lastrecord)
 {
 	const char	*r;
-	int		f, len, sql_offset, lastvalue_type;
+	int		f, len;
 	int		res = FAIL;
-	char		lastvalue[MAX_STRING_LEN], lastclock[MAX_STRING_LEN];
+	char		*value_esc;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In process_record ()");
+	zabbix_log(LOG_LEVEL_DEBUG, "In process_record()");
 
-	r = record;
+	if (*sql_offset == 0)
+	{
+#ifdef HAVE_ORACLE
+		zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 8, "begin\n");
+#endif
 
-	sql_offset = 0;
-	zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, 128, "insert into %s (",
-		table->table);
-
-	if (0 != (table->flags & ZBX_HISTORY_SYNC))
-		zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, 128, "nodeid,");
-
-	for (f = 0; table->fields[f].name != 0; f++) {
-		if (0 != (table->flags & ZBX_HISTORY_SYNC) && 0 == (table->fields[f].flags & ZBX_HISTORY_SYNC))
-			continue;
-
-		zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, 128, "%s,",
-			table->fields[f].name);
+#ifdef HAVE_MYSQL
+		begin_history_sql(sql, sql_allocated, sql_offset, table);
+#endif
 	}
 
-	sql_offset--;
-	zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, 64, ") values (");
+#ifndef HAVE_MYSQL
+	begin_history_sql(sql, sql_allocated, sql_offset, table);
+#endif
 
+	zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 2, "(");
 	if (0 != (table->flags & ZBX_HISTORY_SYNC))
-		zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, 128, "%d,",
-			nodeid);
-		
-	for (f = 0; table->fields[f].name != 0; f++) {
-		if ((table->flags & ZBX_HISTORY_SYNC) && 0 == (table->fields[f].flags & ZBX_HISTORY_SYNC))
+		zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 16, "%d,",
+				nodeid);
+
+	for (r = record, f = 0; table->fields[f].name != 0; f++) {
+		if (0 != (table->flags & ZBX_HISTORY_SYNC) && 0 == (table->fields[f].flags & ZBX_HISTORY_SYNC))
 			continue;
 
 		if (NULL == r)
 			goto error;
 
-		len = zbx_get_next_field(&r, tmp, tmp_allocated, ZBX_DM_DELIMITER);
+		len = zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
 
 		if (table->fields[f].type == ZBX_TYPE_INT ||
-			table->fields[f].type == ZBX_TYPE_UINT ||
-			table->fields[f].type == ZBX_TYPE_ID ||
-			table->fields[f].type == ZBX_TYPE_FLOAT)
+				table->fields[f].type == ZBX_TYPE_UINT ||
+				table->fields[f].type == ZBX_TYPE_ID ||
+				table->fields[f].type == ZBX_TYPE_FLOAT)
 		{
-			zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, len + 8, "%s,",
-				*tmp);
-		} else { /* ZBX_TYPE_CHAR ZBX_TYPE_BLOB ZBX_TYPE_TEXT */
-			if (0 == len)
-				zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, 8, "'',");
-			else
-				zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, len + 8, "0x%s,",
-					*tmp);
+			zbx_snprintf_alloc(sql, sql_allocated, sql_offset, len + 2, "%s,",
+					buffer);
 		}
+		else if (table->fields[f].type == ZBX_TYPE_BLOB)
+		{
+#ifdef HAVE_POSTGRESQL
+			len = zbx_hex2binary(buffer);
+			len = zbx_pg_escape_bytea((u_char *)buffer, len, &tmp, &tmp_allocated);
 
-		if (lastrecord && 0 != (table->flags & ZBX_HISTORY_SYNC)) {
-			if (0 == strcmp(table->fields[f].name, "clock")) {
-				zbx_strlcpy(lastclock, *tmp, sizeof(lastclock));
-			} else if (0 == strcmp(table->fields[f].name, "value")) {
-				zbx_strlcpy(lastvalue, *tmp, sizeof(lastvalue));
-				lastvalue_type = table->fields[f].type;
+			zbx_snprintf_alloc(sql, sql_allocated, sql_offset, len + 4, "'%s',");
+#else
+			if ('\0' == *buffer)
+				zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 4, "'',");
+			else
+				zbx_snprintf_alloc(sql, sql_allocated, sql_offset, len + 4, "0x%s,",
+						buffer);
+#endif
+		}
+		else	/* ZBX_TYPE_TEXT, ZBX_TYPE_CHAR */
+		{
+			zbx_hex2binary(buffer);
+			value_esc = DBdyn_escape_string(buffer);
+			len = strlen(value_esc);
+
+			zbx_snprintf_alloc(sql, sql_allocated, sql_offset, len + 4, "'%s',",
+					value_esc);
+
+			zbx_free(value_esc);
+		}
+	}
+
+	(*sql_offset)--;
+
+#ifdef HAVE_MYSQL
+	zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 3, "),");
+#else
+	zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 4, ");\n");
+#endif
+
+	if (lastrecord || *sql_offset > ZBX_MAX_SQL_SIZE)
+	{
+#ifdef HAVE_ORACLE
+		zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 8, "end;\n");
+#endif
+
+#ifdef HAVE_MYSQL
+		(*sql_offset)--;
+		zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 4, ";\n");
+#endif
+		if (DBexecute("%s", *sql) >= ZBX_DB_OK)
+			res = SUCCEED;
+		(*sql_offset) = 0;
+	}
+	else
+		res = SUCCEED;
+
+	return res;
+error:
+	zabbix_log( LOG_LEVEL_ERR, "NODE %d: Received invalid record from node %d for node %d [%s]",
+		CONFIG_NODEID,
+		sender_nodeid,
+		nodeid,
+		record);
+
+	return FAIL;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Function: update_items                                                     *
+ *                                                                            *
+ * Purpose: process record update                                             *
+ *                                                                            *
+ * Parameters:                                                                *
+ *                                                                            *
+ * Return value:  SUCCEED - processed successfully                            *
+ *                FAIL - an error occured                                     *
+ *                                                                            *
+ * Author:                                                                    *
+ *                                                                            *
+ * Comments:                                                                  *
+ *                                                                            *
+ ******************************************************************************/
+static int	process_items(char **sql, int *sql_allocated, int *sql_offset, int sender_nodeid, int nodeid, const ZBX_TABLE *table,
+		const char *record, int lastrecord)
+{
+	const char	*r;
+	int		f, len, res = FAIL;
+	zbx_uint64_t	itemid = 0;
+	char		*value_esc;
+	int		clock, value_type = -1;
+	double		value_double;
+	zbx_uint64_t	value_uint64;
+
+	zabbix_log(LOG_LEVEL_DEBUG, "In process_items()");
+
+	if (*sql_offset == 0)
+	{
+#ifdef HAVE_ORACLE
+		zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 8, "begin\n");
+#endif
+	}
+
+	zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 40, "update items set prevvalue=lastvalue");
+
+	for (r = record, f = 0; table->fields[f].name != 0; f++) {
+		if (0 != (table->flags & ZBX_HISTORY_SYNC) && 0 == (table->fields[f].flags & ZBX_HISTORY_SYNC))
+			continue;
+
+		if (NULL == r)
+			goto error;
+
+		len = zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER);
+
+		if (0 == strcmp(table->fields[f].name, "itemid"))
+			ZBX_STR2UINT64(itemid, buffer)
+
+		if (table->fields[f].type == ZBX_TYPE_INT ||
+				table->fields[f].type == ZBX_TYPE_UINT ||
+				table->fields[f].type == ZBX_TYPE_ID ||
+				table->fields[f].type == ZBX_TYPE_FLOAT)
+		{
+			if (0 == strcmp(table->fields[f].name, "clock"))
+			{
+				zbx_snprintf_alloc(sql, sql_allocated, sql_offset, len + 16, ",lastclock=%s",
+						buffer);
+				clock = atoi(buffer);
+			}
+			else if (0 == strcmp(table->fields[f].name, "value"))
+			{
+				zbx_snprintf_alloc(sql, sql_allocated, sql_offset, len + 16, ",lastvalue=%s",
+						buffer);
+
+				value_type = table->fields[f].type;
+				if (value_type == ZBX_TYPE_FLOAT)
+					value_double = atof(buffer);
+				else if (value_type == ZBX_TYPE_UINT)
+					ZBX_STR2UINT64(value_uint64, buffer)
+			}
+		}
+		else	/* ZBX_TYPE_TEXT, ZBX_TYPE_CHAR */
+		{
+			if (0 == strcmp(table->fields[f].name, "value"))
+			{
+				zbx_hex2binary(buffer);
+				value_esc = DBdyn_escape_string_len(buffer, ITEM_LASTVALUE_LEN);
+				len = strlen(value_esc);
+
+				zbx_snprintf_alloc(sql, sql_allocated, sql_offset, len + 16, ",lastvalue='%s'",
+						value_esc);
+
+				zbx_free(value_esc);
 			}
 		}
 	}
 
-	sql_offset--;
-	zbx_snprintf_alloc(sql, sql_allocated, &sql_offset, 8, ")");
+	if (value_type == ZBX_TYPE_FLOAT)
+		DBadd_trend(itemid, value_double, clock);
+	else if (value_type == ZBX_TYPE_UINT)
+		DBadd_trend_uint(itemid, value_double, clock);
 
-	if (DBexecute("%s", *sql) >= ZBX_DB_OK)
+	zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 40, " where itemid=" ZBX_FS_UI64 ";\n",
+			itemid);
+
+	if (lastrecord || *sql_offset > ZBX_MAX_SQL_SIZE)
+	{
+#ifdef HAVE_ORACLE
+		zbx_snprintf_alloc(sql, sql_allocated, sql_offset, 8, "end;\n");
+#endif
+		if (DBexecute("%s", *sql) >= ZBX_DB_OK)
+			res = SUCCEED;
+		(*sql_offset) = 0;
+	}
+	else
 		res = SUCCEED;
 
 	return res;
@@ -395,19 +477,32 @@ error:
 int	node_history(char *data, size_t datalen)
 {
 	const char	*r;
-	char		*newline = NULL, *tmp = NULL, *sql = NULL;
+	char		*newline = NULL;
 	char		*pos;
-	int		tmp_allocated = 4096, sql_allocated = 8192;
-	int		sender_nodeid = 0, nodeid = 0, firstline = 1, events = 0;
+	int		sender_nodeid = 0, nodeid = 0, firstline = 1, events = 0, history = 0;
 	const ZBX_TABLE	*table_sync = NULL, *table = NULL;
 	int		res = SUCCEED;
 
+	char		*sql1 = NULL, *sql2 = NULL, *sql3 = NULL;
+	int		sql1_allocated, sql2_allocated, sql3_allocated;
+	int		sql1_offset, sql2_offset, sql3_offset;
+
 	assert(data);
 
+/*	zabbix_set_log_level(LOG_LEVEL_DEBUG);*/
 	zabbix_log(LOG_LEVEL_DEBUG, "In node_history()");
 
+	buffer_allocated = 4096;
+	sql1_allocated = 32768;
+	sql2_allocated = 32768;
+	sql3_allocated = 32768;
+	tmp_allocated = 4096;
+
+	buffer = zbx_malloc(buffer, buffer_allocated);
+	sql1 = zbx_malloc(sql1, sql1_allocated);
+	sql2 = zbx_malloc(sql2, sql2_allocated);
+	sql3 = zbx_malloc(sql3, sql3_allocated);
 	tmp = zbx_malloc(tmp, tmp_allocated);
-	sql = zbx_malloc(sql, sql_allocated);
 
 	DBbegin();
 
@@ -416,49 +511,57 @@ int	node_history(char *data, size_t datalen)
 			*newline = '\0';
 
 		if (1 == firstline) {
-			zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* constant 'History' */
-			zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* sender_nodeid */
-			sender_nodeid=atoi(tmp);
-			zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* nodeid */
-			nodeid=atoi(tmp);
-			zbx_get_next_field(&r, &tmp, &tmp_allocated, ZBX_DM_DELIMITER); /* tablename */
+			zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER); /* constant 'History' */
+			zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER); /* sender_nodeid */
+			sender_nodeid=atoi(buffer);
+			zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER); /* nodeid */
+			nodeid=atoi(buffer);
+			zbx_get_next_field(&r, &buffer, &buffer_allocated, ZBX_DM_DELIMITER); /* tablename */
 
-			table = DBget_table(tmp);
-			if (0 == (table->flags & (ZBX_HISTORY | ZBX_HISTORY_SYNC | ZBX_HISTORY_TRENDS)))
+			table = DBget_table(buffer);
+			if (0 == (table->flags & (ZBX_HISTORY | ZBX_HISTORY_SYNC)))
 				table = NULL;
 
 			if (NULL != table && 0 != (table->flags & ZBX_HISTORY_SYNC)) {
 				table_sync = table;
-				if (NULL != (pos = strstr(tmp, "_sync"))) {
+				if (NULL != (pos = strstr(buffer, "_sync"))) {
 					*pos = '\0';
-					table = DBget_table(tmp);
+					table = DBget_table(buffer);
 				}
 			}
 
 			if (NULL != table && 0 == strcmp(table->table, "events"))
 				events = 1;
 
+			if (NULL != table && 0 == strncmp(table->table, "history", 7))
+				history = 1;
+
 			if (NULL == table) {
-				zabbix_log(LOG_LEVEL_WARNING, "NODE %d: Invalid received data: unknown tablename \"%s\"",
+				zabbix_log(LOG_LEVEL_ERR, "NODE %d: Invalid received data: unknown tablename \"%s\"",
 					CONFIG_NODEID,
-					tmp);
+					buffer);
 			}
 			if (NULL != newline) {
-				zabbix_log(LOG_LEVEL_WARNING, "NODE %d: Received %s from node %d for node %d datalen %zd",
+				zabbix_log(LOG_LEVEL_WARNING, "NODE %d: Received %s from node %d for node %d datalen %d",
 					CONFIG_NODEID,
-					tmp,
+					buffer,
 					sender_nodeid,
 					nodeid,
-					datalen);
+					(int)datalen);
 			}
 			firstline = 0;
+			sql1_offset = 0;
+			sql2_offset = 0;
+			sql3_offset = 0;
 		} else if (NULL != table) {
 			if (events) {
-				res = process_record_event(sender_nodeid, nodeid, table, r, &tmp, &tmp_allocated);
+				res = process_record_event(sender_nodeid, nodeid, table, r);
 			} else {
-				res = process_record(sender_nodeid, nodeid, table, r, &tmp, &tmp_allocated, &sql, &sql_allocated, NULL == newline);
+				res = process_record(&sql1, &sql1_allocated, &sql1_offset, sender_nodeid, nodeid, table, r, newline ? 0 : 1);
+				if (SUCCEED == res && 0 != history)
+					res = process_items(&sql2, &sql2_allocated, &sql2_offset, sender_nodeid, nodeid, table, r, newline ? 0 : 1);
 				if (SUCCEED == res && NULL != table_sync && 0 != CONFIG_MASTER_NODEID)
-					res = process_record(sender_nodeid, nodeid, table_sync, r, &tmp, &tmp_allocated, &sql, &sql_allocated, 0);
+					res = process_record(&sql3, &sql3_allocated, &sql3_offset, sender_nodeid, nodeid, table_sync, r, newline ? 0 : 1);
 			}
 		}
 
@@ -473,8 +576,12 @@ int	node_history(char *data, size_t datalen)
 	else
 		DBrollback();
 
-	zbx_free(sql);
 	zbx_free(tmp);
+	zbx_free(sql1);
+	zbx_free(sql2);
+	zbx_free(sql3);
+	zbx_free(buffer);
 
+/*	zabbix_set_log_level(LOG_LEVEL_WARNING);*/
 	return res;
 }
