@@ -21,6 +21,6 @@
 #ifndef ZABBIX_NODESYNC_H
 #define ZABBIX_NODESYNC_H
 
-int	node_sync(char *data);
+int	node_sync(char *data, int *sender_nodeid, int *nodeid);
 
 #endif
