@@ -30,8 +30,9 @@
 #include <time.h>
 
 #include "common.h"
-#include "functions.h"
 #include "log.h"
+#include "zbxserver.h"
+
 #include "zlog.h"
 
 /******************************************************************************
@@ -56,20 +57,25 @@ void __zbx_zabbix_syslog(const char *fmt, ...)
 
 	DB_ITEM		item;
 	DB_RESULT	result;
-	DB_ROW	row;
-
+	DB_ROW		row;
 	AGENT_RESULT	agent;
+	time_t		now;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In zabbix_log()");
 
 	/* This is made to disable writing to database for watchdog */
 	if(CONFIG_ENABLE_LOG == 0)	return;
 
-	result = DBselect("select %s where h.hostid=i.hostid and i.key_='%s' and i.value_type=%d and" ZBX_COND_NODEID,
-		ZBX_SQL_ITEM_SELECT,
-		SERVER_ZABBIXLOG_KEY,
-		ITEM_VALUE_TYPE_STR,
-		LOCAL_NODE("h.hostid"));
+	result = DBselect("select %s where h.hostid=i.hostid and h.status=%d and i.status=%d"
+			" and h.proxy_hostid=0 and i.key_='%s' and i.value_type=%d" DB_NODE,
+			ZBX_SQL_ITEM_SELECT,
+			ITEM_STATUS_ACTIVE,
+			HOST_STATUS_MONITORED,
+			SERVER_ZABBIXLOG_KEY,
+			ITEM_VALUE_TYPE_STR,
+			DBnode_local("h.hostid"));
+
+	now = time(NULL);
 
 	while((row=DBfetch(result)))
 	{
@@ -82,10 +88,10 @@ void __zbx_zabbix_syslog(const char *fmt, ...)
 
 		init_result(&agent);
 		SET_STR_RESULT(&agent, strdup(value_str));
-		process_new_value(&item,&agent);
-		free_result(&agent);
 
-		update_triggers(item.itemid);
+		process_new_value(&item, &agent, now);
+
+		free_result(&agent);
 	}
 
 	DBfree_result(result);
