@@ -11,11 +11,14 @@ alter table alerts drop index alerts_4;
 alter table alerts drop index alerts_5;
 alter table alerts drop index alerts_6;
 
-alter table alerts drop triggerid;
 alter table alerts add eventid bigint(20) unsigned NOT NULL default '0' after actionid;
 alter table alerts add esc_step integer DEFAULT '0'     NOT NULL;
 alter table alerts add alerttype integer DEFAULT '0'     NOT NULL;
 
+update alerts, events set alerts.eventid = events.eventid where events.objectid = alerts.triggerid and events.object = 0 and alerts.eventid = 0 and events.clock = alerts.clock;
+update alerts, events set alerts.eventid = events.eventid where events.objectid = alerts.triggerid and events.object = 0 and alerts.eventid = 0 and events.clock = alerts.clock + 1;
+alter table alerts drop triggerid;
+
 CREATE INDEX alerts_1 on alerts (actionid);
 CREATE INDEX alerts_2 on alerts (clock);
 CREATE INDEX alerts_3 on alerts (eventid);
@@ -59,6 +62,7 @@ CREATE INDEX events_2 on events (clock);
 alter table graphs_items change color color varchar(32) DEFAULT '009600' NOT NULL;
 
 CREATE INDEX graphs_items_1 on graphs_items (itemid);
+CREATE INDEX graphs_items_2 on graphs_items (graphid);
 alter table graphs add show_legend int(11) NOT NULL default '0';
 alter table graphs add show_3d int(11) NOT NULL default '0';
 alter table graphs add percent_left            double(16,4)            DEFAULT '0'     NOT NULL;
