@@ -23,7 +23,12 @@ CREATE TABLE alerts_tmp (
         PRIMARY KEY (alertid)
 ) with OIDS;
 
-insert into alerts_tmp (alertid,actionid,userid,clock,mediatypeid,sendto,subject,message,status,retries,error,nextcheck) select alertid,actionid,userid,clock,mediatypeid,sendto,subject,message,status,retries,error,nextcheck from alerts;
+alter table alerts add eventid bigint DEFAULT '0' NOT NULL;
+
+update alerts set eventid = e.eventid from events e where e.objectid = alerts.triggerid and e.object = 0 and alerts.eventid = 0 and e.clock = alerts.clock;
+update alerts set eventid = e.eventid from events e where e.objectid = alerts.triggerid and e.object = 0 and alerts.eventid = 0 and e.clock = alerts.clock + 1;
+
+insert into alerts_tmp (alertid,actionid,eventid,userid,clock,mediatypeid,sendto,subject,message,status,retries,error,nextcheck) select alertid,actionid,eventid,userid,clock,mediatypeid,sendto,subject,message,status,retries,error,nextcheck from alerts;
 update alerts_tmp set status=3 where retries>=2;
 
 drop table alerts;
@@ -93,6 +98,7 @@ drop index events_2;
 CREATE INDEX events_1 on events (object,objectid,eventid);
 CREATE INDEX events_2 on events (clock);
 CREATE INDEX graphs_items_1 on graphs_items (itemid);
+CREATE INDEX graphs_items_2 on graphs_items (graphid);
 alter table graphs add show_legend integer NOT NULL default '0';
 alter table graphs add show_3d integer NOT NULL default '0';
 alter table graphs add percent_left            numeric(16,4)            DEFAULT '0'     NOT NULL;
